const locale = {
    "Allow scroll wheel zoom?": "¿Permitir acercar con la rueda central del ratón?",
    "Automatic": "Automático",
    "Ball": "Bola",
    "Cancel": "Cancelar",
    "Caption": "Subtítulo",
    "Choose the data format": "Elegir el formato de datos",
    "Choose the layer of the feature": "Elegir la capa del elemento",
    "Circle": "Círculo",
    "Clustered": "Agrupados",
    "Data browser": "Navegador de datos",
    "Default": "Predeterminado",
    "Default zoom level": "Nivel de acercamiento predeterminado",
    "Default: name": "Predeterminado: nombre",
    "Display label": "Mostrar etiqueta",
    "Display the control to open OpenStreetMap editor": "Mostrar el control para abrir el editor OpenStreetMap",
    "Display the data layers control": "Mostrrar el control de la capa de datos",
    "Display the embed control": "Mostrar el control de embebido",
    "Display the fullscreen control": "Mostrar el control de pantalla completa",
    "Display the locate control": "Mostrar el control de ubicación",
    "Display the measure control": "Mostrar el control de medida",
    "Display the search control": "Mostrar el control de búsqueda",
    "Display the tile layers control": "Mostrar el control de capas de teselas",
    "Display the zoom control": "Mostrar el control de acercamiento",
    "Do you want to display a caption bar?": "¿Quiere mostrar la barra de subtítulos?",
    "Do you want to display a minimap?": "¿Quiere mostrar un minimapa?",
    "Do you want to display a panel on load?": "¿Quiere mostrar un panel al cargar?",
    "Do you want to display popup footer?": "¿Quiere mostrar la ventana emergente en el pie de página?",
    "Do you want to display the scale control?": "¿Quiere mostrar el control de escala?",
    "Do you want to display the «more» control?": "¿Quiere mostrar el control «más»?",
    "Drop": "Gota",
    "GeoRSS (only link)": "GeoRSS (sólo enlace)",
    "GeoRSS (title + image)": "GeoRSS (título + imagen)",
    "Heatmap": "Mapa de calor",
    "Icon shape": "Forma de icono",
    "Icon symbol": "Símbolo del icono",
    "Inherit": "Heredar",
    "Label direction": "Dirección de la etiqueta",
    "Label key": "Etiqueta de la clave",
    "Labels are clickable": "Las etiquetas se pueden hacer clic",
    "None": "Ninguno",
    "On the bottom": "En la parte inferior",
    "On the left": "A la izquierda",
    "On the right": "A la derecha",
    "On the top": "En la parte superior",
    "Popup content template": "Plantilla de contenido emergente",
    "Side panel": "Panel lateral",
    "Simplify": "Simplificar",
    "Table": "Tabla",
    "always": "siempre",
    "clear": "limpiar",
    "collapsed": "contraído",
    "color": "color",
    "dash array": "serie de guiones",
    "define": "definir",
    "description": "descripción",
    "expanded": "expandido",
    "fill": "rellenar",
    "fill color": "color de relleno",
    "fill opacity": "opacidad del relleno",
    "hidden": "escondido",
    "iframe": "iframe",
    "inherit": "heredar",
    "name": "nombre",
    "never": "nunca",
    "new window": "nueva ventana",
    "no": "no",
    "on hover": "al pasar el ratón",
    "opacity": "opacidad",
    "parent window": "ventana principal",
    "stroke": "trazo",
    "weight": "peso",
    "yes": "si",
    "{delay} seconds": "{delay} segundos",
    "# one hash for main heading": "# una almohadilla para el encabezado principal",
    "## two hashes for second heading": "## dos almohadillas para el encabezado secundario",
    "### three hashes for third heading": "### tres almohadillas para el encabezado ternario",
    "**double star for bold**": "**dos asteriscos para negrita**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista de números separados por comas que define el patrón de trazos. Por ejemplo: \"5, 10, 15\".",
    "About": "Acerca de",
    "Action not allowed :(": "Acción no permitida :(",
    "Activate slideshow mode": "Activar el modo presentación de diapositivas",
    "Add a layer": "Añadir una capa",
    "Add a line to the current multi": "Añadir una línea para el multi elemento actual",
    "Add a new property": "Añadir una nueva propiedad",
    "Add a polygon to the current multi": "Añadir un polígono al multi elemento actual",
    "Advanced actions": "Acciones avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "All properties are imported.": "Todas las propiedades están importadas.",
    "Allow interactions": "Permitir interacciones",
    "An error occured": "Ocurrió un error",
    "Are you sure you want to cancel your changes?": "¿Está seguro que quiere cancelar sus cambios?",
    "Are you sure you want to clone this map and all its datalayers?": "¿Está seguro que quiere clonar este mapa y todas sus capas de datos?",
    "Are you sure you want to delete the feature?": "¿Está seguro que quiere borrar el elemento?",
    "Are you sure you want to delete this layer?": "¿Está seguro que quiere borrar esta capa?",
    "Are you sure you want to delete this map?": "¿Está seguro que quiere borrar este mapa?",
    "Are you sure you want to delete this property on all the features?": "¿Esta seguro que quiere borrar esta propiedad en todos los elementos?",
    "Are you sure you want to restore this version?": "¿Está seguro que quiere restaurar esta versión?",
    "Attach the map to my account": "Adjuntar el mapa a mi cuenta",
    "Auto": "Automático",
    "Autostart when map is loaded": "Autocomenzar cuando el mapa esté cargado",
    "Bring feature to center": "Traer el elemento al centro",
    "Browse data": "Navegar los datos",
    "Cancel edits": "Cancelar las ediciones",
    "Center map on your location": "Centrar el mapa en su ubicación",
    "Change map background": "Cambiar el fondo del mapa",
    "Change tilelayers": "Cambiar la capa de teselas",
    "Choose a preset": "Elegir un preestablecido",
    "Choose the format of the data to import": "Elegir el formato de los datos a importar",
    "Choose the layer to import in": "Elegir la capa a la que se importa",
    "Click last point to finish shape": "Haga clic en el último punto para terminar la figura",
    "Click to add a marker": "Haga clic para añadir un marcador",
    "Click to continue drawing": "Haga clic para continuar dibujando",
    "Click to edit": "Clic para editar",
    "Click to start drawing a line": "Haga clic para empezar a dibujar una línea",
    "Click to start drawing a polygon": "Haga clic para empezar a dibujar un polígono",
    "Clone": "Clonar",
    "Clone of {name}": "Clón de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Close": "Cerrar",
    "Clustering radius": "Radio de agrupamiento",
    "Comma separated list of properties to use when filtering features": "Lista separada por comas de las propiedades a utilizar al filtrar los elementos",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por coma, tabulador o punto y coma. SRS WGS84 está implícito. Solo se importan las geometrías de los puntos. La importación buscará en los encabezados de las columnas cualquier mención de «lat» y «lon» al principio del encabezado, sin distinción de mayúsculas y minúsculas. Todas las demás columnas se importan como propiedades.",
    "Continue line": "Línea continua",
    "Continue line (Ctrl+Click)": "Línea continuada (Ctrl+Clic)",
    "Coordinates": "Coordenadas",
    "Credits": "Créditos",
    "Current view instead of default map view?": "¿Vista actual en lugar de la vista del mapa predeterminada?",
    "Custom background": "Fondo personalizado",
    "Data is browsable": "Los datos son navegables",
    "Default interaction options": "Opciones de interacción predeterminados",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de la figura predeterminada",
    "Define link to open in a new window on polygon click.": "Defina un enlace para abrir en un nueva ventana al hacer clic en el polígono.",
    "Delay between two transitions when in play mode": "Retraso entre dos transiciones cuando se está en el modo de reproducción",
    "Delete": "Borrar",
    "Delete all layers": "Borrar todas las capas",
    "Delete layer": "Borrar capa",
    "Delete this feature": "Borrar este elemento",
    "Delete this property on all the features": "Borrar esta propiedad en todos los elementos",
    "Delete this shape": "Borrar esta figura",
    "Delete this vertex (Alt+Click)": "Borrar este vértice (Alt+Clic)",
    "Directions from here": "Direcciones desde aquí",
    "Display measure": "Mostrar medición",
    "Display on load": "Mostrar al cargar",
    "Download": "Descargar",
    "Download data": "Descargar datos",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a line": "Dibuja una línea",
    "Draw a marker": "Dibuja un marcador",
    "Draw a polygon": "Dibuja un polígono",
    "Draw a polyline": "Dibuja una polilínea",
    "Dynamic": "Dinámico",
    "Dynamic properties": "Propiedades dinámicas",
    "Edit": "Editar",
    "Edit feature's layer": "Editar la capa del elemento",
    "Edit map properties": "Editar propiedades del mapa",
    "Edit map settings": "Editar ajustes del mapa",
    "Edit properties in a table": "Editar propiedades en una tabla",
    "Edit this feature": "Editar este elemento",
    "Embed and share this map": "Embeber y compartir este mapa",
    "Embed the map": "Embeber el mapa",
    "Empty": "Vaciar",
    "Error in the tilelayer URL": "Error en la URL del la capa de teselas",
    "Error while fetching {url}": "Error al traer {url}",
    "Exit Fullscreen": "Salir de la pantalla completa",
    "Extract shape to separate feature": "Extraer la figura a un elemento separado",
    "Fetch data each time map view changes.": "Traer datos cada vez que la vista del mapa cambie.",
    "Filter keys": "Claves de filtrado",
    "Format": "Formato",
    "From zoom": "Desde el acercamiento",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propiedad de la intensidad del mapa de calor",
    "Heatmap radius": "Radio del mapa de calor",
    "Help": "Ayuda",
    "Hide controls": "Ocultar controles",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Cuánto simplificar la polilínea en cada nivel de acercamiento (más = mejor rendimiento y aspecto más suave, menos = más preciso)",
    "If false, the polygon will act as a part of the underlying map.": "Si falso, el polígono actuará como una parte del mapa subyacente.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altura personalizada (en píxeles): {{{http://iframe.url.com|altura}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con alto y ancho (en px) personalizado: {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imagen con anchura personalizada (en píxeles): {{http://imagen.url.com|anchura}}",
    "Image: {{http://image.url.com}}": "Imagen: {{http://imagen.url.com}}",
    "Import": "Importar",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar en una nueva capa",
    "Imports all umap data, including layers and settings.": "Importar todos los datos umap, incluyendo capas y ajustes.",
    "Include full screen link?": "¿Incluir el enlace a pantalla completa?",
    "Interaction options": "Opciones de interacción",
    "Invalid umap data": "Datos umap inválido",
    "Invalid umap data in {filename}": "Datos umap inválido en {filename}",
    "Keep current visible layers": "Guardar capas visibles actuales",
    "Latitude": "Latitud",
    "Layer": "Capa",
    "Layer properties": "Propiedades de la capa",
    "Licence": "Licencia",
    "Limit bounds": "Límites",
    "Link to…": "Enlace a...",
    "Link with text: [[http://example.com|text of the link]]": "Enlace con texto: [[http://ejemplo.com|texto del enlace]]",
    "Long credits": "Créditos largos",
    "Longitude": "Longitud",
    "Make main shape": "Hacer la figura principal",
    "Manage layers": "Gestionar capas",
    "Map background credits": "Créditos del fondo del mapa",
    "Map has been attached to your account": "El mapa se ha adjuntado a su cuenta",
    "Map has been saved!": "¡Se ha guardado el mapa!",
    "Map user content has been published under licence": "El contenido del mapa del usuario se ha publicado bajo la licencia",
    "Map's editors": "Editores del mapa",
    "Map's owner": "Propietario del mapa",
    "Merge lines": "Combinar líneas",
    "More controls": "Más controles",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Debe ser un valor CSS válido (por ejemplo: DarkBlue o #123456)",
    "No licence has been set": "Ninguna licencia se ha establecida",
    "No results": "Sin resultados",
    "Only visible features will be downloaded.": "Sólo se descargarán los elementos visibles.",
    "Open download panel": "Abrir el panel de descarga",
    "Open link in…": "Abrir enlace en...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abre la extensión de este mapa en un editor de mapas para proveer datos más precisos a OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedad de intensidad opcional para el mapa de calor",
    "Optional. Same as color if not set.": "Opcional. Igual que el color si no está establecido.",
    "Override clustering radius (default 80)": "Sobrescribir el radio de agrupación (predeterminado 80)",
    "Override heatmap radius (default 25)": "Sobrescribir el radio del mapa de calor (predeterminado 25)",
    "Please be sure the licence is compliant with your use.": "Asegúrese que la licencia sea compatible con el uso que le va a dar.",
    "Please choose a format": "Elija un formato",
    "Please enter the name of the property": "Introduzca el nombre de la propiedad",
    "Please enter the new name of this property": "Introduzca el nuevo nombre de esta propiedad",
    "Problem in the response": "Problema en la respuesta",
    "Problem in the response format": "Problema con el formato de respuesta",
    "Properties imported:": "Propiedades importadas:",
    "Provide an URL here": "Proporcione una URL aquí",
    "Proxy request": "Petición proxy",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Quitar la figura del multi elemento",
    "Rename this property on all the features": "Renombrar esta propiedad en todos los elementos",
    "Replace layer content": "Reemplaza el contenido de la capa",
    "Restore this version": "Restaurar esta versión",
    "Save": "Guardar",
    "Save anyway": "Guardar de todos modos",
    "Save current edits": "Guardar las ediciones actuales",
    "Save this center and zoom": "Guardar este centrado y acercamiento",
    "Save this location as new feature": "Guardar esta ubicación como nuevo elemento",
    "Search a place name": "Buscar el nombre de un lugar",
    "Search location": "Buscar ubicación",
    "See all": "Ver todo",
    "See data layers": "Ver capas de datos",
    "See full screen": "Ver pantalla completa",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Establecer en falso para ocultar esta capa de la presentación de diapositivas, el navegador de datos, la navegación emergente...",
    "Shape properties": "Propiedades de la figura",
    "Short URL": "URL corta",
    "Short credits": "Créditos cortos",
    "Show/hide layer": "Mostrar/ocultar capa",
    "Simple link: [[http://example.com]]": "Enlace simple: [[http://ejemplo.com]]",
    "Slideshow": "Presentación de diapositivas",
    "Sort key": "Orden de la clave",
    "Split line": "Linea de división",
    "Start a hole here": "Iniciar un agujero aquí",
    "Start editing": "Comenzar a editar",
    "Start slideshow": "Iniciar presentación de diapositivas",
    "Stop editing": "Parar de editar",
    "Stop slideshow": "Parar presentación de diapositivas",
    "Supported scheme": "Esquema soportado",
    "Supported variables that will be dynamically replaced": "Las variables soportadas que serán reemplazadas dinámicamente",
    "TMS format": "formato TMS",
    "Text color for the cluster label": "Color del texto para la etiqueta clúster",
    "Text formatting": "Formato de texto",
    "To use if remote server doesn't allow cross domain (slower)": "Para utilizar si el servidor remoto no permite dominios cruzados (más lento)",
    "To zoom": "Para acercar/alejar",
    "Transfer shape to edited feature": "Transferir la figura al elemento editado",
    "Transform to lines": "Transformar a líneas",
    "Transform to polygon": "Transformar a polígono",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "No se puede detectar el formato de archivo {filename}",
    "Untitled layer": "Capa sin título",
    "Untitled map": "Mapa sin título",
    "Update permissions": "Actualizar permisos",
    "Update permissions and editors": "Actualizar permisos y editores",
    "Url": "Url",
    "Use current bounds": "Utilizar límites actuales",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utilizar marcadores de posición con propiedades del elemento entre paréntesis, ejemplo &#123;name&#125;, serán reemplazados dinámicamente por los valores correspondientes.",
    "User content credits": "Créditos del contenido del usuario",
    "User interface options": "Opciones de la interface de usuario",
    "Versions": "Versiones",
    "View Fullscreen": "Ver en pantalla completa",
    "Where do we go from here?": "¿A dónde vamos a partir de aquí?",
    "Whether to display or not polygons paths.": "Si desea mostrar o no el trayecto de los polígonos.",
    "Whether to fill polygons with color.": "Si desea rellenar los polígonos con color.",
    "Who can edit": "Quién puede editar",
    "Who can view": "Quién puede ver",
    "Will be displayed in the bottom right corner of the map": "Se mostrará en la esquina inferior izquierda del mapa",
    "Will be visible in the caption of the map": "Será visible en el subtítulo del mapa",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "¡Oops! Alguien parece haber editado los datos. Puedes guardar de todos modos, pero esto va a borrar los cambios realizados por otros.",
    "Zoom in": "Acercar",
    "Zoom level for automatic zooms": "Nivel de acercamiento para acercamientos automáticos",
    "Zoom out": "Alejar",
    "Zoom to layer extent": "Acercamiento al nivel de la capa",
    "Zoom to the next": "Acercamiento al siguiente",
    "Zoom to the previous": "Acercamiento al anterior",
    "Zoom to this feature": "Acercamiento a este elemento",
    "Zoom to this place": "Acercamiento a este lugar",
    "attribution": "atribución",
    "by": "por",
    "display name": "mostrar nombre",
    "height": "altura",
    "licence": "licencia",
    "max East": "máximo Este",
    "max North": "máximo Norte",
    "max South": "máximo Sur",
    "max West": "máximo Oeste",
    "max zoom": "acercamiento máximo",
    "min zoom": "acercamiento mínimo",
    "next": "siguiente",
    "previous": "anterior",
    "width": "anchura",
    "{count} errors during import: {message}": "{count} errores durante la importación: {message}",
    "Measure distances": "Medir distancias",
    "NM": "NM",
    "kilometers": "kilómetros",
    "km": "km",
    "mi": "mi",
    "miles": "millas",
    "nautical miles": "millas náuticas",
    "1 day": "1 día",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "Cache proxied request": "Caché de la petición proxy",
    "No cache": "Sin caché",
    "Popup": "Ventana emergente",
    "Popup (large)": "Ventana emergente (grande)",
    "Popup content style": "Estilo del contenido emergente",
    "Popup shape": "Forma de la ventana emergente",
    "Skipping unknown geometry.type: {type}": "Ignorando tipo de geometría desconocida: {type}",
    "Optional.": "Opcional.",
    "Paste your data here": "Pega tus datos aquí",
    "Please save the map first": "Guarde primero el mapa",
    "Feature identifier key": "Clave de identificación del elemento",
    "Open current feature on load": "Abrir el elemento actual al cargar",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "El nombre de la propiedad a utilizar como identificador único del elemento.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{área} acres",
    "{area}&#8239;ha": "{área} ha",
    "{area}&#8239;m&sup2;": "{área} m&sup2;",
    "{area}&#8239;mi&sup2;": "{área} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{área} yd&sup2;",
    "{distance}&#8239;NM": "{distancia} NM",
    "{distance}&#8239;km": "{distancia} km",
    "{distance}&#8239;m": "{distancia} m",
    "{distance}&#8239;miles": "{distancia} millas",
    "{distance}&#8239;yd": "{distancia} yd",
    " (area: {measure})": "(área: {medida})",
    " (length: {measure})": "(longitud: {medida})",
    "Animated transitions": "Transiciones animadas",
    "Background overlay url": "Url de superposición de fondo",
    "Custom overlay": "Superposición personalizada",
    "Display the star map button": "Mostrar el botón del mapa de estrellas",
    "Error in the overlay URL": "Error en la URL de la superposición",
    "Map has been starred": "El mapa ha sido marcado con una estrella",
    "Map has been unstarred": "El mapa se ha desprotegido",
    "Opacity": "Opacidad",
    "Star this map": "Marcar este mapa con una estrella",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "El símbolo puede ser un carácter unicode o una URL. Puede utilizar propiedades de características como variables: ej.: con \"http://myserver.org/images/{nombre}.png\", la variable {nombre} se sustituirá por el valor \"nombre\" de cada marcador.",
    "Direct link": "Enlace directo",
    "Export options": "Opciones de exportación",
    "The zoom and center have been modified.": "Se han modificado el zoom y el centro.",
    "Congratulations, your map has been created!": "Enhorabuena, ¡su mapa ha sido creado!",
    "Copy link": "Copiar enlace",
    "Email": "Correoe",
    "Secret edit link copied to clipboard!": "Enlace de edición secreto copiado en el portapapeles",
    "Send me the link": "Envíeme el enlace",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "¡Su mapa ha sido creado! Como no ha iniciado sesión, aquí tiene el enlace secreto para editar el mapa:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Lista separada por comas de las propiedades que se utilizarán para ordenar las características. Para invertir la ordenación, anteponga un signo menos (-). Ej. miclave,-otraclave.",
    "Toggle edit mode (⇧+Click)": "Conmutar el modo de edición (⇧+Clic)",
    "icon opacity": "opacidad del icono",
    "*single star for italic*": "*una estrella para cursiva*",
    "--- for a horizontal rule": "--- para una regla horizontal",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "El nombre de la propiedad a utilizar como etiqueta de la característica (ej.: \"nom\"). También puede utilizar propiedades entre paréntesis para utilizar más de una o mezclarlas con contenido estático (p. ej.: \"{nombre} en {lugar}\").",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Lista separada por comas de las propiedades a utilizar para la búsqueda de facetas (ej.: miclave,otraclave). Para controlar la etiqueta, añádala después de | (ej.: mykey|Mi Clave,otherkey|Otra Clave)",
    "Default view": "Vista predeterminada",
    "Facet keys": "Claves de facetas",
    "Facet search": "Búsqueda de faceta",
    "Feature properties": "Propiedades de las funciones",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Problema para llegar a esa URL (problema de red o protección CORS): {url}",
    "Latest feature": "Última novedad",
    "No results for these facets": "No hay resultados para estas facetas",
    "Saved center and zoom": "Centro y zoom guardados",
    "User location": "Ubicación del usuario",
    "Visibility: {status}": "Visibilidad: {estado}",
    "Fit all data": "Ajustar todos los datos",
    "Verify remote URL": "Verificar URL remota",
    "Add": "Añadir",
    "Change": "Cambiar",
    "Powered by uMap": "Desarrollado por uMap",
    "Search": "Buscar",
    "Datalayers": "Capas de datos",
    "Secret edit link:": "Enlace secreto de edición:",
    "Who can edit \"{layer}\"": "Quién puede editar \"{layer}\"",
    "Current map view": "Vista actual del mapa",
    "Filter": "Filtro",
    "Choropleth": "Coropleto",
    "Choropleth breakpoints": "Puntos de ruptura de la Coropleta",
    "Choropleth classes": "Clases de coropletas",
    "Choropleth color palette": "Paleta de colores Coropleta",
    "Choropleth mode": "Modo Coropleta",
    "Choropleth property value": "Valor de la propiedad Choropleta",
    "Comma separated list of numbers, including min and max values.": "Lista de números separados por comas, incluidos los valores mínimo y máximo.",
    "Equidistant": "Equidistante",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-medias",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Número de clases deseadas (predeterminadas 5)",
    "Quantiles": "Cuantiles",
    "Show this layer in the caption": "Mostrar esta capa en la leyenda",
    "Back to preview": "Volver a la vista previa",
    "Drawing": "Dibujo",
    "Edit the title of the map": "Editar el título del mapa",
    "Go to the homepage": "Ir a la página de inicio",
    "Switch to edit mode": "Cambiar al modo de edición",
    "Update who can see and edit the map": "Actualizar quién puede ver y editar el mapa",
    "View": "Vista",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("es", locale)
L.setLocale("es")
