const locale = {
    "Allow scroll wheel zoom?": "Povolit přibližování kolečkem myši?",
    "Automatic": "Automatic",
    "Ball": "špendlík",
    "Cancel": "Storno",
    "Caption": "Popisek",
    "Choose the data format": "Vyberte formát dat",
    "Choose the layer of the feature": "Zvolte vrstvu do které objekt patří",
    "Circle": "Kruh",
    "Clustered": "Shluková",
    "Data browser": "Prohlížeč dat",
    "Default": "Výchozí",
    "Default zoom level": "Výchozí přiblížení",
    "Default: name": "Výchozí: name (název objektu)",
    "Display label": "Zobrazit popisek",
    "Display the control to open OpenStreetMap editor": "Zobrazit možnost upravit mapu v OpenStreetMap editoru",
    "Display the data layers control": "Zobrazit tlačítko nastavení datových vrstev",
    "Display the embed control": "Zobrazit tlačítko pro sdílení mapy",
    "Display the fullscreen control": "Zobrazit tlačítko pro celoobrazovkový režim",
    "Display the locate control": "Zobrazit tlačítko pro určení polohy",
    "Display the measure control": "Zobrazit tlačítko pro měření vzdálenosti",
    "Display the search control": "Zobrazit vyhledávání",
    "Display the tile layers control": "Zobrazit tlačítko pro změnu mapového podkladu",
    "Display the zoom control": "Zobrazit ovládání přiblížení",
    "Do you want to display a caption bar?": "Chcete zobrazit panel s popiskem?",
    "Do you want to display a minimap?": "Chcete zobrazit minimapu?",
    "Do you want to display a panel on load?": "Chcete při načtení zobrazit panel?",
    "Do you want to display popup footer?": "Chcete v bublině zobrazit navigační panel?",
    "Do you want to display the scale control?": "Chcete zobrazit měřítko mapy?",
    "Do you want to display the «more» control?": "Přejete si zobrazovat ovládací prvek «více»?",
    "Drop": "Pustit",
    "GeoRSS (only link)": "GeoRSS (jen odkaz)",
    "GeoRSS (title + image)": "GeoRSS (titulek + obrázek)",
    "Heatmap": "Teplotní mapa",
    "Icon shape": "Tvar ikony",
    "Icon symbol": "Symbol ikony",
    "Inherit": "výchozí",
    "Label direction": "Směr popisku",
    "Label key": "Tlačítko popisku",
    "Labels are clickable": "Popisky jsou klikatelné",
    "None": "Žádný",
    "On the bottom": "Zespod",
    "On the left": "Nalevo",
    "On the right": "Napravo",
    "On the top": "Shora",
    "Popup content template": "Šablona obsahu bubliny",
    "Side panel": "Boční panel",
    "Simplify": "Zjednodušit",
    "Table": "Tabulka",
    "always": "vždy",
    "clear": "vymazat",
    "collapsed": "sbalené",
    "color": "barva",
    "dash array": "styl přerušované čáry",
    "define": "definovat",
    "description": "popis",
    "expanded": "rozbalené",
    "fill": "výplň",
    "fill color": "barva výplně",
    "fill opacity": "průhlednost výplně",
    "hidden": "skryté",
    "iframe": "iframe",
    "inherit": "výchozí",
    "name": "název",
    "never": "nikdy",
    "new window": "nové okno",
    "no": "ne",
    "on hover": "při přejetí myší",
    "opacity": "průhlednost",
    "parent window": "rodičovské okno",
    "stroke": "linka",
    "weight": "šířka linky",
    "yes": "ano",
    "{delay} seconds": "{delay} sekund",
    "# one hash for main heading": "# jedna mřížka pro hlavní nadpis",
    "## two hashes for second heading": "## dvě mřížky pro nadpis druhé úrovně",
    "### three hashes for third heading": "### podnadpis třetí úrovně",
    "**double star for bold**": "**vše mezi dvěma hvězdičkami je tučně**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Čárkami oddělený seznam čísel, který popisuje vzorek přerušované čáry. Např. «5, 10, 15».",
    "About": "O mapě",
    "Action not allowed :(": "Akce nepovolena :(",
    "Activate slideshow mode": "Aktivovat prezentační mód",
    "Add a layer": "Přidat vrstvu",
    "Add a line to the current multi": "Přidat čáru k současnému multi",
    "Add a new property": "Přidat novou vlastnost",
    "Add a polygon to the current multi": "Přidat polygon k současnému multi",
    "Advanced actions": "Pokročilé akce",
    "Advanced properties": "Pokročilé vlastnosti",
    "All properties are imported.": "Všechny vlastnosti jsou importovány.",
    "Allow interactions": "Povolit interakce",
    "An error occured": "Došlo k chybě",
    "Are you sure you want to cancel your changes?": "Jste si jisti že chcete stornovat vaše úpravy?",
    "Are you sure you want to clone this map and all its datalayers?": "Určitě chcete vytvořit kopii celé této mapy a všech jejich vrstev?",
    "Are you sure you want to delete the feature?": "Určitě chcete vymazat tento objekt?",
    "Are you sure you want to delete this layer?": "Jste si jisti, že chcete smazat tuto vrstvu?",
    "Are you sure you want to delete this map?": "Jste si jisti, že chcete vymazat tuto celou mapu?",
    "Are you sure you want to delete this property on all the features?": "Určitě chcete smazat tuto vlastnost na všech objektech?",
    "Are you sure you want to restore this version?": "Opravdu si přejete obnovit tuto verzi?",
    "Attach the map to my account": "Připojte mapu k mému účtu",
    "Auto": "Automatická",
    "Autostart when map is loaded": "Spustit po načtení mapy",
    "Bring feature to center": "Centruj mapu na objektu",
    "Browse data": "Prohlížet data",
    "Cancel edits": "Stornovat úpravy",
    "Center map on your location": "Přemístit se na mapě na vaši polohu",
    "Change map background": "Změnit pozadí mapy",
    "Change tilelayers": "Změnit pozadí mapy",
    "Choose a preset": "Zvolte přednastavení",
    "Choose the format of the data to import": "Zvolte v jakém formátu jsou importovaná data",
    "Choose the layer to import in": "Zvolte vrstvu, do které se bude importovat",
    "Click last point to finish shape": "Klikněte na poslední bod pro dokončení tvaru",
    "Click to add a marker": "Kliknutím přidáš značku",
    "Click to continue drawing": "Kliknutím můžeš pokračovat v kreslení",
    "Click to edit": "Klikněte pro úpravy",
    "Click to start drawing a line": "Klikněte pro začátek kreslení čáry",
    "Click to start drawing a polygon": "Klikněte pro začátek kreslení polygonu",
    "Clone": "Klonovat",
    "Clone of {name}": "Klon objektu {name}",
    "Clone this feature": "Vytvoř vlastní kopii této vlastnosti",
    "Clone this map": "Vytvořit vlastní kopii této mapy",
    "Close": "Zavřít",
    "Clustering radius": "Poloměr shlukování",
    "Comma separated list of properties to use when filtering features": "Čárkami oddělený seznam vlastností pro filtrování objektů",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Hodnoty oddělené čárkou, tabulátorem, nebo středníkem. předpokládá se SRS WGS84 a jsou importovány jen polohy bodů. Import hledá záhlaví sloupců začínající na \"lat\" nebo \"lon\" a ty považuje za souřadnice (na velikosti písmen nesejde). Ostatní sloupce jsou importovány jako vlastnosti.",
    "Continue line": "Pokračovat v čáře",
    "Continue line (Ctrl+Click)": "Pokračovat v čáře (Ctrl+Klik)",
    "Coordinates": "Souřadnice",
    "Credits": "Autorství",
    "Current view instead of default map view?": "Současný pohled namísto výchozího?",
    "Custom background": "Vlastní pozadí",
    "Data is browsable": "Data se dají procházet",
    "Default interaction options": "Výchozí možnosti interakce",
    "Default properties": "Výchozí vlastnosti",
    "Default shape properties": "Výchozí nastavení tvaru",
    "Define link to open in a new window on polygon click.": "Definice odkazu, který se otevře v novém okně po kliknutí na polygon.",
    "Delay between two transitions when in play mode": "Zpoždění mezi dvěma předěly v přehrávacím módu",
    "Delete": "Vymazat",
    "Delete all layers": "Vymazat všechny vrstvy",
    "Delete layer": "Vymazat vrstvu",
    "Delete this feature": "Vymazat objekt",
    "Delete this property on all the features": "Smazat tuto vlastnost na všech objektech",
    "Delete this shape": "Smazat tento tvar",
    "Delete this vertex (Alt+Click)": "Smazat tento bod (Alt+Klik)",
    "Directions from here": "Navigovat odsud",
    "Display measure": "Zobrazit měřítko",
    "Display on load": "Zobrazit při startu",
    "Download": "Stažení",
    "Download data": "Stáhnout data",
    "Drag to reorder": "Přetáhni pro přeskupení",
    "Draw a line": "Nakreslit jednoduchou čáru",
    "Draw a marker": "Umístit značku místa",
    "Draw a polygon": "Vyznačit oblast",
    "Draw a polyline": "Nakreslit čáru",
    "Dynamic": "Dynamicky",
    "Dynamic properties": "Dynamické vlastnosti",
    "Edit": "Upravit",
    "Edit feature's layer": "Upravit vrstvu objektu",
    "Edit map properties": "Nastavení mapy",
    "Edit map settings": "Nastavení mapy",
    "Edit properties in a table": "Upravit vlastnosti v tabulce",
    "Edit this feature": "Upravit tento objekt",
    "Embed and share this map": "Sdílet mapu nebo ji vložit do jiného webu",
    "Embed the map": "Vložit mapu do jiného webu",
    "Empty": "Vyprázdnit",
    "Error in the tilelayer URL": "Chyba v URL vrstvy dlaždic",
    "Error while fetching {url}": "Chyba při načítání {url}",
    "Exit Fullscreen": "Ukončit režim celé obrazovky",
    "Extract shape to separate feature": "Vyjmout tvar do samostatného objektu",
    "Fetch data each time map view changes.": "Získat data při každé změně zobrazení mapy.",
    "Filter keys": "Filtrovací klávesy",
    "Format": "Formát",
    "From zoom": "Maximální oddálení",
    "Go to «{feature}»": "Jdi na  \"{feature}\"",
    "Heatmap intensity property": "Vlastnost pro intenzitu teplotní mapy",
    "Heatmap radius": "Poloměr teplotní mapy",
    "Help": "Nápověda",
    "Hide controls": "Skrýt ovládací prvky",
    "Home": "Domů",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Jak moc zahlazovat a zjednodušovat při oddálení (větší = rychlejší odezva a plynulejší vzhled, menší = přesnější)",
    "If false, the polygon will act as a part of the underlying map.": "Pokud je vypnuto, polygon se bude chovat jako součást mapového podkladu.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe s vlastní výškou (v px): {{{http://iframe.url.com|výška}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe s vlastní výškou a šířkou (in px): {{{http://iframe.url.com|výška*šířka}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Obrázek s vlastní šířkou (v px): {{http://obrazek.url.com|šířka}}",
    "Image: {{http://image.url.com}}": "Obrázek: {{http://priklad.cz/obrazek.jpg}}",
    "Import": "Importovat",
    "Import data": "Import dat",
    "Import in a new layer": "Importovat do nové vrstvy",
    "Imports all umap data, including layers and settings.": "Importuje všechy data umapy, včetně vrstev a nastavení",
    "Include full screen link?": "Zahrnout odkaz na celou obrazovku?",
    "Interaction options": "Možnosti interakce",
    "Invalid umap data": "Neplatná data umapy",
    "Invalid umap data in {filename}": "Neplatná data umapy v souboru {filename}",
    "Keep current visible layers": "Použít aktuální zobrazení vrstev",
    "Latitude": "Sev. šířka",
    "Layer": "Vrstva",
    "Layer properties": "Vlastnosti vrstvy",
    "Licence": "Licence",
    "Limit bounds": "Hranice zobrazení",
    "Link to…": "Odkaz na…",
    "Link with text: [[http://example.com|text of the link]]": "Odkaz: [[http://priklad.cz/stranka|text odkazu]]",
    "Long credits": "Dlouhý text autorství",
    "Longitude": "Délka",
    "Make main shape": "Učinit hlavním tvarem",
    "Manage layers": "Spravovat vrstvy",
    "Map background credits": "Autorství pozadí mapy",
    "Map has been attached to your account": "Mapa byla připojena k vašemu účtu",
    "Map has been saved!": "Mapa byla uložena",
    "Map user content has been published under licence": "Uživatelská data jsou zveřejněna pod licencí",
    "Map's editors": "Mapoví editoři",
    "Map's owner": "Majitel mapy",
    "Merge lines": "Spojit čáry",
    "More controls": "Více ovládacích prvků",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Platný název v CSS (např.: Red, Blue nebo #123456)",
    "No licence has been set": "Nebyla nastavena licence",
    "No results": "Žádné výsledky",
    "Only visible features will be downloaded.": "Budou staženy jen viditelné objekty",
    "Open download panel": "Otevřít panel na stahování",
    "Open link in…": "Otevřít adresu v…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otevři tuto oblast v editoru OpenStreetMap. Toto vám umožní editovat přímo základní mapová data a přispět tak v tvorbě svobodné mapy pro všechny.",
    "Optional intensity property for heatmap": "Volitelná vlastnost pro výpočet intenzity v teplotní mapě",
    "Optional. Same as color if not set.": "Nepovinné. Stejné jako barva, pokud není nastaveno.",
    "Override clustering radius (default 80)": "Přepsat shlukovací poloměr (výchozí hodnota 80)",
    "Override heatmap radius (default 25)": "Přepsat poloměr teplotní mapy (výchozí hodnota 25)",
    "Please be sure the licence is compliant with your use.": "Prosíme ujistěte se, že licence je ve shodě s tím jak mapu používáte.",
    "Please choose a format": "Zvolte formát",
    "Please enter the name of the property": "Zadejte prosím název vlastnosti",
    "Please enter the new name of this property": "Zadejte prosím nový název této vlastnosti",
    "Problem in the response": "Problém při odpovědi",
    "Problem in the response format": "Problém ve formátu odpovědi",
    "Properties imported:": "Importované vlastnosti:",
    "Provide an URL here": "Sem vložte odkaz",
    "Proxy request": "Požadavky přes proxy",
    "Remote data": "Vzdálená data",
    "Remove shape from the multi": "Odebrat tvar z multi",
    "Rename this property on all the features": "Přejmenovat tuto vlastnost na všech objektech",
    "Replace layer content": "Nahradit obsah vrstvy",
    "Restore this version": "Obnovit tuto verzi",
    "Save": "Ulož",
    "Save anyway": "I tak uložit",
    "Save current edits": "Ulož nedávné změny",
    "Save this center and zoom": "Ulož tuto pozici mapy a její přiblížení",
    "Save this location as new feature": "Uložit tuto pozici jako nový objekt",
    "Search a place name": "Vyhledejte název místa",
    "Search location": "Vyhledat místo na mapě",
    "See all": "Zobraz vše",
    "See data layers": "Zobrazit datové vrstvy",
    "See full screen": "Na celou obrazovku",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Nastavte na false pro ukrytí této vrstvy z prezentace, prohlížeče dat, vyskakovací navigace...",
    "Shape properties": "Vlastností tvaru",
    "Short URL": "Krátký odkaz",
    "Short credits": "Krátký text autorství",
    "Show/hide layer": "Skrytí/zobrazení vrstvy",
    "Simple link: [[http://example.com]]": "Jednoduchý odkaz: [[http://priklad.cz]]",
    "Slideshow": "Prezentace",
    "Sort key": "Řadící klávesa",
    "Split line": "Rozdělit čáru",
    "Start a hole here": "Začít tady díru",
    "Start editing": "Začít editaci",
    "Start slideshow": "Spustit prezentaci",
    "Stop editing": "Přerušit úpravy",
    "Stop slideshow": "Zastavit prezentaci",
    "Supported scheme": "Podporované schéma",
    "Supported variables that will be dynamically replaced": "Podporované proměnné, které budou automaticky nahrazeny",
    "TMS format": "formát TMS",
    "Text color for the cluster label": "Barva textu popisku shluku",
    "Text formatting": "Formátování textu",
    "To use if remote server doesn't allow cross domain (slower)": "Pro případ že vzdálený server neumožňuje cross domain (pomalejší)",
    "To zoom": "Maximální přiblížení",
    "Transfer shape to edited feature": "Přenést tvar do editovaného objektu",
    "Transform to lines": "Převést na čáry",
    "Transform to polygon": "Převést na polygon",
    "Type of layer": "Druh vrstvy",
    "Unable to detect format of file {filename}": "Nepodařilo se detekovat formát souboru {filename}",
    "Untitled layer": "Nepojmenovaná vrstva",
    "Untitled map": "Mapa bez názvu",
    "Update permissions": "Aktualizace oprávnění",
    "Update permissions and editors": "Nastavení přístupu a práva editace",
    "Url": "Url",
    "Use current bounds": "Použít současné hranice",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Použijte zástupný text s vlastnostmi objektů mezi složenými závorkami, např. &#123;name&#125; &mdash; budou dynamicky nahrazeny odpovídajícími hodnotami.",
    "User content credits": "Autorství uživatelského obsahu",
    "User interface options": "Nastavení ovládacích prvků mapy",
    "Versions": "Verze",
    "View Fullscreen": "Otevřít přes celou obrazovku",
    "Where do we go from here?": "Co všechno teď můžete udělat?",
    "Whether to display or not polygons paths.": "Zda se mají či nemají zobrazovat cesty polygonů.",
    "Whether to fill polygons with color.": "Zda vyplnit polygony barvou.",
    "Who can edit": "Kdo může upravit",
    "Who can view": "Kdo může zobrazit",
    "Will be displayed in the bottom right corner of the map": "Bude zobrazeno s mapou napravo dole",
    "Will be visible in the caption of the map": "Bude zobrazeno v popisu mapy",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ojoj! Někdo jiný mezitím také upravil data. Můžete je uložit bez ohledu na to, ale smažete tak jeho změny.",
    "Zoom in": "Přiblížit",
    "Zoom level for automatic zooms": "Úroveň přiblížení pro automatické přiblížení",
    "Zoom out": "Oddálit",
    "Zoom to layer extent": "Přizpůsobit přiblížení vrstvě",
    "Zoom to the next": "Skočit na následující",
    "Zoom to the previous": "Skočit na předchozí",
    "Zoom to this feature": "Přiblížit na tento objekt",
    "Zoom to this place": "Přiblížit na toto místo",
    "attribution": "autorství",
    "by": "od",
    "display name": "zobrazit název",
    "height": "výška",
    "licence": "licence",
    "max East": "maximálně na Východ",
    "max North": "maximálně na Sever",
    "max South": "maximálně na Jih",
    "max West": "maximálně na Západ",
    "max zoom": "maximální přiblížení",
    "min zoom": "maximální oddálení",
    "next": "další",
    "previous": "předchozí",
    "width": "šířka",
    "{count} errors during import: {message}": "{count} chyb při importu: {message}",
    "Measure distances": "Měření vzdáleností",
    "NM": "NM",
    "kilometers": "kilometry",
    "km": "km",
    "mi": "mi",
    "miles": "míle",
    "nautical miles": "námořní míle",
    "1 day": "1 den",
    "1 hour": "1 hodina",
    "5 min": "5 minut",
    "Cache proxied request": "Požadavek na zástupnou mezipaměť",
    "No cache": "Žádná mezipaměť",
    "Popup": "Popup",
    "Popup (large)": "Popup (velký)",
    "Popup content style": "Styl obsahu popupu",
    "Popup shape": "Tvar popupu",
    "Skipping unknown geometry.type: {type}": "Přeskakuji neznámý geometry.type: {type}",
    "Optional.": "Volitelné.",
    "Paste your data here": "Zde vložte svá data",
    "Please save the map first": "Prosím, nejprve uložte mapu",
    "Feature identifier key": "Identifikační klíč funkce",
    "Open current feature on load": "Otevřít současnou funkci při zatížení",
    "Permalink": "Trvalý odkaz",
    "The name of the property to use as feature unique identifier.": "Název vlastnosti pro použití v popisku jedinečného identifikátoru objektu.",
    "Do you want to display caption menus?": "Chcete zobrazit nabídky s popiskem?",
    "Example: key1,key2,key3": "Příklad: key1,key2,key3",
    "Invalid latitude or longitude": "Neplatná zeměpisná šířka nebo délka",
    "Invalide property name: {name}": "Neplatný název vlastnosti: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} akry",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} míle",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(plocha: {measure})",
    " (length: {measure})": "(délka: {measure})",
    "Animated transitions": "Animované přechody",
    "Background overlay url": "Url překrytí pozadí",
    "Custom overlay": "Vlastní překryv",
    "Display the star map button": "Zobrazit tlačítko mapy označené hvězdičkou",
    "Error in the overlay URL": "Chyba u URL překryvu dlaždic",
    "Map has been starred": "Mapa byla označena hvězdičkou",
    "Map has been unstarred": "Označení mapy hvězdičkou bylo zrušeno",
    "Opacity": "Průhlednost",
    "Star this map": "Označit tuto mapu hvězdičkou",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol může mít buď znak unicode nebo URL. Vlastnosti můžete použít jako proměnné: např. Pomocí \"http://myserver.org/images/{name}.png\" bude proměnná {name} nahrazena hodnotou \"name\" každé značky.",
    "Direct link": "Přímý odkaz",
    "Export options": "Exportovat možnosti",
    "The zoom and center have been modified.": "Přiblížení a střed mapy byly modifikovány",
    "Congratulations, your map has been created!": "Gratulujeme, vaše mapa byla vytvořena!",
    "Copy link": "Kopírovat odkaz",
    "Email": "E-mail",
    "Secret edit link copied to clipboard!": "Tajný odkaz na úpravy do schránky!",
    "Send me the link": "Pošlete mi odkaz",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Vaše mapa byla vytvořena! Protože nejste přihlášeni, zde je váš tajný odkaz na úpravu mapy, uschovejte jej prosím:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Čárkami oddělený seznam vlastností, které se mají použít pro třídění prvků. Chcete-li řazení obrátit, vložte před něj znaménko mínus (-). Např. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Přepnout do editovacího módu (⇧+Klik)",
    "icon opacity": "průhlednost ikony",
    "*single star for italic*": "*vše mezi hvězdičkami bude kurzívou*",
    "--- for a horizontal rule": "--- vytvoří vodorovnou linku",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "Název vlastnosti, která se má použít jako popis funkce (např.: \"nom\"). Můžete také použít vlastnosti uvnitř hranatých závorek a použít více než jednu nebo je kombinovat se statickým obsahem (např.: \"{jméno} v {místo}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Seznam vlastností oddělených čárkou, které se mají použít pro hledání aspektů (např.: mykey,otherkey). Chcete-li změnit popisek, přidejte jej za | (např.: mykey|Můj klíč,otherkey|Jiný klíč)",
    "Default view": "Výchozí zobrazení",
    "Facet keys": "Aspekty klíče",
    "Facet search": "hledání aspektů",
    "Feature properties": "Vlastnosti funkce",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Problém s dosažením této adresy URL (síťový problém nebo ochrana CORS): {url}",
    "Latest feature": "Nejnovější funkce",
    "No results for these facets": "Žádné výsledky pro tyto aspekty",
    "Saved center and zoom": "Uložený střed a zoom",
    "User location": "Poloha uživatele",
    "Visibility: {status}": "Viditelnost: {status}",
    "Fit all data": "Přizpůsobení všech dat",
    "Verify remote URL": "Ověřit vzdálenou adresu URL",
    "Add": "Přidat",
    "Change": "Změnit",
    "Powered by uMap": "Běží na uMap",
    "Search": "Hledat",
    "Datalayers": "Datové vrstvy",
    "Secret edit link:": "Tajný odkaz na úpravy:",
    "Who can edit \"{layer}\"": "Kdo může upravovat \"{layer}\"",
    "Current map view": "Aktuální zobrazení mapy",
    "Filter": "Filtr",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth třídy",
    "Choropleth color palette": "Choropleth paleta barev",
    "Choropleth mode": "Choropleth režim",
    "Choropleth property value": "Choropleth hodnota objektu",
    "Comma separated list of numbers, including min and max values.": "Seznam čísel oddělených čárkou, včetně minimálních a maximálních hodnot.",
    "Equidistant": "Stejně vzdálené",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Ručně",
    "Number of desired classes (default 5)": "Počet požadovaných tříd (výchozí 5)",
    "Quantiles": "Kvantily",
    "Show this layer in the caption": "Zobrazit tuto vrstvu v nadpisu",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("cs_CZ", locale)
L.setLocale("cs_CZ")
