const locale = {
    "Allow scroll wheel zoom?": "Engedélyezi-e a görgetést nagyításkor?",
    "Automatic": "Automatikus",
    "Ball": "Gombostű",
    "Cancel": "Mégse",
    "Caption": "Cím",
    "Choose the data format": "Adatformátum kiválasztása",
    "Choose the layer of the feature": "Objektum rétegének kiválasztása",
    "Circle": "Kör",
    "Clustered": "Csoportosított",
    "Data browser": "Adatböngésző",
    "Default": "Alapértelmezett",
    "Default zoom level": "Alapértelmezett nagyítási szint",
    "Default: name": "Alapértelmezett: név",
    "Display label": "Felirat megjelenítése",
    "Display the control to open OpenStreetMap editor": "Az OpenStreetMap szerkesztő megnyitása vezérlő megjelenítése",
    "Display the data layers control": "Adatrétegek vezérlő megjelenítése",
    "Display the embed control": "Beágyazás vezérlő megjelenítése",
    "Display the fullscreen control": "Teljes képernyő vezérlő megjelenítése",
    "Display the locate control": "Saját pozícióhoz igazítás vezérlő megjelenítése",
    "Display the measure control": "Mérés vezérlő megjelenítése",
    "Display the search control": "Keresés vezérlő megjelenítése",
    "Display the tile layers control": "Mozaikrétegek vezérlő megjelenítése",
    "Display the zoom control": "Nagyítás vezérlő megjelenítése",
    "Do you want to display a caption bar?": "Szeretné megjeleníteni a címsávot?",
    "Do you want to display a minimap?": "Szeretne megjeleníteni egy kis térképet?",
    "Do you want to display a panel on load?": "Betöltéskor szeretne-e megjeleníteni egy panelt?",
    "Do you want to display popup footer?": "Szeretn-e megjeleníteni egy előugró láblécet?",
    "Do you want to display the scale control?": "Szeretné megjeleníteni a méretarány vezérlőt?",
    "Do you want to display the «more» control?": "Szeretné megjeleníteni a „továbbiak” vezérlőt?",
    "Drop": "Csepp",
    "GeoRSS (only link)": "GeoRSS (csak link)",
    "GeoRSS (title + image)": "GeoRSS (cím + kép)",
    "Heatmap": "Intenzitástérkép",
    "Icon shape": "Ikon alakja",
    "Icon symbol": "Ikonszimbólum",
    "Inherit": "Öröklés",
    "Label direction": "Felirat iránya",
    "Label key": "Felirathoz használt kulcs",
    "Labels are clickable": "Kattintható feliratok",
    "None": "Semmi",
    "On the bottom": "Lent",
    "On the left": "Balra",
    "On the right": "Jobbra",
    "On the top": "Fent",
    "Popup content template": "Előugró tartalom sablonja",
    "Side panel": "Oldalsó panel",
    "Simplify": "Egyszerűsítés",
    "Table": "Táblázat",
    "always": "mindig",
    "clear": "alaphelyzet",
    "collapsed": "összecsukva",
    "color": "szín",
    "dash array": "Szaggatottság mintázata",
    "define": "meghatározás",
    "description": "leírás",
    "expanded": "kiterjesztett",
    "fill": "kitöltés",
    "fill color": "kitöltés színe",
    "fill opacity": "kitöltés átlátszósága",
    "hidden": "rejtett",
    "iframe": "iframe",
    "inherit": "öröklés",
    "name": "név",
    "never": "soha",
    "new window": "új ablak",
    "no": "nincs",
    "on hover": "rámutatáskor",
    "opacity": "átlátszóság",
    "parent window": "szülőablak",
    "stroke": "körvonal",
    "weight": "vastagság",
    "yes": "igen",
    "{delay} seconds": "{delay} másodperc",
    "# one hash for main heading": "# egy számjel: fő címsor",
    "## two hashes for second heading": "## két számjel: második címsor",
    "### three hashes for third heading": "### három számjel: harmadik címsor",
    "**double star for bold**": "**két csillag: félkövér**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Vesszővel tagolt számsor, amely meghatározza a szaggatott vonalak mintázatát. Például 5,10,15 Ha nem világos, próbálkozz!",
    "About": "Névjegy",
    "Action not allowed :(": "Nem engedélyezett művelet :(",
    "Activate slideshow mode": "Diavetítésmód aktiválása",
    "Add a layer": "Réteg hozzáadása",
    "Add a line to the current multi": "Vonal hozzáadása a jelenlegi alakzatcsoporthoz",
    "Add a new property": "Új tulajdonság hozzáadása",
    "Add a polygon to the current multi": "Sokszög hozzáadása a jelenlegi alakzatcsoporthoz",
    "Advanced actions": "Speciális műveletek",
    "Advanced properties": "Speciális tulajdonságok",
    "All properties are imported.": "Minden tulajdonság importálva lett.",
    "Allow interactions": "Interakció engedélyezése",
    "An error occured": "Hiba történt",
    "Are you sure you want to cancel your changes?": "Biztosan elveti a módosításait?",
    "Are you sure you want to clone this map and all its datalayers?": "Biztosan klónozza a térképet és az összes adatrétegét?",
    "Are you sure you want to delete the feature?": "Biztosan törölni szeretné ezt az objektumot?",
    "Are you sure you want to delete this layer?": "Biztosan törölni szeretné ezt a réteget?",
    "Are you sure you want to delete this map?": "Biztosan törölni szeretné ezt a térképet?",
    "Are you sure you want to delete this property on all the features?": "Biztosan törölni szeretné ezt a tulajdonságot az összes objektumról?",
    "Are you sure you want to restore this version?": "Biztosan ezt a változatot akarja helyreállítani?",
    "Attach the map to my account": "Térkép csatolása a fiókomhoz",
    "Auto": "Automatikus",
    "Autostart when map is loaded": "Automatikus indulás a térkép betöltése után",
    "Bring feature to center": "Objektum középre hozása",
    "Browse data": "Adatok böngészése",
    "Cancel edits": "Szerkesztések elvetése",
    "Center map on your location": "A térkép közepének igazítása a saját pozícióhoz",
    "Change map background": "Térkép hátterének módosítása",
    "Change tilelayers": "Mozaikrétegek módosítása",
    "Choose a preset": "Előbeállítás kiválasztása",
    "Choose the format of the data to import": "Importálandó adatok formátumának kiválasztása",
    "Choose the layer to import in": "Importálandó réteg kiválasztása",
    "Click last point to finish shape": "Az alakzat befejezéséhez kattintson az utolsó pontra",
    "Click to add a marker": "Jelölő hozzáadásához kattintson",
    "Click to continue drawing": "Kattintson a rajzolás folytatásához",
    "Click to edit": "Kattintson a szerkesztéshez",
    "Click to start drawing a line": "Kattintson egy vonal rajzolásához",
    "Click to start drawing a polygon": "Kattintson egy sokszög rajzolásához",
    "Clone": "Klónozás",
    "Clone of {name}": "{name} klónozása",
    "Clone this feature": "Objektum klónozása",
    "Clone this map": "Térkép klónozása",
    "Close": "Bezárás",
    "Clustering radius": "Csoportosítás sugara",
    "Comma separated list of properties to use when filtering features": "Tulajdonságok vesszővel tagolt sora, amely objektumok szűrésére használható",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Vesszővel, pontosvesszővel vagy tabulátorral tagolt értékek a WGS84 referenciarendszer szerint. Csak a pontok pozíciója importálódik. Az import során az oszlopfejlécekben, a címsor kezdetén található „lat” és „long” említések vétetenek figyelembe; kis- vagy nagybetű nem számít. Az összes többi oszlop tulajdonságként importálódik.",
    "Continue line": "Vonal folytatása",
    "Continue line (Ctrl+Click)": "Vonal folytatása (Ctrl+Kattintás)",
    "Coordinates": "Koordináták",
    "Credits": "Alkotók",
    "Current view instead of default map view?": "Használja-e a jelenlegi nézetet az alapértelmezett helyett?",
    "Custom background": "Egyedi háttér",
    "Data is browsable": "Az adatok böngészhetők",
    "Default interaction options": "Alapértelmezett interakciós beállítások",
    "Default properties": "Alapértelmezett tulajdonságok",
    "Default shape properties": "Alapértelmezett alakzattulajdonságok",
    "Define link to open in a new window on polygon click.": "Link meghatározása, amely megnyílik a sokszögre kattintva.",
    "Delay between two transitions when in play mode": "Az áttűnések közötti késés lejátszási üzemmódban",
    "Delete": "Törlés",
    "Delete all layers": "Összes réteg törlése",
    "Delete layer": "Réteg törlése",
    "Delete this feature": "Objektum törlése",
    "Delete this property on all the features": "Tulajdonság törlése az összes objektumról",
    "Delete this shape": "Alakzat törlése",
    "Delete this vertex (Alt+Click)": "Sarokpont törlése (Alt+Klikk)",
    "Directions from here": "Irányok innen",
    "Display measure": "Távolságmérő megjelenítése",
    "Display on load": "Megjelenítés betöltéskor",
    "Download": "Letöltés",
    "Download data": "Adatok letöltése",
    "Drag to reorder": "Az átrendezéshez húzza át",
    "Draw a line": "Vonal rajzolása",
    "Draw a marker": "Jelölő rajzolása",
    "Draw a polygon": "Sokszög rajzolása",
    "Draw a polyline": "Töröttvonal rajzolása",
    "Dynamic": "Dinamikus",
    "Dynamic properties": "Dinamikus tulajdonságok",
    "Edit": "Szerkesztés",
    "Edit feature's layer": "Objektum rétegének szerkesztése",
    "Edit map properties": "Térkép tulajdonságainak szerkesztése",
    "Edit map settings": "Térkép beállításainak szerkesztése",
    "Edit properties in a table": "Tulajdonságok szerkesztése táblázatban",
    "Edit this feature": "Objektum szerkesztése",
    "Embed and share this map": "Térkép beágyazása és megosztása",
    "Embed the map": "Térkép beágyazása",
    "Empty": "Kiürítés",
    "Error in the tilelayer URL": "Hiba a mozaikréteg URL-jében",
    "Error while fetching {url}": "Hiba történt e webcím beolvasásakor: {url}",
    "Exit Fullscreen": "Kilépés a teljes képernyős nézetből",
    "Extract shape to separate feature": "Alakzat kiemelése objektum széválasztásához",
    "Fetch data each time map view changes.": "Adatok beolvasása a térkép nézetének minden egyes változásánál.",
    "Filter keys": "Szűréshez használt kulcsok",
    "Format": "Formátum",
    "From zoom": "Ettől a nagyítási szinttől",
    "Go to «{feature}»": "Ugrás ide: «{feature}»",
    "Heatmap intensity property": "Intenzitástérkép tulajdonságai",
    "Heatmap radius": "Intenzitástérkép sugara",
    "Help": "Súgó",
    "Hide controls": "Vezérlők elrejtése",
    "Home": "Kezdőlap",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Mennyire egyszerűsödjék egy töröttvonal az egyes nagyítási fokozatoknál (jobban = jobb teljesítmény és simább kinézet, kevésbé = nagyobb pontosság)",
    "If false, the polygon will act as a part of the underlying map.": "Ha hamis, akkor a sokszög az alapját jelentő térkép részeként fog viselkedni.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe egyedi magassággal (pixel): {{{http://iframe.url.com|magasság}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe egyedi magassággal és szélességgel (pixel): {{{http://iframe.url.com|magasság*szélesség}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Kép egyedi szélességgel (pixel): {{http://image.url.com|szélesség}}",
    "Image: {{http://image.url.com}}": "Kép: {{http://image.url.com}}",
    "Import": "Importálás",
    "Import data": "Adatok importálása",
    "Import in a new layer": "Importálás új rétegbe",
    "Imports all umap data, including layers and settings.": "Minden uMap-adatot (többek között a rétegeket és a beállításokat is) importálja.",
    "Include full screen link?": "Tartalmazzon-e teljes képernyős nézetre vezető linket?",
    "Interaction options": "Interakció beállításai",
    "Invalid umap data": "Érvénytelen uMap-adatok",
    "Invalid umap data in {filename}": "Érvénytelen uMap-adatok: {filename}",
    "Keep current visible layers": "A jelenleg látható rétegek megtartása",
    "Latitude": "Szélesség",
    "Layer": "Réteg",
    "Layer properties": "Réteg tulajdonságai",
    "Licence": "Licenc",
    "Limit bounds": "Térkép szélei",
    "Link to…": "Link…",
    "Link with text: [[http://example.com|text of the link]]": "Link szöveggel: [[http://pelda.hu|szöveg]]",
    "Long credits": "Alkotók részletesen",
    "Longitude": "Hosszúság",
    "Make main shape": "Legyen főalakzat",
    "Manage layers": "Rétegek kezelése",
    "Map background credits": "Térképháttér alkotói",
    "Map has been attached to your account": "A térkép az ön fiókjához csatoltatott",
    "Map has been saved!": "Térkép mentve",
    "Map user content has been published under licence": "A térkép felhasználói tartalma licenc szerint lett közzétéve",
    "Map's editors": "Térkép szerkesztői",
    "Map's owner": "Térkép tulajdonosa",
    "Merge lines": "Vonalak egyesítése",
    "More controls": "További vezérlők",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Érvényes CSS-értéknek kell lennie (pl. DarkBlue vagy #123456)",
    "No licence has been set": "Licenc még nincs megadva",
    "No results": "Nincs eredmény",
    "Only visible features will be downloaded.": "Csak a látható objektumok lesznek letöltve.",
    "Open download panel": "Letöltési panel megnyitása",
    "Open link in…": "Link megnyitása itt:",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "A térképkivágás megnyitása egy térképszerkesztőben, hogy az OpenStreetMapbe pontosabb adatokat lehessen előállítani",
    "Optional intensity property for heatmap": "Intenzitástérkép nem kötelező tulajdonsága",
    "Optional. Same as color if not set.": "Nem kötelező. Ha nincs beállítva, akkor ugyanaz, mint a szín.",
    "Override clustering radius (default 80)": "Csoportosítás sugarának felülírása (alapértelmezett: 80)",
    "Override heatmap radius (default 25)": "Intenzitástérkép sugarának felülírása (alapértelmezett: 25)",
    "Please be sure the licence is compliant with your use.": "Győződjön meg róla, hogy a licenc megfelel a térkép felhasználásának.",
    "Please choose a format": "Válassza ki a formátumot",
    "Please enter the name of the property": "Adja meg a tulajdonság nevét",
    "Please enter the new name of this property": "Adja meg a tulajdonság új nevét",
    "Problem in the response": "Hiba a válaszban",
    "Problem in the response format": "Hiba a válasz formátumában",
    "Properties imported:": "Importált tulajdonságok:",
    "Provide an URL here": "Itt adjon meg egy URL-t",
    "Proxy request": "Proxykérés",
    "Remote data": "Távoli adatok",
    "Remove shape from the multi": "Alakzat eltávolítása a jelenlegi alakzatcsoportból",
    "Rename this property on all the features": "Tulajdonság eltávolítása az összes objektumról",
    "Replace layer content": "Réteg tartalmának lecserélése",
    "Restore this version": "Ennek a változatnak a visszaállítása",
    "Save": "Mentés",
    "Save anyway": "Mentés mindenképpen",
    "Save current edits": "Jelenlegi szerkesztések mentése",
    "Save this center and zoom": "Mentés a jelenlegi középponttal és nagyítással",
    "Save this location as new feature": "E hely mentése új objektumként",
    "Search a place name": "Helynév keresése",
    "Search location": "Hely keresése",
    "See all": "Összes megtekintése",
    "See data layers": "Adatrétegek megtekintése",
    "See full screen": "Teljes képernyős nézet megtekintése",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Állítsa hamisra, hogy elrejtse ezt a réteget a diavetítésből, az adatböngészőből, az előugró navigációból stb.",
    "Shape properties": "Alakzat tulajdonságai",
    "Short URL": "Rövid URL",
    "Short credits": "Alkotók röviden",
    "Show/hide layer": "Réteg megjelenítése/elrejtése",
    "Simple link: [[http://example.com]]": "Egyszerű link: [[http://pelda.hu]]",
    "Slideshow": "Diavetítés",
    "Sort key": "Sorba rendezéshez használt kulcs",
    "Split line": "Vonal elvágása",
    "Start a hole here": "Lyuk rajzolása itt",
    "Start editing": "Szerkesztés megkezdése",
    "Start slideshow": "Diavetítés indítása",
    "Stop editing": "Szerkesztés befejezése",
    "Stop slideshow": "Diavetítés befejezése",
    "Supported scheme": "Támogatott séma",
    "Supported variables that will be dynamically replaced": "Támogatott változók, amelyek dinamikusan behelyettesítődnek",
    "TMS format": "TMS-formátum",
    "Text color for the cluster label": "Csoportcímke szövegének színe",
    "Text formatting": "Szövegformázás",
    "To use if remote server doesn't allow cross domain (slower)": "Akkor használja, ha a távoli kiszolgáló nem engedélyezi a tartományok közötti (cross-domain) átvitelt (lassabb)",
    "To zoom": "Eddig a nagyítási szintig",
    "Transfer shape to edited feature": "Alakzat átalakítása szerkesztett objektummá",
    "Transform to lines": "Átalakítás vonallá",
    "Transform to polygon": "Átalakítás sokszöggé",
    "Type of layer": "Réteg típusa",
    "Unable to detect format of file {filename}": "A(z) {filename} fájl formátumának megállapítása nem sikerült",
    "Untitled layer": "Cím nélküli réteg",
    "Untitled map": "Cím nélküli térkép",
    "Update permissions": "Jogosultságok frissítése",
    "Update permissions and editors": "Jogosultságok és szerkesztők frissítése",
    "Url": "URL",
    "Use current bounds": "Jelenlegi nézet használata",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Olyan helyőrzőket használjon, amelyeknél az objektumtulajdonságok zárójelben vannak, például &#123;name&#125;. A megfelelő értékek dinamikusan behelyettesítődnek a tulajdonságok helyébe.",
    "User content credits": "Felhasználói tartalom alkotói",
    "User interface options": "Felhasználói felület tulajdonságai",
    "Versions": "Verziók",
    "View Fullscreen": "Megjelenítés teljes képernyőn",
    "Where do we go from here?": "Merre tovább?",
    "Whether to display or not polygons paths.": "Megjelenjenek-e a sokszög oldalai?",
    "Whether to fill polygons with color.": "Ki legyen-e színezve a sokszög?",
    "Who can edit": "Ki szerkesztheti?",
    "Who can view": "Ki láthatja?",
    "Will be displayed in the bottom right corner of the map": "A térkép jobb alsó sarkában fog megjelenni",
    "Will be visible in the caption of the map": "A térkép címsávjában fog megjelenni",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ajjaj… Úgy tűnik, időközben valaki más is szerkesztette az adatokat. Ennek ellenére elmentheti őket, de ezzel az időközben mások által végzett módosítások el fognak veszni.",
    "Zoom in": "Nagyítás",
    "Zoom level for automatic zooms": "Nagyítási szint automatikus nagyításoknál",
    "Zoom out": "Kicsinyítés",
    "Zoom to layer extent": "Nagyítás a teljes rétegre",
    "Zoom to the next": "Nagyítás a következőre",
    "Zoom to the previous": "Nagyítás az előzőre",
    "Zoom to this feature": "Nagyítás erre az objektumra",
    "Zoom to this place": "Nagyítás erre a helyre",
    "attribution": "szerzőmegjelölés",
    "by": "- készítette:",
    "display name": "név megjelenítése",
    "height": "magasság",
    "licence": "licenc",
    "max East": "keletre eddig",
    "max North": "északra eddig",
    "max South": "délre eddig",
    "max West": "nyugatra eddig",
    "max zoom": "legnagyobb nagyítás",
    "min zoom": "legkisebb nagyítás",
    "next": "következő",
    "previous": "előző",
    "width": "szélesség",
    "{count} errors during import: {message}": "{count} hiba történt az importálás közben: {message}",
    "Measure distances": "Távolságmérés",
    "NM": "tengeri mérföld",
    "kilometers": "kilométer",
    "km": "km",
    "mi": "mérföld",
    "miles": "mérföld",
    "nautical miles": "tengeri mérföld",
    "1 day": "1 nap",
    "1 hour": "1 óra",
    "5 min": "5 perc",
    "Cache proxied request": "Proxy keresztül továbbított gyorsítótárkérés",
    "No cache": "Nincs gyorsítótár",
    "Popup": "Felugró",
    "Popup (large)": "Felugró (nagy)",
    "Popup content style": "Felugró tartalom stílusa",
    "Popup shape": "Felugró ablak alakja",
    "Skipping unknown geometry.type: {type}": "Ismeretlen ({type}) geometriai típus kihagyása",
    "Optional.": "Nem kötelező.",
    "Paste your data here": "Illessze be ide az adatokat",
    "Please save the map first": "Először mentse a térképet",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Szeretné megjeleníteni a térkép címsávmenüjét?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Mindig látható alkotók",
    "Permanent credits background": "Háttér a mindig látható alkotók mögött",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Mindig látható lesz a térkép bal alsó sarkában",
    "{area}&#8239;acres": "{area} acre",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mf&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yard&sup2;",
    "{distance}&#8239;NM": "{distance} tengeri mf.",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} mf",
    "{distance}&#8239;yd": "{distance} yard",
    " (area: {measure})": "(terület: {measure})",
    " (length: {measure})": "(távolság: {measure})",
    "Animated transitions": "Animált áttűnések",
    "Background overlay url": "Háttérbeli fedőréteg URL-je",
    "Custom overlay": "Egyedi fedőréteg",
    "Display the star map button": "Térképet megcsillagozó gomb megjelenítése",
    "Error in the overlay URL": "Hiba a fedőréteg URL-jében",
    "Map has been starred": "Térkép megcsillagozva",
    "Map has been unstarred": "Térkép csillagozása visszavonva",
    "Opacity": "Átlátszóság",
    "Star this map": "Térkép megcsillagozása",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "A szimbólum egy unicode karakter vagy egy URL lehet. Az objektum tulajdonságai változóként használhatók. Például „http://myserver.org/images/{name}.png” használatánál az egyes jelölők „name” értékei behelyettesítődnek {name} változó helyén.",
    "Direct link": "Közvetlen link",
    "Export options": "Exportálási beállítások",
    "The zoom and center have been modified.": "A nagyítás és a középpont módosult.",
    "Congratulations, your map has been created!": "Gratulálunk, a térképe elkészült!",
    "Copy link": "Link másolása",
    "Email": "E-mail",
    "Secret edit link copied to clipboard!": "Titkos szerkesztési link a vágólapra másolva.",
    "Send me the link": "Link elküldése magamnak",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "A térképee elkészült! Mivel nincs bejelentkezve, itt egy titkos link a térkép szerkesztéséhez, kérjük, őrizze meg:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "A jellemzők sorba rendezéséhez használandó tulajdonságok vesszővel tagolt sora. A sorba rendezés megfordításához tegyen mínusz jelet (-) elé. Például: kulcs,-másikkulcs.",
    "Toggle edit mode (⇧+Click)": "Szerkesztési mód be-/kikapcsolás (⇧+kattintás)",
    "icon opacity": "Ikon átlátszósága",
    "*single star for italic*": "*egy csillag: dőlt*",
    "--- for a horizontal rule": "--- vízszintes vonal",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "Az objektum feliratához használandó tulajdonság neve (pl.: \"név\"). Használhat zárójelben lévő tulajdonságokat is, ha egynél többet szeretne használni, vagy keverheti statikus tartalommal is (pl.: \"{településnév} városban található {utcanév}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "A szűréshez használandó tulajdonságok vesszővel tagolt listája (pl.: kulcs,másikkulcs). A felirat beállításához adja hozzá a felirat szövegét a „|” jel után (pl.: kulcs|Első jellemző,másikkulcs|Második jellemző)",
    "Default view": "Alapértelmezett nézet",
    "Facet keys": "Szűrési tényezők",
    "Facet search": "Szűrés",
    "Feature properties": "Objektum tulajdonságai",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Hiba történt az URL elérésekor (hálózati probléma vagy külső weboldalak használata elleni CORS-védelem): {url}",
    "Latest feature": "Legutóbbi objektum",
    "No results for these facets": "Erre a szűrésre nincs eredmény",
    "Saved center and zoom": "Elmentett középpont és nagyítás",
    "User location": "Felhasználó pozíciója",
    "Visibility: {status}": "Láthatóság: {status}",
    "Fit all data": "Legyen látható az összes adat",
    "Verify remote URL": "Távoli URL ellenőrzése",
    "Add": "Hozzáadás",
    "Change": "Módosítás",
    "Powered by uMap": "Üzemeltető: uMap",
    "Search": "Keresés",
    "Datalayers": "Adatrétegek",
    "Secret edit link:": "Titkos szerkesztési link:",
    "Who can edit \"{layer}\"": "Ki szerkesztheti ezt a réteget: {layer}?",
    "Current map view": "Jelenlegi térképnézet",
    "Filter": "Szűrő",
    "Choropleth": "Kartogram",
    "Choropleth breakpoints": "Kartogram töréspontjai",
    "Choropleth classes": "Kartogram kategóriái",
    "Choropleth color palette": "Kartogram színskálája",
    "Choropleth mode": "Kartogram mód",
    "Choropleth property value": "Kartogram tulajdonságértékei",
    "Comma separated list of numbers, including min and max values.": "Vesszővel tagolt számsor, közte a legkisebb és a legnagyobb értékek.",
    "Equidistant": "Azonos távolságok",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-középpont",
    "Manual": "Manuális",
    "Number of desired classes (default 5)": "Kívánt kategóriák száma (alapértelmezés: 5)",
    "Quantiles": "Kvantilisek",
    "Show this layer in the caption": "Réteg megjelenítése a címsávban",
    "Back to preview": "Vissza az előnézethez",
    "Drawing": "Rajzolás",
    "Edit the title of the map": "Térkép címének szerkesztése",
    "Go to the homepage": "Ugrás a főoldalra",
    "Switch to edit mode": "Átkapcsolás szerkesztési módra",
    "Update who can see and edit the map": "Annak frissítése, hogy ki láthatja és szerkesztheti a térképet",
    "View": "Megtekintés",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("hu", locale)
L.setLocale("hu")
