const locale = {
    "Allow scroll wheel zoom?": "Мащабиране с колелцето на мишката?",
    "Automatic": "Автоматично",
    "Ball": "топка",
    "Cancel": "Отмени",
    "Caption": "Надпис",
    "Choose the data format": "Изберете формата на данните",
    "Choose the layer of the feature": "Изберете слой на функцията",
    "Circle": "окръжност",
    "Clustered": "Клъстер",
    "Data browser": "Data browser",
    "Default": "по подразбиране",
    "Default zoom level": "Default zoom level",
    "Default: name": "Default: name",
    "Display label": "Показване на етикет",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Показване управлението за цял екран",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Показване на търсене",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Искате ли да се покаже надпис бар?",
    "Do you want to display a minimap?": "Искате ли да се покаже миникартата?",
    "Do you want to display a panel on load?": "Искате ли да се покаже панел на зареждане?",
    "Do you want to display popup footer?": "Искате ли да се покаже изскачащ колонтитул?",
    "Do you want to display the scale control?": "Искате ли да се показва мащаб контрола?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "маркер",
    "GeoRSS (only link)": "GeoRSS (само за връзка)",
    "GeoRSS (title + image)": "GeoRSS (заглавие + изображение)",
    "Heatmap": "Топлинна карта",
    "Icon shape": "Форма на иконата",
    "Icon symbol": "Символ на иконата",
    "Inherit": "Наследи",
    "Label direction": "Посока на текста на етикета",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Нищо",
    "On the bottom": "Отдолу",
    "On the left": "Вляво",
    "On the right": "Вдясно",
    "On the top": "Отгоре",
    "Popup content template": "Popup content template",
    "Side panel": "Страничен панел",
    "Simplify": "Опрости",
    "Table": "Table",
    "always": "винаги",
    "clear": "изчисти",
    "collapsed": "collapsed",
    "color": "цвят",
    "dash array": "dash array",
    "define": "define",
    "description": "описание",
    "expanded": "expanded",
    "fill": "запълни",
    "fill color": "попълнете цвят",
    "fill opacity": "попълнете непрозрачност",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "наследи",
    "name": "име",
    "never": "никога",
    "new window": "new window",
    "no": "не",
    "on hover": "при преминаване с мишката",
    "opacity": "непрозрачност",
    "parent window": "родителски прозорец",
    "stroke": "stroke",
    "weight": "тегло",
    "yes": "да",
    "{delay} seconds": "{забавяне} сек.",
    "# one hash for main heading": "# един хеш за главната позиция",
    "## two hashes for second heading": "два хеша за втората таблица",
    "### three hashes for third heading": "# # # Три хеша за трета позиция",
    "**double star for bold**": "двойна звезда за удебеление",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "относно",
    "Action not allowed :(": "Не  позволено действие",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Добавете слой",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Разширено действия",
    "Advanced properties": "Разширени свойства",
    "All properties are imported.": "Всички свойства са внесени.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Възникна грешка",
    "Are you sure you want to cancel your changes?": "Наистина ли искате да отмените вашите промени?",
    "Are you sure you want to clone this map and all its datalayers?": "Наистина ли искате да клонирате тази карта и всички негови слоеве данни ?",
    "Are you sure you want to delete the feature?": "Сигурни ли сте, че искате да изтриете тази функция?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Сигурни ли сте, че искате да изтриете тази карта?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Преглед данни",
    "Cancel edits": "Отмени редакциите",
    "Center map on your location": "Center map on your location",
    "Change map background": "Промяна фона на картата",
    "Change tilelayers": "Променете слоевете",
    "Choose a preset": "Изберете предварително зададен",
    "Choose the format of the data to import": "Изберете формат на данните за внос",
    "Choose the layer to import in": "Избери слой за внасяне в",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Click to add a marker",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone": "Клонинг",
    "Clone of {name}": "Клонинг на {име}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "клонира тази карта",
    "Close": "Close",
    "Clustering radius": "радиус на клъстери",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Continue line",
    "Continue line (Ctrl+Click)": "Продължаване на линията (Ctrl+Click)",
    "Coordinates": "Координати",
    "Credits": "приемам като достоверен",
    "Current view instead of default map view?": "Текущ изглед, вместо по подразбиране вижте карта?",
    "Custom background": "Потребителски фон",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Интерактивни функции по подразбиране",
    "Default properties": "По подразбиране свойства",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Изтрий",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Изтриване на тази функция",
    "Delete this property on all the features": "Delete this property on all the features",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "Упътвания от тук",
    "Display measure": "Display measure",
    "Display on load": "Дисплей на зареждане",
    "Download": "Download",
    "Download data": "Изтегляне на данни",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Начертайте линия",
    "Draw a marker": "Начертайте маркер",
    "Draw a polygon": "Начертайте полигон",
    "Draw a polyline": "Начертайте полилиния",
    "Dynamic": "динамичен",
    "Dynamic properties": "Dynamic properties",
    "Edit": "Редактиране",
    "Edit feature's layer": "Редактиране функцията на слоя",
    "Edit map properties": "Редактирай свойствата на картата",
    "Edit map settings": "Редактиране на настройките на картата",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Редактирайте тази характеристика",
    "Embed and share this map": "Вграждане и споделяне тази карта",
    "Embed the map": "Вграждане на карта",
    "Empty": "Празно",
    "Error in the tilelayer URL": "Грешка в URL адреса на слоя",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Format": "формат",
    "From zoom": "От мащабиране",
    "Go to «{feature}»": "Go to «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "радиус на Топлинна карта",
    "Help": "Помощ",
    "Hide controls": "Скрий контролите",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Колко да опрости полилинията на всяко ниво увеличение (повече = по-добра производителност и по-гладко на вид, по-малко = по-точно)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Изображение с поръчкова ширина (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "изображение: {{http://image.url.com}}",
    "Import": "внасяне",
    "Import data": "Внасям данни",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Включи пълна връзка на екрана?",
    "Interaction options": "Интерактивни функции",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "Layer",
    "Layer properties": "Layer properties",
    "Licence": "Лиценз",
    "Limit bounds": "Limit bounds",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Връзка с текст: [[http://example.com|текст на връзката]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "Още контроли",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Само видими функции ще бъдат изтеглени.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Отворете тази карта в степен редактор на карта, за да предостави по-точни данни,OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "По избор Същото като цвят, ако не е настроена.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Моля, бъдете сигурни, че лицензът е съвместим с вашата употреба.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Problem in the response": "Проблем в отзивите",
    "Problem in the response format": "Проблем във формата на отговор",
    "Properties imported:": "Внесени свойства:",
    "Provide an URL here": "Представете URL тук",
    "Proxy request": "Proxy request",
    "Remote data": "отдалечена база данни",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "запазвам",
    "Save anyway": "Save anyway",
    "Save current edits": "Запиши текущите редакции",
    "Save this center and zoom": "Запази този център и размер",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "See all": "See all",
    "See data layers": "See data layers",
    "See full screen": "Виж на цял екран",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Кратко URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Покажи / скрий слой",
    "Simple link: [[http://example.com]]": "проста връзка:[[http://example.com]]",
    "Slideshow": "Slideshow",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Започнете редактиране",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Спри редактирането",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Поддържана схема",
    "Supported variables that will be dynamically replaced": "Поддържаните променливи, които ще бъдат динамично заменени",
    "TMS format": "TMS формат",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "форматиране на текст",
    "To use if remote server doesn't allow cross domain (slower)": "За да се използва, ако отдалечен сървър не позволява кръстосан домейн (по-бавно)",
    "To zoom": "За да увеличите",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Трансформация на линии",
    "Transform to polygon": "Трансформация на полигон",
    "Type of layer": "Вид на слой",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Неозаглавен слой",
    "Untitled map": "Неозаглавена карта",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Актуализиране на разрешения и редактори",
    "Url": "URL адрес",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "User content credits",
    "User interface options": "Опции на потребителския интерфейс",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Къде да отидем от тук?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "Zoom in": "Zoom in",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Намаляване на мащаба",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Увеличаване на тази характеристика",
    "Zoom to this place": "Zoom to this place",
    "attribution": "приписване",
    "by": "чрез",
    "display name": "показвано име",
    "height": "височина",
    "licence": "лиценз",
    "max East": "максимум Източен",
    "max North": "максимум Северен",
    "max South": "максимум Южен",
    "max West": "максимум Западна",
    "max zoom": "максимум мащабиране",
    "min zoom": "минимално мащабиране",
    "next": "next",
    "previous": "previous",
    "width": "широчина",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Optional.",
    "Paste your data here": "Paste your data here",
    "Please save the map first": "Please save the map first",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("bg", locale)
L.setLocale("bg")
