"""Settings for Development Server"""
from umap.settings.base import *  # pylint: disable=W0614,W0401

DEBUG = True
TEMPLATE_DEBUG = DEBUG

VAR_ROOT = "/var/www/umap"
MEDIA_ROOT = os.path.join(VAR_ROOT, "uploads")
STATIC_ROOT = os.path.join(VAR_ROOT, "static")

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.postgresql_psycopg2",
        "NAME": "umap",
    }
}
