const locale = {
    "Allow scroll wheel zoom?": "السماح بالتكبير بتمرير عجلة الفأرة؟",
    "Automatic": "تلقائي",
    "Ball": "كرة",
    "Cancel": "إلغاء",
    "Caption": "شرح",
    "Choose the data format": "اختر تنسيق البيانات",
    "Choose the layer of the feature": "اختر طبقة الشكل",
    "Circle": "دائرة",
    "Clustered": "متجمع",
    "Data browser": "متصفح البيانات",
    "Default": "افتراضي",
    "Default zoom level": "مستوى التكبير الافتراضي",
    "Default: name": "اسم: افتراضي",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "Do you want to display a minimap?",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "Do you want to display popup footer?",
    "Do you want to display the scale control?": "Do you want to display the scale control?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (only link)",
    "GeoRSS (title + image)": "GeoRSS (title + image)",
    "Heatmap": "Heatmap",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Inherit",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "None",
    "On the bottom": "في الأسفل",
    "On the left": "على اليسار",
    "On the right": "على اليمين",
    "On the top": "إلى الأعلى",
    "Popup content template": "Popup content template",
    "Side panel": "لوحة جانبية",
    "Simplify": "بسّط",
    "Table": "جدول",
    "always": "دائماً",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "لون",
    "dash array": "dash array",
    "define": "حدّد",
    "description": "تقديم",
    "expanded": "expanded",
    "fill": "fill",
    "fill color": "fill color",
    "fill opacity": "fill opacity",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "inherit",
    "name": "إسم",
    "never": "أبداً",
    "new window": "نافدة جديدة",
    "no": "لا",
    "on hover": "on hover",
    "opacity": "شفافية",
    "parent window": "parent window",
    "stroke": "stroke",
    "weight": "weight",
    "yes": "نعم",
    "{delay} seconds": "{الأجل} ثواني",
    "# one hash for main heading": "# one hash for main heading",
    "## two hashes for second heading": "## two hashes for second heading",
    "### three hashes for third heading": "### three hashes for third heading",
    "**double star for bold**": "**double star for bold**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "About",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "أضف طبقة",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Advanced actions",
    "Advanced properties": "Advanced properties",
    "All properties are imported.": "All properties are imported.",
    "Allow interactions": "يسمح بالتفاعل",
    "An error occured": "حصل خطأ",
    "Are you sure you want to cancel your changes?": "هل تريد فعلاً إلغاء تغييراتك ؟",
    "Are you sure you want to clone this map and all its datalayers?": "Are you sure you want to clone this map and all its datalayers?",
    "Are you sure you want to delete the feature?": "هل تريد فعلاً حذف الخاصية ؟",
    "Are you sure you want to delete this layer?": "هل تريد فعلاً حذف هذه الطبقة ؟",
    "Are you sure you want to delete this map?": "هل تريد فعلاً حذف هذه الخريطة ؟",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "تصفح البيانات",
    "Cancel edits": "Cancel edits",
    "Center map on your location": "Center map on your location",
    "Change map background": "Change map background",
    "Change tilelayers": "Change tilelayers",
    "Choose a preset": "Choose a preset",
    "Choose the format of the data to import": "Choose the format of the data to import",
    "Choose the layer to import in": "Choose the layer to import in",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Click to add a marker",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone": "Clone",
    "Clone of {name}": "Clone of {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Clone this map",
    "Close": "أغلق",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "واصل الخط",
    "Continue line (Ctrl+Click)": "Continue line (Ctrl+Click)",
    "Coordinates": "Coordinates",
    "Credits": "Credits",
    "Current view instead of default map view?": "Current view instead of default map view?",
    "Custom background": "Custom background",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Default properties",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "حذف",
    "Delete all layers": "حذف كل الطبقات",
    "Delete layer": "حذف طبقة",
    "Delete this feature": "حذف هذه الخاصية",
    "Delete this property on all the features": "Delete this property on all the features",
    "Delete this shape": "حذف هذا الشكل",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "Directions from here",
    "Display measure": "Display measure",
    "Display on load": "Display on load",
    "Download": "Download",
    "Download data": "تحميل بيانات",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "رسم خط",
    "Draw a marker": "رسم علامة",
    "Draw a polygon": "رسم متعدد أضلاع",
    "Draw a polyline": "Draw a polyline",
    "Dynamic": "Dynamic",
    "Dynamic properties": "Dynamic properties",
    "Edit": "Edit",
    "Edit feature's layer": "Edit feature's layer",
    "Edit map properties": "Edit map properties",
    "Edit map settings": "Edit map settings",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Edit this feature",
    "Embed and share this map": "Embed and share this map",
    "Embed the map": "Embed the map",
    "Empty": "Empty",
    "Error in the tilelayer URL": "Error in the tilelayer URL",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "الخروج من الشاشة الكاملة",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Format": "Format",
    "From zoom": "From zoom",
    "Go to «{feature}»": "Go to «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "مساعدة",
    "Hide controls": "Hide controls",
    "Home": "الصفحة الرئيسية",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Import data",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "طبقة",
    "Layer properties": "خصوصيات طبقة",
    "Licence": "الترخيص",
    "Limit bounds": "Limit bounds",
    "Link to…": "الرابط إلى...",
    "Link with text: [[http://example.com|text of the link]]": "Link with text: [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "More controls",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Only visible features will be downloaded.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Please be sure the licence is compliant with your use.",
    "Please choose a format": "الرجاء إختيار الشكل",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Problem in the response": "Problem in the response",
    "Problem in the response format": "Problem in the response format",
    "Properties imported:": "Properties imported:",
    "Provide an URL here": "Provide an URL here",
    "Proxy request": "Proxy request",
    "Remote data": "Remote data",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "تسجيل",
    "Save anyway": "Save anyway",
    "Save current edits": "Save current edits",
    "Save this center and zoom": "Save this center and zoom",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "See all": "See all",
    "See data layers": "See data layers",
    "See full screen": "See full screen",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Short URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Show/hide layer",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Start editing",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop editing",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "To zoom",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Untitled layer",
    "Untitled map": "Untitled map",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Update permissions and editors",
    "Url": "Url",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "User content credits",
    "User interface options": "User interface options",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "Zoom in": "Zoom in",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Zoom out",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Zoom to this feature",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "height",
    "licence": "licence",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "next",
    "previous": "previous",
    "width": "width",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "1 day": "1 day",
    "1 hour": "ساعة",
    "5 min": "5 دقائق",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Optional.",
    "Paste your data here": "Paste your data here",
    "Please save the map first": "Please save the map first",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("ar", locale)
L.setLocale("ar")
