const locale = {
    "Allow scroll wheel zoom?": "Tillåt zoom med musens rullhjul?",
    "Automatic": "Automatisk",
    "Ball": "Knappnål",
    "Cancel": "Avbryt",
    "Caption": "Sidfotsfält",
    "Choose the data format": "Välj dataformat",
    "Choose the layer of the feature": "Välj lager för objektet",
    "Circle": "Cirkel",
    "Clustered": "Kluster",
    "Data browser": "Databläddrare",
    "Default": "Förvalt värde",
    "Default zoom level": "Förvald zoomnivå",
    "Default: name": "Namn förvalt",
    "Display label": "Visa etikett",
    "Display the control to open OpenStreetMap editor": "Visa knapp för att öppna OpenStreetMap redigerare",
    "Display the data layers control": "Visa verktyg för datalager",
    "Display the embed control": "Visa verktyg för att bädda in och dela",
    "Display the fullscreen control": "Visa verktyg för fullskärm",
    "Display the locate control": "Visa lokaliseringsverktyg",
    "Display the measure control": "Visa mätverktyg",
    "Display the search control": "Visa sökverktyg",
    "Display the tile layers control": "Visa verktyg för bakgrundskarta (tiles)",
    "Display the zoom control": "Visa zoomverktyg",
    "Do you want to display a caption bar?": "Vill du visa ett sidfotsfält?",
    "Do you want to display a minimap?": "Vill du visa en minikarta?",
    "Do you want to display a panel on load?": "Vill du visa en panel vid uppstart?",
    "Do you want to display popup footer?": "Vill du visa en sidfot-popup?",
    "Do you want to display the scale control?": "Vill du visa skalstocken?",
    "Do you want to display the «more» control?": "Vill du visa panelen med \"Fler verktyg\"?",
    "Drop": "Dropp-nål",
    "GeoRSS (only link)": "GeoRSS (enbart länk)",
    "GeoRSS (title + image)": "GeoRSS (titel + bild)",
    "Heatmap": "Värmekarta",
    "Icon shape": "Ikonform",
    "Icon symbol": "Ikonsymbol",
    "Inherit": "Ärv",
    "Label direction": "Riktning för etikett",
    "Label key": "Etikettnyckel",
    "Labels are clickable": "Klickbara etiketter",
    "None": "Ingen",
    "On the bottom": "Under",
    "On the left": "Till vänster",
    "On the right": "Till höger",
    "On the top": "Ovanför",
    "Popup content template": "Mall för popup-innehåll",
    "Side panel": "Sidopanel",
    "Simplify": "Förenkla",
    "Table": "Tabell",
    "always": "alltid",
    "clear": "återställ",
    "collapsed": "minimerad",
    "color": "färg",
    "dash array": "streckad linje-stil",
    "define": "anpassa",
    "description": "beskrivning",
    "expanded": "utökad",
    "fill": "fyll",
    "fill color": "fyllnadsfärg",
    "fill opacity": "fyllsynlighet",
    "hidden": "dold",
    "iframe": "IFrame (inbäddad html-ram)",
    "inherit": "ärv",
    "name": "namn",
    "never": "aldrig",
    "new window": "nytt fönster",
    "no": "nej",
    "on hover": "vid hovring",
    "opacity": "synlighet",
    "parent window": "föräldrafönster",
    "stroke": "streck",
    "weight": "tjocklek",
    "yes": "ja",
    "{delay} seconds": "{delay} sekunder",
    "# one hash for main heading": "# en fyrkant för huvudrubrik",
    "## two hashes for second heading": "## två fyrkanter för andra rubrik",
    "### three hashes for third heading": "### tre fyrkanter för tredje rubrik",
    "**double star for bold**": "**dubbla stjärntecken för fetstil**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommaseparerad lista med nummer som definierar mönstret för den streckade linjen. Ex: \"5, 10, 15\"",
    "About": "Om kartan",
    "Action not allowed :(": "Åtgärden är inte tillåten :(",
    "Activate slideshow mode": "Aktivera bildspelsläge",
    "Add a layer": "Lägg till lager",
    "Add a line to the current multi": "Lägg till en linje till aktuell multi",
    "Add a new property": "Lägg till en ny egenskap",
    "Add a polygon to the current multi": "Lägg till en polygon till aktuell multi",
    "Advanced actions": "Avancerade åtgärder",
    "Advanced properties": "Avancerade egenskaper",
    "All properties are imported.": "Alla attribut importeras.",
    "Allow interactions": "Tillåt interaktion",
    "An error occured": "Ett fel inträffade",
    "Are you sure you want to cancel your changes?": "Är du säker på att du vill avbryta dina ändringar?",
    "Are you sure you want to clone this map and all its datalayers?": "Är du säker på att du vill skapa en kopia av kartan och alla datalager?",
    "Are you sure you want to delete the feature?": "Är du säker på att du vill radera objektet?",
    "Are you sure you want to delete this layer?": "Är du säker på att du vill radera lagret?",
    "Are you sure you want to delete this map?": "Är du säker på att du vill radera denna karta?",
    "Are you sure you want to delete this property on all the features?": "Är du säker på att du vill radera denna egenskap för alla objekt?",
    "Are you sure you want to restore this version?": "Är du säker på att du vill återställa till den här versionen?",
    "Attach the map to my account": "Koppla kartan till mitt konto",
    "Auto": "Automatiskt",
    "Autostart when map is loaded": "Starta automatiskt när kartan lästs in.",
    "Bring feature to center": "Centrera objektet",
    "Browse data": "Bläddra i datat",
    "Cancel edits": "Avbryt ändringar",
    "Center map on your location": "Centrera kartan till din plats",
    "Change map background": "Ändra kartbakgrund",
    "Change tilelayers": "Byt bakgrundskarta",
    "Choose a preset": "Välj förinställning",
    "Choose the format of the data to import": "Välj dataformat för importen",
    "Choose the layer to import in": "Välj lager att importera till",
    "Click last point to finish shape": "Klicka på sista punkten för att slutföra formen",
    "Click to add a marker": "Klicka för att lägga till en markör",
    "Click to continue drawing": "Klicka för att fortsätta rita",
    "Click to edit": "Klicka för att redigera",
    "Click to start drawing a line": "Klicka för att börja rita en linje",
    "Click to start drawing a polygon": "Klicka för att börja rita en polygon",
    "Clone": "Duplicera",
    "Clone of {name}": "Kopia av {name}",
    "Clone this feature": "Kopiera detta objekt",
    "Clone this map": "Skapa en kopia av kartan",
    "Close": "Stäng",
    "Clustering radius": "Klusterradie",
    "Comma separated list of properties to use when filtering features": "Kommaseparerad lista med attribut, som används vid filtrering av objekt",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma, tabb eller semikolon separerade värden. SRS WGS84 är underförstått. Bara punktgeometrier importeras. Importen letar kolumnrubriker som startar med «lat» eller «lon», ej skiftlägeskänslig. Övriga kolumner importeras som attribut.",
    "Continue line": "Fortsätt linjen",
    "Continue line (Ctrl+Click)": "Fortsätt linjen (Ctrl+klick)",
    "Coordinates": "Koordinater",
    "Credits": "Upphov och erkännanden",
    "Current view instead of default map view?": "Nuvarande vy istället för den förinställda vyn?",
    "Custom background": "Anpassad bakgrund",
    "Data is browsable": "Data är tillgängligt för bläddring",
    "Default interaction options": "Förinställda alternativ för interaktion",
    "Default properties": "Standardegenskaper",
    "Default shape properties": "Förinställda formategenskaper",
    "Define link to open in a new window on polygon click.": "Sätt länk att öppna i ett nytt fönster vid klick.",
    "Delay between two transitions when in play mode": "Tid mellan övergångar i uppspelningsläge",
    "Delete": "Radera",
    "Delete all layers": "Radera alla lager",
    "Delete layer": "Radera lager",
    "Delete this feature": "Radera objektet",
    "Delete this property on all the features": "Ta bort denna egenskap från alla objekt",
    "Delete this shape": "Radera figuren",
    "Delete this vertex (Alt+Click)": "Radera noden (Alt+klick)",
    "Directions from here": "Vägbeskrivning härifrån",
    "Display measure": "Visa mått",
    "Display on load": "Visa vid uppstart",
    "Download": "Ladda ned",
    "Download data": "Ladda ned data",
    "Drag to reorder": "Dra för att sortera om",
    "Draw a line": "Rita en linje",
    "Draw a marker": "Rita en markör",
    "Draw a polygon": "Rita en polygon",
    "Draw a polyline": "Rita en multilinje",
    "Dynamic": "Dynamisk",
    "Dynamic properties": "Dynamiska egenskaper",
    "Edit": "Redigera",
    "Edit feature's layer": "Redigera objektets lager",
    "Edit map properties": "Redigera kartans egenskaper",
    "Edit map settings": "Redigera kartans inställningar",
    "Edit properties in a table": "Redigera attribut i en tabell",
    "Edit this feature": "Redigera objektet",
    "Embed and share this map": "Bädda in och dela den här kartan",
    "Embed the map": "Bädda in kartan",
    "Empty": "Töm",
    "Error in the tilelayer URL": "Fel i webbadressen för bakgrundskartan (tile-lagret)",
    "Error while fetching {url}": "Fel vid hämtning av {url}",
    "Exit Fullscreen": "Lämna helskärmsläge",
    "Extract shape to separate feature": "Extrahera figuren till separat objekt",
    "Fetch data each time map view changes.": "Hämta data varje gång kartvisningen ändras.",
    "Filter keys": "Filternycklar",
    "Format": "Format",
    "From zoom": "Från zoom",
    "Go to «{feature}»": "Gå till «{feature}»",
    "Heatmap intensity property": "Värmekartans intensitet",
    "Heatmap radius": "Värmekartans radie",
    "Help": "Hjälp",
    "Hide controls": "Dölj verktygsfälten",
    "Home": "Hem",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hur mycket ska polygoner och multilinjer förenklas vid olika zoom-nivåer? (Mer = bättre prestanda och mjukare utseende, Mindre = mer exakt)",
    "If false, the polygon will act as a part of the underlying map.": "Om falskt, visas polygonen som en del av bakgrundskartan.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe med specifik höjd (i pixlar): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe med specifik höjd och bredd (i pixlar): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe (inbäddad ram): {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Bild med specifik bredd (i pixlar): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Bild: {{http://image.url.com}}",
    "Import": "Importera",
    "Import data": "Importera data",
    "Import in a new layer": "Importera till ett nytt lager",
    "Imports all umap data, including layers and settings.": "Importerar allt uMap data, inklusive lager och inställningar.",
    "Include full screen link?": "Inkludera länk till fullskärmssida?",
    "Interaction options": "Alternativ för interaktion",
    "Invalid umap data": "Ogiltigt uMap-data",
    "Invalid umap data in {filename}": "Ogiltigt uMap-data i {filename}",
    "Keep current visible layers": "Bevara nuvarande synliga lager",
    "Latitude": "Latitud",
    "Layer": "Lager",
    "Layer properties": "Lageregenskaper",
    "Licence": "Licens",
    "Limit bounds": "Begränsa visningsområdet",
    "Link to…": "Länk till…",
    "Link with text: [[http://example.com|text of the link]]": "Hyperlänk med egen text: [[https://www.exempel.se|Länktext]]",
    "Long credits": "Upphov och erkännanden (sidfotsfält)",
    "Longitude": "Longitud",
    "Make main shape": "Gör huvudformen",
    "Manage layers": "Hantera lager",
    "Map background credits": "Bakgrundskartans upphov och erkännanden",
    "Map has been attached to your account": "Kartan har kopplats till ditt konto.",
    "Map has been saved!": "Kartan har sparats!",
    "Map user content has been published under licence": "Kartan användarinnehåll har publicerats under licens",
    "Map's editors": "Kartans redaktörer",
    "Map's owner": "Kartans ägare",
    "Merge lines": "Sammanfoga linjer",
    "More controls": "Fler verktyg",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Giltigt CSS värde krävs (ex: DarkBlue eller #123456)",
    "No licence has been set": "Ingen licens har valts.",
    "No results": "Inga träffar tyvärr. Har du stavat rätt?",
    "Only visible features will be downloaded.": "Endast synliggjorda kartobjekt kommer att laddas ner.",
    "Open download panel": "Öppna nedladdningspanelen",
    "Open link in…": "Öppna länk med...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Öppna detta kartområde i en redigerare för att bidra med mer och bättre data till OpenStreetMap.",
    "Optional intensity property for heatmap": "Valfritt intensitetsläge för värmekartan",
    "Optional. Same as color if not set.": "Valfritt. Annars samma som färg ovan.",
    "Override clustering radius (default 80)": "Åsidosätt kluster radie (80 förvalt)",
    "Override heatmap radius (default 25)": "Åsidosätt värmekartans radie (25 förvalt)",
    "Please be sure the licence is compliant with your use.": "Säkerställ att din användning av datat överensstämmer med dess licens eller upphovsrätt.",
    "Please choose a format": "Välj ett format",
    "Please enter the name of the property": "Ange namnet på egenskapen",
    "Please enter the new name of this property": "Ange det nya namnet för den här egenskapen",
    "Problem in the response": "Servern svarade med ett fel",
    "Problem in the response format": "Fel format i serversvaret",
    "Properties imported:": "Attribut som importeras:",
    "Provide an URL here": "Ange en webbadress",
    "Proxy request": "Proxyförfrågan",
    "Remote data": "Fjärrdata",
    "Remove shape from the multi": "Radera figuren från aktuell multi",
    "Rename this property on all the features": "Byt namn på den här egenskapen för alla objekt",
    "Replace layer content": "Ersätt lagrets innehåll",
    "Restore this version": "Återställ denna version",
    "Save": "Spara",
    "Save anyway": "Spara ändå",
    "Save current edits": "Spara nuvarande ändringar",
    "Save this center and zoom": "Spara aktuell vy och zoomnivå",
    "Save this location as new feature": "Spara denna plats som nytt kartobjekt",
    "Search a place name": "Sök efter ett platsnamn",
    "Search location": "Sök plats",
    "See all": "Se alla",
    "See data layers": "Visa datalager",
    "See full screen": "Öppna i fullskärm",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Slå av för att dölja lagret från bilspelsvisning, databläddrare, popup-navigering etc",
    "Shape properties": "Formategenskaper",
    "Short URL": "Kort URL",
    "Short credits": "Upphov och erkännanden (kort)",
    "Show/hide layer": "Visa/dölj lager",
    "Simple link: [[http://example.com]]": "Enkel hyperlänk: [[https://www.exempel.se]]",
    "Slideshow": "Bildspelsläge",
    "Sort key": "Sorteringsnyckel",
    "Split line": "Dela upp linje",
    "Start a hole here": "Infoga ett hål här",
    "Start editing": "Börja redigera",
    "Start slideshow": "Starta bildspel",
    "Stop editing": "Avsluta redigering",
    "Stop slideshow": "Stoppa bildspel",
    "Supported scheme": "Schema som stöds",
    "Supported variables that will be dynamically replaced": "Variabler som stöds att ersättas dynamiskt",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Textfärg för klusteretiketten",
    "Text formatting": "Textformatering",
    "To use if remote server doesn't allow cross domain (slower)": "Att använda om fjärrservern inte tillåter gränsöverskridande domäner (långsammare)",
    "To zoom": "Till zoom",
    "Transfer shape to edited feature": "Överför format till redigerat objekt",
    "Transform to lines": "Transformera till linjer",
    "Transform to polygon": "Transformera till polygon",
    "Type of layer": "Lagertyp",
    "Unable to detect format of file {filename}": "Misslyckades att känna igen filformatet på filen {filename}",
    "Untitled layer": "Namnlöst lager",
    "Untitled map": "Namnlös karta",
    "Update permissions": "Uppdatera behörigheter",
    "Update permissions and editors": "Uppdatera behörigheter och redaktörer",
    "Url": "URL",
    "Use current bounds": "Använd nuvarande visningsgränser",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Använd platshållare med objektattribut i klammerparenteser, ex. &#123;namn&#125;. De ersätts dynamiskt med objektets motsvarande värde.",
    "User content credits": "Användarinnehållets upphov och erkännanden",
    "User interface options": "Alternativ för användargränssnitt",
    "Versions": "Versioner",
    "View Fullscreen": "Visa fullskärm",
    "Where do we go from here?": "Hela världen ligger öppen. Sluta aldrig lära, utforska och dela med dig. Vart tar vi vägen idag?",
    "Whether to display or not polygons paths.": "Om polygonens konturlinje ska ritas ut eller inte.",
    "Whether to fill polygons with color.": "Om polygonens yta ska fyllas med färg.",
    "Who can edit": "Vem kan redigera",
    "Who can view": "Vem kan visa",
    "Will be displayed in the bottom right corner of the map": "Visas i nedre högra hörnet av kartan",
    "Will be visible in the caption of the map": "Visas i sidfotsfältet under kartan",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Hoppsan! \nNågon annan verkar ha hunnit före och redigerat i kartan redan! Du kan spara ändå, men det kommer att radera ändringar som någon annan har gjort.",
    "Zoom in": "Zooma in",
    "Zoom level for automatic zooms": "Zoomnivå för automatisk zoom",
    "Zoom out": "Zooma ut",
    "Zoom to layer extent": "Zooma till lagrets omfång",
    "Zoom to the next": "Panorera till nästa",
    "Zoom to the previous": "Panorera till föregående",
    "Zoom to this feature": "Zooma till detta objekt",
    "Zoom to this place": "Zooma till denna plats",
    "attribution": "attribution",
    "by": "av",
    "display name": "namn",
    "height": "höjd",
    "licence": "licens",
    "max East": "max Öst",
    "max North": "max Nord",
    "max South": "max Syd",
    "max West": "max Väst",
    "max zoom": "maxgräns zoom",
    "min zoom": "minimigräns zoom",
    "next": "nästa",
    "previous": "föregående",
    "width": "bredd",
    "{count} errors during import: {message}": "{count} fel under importen: {message}",
    "Measure distances": "Mät avstånd",
    "NM": "M",
    "kilometers": "kilometer",
    "km": "km",
    "mi": "miles",
    "miles": "engelska mil",
    "nautical miles": "nautiska mil",
    "1 day": "1 dag",
    "1 hour": "1 timme",
    "5 min": "5 min",
    "Cache proxied request": "Cachelagra proxyförfrågan",
    "No cache": "Ingen cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (stor)",
    "Popup content style": "Innehållsstil för popupfönster",
    "Popup shape": "Popup format",
    "Skipping unknown geometry.type: {type}": "Okänd geometrityp ignoreras: {type}",
    "Optional.": "Valfri.",
    "Paste your data here": "Klistra in data här",
    "Please save the map first": "Spara kartan först, tack &#128521;",
    "Feature identifier key": "Unik nyckel för objekt",
    "Open current feature on load": "Öppna nuvarande objekt vid uppstart",
    "Permalink": "Permanent länk",
    "The name of the property to use as feature unique identifier.": "Egenskapen att använda som unik nyckel för objekten (ex: \"id\")",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acre (ung. tunnland)",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} kvadrat-mile",
    "{area}&#8239;yd&sup2;": "{area} kvadrat-yard",
    "{distance}&#8239;NM": "{distance} M",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} engelska mil",
    "{distance}&#8239;yd": "{distance} yard",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(längd: {measure})",
    "Animated transitions": "Animerade övergångar",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Kartan har stjärnmärkts",
    "Map has been unstarred": "Stjärnmärkningen har tagits bort ",
    "Opacity": "Synlighet",
    "Star this map": "Stjärnmärk kartan",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direktlänk",
    "Export options": "Exportalternativ",
    "The zoom and center have been modified.": "Zoom och centrering har ändrats.",
    "Congratulations, your map has been created!": "Grattis, din karta har skapats!",
    "Copy link": "Kopiera länk",
    "Email": "E-post ",
    "Secret edit link copied to clipboard!": "Hemlig redigeringslänk kopierad till klippbordet",
    "Send me the link": "Skicka länken till mig",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Din karta har skapats! Eftersom du inte är inloggad, här är din hemliga länk för att redigera kartan. Spara den på ett säkert ställe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "Ikonsynlighet",
    "*single star for italic*": "*en asterisk för kursivt*",
    "--- for a horizontal rule": "--- för en vågrät linje",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("sv", locale)
L.setLocale("sv")
