# Generated by Django 1.10.3 on 2016-11-26 16:11
from __future__ import unicode_literals

from django.db import migrations


def add_licence(apps, *args):
    Licence = apps.get_model('umap', 'Licence')
    if Licence.objects.count():
        return
    Licence(
        name='ODbL',
        details='http://opendatacommons.org/licenses/odbl/').save()


class Migration(migrations.Migration):

    dependencies = [
        ('umap', '0003_add_tilelayer'),
    ]

    operations = [
        migrations.RunPython(add_licence),
    ]
