# Generated by Django 4.2.2 on 2023-08-16 05:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0011_alter_map_edit_status_alter_map_share_status"),
    ]

    operations = [
        migrations.AddField(
            model_name="datalayer",
            name="settings",
            field=models.JSONField(
                blank=True, default=dict, null=True, verbose_name="settings"
            ),
        ),
    ]
