const locale = {
    "Allow scroll wheel zoom?": "Дозволити зміну масштабу колесом миші?",
    "Automatic": "Автоматично",
    "Ball": "Шпилька",
    "Cancel": "Скасувати",
    "Caption": "Заголовок",
    "Choose the data format": "Виберіть формат даних",
    "Choose the layer of the feature": "Виберіть шар для об’єкта",
    "Circle": "Коло",
    "Clustered": "Кластеризованний",
    "Data browser": "Оглядач даних",
    "Default": "Типово",
    "Default zoom level": "Типовий масштаб",
    "Default: name": "Типова назва",
    "Display label": "Показувати підписи",
    "Display the control to open OpenStreetMap editor": "Показувати кнопку переходу в редактор OpenStreetMap",
    "Display the data layers control": "Показувати перемикач шарів даних",
    "Display the embed control": "Показувати вбудовані елементи керування",
    "Display the fullscreen control": "Показувати перемикач повноекранного режиму",
    "Display the locate control": "Показувати кнопку визначення місцезнаходження",
    "Display the measure control": "Показувати інструменти вимірювання",
    "Display the search control": "Показувати засоби для пошуку",
    "Display the tile layers control": "Показувати перемикач шарів",
    "Display the zoom control": "Показувати елементи керування масштабуванням",
    "Do you want to display a caption bar?": "Показувати рядок заголовку?",
    "Do you want to display a minimap?": "Показувати мінімапу?",
    "Do you want to display a panel on load?": "Показувати панель керування при завантаженні?",
    "Do you want to display popup footer?": "Хочете використовувати спливаючу підказку знизу?",
    "Do you want to display the scale control?": "Показувати шкалу відстаней?",
    "Do you want to display the «more» control?": "Показувати кнопку «Більше»?",
    "Drop": "Крапля",
    "GeoRSS (only link)": "GeoRSS (лише посилання)",
    "GeoRSS (title + image)": "GeoRSS (заголовок та зображення)",
    "Heatmap": "Теплова мапа",
    "Icon shape": "Форма значка",
    "Icon symbol": "Символ значка",
    "Inherit": "Успадковувати",
    "Label direction": "Напрямок підпису",
    "Label key": "Підпис ключа",
    "Labels are clickable": "Мітки клікабельні",
    "None": "Ні",
    "On the bottom": "Знизу",
    "On the left": "Ліворуч",
    "On the right": "Праворуч",
    "On the top": "Зверху",
    "Popup content template": "Шаблон спливаючої підказки",
    "Side panel": "Бічна панель",
    "Simplify": "Спростити",
    "Table": "Таблиця",
    "always": "завжди",
    "clear": "очистити",
    "collapsed": "згорнуто",
    "color": "колір",
    "dash array": "штрихи",
    "define": "визначити",
    "description": "опис",
    "expanded": "розгорнуто",
    "fill": "заливка",
    "fill color": "колір заливки",
    "fill opacity": "непрозорість заливки",
    "hidden": "приховано",
    "iframe": "iframe",
    "inherit": "успадковувати",
    "name": "назва",
    "never": "ніколи",
    "new window": "new window",
    "no": "ні",
    "on hover": "при наведенні",
    "opacity": "непрозорість",
    "parent window": "батьківське вікно",
    "stroke": "штрихи",
    "weight": "товщина",
    "yes": "так",
    "{delay} seconds": "{delay} секунди",
    "# one hash for main heading": "# один знак решітки — основний заголовок",
    "## two hashes for second heading": "## два знаки решітки — підзаголовок",
    "### three hashes for third heading": "### три знаки решітки — підзаголовок підзаголовка",
    "**double star for bold**": "**подвійні зірочки — жирний**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Розділені комами числа, що представляють шаблон довжини штрихів та проміжків пунктирної лінії. Напр.: \"5, 10,15\".",
    "About": "Про це",
    "Action not allowed :(": "Дія недоступна :(",
    "Activate slideshow mode": "Активувати режим слайдшоу",
    "Add a layer": "Додати шар",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Додати новий параметр",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Додаткові дії",
    "Advanced properties": "Розширенні параметри",
    "All properties are imported.": "Усі параметри імпортовано.",
    "Allow interactions": "Дозволити взаємодію",
    "An error occured": "Виникла помилка",
    "Are you sure you want to cancel your changes?": "Ви впевнені, що хочете скасувати зроблені зміни?",
    "Are you sure you want to clone this map and all its datalayers?": "Ви впевнені, що бажаєте скопіювати цю мапу з її усіма даними",
    "Are you sure you want to delete the feature?": "Ви впевнені, що хочете вилучити об’єкт?",
    "Are you sure you want to delete this layer?": "Ви впевнені, що хочете вилучити цей шар?",
    "Are you sure you want to delete this map?": "Ви впевнені, що хочете вилучити мапу?",
    "Are you sure you want to delete this property on all the features?": "Ви впевнені, що хочете вилучити цей параметр у всіх об’єктів?",
    "Are you sure you want to restore this version?": "Ви впевнені, що хочете відновити цю версію?",
    "Attach the map to my account": "Додати мапу до мого облікового запису",
    "Auto": "Автоматично",
    "Autostart when map is loaded": "Автозапуск при завантаженні мапи",
    "Bring feature to center": "Помістити об’єкт в центр",
    "Browse data": "Огляд даних",
    "Cancel edits": "Скасувати правки",
    "Center map on your location": "Центрувати мапу за Вашим місцем розташування",
    "Change map background": "Змінити фонову мапу",
    "Change tilelayers": "Вибрати фонові шари",
    "Choose a preset": "Виберіть шаблон",
    "Choose the format of the data to import": "Виберіть формат даних для імпорту",
    "Choose the layer to import in": "Виберіть шар для імпорту в нього",
    "Click last point to finish shape": "Клацніть на останній точці, щоб завершити",
    "Click to add a marker": "Клацніть, щоб додати позначку",
    "Click to continue drawing": "Клацайте, щоб продовжити креслення",
    "Click to edit": "Натисніть для редагування",
    "Click to start drawing a line": "Клацайте, щоб продовжити креслення",
    "Click to start drawing a polygon": "Клацніть, щоб почати креслення багатокутника",
    "Clone": "Створити копію",
    "Clone of {name}": "Копія {name}",
    "Clone this feature": "Клонувати цей об’єкт",
    "Clone this map": "Створити копію мапи",
    "Close": "Закрити",
    "Clustering radius": "Радіус кластеризації",
    "Comma separated list of properties to use when filtering features": "Список параметрів, розділених комами, для використання при фільтрації",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Як роздільник використовуються коми, табуляції і крапки з комою.  Застосовується датум WGS84. Імпорт переглядає заголовок на наявність полів «lat» та «lon», регістр не має значення.  Усі інші поля імпортуються як параметри.",
    "Continue line": "Продовжити лінію",
    "Continue line (Ctrl+Click)": "Продовжити лінію (Ctrl+клацання)",
    "Coordinates": "Координати",
    "Credits": "Авторські права / подяки",
    "Current view instead of default map view?": "Поточний вид замість типового виду мапи?",
    "Custom background": "Користувацька фонова мапа",
    "Data is browsable": "Дані можна переглядати",
    "Default interaction options": "Типові параметри взаємодії",
    "Default properties": "Типові параметри",
    "Default shape properties": "Типові параметри полігону",
    "Define link to open in a new window on polygon click.": "Задати посилання для відкриття нового вікна при клацанні на полігоні.",
    "Delay between two transitions when in play mode": "Затримка між переходами в режими відтворення",
    "Delete": "Вилучити",
    "Delete all layers": "Вилучити всі шари",
    "Delete layer": "Вилучити шар",
    "Delete this feature": "Вилучити цей об’єкт",
    "Delete this property on all the features": "Вилучити цей параметр у всіх об’єктів",
    "Delete this shape": "Вилучити цей полігон",
    "Delete this vertex (Alt+Click)": "Вилучити цю вершину (Alt+клік)",
    "Directions from here": "Маршрут звідси",
    "Display measure": "Показати вимірювання",
    "Display on load": "Показувати під час завантаження",
    "Download": "Звантажити",
    "Download data": "Звантажити дані",
    "Drag to reorder": "Перетягніть, щоб змінити порядок",
    "Draw a line": "Креслити лінію",
    "Draw a marker": "Додати позначку",
    "Draw a polygon": "Накреслити полігон",
    "Draw a polyline": "Накреслити ламану",
    "Dynamic": "Динамічний",
    "Dynamic properties": "Динамічні властивості",
    "Edit": "Редагувати",
    "Edit feature's layer": "Змінити шар об’єкту",
    "Edit map properties": "Змінити параметри мапи",
    "Edit map settings": "Змінити налаштування мапи",
    "Edit properties in a table": "Редагувати параметри в таблиці",
    "Edit this feature": "Редагувати цей об’єкт",
    "Embed and share this map": "Вбудувати мапу та поділитися нею",
    "Embed the map": "Вбудувати мапу",
    "Empty": "Очистити",
    "Error in the tilelayer URL": "Помилка в посиланні на шар мапи",
    "Error while fetching {url}": "Помилка при отриманні {url}",
    "Exit Fullscreen": "Вийти з повноекранного режиму",
    "Extract shape to separate feature": "Виокремити полігон в окремий об’єкт",
    "Fetch data each time map view changes.": "Запитувати нові дані під час кожного оновлення мапи.",
    "Filter keys": "Фільтрувати ключі",
    "Format": "Формат",
    "From zoom": "З масштабу",
    "Go to «{feature}»": "Перейти до «{feature}»",
    "Heatmap intensity property": "Параметр інтенсивності теплової мапи",
    "Heatmap radius": "Радіус для теплової мапи",
    "Help": "Довідка",
    "Hide controls": "Прибрати елементи керування",
    "Home": "Головна",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Наскільки сильно спрощувати лінії на кожному масштабі (більше значення — більша швидкість, але виглядає гірше; менше значення — більш точне зображення)",
    "If false, the polygon will act as a part of the underlying map.": "Якщо ні, тоді полігон буде виглядати як частина мапи",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe із зазначенням висоти (в пікселях): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe з власними висотою та шириною (у пікселях): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Зображення із зазначенням ширини (в пікселях): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Зображення: {{http://image.url.com}}",
    "Import": "Імпорт",
    "Import data": "Імпорт даних",
    "Import in a new layer": "Імпортувати в новий шар",
    "Imports all umap data, including layers and settings.": "Імпортувати всі дані, включаючи інформацію про шари та налаштування.",
    "Include full screen link?": "Долучити посилання на повноекранний вид?",
    "Interaction options": "Параметри взаємодії",
    "Invalid umap data": "Невірні umap-дані",
    "Invalid umap data in {filename}": "Невірні umap-дані у файлі {filename}",
    "Keep current visible layers": "Залишити поточні видимі шари",
    "Latitude": "Широта",
    "Layer": "Шар",
    "Layer properties": "Параметри шару",
    "Licence": "Ліцензія",
    "Limit bounds": "Встановлення меж",
    "Link to…": "Послатись…",
    "Link with text: [[http://example.com|text of the link]]": "Посилання з текстом: [[http://example.com|текст для посилання]]",
    "Long credits": "Повний опис прав/подяки",
    "Longitude": "Довгота",
    "Make main shape": "Утворити основну форму",
    "Manage layers": "Керування шарами",
    "Map background credits": "Права/подяки на фонову мапу",
    "Map has been attached to your account": "Мапа була прикріплена до Вашого облікового запису",
    "Map has been saved!": "Мапу збережено!",
    "Map user content has been published under licence": "Картографічні дані користувача опубліковані згідно ліцензії",
    "Map's editors": "Редактори мапи",
    "Map's owner": "Власник мапи",
    "Merge lines": "Об’єднати лінії",
    "More controls": "Інші елементи керування",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Повинно бути чинне CSS-значення (на кшталт DarkBlue чи #123456)",
    "No licence has been set": "Ліцензію не було зазначено",
    "No results": "Немає результатів",
    "Only visible features will be downloaded.": "Будуть завантажені лише видимі об’єкти.",
    "Open download panel": "Відкрити панель звантаження",
    "Open link in…": "Відкрити посилання у…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Відкрийте цю частину мапи в редакторі OpenStreetMap, щоб поліпшити дані",
    "Optional intensity property for heatmap": "Додаткові параметри інтенсивності теплової мапи",
    "Optional. Same as color if not set.": "Додатково.  Якщо не вибрано, то як колір.",
    "Override clustering radius (default 80)": "Перевизначити радіус кластеризації (типово 80)",
    "Override heatmap radius (default 25)": "Перевизначити радіус для теплової мапи (типово 25)",
    "Please be sure the licence is compliant with your use.": "Переконайтеся, що ліцензія відповідає правилам використання.",
    "Please choose a format": "Будь ласка, виберіть формат",
    "Please enter the name of the property": "Будь ласка, введіть назву параметра",
    "Please enter the new name of this property": "Будь ласка, введіть нову назву параметра",
    "Problem in the response": "Проблема з відповіддю",
    "Problem in the response format": "Формат відповіді не розпізнано",
    "Properties imported:": "Імпортовані параметри:",
    "Provide an URL here": "Вкажіть посилання тут",
    "Proxy request": "Запит проксі",
    "Remote data": "Віддалені дані",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Перейменувати цей параметр у всіх об’єктів",
    "Replace layer content": "Замінити вміст шару",
    "Restore this version": "Відновити цю версію",
    "Save": "Зберегти",
    "Save anyway": "Зберегти в будь-якому випадку",
    "Save current edits": "Зберегти поточні правки",
    "Save this center and zoom": "Зберегти такі центрування та масштаб",
    "Save this location as new feature": "Зберегти місце розташування як новий об’єкт",
    "Search a place name": "Шукати назву місця",
    "Search location": "Пошук місця",
    "See all": "Переглянути усе",
    "See data layers": "Подивитися шари даних",
    "See full screen": "Дивитися в повноекранному режимі",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Встановіть false, щоб приховати шар в слайдшоу, в перегляді даних та навігації…",
    "Shape properties": "Параметри полігона",
    "Short URL": "Коротке посилання",
    "Short credits": "Короткий опис прав/подяки",
    "Show/hide layer": "Показати/приховати шар",
    "Simple link: [[http://example.com]]": "Просте посилання: [[http://example.com]]",
    "Slideshow": "Слайдшоу",
    "Sort key": "Ключ сортування",
    "Split line": "Розрізати лінію",
    "Start a hole here": "Почати отвір звідси",
    "Start editing": "Почати редагування",
    "Start slideshow": "Почати слайдшоу",
    "Stop editing": "Зупинити редагування",
    "Stop slideshow": "Зупинити слайдшоу",
    "Supported scheme": "Підтримувана схема",
    "Supported variables that will be dynamically replaced": "Підтримувані змінні для автоматичної заміни",
    "TMS format": "Формат TMS",
    "Text color for the cluster label": "Колір тексту для позначок кластера",
    "Text formatting": "Форматування тексту",
    "To use if remote server doesn't allow cross domain (slower)": "Якщо віддалений сервер не дозволяє крос-домен (повільно)",
    "To zoom": "Масштабувати",
    "Transfer shape to edited feature": "Перетворити полігон у редагований об’єкт",
    "Transform to lines": "Перетворити на лінію",
    "Transform to polygon": "Перетворити на полігон",
    "Type of layer": "Тип шару",
    "Unable to detect format of file {filename}": "Не вдається визначити формат файлу {filename}",
    "Untitled layer": "Шар без назви",
    "Untitled map": "Безіменна мапа",
    "Update permissions": "Оновити дозволи",
    "Update permissions and editors": "Налаштувати привілеї та редакторів",
    "Url": "Посилання",
    "Use current bounds": "Використовувати поточні межі",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Використовуйте змінні в дужках з властивостями об’єктів, наприклад, &#123;name&#125;, вони будуть автоматично замінені відповідними значеннями.",
    "User content credits": "Права/подяки на користувацькі дані",
    "User interface options": "Налаштування інтерфейсу",
    "Versions": "Версії",
    "View Fullscreen": "Перегляд на повний екран",
    "Where do we go from here?": "Що можна зробити з мапою далі?",
    "Whether to display or not polygons paths.": "Показувати чи ні контур полігону.",
    "Whether to fill polygons with color.": "Зафарбовувати чи ні полігони.",
    "Who can edit": "Хто може редагувати",
    "Who can view": "Хто може редагувати",
    "Will be displayed in the bottom right corner of the map": "Буде показано в правому нижньому кутку мапи",
    "Will be visible in the caption of the map": "Буде показано у заголовку мапи",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Упс!  Схоже, хтось інший теж редагує ці дані.  Ви можете зберегти свої правки, але це знищить правки іншого учасника.",
    "Zoom in": "Збільшити масштаб",
    "Zoom level for automatic zooms": "Рівень масштабу для автоматичного масштабування",
    "Zoom out": "Зменшити масштаб",
    "Zoom to layer extent": "Масштабувати до кордонів шару",
    "Zoom to the next": "Наблизитися до наступного",
    "Zoom to the previous": "Наблизитися до попереднього",
    "Zoom to this feature": "Наблизитися до цього об’єкта",
    "Zoom to this place": "Наблизити до цього місця",
    "attribution": "attribution",
    "by": "від",
    "display name": "показана назва",
    "height": "висота",
    "licence": "ліцензія",
    "max East": "макс. на схід",
    "max North": "макс. на північ",
    "max South": "макс. на південь",
    "max West": "макс. на захід",
    "max zoom": "максимальний масштаб",
    "min zoom": "мінімальний масштаб",
    "next": "далі",
    "previous": "назад",
    "width": "ширина",
    "{count} errors during import: {message}": "{count} помилок під час імпорту: {message}",
    "Measure distances": "Виміряти відстань",
    "NM": "NM",
    "kilometers": "кілометрів",
    "km": "км",
    "mi": "миля",
    "miles": "миль",
    "nautical miles": "морських миль",
    "1 day": "1 день",
    "1 hour": "1 година",
    "5 min": "5 хвилин",
    "Cache proxied request": "Кешувати запити",
    "No cache": "Кешу немає",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Пропускаємо невідоме значення geometry.type: {type}",
    "Optional.": "Необов’язково.",
    "Paste your data here": "Вставте ваші дані тут",
    "Please save the map first": "Спочатку збережіть вашу мапу",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("uk_UA", locale)
L.setLocale("uk_UA")
