{% load umap_tags umap_tags i18n %}
<table class="maps">
  {% if not is_ajax %}
    <thead>
      <tr>
        <th>{% blocktrans %}Map{% endblocktrans %}</th>
        <th>{% blocktrans %}Name{% endblocktrans %}</th>
        <th>{% blocktrans %}Who can see / edit{% endblocktrans %}</th>
        <th>{% blocktrans %}Last save{% endblocktrans %}</th>
        <th>{% blocktrans %}Owner{% endblocktrans %}</th>
        <th>{% blocktrans %}Actions{% endblocktrans %}</th>
      </tr>
    </thead>
  {% endif %}
  <tbody>
    {% for map_inst in maps %}
      <tr>
        <td>{% map_fragment map_inst prefix=prefix page=request.GET.p %}</td>
        <td>
          <a href="{{ map_inst.get_absolute_url }}">{{ map_inst.name }}</a>
        </td>
        <td>{{ map_inst.get_share_status_display }} / {{ map_inst.get_edit_status_display }}</td>
        <td>{{ map_inst.modified_at }}</td>
        <td>
          <a href="{{ map_inst.owner.get_url }}">{{ map_inst.owner }}</a>
        </td>
        <td>
          <a href="{{ map_inst.get_absolute_url }}?share">{% translate "Share" %}</a>
          <a href="{{ map_inst.get_absolute_url }}?edit">{% translate "Edit" %}</a>
          <a href="{{ map_inst.get_absolute_url }}?download">{% translate "Download" %}</a>
        </td>
      </tr>
    {% endfor %}
  </tbody>
</table>
{% if maps.has_next %}
  <div class="col wide">
    <a href="?{% paginate_querystring maps.next_page_number %}"
       class="button more_button neutral">{% trans "More" %}</a>
  </div>
{% endif %}
