const locale = {
    "Allow scroll wheel zoom?": "Kaydırma tekerleği yakınlaştırmasına izin verilsin mi?",
    "Automatic": "Otomatik",
    "Ball": "Top",
    "Cancel": "İptal",
    "Caption": "Başlık",
    "Choose the data format": "Veri biçimini seçin",
    "Choose the layer of the feature": "Nesnenin katmanını seçin",
    "Circle": "Daire",
    "Clustered": "Kümelenmiş",
    "Data browser": "Veri tarayıcı",
    "Default": "Varsayılan",
    "Default zoom level": "Varsayılan yakınlaştırma seviyesi",
    "Default: name": "Varsayılan: adı",
    "Display label": "Etiketi görüntüle",
    "Display the control to open OpenStreetMap editor": "OpenStreetMap editörünü açmak için denetimi görüntüle",
    "Display the data layers control": "Veri katmanları denetimini görüntüle",
    "Display the embed control": "Yerleştirme denetim görüntüle",
    "Display the fullscreen control": "Tam ekran denetimini görüntüle",
    "Display the locate control": "Konum denetimini görüntüle",
    "Display the measure control": "Ölçüm denetimini görüntüle",
    "Display the search control": "Arama denetimini görüntüle",
    "Display the tile layers control": "Döşeme katmanları kontrolünü göster",
    "Display the zoom control": "Yakınlaştırma denetimini görüntüle",
    "Do you want to display a caption bar?": "Başlık çubuğunu görüntülemek istiyor musunuz?",
    "Do you want to display a minimap?": "Bir minimap görüntülemek istiyor musunuz?",
    "Do you want to display a panel on load?": "Yükleme sırasında bir panel görüntülemek istiyor musunuz?",
    "Do you want to display popup footer?": "Açılır altbilgi görüntülemek istiyor musunuz?",
    "Do you want to display the scale control?": "Ölçek kontrolünü görüntülemek istiyor musunuz?",
    "Do you want to display the «more» control?": "«Daha fazla» denetim görüntülemek istiyor musunuz?",
    "Drop": "Bırak",
    "GeoRSS (only link)": "GeoRSS (sadece bağlantı)",
    "GeoRSS (title + image)": "GeoRSS (başlık + resim)",
    "Heatmap": "Isı haritası",
    "Icon shape": "Simge şekli",
    "Icon symbol": "Simge sembolu",
    "Inherit": "Devral",
    "Label direction": "Etiket yönü",
    "Label key": "Etiketin anahtarı",
    "Labels are clickable": "Etiketler tıklanabilir",
    "None": "Hiçbiri",
    "On the bottom": "Altta",
    "On the left": "Solda",
    "On the right": "Sağda",
    "On the top": "Üstte",
    "Popup content template": "Pop-up içerik şablonu",
    "Side panel": "Yan panel",
    "Simplify": "Basitleştir",
    "Table": "Tablo",
    "always": "her zaman",
    "clear": "temizle",
    "collapsed": "çökmüş",
    "color": "renk",
    "dash array": "dash array",
    "define": "belirt",
    "description": "açıklama",
    "expanded": "genişletilmiş",
    "fill": "doldur",
    "fill color": "dolgu rengi",
    "fill opacity": "dolgu şeffaflığı",
    "hidden": "saklı",
    "iframe": "iframe",
    "inherit": "Devralır",
    "name": "adı",
    "never": "asla",
    "new window": "yeni pencere",
    "no": "hayır",
    "on hover": "vurgulu",
    "opacity": "şeffaflık",
    "parent window": "üst pencere",
    "stroke": "stroke",
    "weight": "kalınlık",
    "yes": "evet",
    "{delay} seconds": "{gecikme} saniye",
    "# one hash for main heading": "# ana başlık için bir hash",
    "## two hashes for second heading": "# # ana başlık için iki hash",
    "### three hashes for third heading": "### ana başlık için üç hash",
    "**double star for bold**": "**kalınlaştırma için iki yıldız**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Hakkında",
    "Action not allowed :(": "Eyleme izin verilmiyor :(",
    "Activate slideshow mode": "Slayt gösterisi modunu etkinleştir",
    "Add a layer": "Bir katman ekle",
    "Add a line to the current multi": "Mevcut çokluya bir satır ekle",
    "Add a new property": "Yeni bir özellik ekle",
    "Add a polygon to the current multi": "Mevcut çokluya bir çokgen ekle",
    "Advanced actions": "Gelişmiş eylemler",
    "Advanced properties": "Gelişmiş özellikler",
    "All properties are imported.": "Tüm özellikler içe aktarılır.",
    "Allow interactions": "Etkileşimlere izin ver",
    "An error occured": "Bir hata oluştu",
    "Are you sure you want to cancel your changes?": "Değişikliklerinizi iptal etmek istediğinizden emin misiniz?",
    "Are you sure you want to clone this map and all its datalayers?": "Bu haritayı ve tüm veri katmanlarını klonlamak istediğinizden emin misiniz?",
    "Are you sure you want to delete the feature?": "Bu nesneyi silmek istediğinizden emin misiniz?",
    "Are you sure you want to delete this layer?": "Bu katmanı silmek istediğinizden emin misiniz?",
    "Are you sure you want to delete this map?": "Bu haritayı silmek istediğinizden emin misiniz?",
    "Are you sure you want to delete this property on all the features?": "Bu özelliği tüm nesnelerde silmek istediğinizden emin misiniz?",
    "Are you sure you want to restore this version?": "Bu sürümü geri yüklemek istediğinizden emin misiniz?",
    "Attach the map to my account": "Haritayı hesabıma ekle",
    "Auto": "Otomatik",
    "Autostart when map is loaded": "Harita yüklendiğinde otomatik başlat",
    "Bring feature to center": "Nesneyi merkeze getir",
    "Browse data": "Verilere göz at",
    "Cancel edits": "Düzenlemeleri iptal et",
    "Center map on your location": "Bulunduğunuz yere göre haritayı ortala",
    "Change map background": "Harita arkaplanını değiştir",
    "Change tilelayers": "Haritalama katmanlarını değiştir",
    "Choose a preset": "Bir ön ayar seç",
    "Choose the format of the data to import": "İçe aktarılacak verilerin biçimini seç",
    "Choose the layer to import in": "İçe aktarılacak katmanı seç",
    "Click last point to finish shape": "Şekli bitirmek için son noktaya tıklayın",
    "Click to add a marker": "Bir işaretleyici eklemek için tıklayın",
    "Click to continue drawing": "Çizime devam etmek için tıklayın",
    "Click to edit": "Düzenlemek için tıkla",
    "Click to start drawing a line": "Çizgi çizmeye başlamak için tıkla",
    "Click to start drawing a polygon": "Çokgen çizmeye başlamak için tıkla",
    "Clone": "Kopyala",
    "Clone of {name}": "{name} kopyası",
    "Clone this feature": "Bu özelliği kopyala",
    "Clone this map": "Bu haritayı kopyala",
    "Close": "Kapat",
    "Clustering radius": "Kümeleme yarıçapı",
    "Comma separated list of properties to use when filtering features": "Özellikleri filtrelerken kullanılacak özelliklerin virgülle ayrılmış listesi",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Çizgiye devam et",
    "Continue line (Ctrl+Click)": "Çizgiye devam et (Ctrl+Click)",
    "Coordinates": "Koordinatlar",
    "Credits": "Krediler",
    "Current view instead of default map view?": "Varsayılan harita görünümü yerine mevcut görünüm?",
    "Custom background": "Varsayılan arkaplan",
    "Data is browsable": "Veriler göz atılabilir",
    "Default interaction options": "Varsayılan etkileşim seçenekleri",
    "Default properties": "Varsayılan özellikler",
    "Default shape properties": "Varsayılan şekil özellikleri",
    "Define link to open in a new window on polygon click.": "Poligona tıklayınca yeni bir pencerede açılacak bağlantıyı tanımlayın.",
    "Delay between two transitions when in play mode": "Oynatma modundayken iki geçiş arasında gecikme",
    "Delete": "Sil",
    "Delete all layers": "Bütün katmanları sil",
    "Delete layer": "Katmanı sil",
    "Delete this feature": "Bu özelliği sil",
    "Delete this property on all the features": "Bu özelliği tüm nesnelerde sil",
    "Delete this shape": "Bu şekli sil",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "Directions from here",
    "Display measure": "Ölçüyü göster",
    "Display on load": "Yüklerken görüntüle",
    "Download": "İndir",
    "Download data": "Veriyi indir",
    "Drag to reorder": "Yeniden sıralamak için sürükle",
    "Draw a line": "Bir çizgi çiz",
    "Draw a marker": "Bir işaretleyici çiz",
    "Draw a polygon": "Bir çokgen çiz",
    "Draw a polyline": "Çoklu çizgi çiz",
    "Dynamic": "Dinamik",
    "Dynamic properties": "Dinamik özellikler",
    "Edit": "Düzenle",
    "Edit feature's layer": "Özellikler katmanını düzenle",
    "Edit map properties": "Harita özelliklerini düzenle",
    "Edit map settings": "Harita ayarlarını düzenle",
    "Edit properties in a table": "Özellikleri bir tabloda düzenle",
    "Edit this feature": "Bu özelliği düzenle",
    "Embed and share this map": "Bu haritayı yerleştir ve paylaş",
    "Embed the map": "Haritayı yerleştir",
    "Empty": "Boşalt",
    "Error in the tilelayer URL": "Katman URL'sinde hata",
    "Error while fetching {url}": "{url} getirilirken hata oluştu",
    "Exit Fullscreen": "Tam ekrandan çık",
    "Extract shape to separate feature": "Özelliği ayırmak için şekli ayıklayın",
    "Fetch data each time map view changes.": "Harita görünümü her değiştiğinde verileri alın.",
    "Filter keys": "Anahtarları filtrele",
    "Format": "Format",
    "From zoom": "Yakınlaştırmadan",
    "Go to «{feature}»": "«{feature}» git",
    "Heatmap intensity property": "Isı haritası yoğunluk özelliği",
    "Heatmap radius": "Isı haritası yarıçapı",
    "Help": "Yardım",
    "Hide controls": "Kontrolleri gizle",
    "Home": "Ana sayfa",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "Yanlış ise, çokgen altta yatan haritanın bir parçası olarak hareket edecektir.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Özel genişliğe sahip resim (piksel cinsinden): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Görüntü: {{http://image.url.com}}",
    "Import": "İçe aktar",
    "Import data": "İçeri veri aktar",
    "Import in a new layer": "Yeni katman aktar",
    "Imports all umap data, including layers and settings.": "Katmanlar ve özellikler dahil olmak üzere bütün umap verisini ekle.",
    "Include full screen link?": "Tam ekran bağlantısını ekle?",
    "Interaction options": "Etkileşim seçenekleri",
    "Invalid umap data": "Geçersiz umap verisi",
    "Invalid umap data in {filename}": "{filename}'de geçersiz umap verisi",
    "Keep current visible layers": "Şuan görünen katmanları tut",
    "Latitude": "Enlem",
    "Layer": "Katman",
    "Layer properties": "Katman özellikleri",
    "Licence": "Lisans",
    "Limit bounds": "Sınırı sınırlandır",
    "Link to…": "Şuna bağlantı...",
    "Link with text: [[http://example.com|text of the link]]": "Metin ile bağlantı: [[http://example.com|text of the link]]",
    "Long credits": "Uzun krediler",
    "Longitude": "Boylam",
    "Make main shape": "Ana şekil yap",
    "Manage layers": "Katmanları yönet",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Harita hesabınıza bağlandı",
    "Map has been saved!": "Harita kaydedildi!",
    "Map user content has been published under licence": "Harita kullanıcı içeriği lisans altında yayınlandı",
    "Map's editors": "Haritanın editörü",
    "Map's owner": "Haritanın sahibi",
    "Merge lines": "Çizgileri birleştir",
    "More controls": "Daha fazla kontrol",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Geçerli CSS değeri olmalı (örneğin: DarkBlue ya da #123456)",
    "No licence has been set": "Hiçbir lisans ayarlanmadı",
    "No results": "Sonuç yok",
    "Only visible features will be downloaded.": "Sadece görünen özellikler indirilecek",
    "Open download panel": "İndirme panelini aç",
    "Open link in…": "Bağlantıyı şurada aç",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "OpenStreetMap'e daha doğru veri sağlayabilmek için bu harita kapsamını bir harita düzenleyicide aç",
    "Optional intensity property for heatmap": "Isı haritası için isteğe bağlı yoğunluk özelliği",
    "Optional. Same as color if not set.": "İsteğe bağlı. Eğer ayarlanmazsa renk ile aynı.",
    "Override clustering radius (default 80)": "Kümeleme yarıçapını geçersiz kıl (varsayılan 80)",
    "Override heatmap radius (default 25)": "Isı haritası yarıçapını geçersiz kıl (varsayılan 25)",
    "Please be sure the licence is compliant with your use.": "Lütfen lisansın kullanımınızla uyumlu olduğundan emin olun.",
    "Please choose a format": "Lütfen bir biçim seçin",
    "Please enter the name of the property": "Lütfen bu özelliğin adını girin",
    "Please enter the new name of this property": "Lütfen bu özelliğin yeni adını girin",
    "Problem in the response": "Yanıtta sorun",
    "Problem in the response format": "Yanıt biçiminde sorun",
    "Properties imported:": "İçe aktarılan özellikler:",
    "Provide an URL here": "Buraya bir URL girin",
    "Proxy request": "Proxy isteği",
    "Remote data": "Uzaktan veriler",
    "Remove shape from the multi": "Şekli çokludan kaldır",
    "Rename this property on all the features": "Bu özelliği tüm nesnelerde yeniden adlandırın",
    "Replace layer content": "Katman içeriğini değiştir",
    "Restore this version": "Bu sürümü geri yükleyin",
    "Save": "Kaydet",
    "Save anyway": "Yine de kaydet",
    "Save current edits": "Şimdiki düzenlemeleri kaydet",
    "Save this center and zoom": "Bu merkezi kaydet ve yakınlaştır",
    "Save this location as new feature": "Bu konumu yeni özellik olarak kaydet",
    "Search a place name": "Yer adı ara",
    "Search location": "Konum ara",
    "See all": "Hepsini gör",
    "See data layers": "Veri katmanlarını gör",
    "See full screen": "Tam ekranda gör",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Bu katmanı slayt gösterisinden, veri tarayıcısından, pop-up gezinmeden gizlemek için yanlış olarak ayarlayın ...",
    "Shape properties": "Şekil özellikleri",
    "Short URL": "Kısa URL",
    "Short credits": "Kısa krediler",
    "Show/hide layer": "Katmanı göster/gizle",
    "Simple link: [[http://example.com]]": "Basit bağlantı: [[http://example.com]]",
    "Slideshow": "Slayt gösterisi",
    "Sort key": "Kısa anahtar",
    "Split line": "Çizgiyi böl",
    "Start a hole here": "Burada bir delik aç",
    "Start editing": "Düzenlemeye başla",
    "Start slideshow": "Slayt gösterisini başlat",
    "Stop editing": "Düzenlemeyi durdur",
    "Stop slideshow": "Slayt gösterisini durdur",
    "Supported scheme": "Desteklenen şema",
    "Supported variables that will be dynamically replaced": "Dinamik olarak değiştirilecek desteklenen değişkenler",
    "TMS format": "TMS formatı",
    "Text color for the cluster label": "Küme etiketi için metin rengi",
    "Text formatting": "Metin biçimlendirme",
    "To use if remote server doesn't allow cross domain (slower)": "Uzak sunucu etki alanları arası izin vermiyorsa kullanmak için (daha yavaş)",
    "To zoom": "Yakınlaştırmak için",
    "Transfer shape to edited feature": "Şekli düzenlenmiş özelliğe transfer et",
    "Transform to lines": "Çizgilere dönüştür",
    "Transform to polygon": "Çokgene dönüştür",
    "Type of layer": "Katmanın tipi",
    "Unable to detect format of file {filename}": "Dosyanın biçimi belirlenemedi {filename}",
    "Untitled layer": "Adlandırılmamış katman",
    "Untitled map": "Adlandırılmamış harita",
    "Update permissions": "İzinleri güncelle",
    "Update permissions and editors": "İzinleri ve düzenleyicileri güncelleyin",
    "Url": "Url",
    "Use current bounds": "Geçerli sınırları kullan",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Parantezler arasında nesne özelliklerine sahip yer tutucuları kullanın, örneğin. &#123;isim&#125;, dinamik olarak karşılık gelen değerlerle değiştirilecektir.",
    "User content credits": "Kullanıcı içerik kredisi",
    "User interface options": "Kullanıcı arayüzü seçenekleri",
    "Versions": "Sürümler",
    "View Fullscreen": "Tam ekranda görüntüle",
    "Where do we go from here?": "Buradan sonra nereye gidiyoruz?",
    "Whether to display or not polygons paths.": "Çokgen yolların görüntülenip görüntülenmeyeceği",
    "Whether to fill polygons with color.": "Çokgenleri renkle doldur ya da doldurma",
    "Who can edit": "Kim düzenleyebilir",
    "Who can view": "Kim görüntüleyebilir",
    "Will be displayed in the bottom right corner of the map": "Haritanın sağ alt köşesinde görüntülenecek",
    "Will be visible in the caption of the map": "Haritanın başlığında görüntülenecek",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Başka biri verileri düzenlemiş gibi görünüyor. Yine de kaydedebilirsiniz, ancak bu başkaları tarafından yapılan değişiklikleri siler.",
    "Zoom in": "Yakınlaştır",
    "Zoom level for automatic zooms": "Otomatik yakınlaştırma için yakınlaştırma seviyesi",
    "Zoom out": "Uzaklaştır",
    "Zoom to layer extent": "Katman genişliğine yakınlaştır",
    "Zoom to the next": "Bir sonrakine yakınlaştır",
    "Zoom to the previous": "Bir öncekine yakınlaştır",
    "Zoom to this feature": "Bu nesneyi yakınlaştır",
    "Zoom to this place": "Bu yere yakınlaştırın",
    "attribution": "atıf",
    "by": "tarafından",
    "display name": "görünen ad",
    "height": "yükseklik",
    "licence": "lisans",
    "max East": "max Doğu",
    "max North": "max Kuzey",
    "max South": "max Güney",
    "max West": "max Batı",
    "max zoom": "max yakınlaştır",
    "min zoom": "min yakınlaştırma",
    "next": "sonraki",
    "previous": "önceki",
    "width": "genişlik",
    "{count} errors during import: {message}": "{sayı} içe aktarma sırasında hatalar: {mesaj}",
    "Measure distances": "Mesafeleri ölçün",
    "NM": "NM",
    "kilometers": "kilometre",
    "km": "km",
    "mi": "mi",
    "miles": "mil",
    "nautical miles": "deniz mil",
    "1 day": "1 gün",
    "1 hour": "1 saat",
    "5 min": "5 dakika",
    "Cache proxied request": "Önbellek proxy isteği",
    "No cache": "Önbellek yok",
    "Popup": "Açılır pencere",
    "Popup (large)": "Açılır pencere (büyük)",
    "Popup content style": "Pop-up içerik stili",
    "Popup shape": "Pop-up şekli",
    "Skipping unknown geometry.type: {type}": "Bilinmeyen geometri tipini atlama: {type}",
    "Optional.": "İsteğe bağlı.",
    "Paste your data here": "Paste your data here",
    "Please save the map first": "Lütfen önce haritayı kaydedin",
    "Feature identifier key": "Nesne tanımlayıcı anahtarı",
    "Open current feature on load": "Mevcut yüklemede olan nesneyi aç",
    "Permalink": "Kalıcı bağlantı",
    "The name of the property to use as feature unique identifier.": "Nesne özgün tanımlayıcısı olarak kullanılacak özelliğin adı",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("tr", locale)
L.setLocale("tr")
