const locale = {
    "Allow scroll wheel zoom?": "Tillad zoom med scrollhjul?",
    "Automatic": "Automatisk",
    "Ball": "Kugle",
    "Cancel": "Fortryd",
    "Caption": "Billedtekst",
    "Choose the data format": "Vælg dataformat",
    "Choose the layer of the feature": "Vælg objektets lag",
    "Circle": "Cirkel",
    "Clustered": "Klynge",
    "Data browser": "Databrowser",
    "Default": "Standard",
    "Default zoom level": "Standardzoomniveau",
    "Default: name": "Standard:-navn",
    "Display label": "Visningslabel",
    "Display the control to open OpenStreetMap editor": "Vis kontrollen til åbning af OpenStreetMap-editoren",
    "Display the data layers control": "Vis datalagkontrollen",
    "Display the embed control": "Vis indlejringskontrollen",
    "Display the fullscreen control": "Vis fuldskærmskontrollen",
    "Display the locate control": "Vis lokaliseringskontrollen",
    "Display the measure control": "Vis opmålingskontrollen",
    "Display the search control": "Vis søgekontrollen",
    "Display the tile layers control": "Vis fliselagskontrollen",
    "Display the zoom control": "Vis zoomkontrollen",
    "Do you want to display a caption bar?": "Vil du vise en billedtekst?",
    "Do you want to display a minimap?": "Vil du vise  et miniaturekort?",
    "Do you want to display a panel on load?": "Vil du vise et panel ved indlæsning?",
    "Do you want to display popup footer?": "Vil du vise popupnoten?",
    "Do you want to display the scale control?": "Vil du vise målestokskontrollen?",
    "Do you want to display the «more» control?": "Vil du vise \"mere\"-kontrollen?",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (kun link)",
    "GeoRSS (title + image)": "GeoRSS (titel + billede)",
    "Heatmap": "Heatmap",
    "Icon shape": "Ikonfacon",
    "Icon symbol": "Ikonsymbol",
    "Inherit": "Nedarv",
    "Label direction": "Labelretning",
    "Label key": "Labelnøgle",
    "Labels are clickable": "Labels er klikbare",
    "None": "Ingen",
    "On the bottom": "I bunden",
    "On the left": "Til venstre",
    "On the right": "Til højre",
    "On the top": "I toppen",
    "Popup content template": "Popups indholdsskabelon",
    "Side panel": "Sidepanel",
    "Simplify": "Simplificer",
    "Table": "Tabel",
    "always": "altid",
    "clear": "tøm",
    "collapsed": "klappet sammen",
    "color": "farver",
    "dash array": "stiplet række",
    "define": "definer",
    "description": "beskrivelse",
    "expanded": "udvidet",
    "fill": "udfyldning",
    "fill color": "udfyldningsfarve",
    "fill opacity": "udfyldningsgennemsigtighed",
    "hidden": "skjult",
    "iframe": "iframe",
    "inherit": "nedarvet",
    "name": "navn",
    "never": "aldrig",
    "new window": "nyt vindue",
    "no": "nej",
    "on hover": "ved hover",
    "opacity": "gennemsigtighed",
    "parent window": "forældervindue",
    "stroke": "strøg",
    "weight": "vægtning",
    "yes": "ja",
    "{delay} seconds": "{delay} sekunder",
    "# one hash for main heading": "# et hashtag for hovedoverskrift",
    "## two hashes for second heading": "## to hashtags for andet overskriftniveau",
    "### three hashes for third heading": "### tre hashtags for tredje overskriftsniveau",
    "**double star for bold**": "**dobbelt stjerne for fed skrift**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommasepareret nummerliste som definerer stiplingsmønstret. Fx: \"5, 10, 15\".",
    "About": "Om",
    "Action not allowed :(": "Handling er ikke tilladt :(",
    "Activate slideshow mode": "Aktiver slideshowtilstand",
    "Add a layer": "Tilføj et lag",
    "Add a line to the current multi": "Tilføj en linje til nuværende multi",
    "Add a new property": "Tilføj en ny egenskab",
    "Add a polygon to the current multi": "Tilføj en polygon til nuværende multi",
    "Advanced actions": "Avancerede handlinger",
    "Advanced properties": "Avancerede egenskaber",
    "All properties are imported.": "Alle egenskaber er importeret.",
    "Allow interactions": "Tillad interaktioner",
    "An error occured": "Der opstod en fejl",
    "Are you sure you want to cancel your changes?": "Er du sikker på du vil fortryde dine ændringer?",
    "Are you sure you want to clone this map and all its datalayers?": "Er du sikker på du vil klone dette kort og alle dets datalag?",
    "Are you sure you want to delete the feature?": "Er du sikker på at du vil slette dette objekt?",
    "Are you sure you want to delete this layer?": "Er du sikker på at du vil slette dette lag?",
    "Are you sure you want to delete this map?": "Er du sikker på at du vil slette dette kort?",
    "Are you sure you want to delete this property on all the features?": "Er du sikker på du vil slette denne egenskab på alle objekter?",
    "Are you sure you want to restore this version?": "Er du sikker på at du vil genskabe denne version?",
    "Attach the map to my account": "Knyt kortet til min konto",
    "Auto": "Auto",
    "Autostart when map is loaded": "Start automatisk når kort er indlæst",
    "Bring feature to center": "Centrerer objekt",
    "Browse data": "Gennemse data",
    "Cancel edits": "Fortryd redigeringer",
    "Center map on your location": "Centrer kort på din placering",
    "Change map background": "Skift kortbaggrund",
    "Change tilelayers": "Skift kortlag",
    "Choose a preset": "Vælg en forudindstilling",
    "Choose the format of the data to import": "Vælg imports dataformat",
    "Choose the layer to import in": "Vælg lag der skal importeres",
    "Click last point to finish shape": "Klik på det det sidste punkt for at afslutte figur",
    "Click to add a marker": "Klik for at tilføje en  markør",
    "Click to continue drawing": "Klik for at fortsætte indtegning",
    "Click to edit": "Klik for at redigere",
    "Click to start drawing a line": "Klik for at starte indtegning af linje",
    "Click to start drawing a polygon": "Klik for at starte indtegning af polygon",
    "Clone": "Kloning",
    "Clone of {name}": "Klone af {name}",
    "Clone this feature": "Klon dette objekt",
    "Clone this map": "Klon dette kort",
    "Close": "Luk",
    "Clustering radius": "Klyngeradius",
    "Comma separated list of properties to use when filtering features": "Kommasepareret egenskabsliste til brug ved objektfiltrering.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma, tabulering eller semikolon adskiller værdier. SRS WGS84 er underforstået. Kun punktgeometri importeres. Importen vil kigge efter kolonner, der indeholder varianter af \"lat\" eller \"lon\" i begyndelsen af overskriften, uden at tage hensyn til små og store bogstaver. Alle andre kolonner importeres som egenskaber.",
    "Continue line": "Fortsæt linje",
    "Continue line (Ctrl+Click)": "Fortsæt linje (Ctrl+Klik)",
    "Coordinates": "Koordinater",
    "Credits": "Kreditering",
    "Current view instead of default map view?": "Nuværende kortudsnit i stedet for standardkortvisning?",
    "Custom background": "Tilpasset baggrund",
    "Data is browsable": "Data kan gennemses",
    "Default interaction options": "Standardinteraktionsindstillinger",
    "Default properties": "Standardegenskaber",
    "Default shape properties": "Standard figur-egenskaber",
    "Define link to open in a new window on polygon click.": "Definer link der åbnes i et nyt vindue ved klik på polygon.",
    "Delay between two transitions when in play mode": "Forsinkelse mellem to transitioner, når i afspilningstilstand",
    "Delete": "Slet",
    "Delete all layers": "Slet alle lag",
    "Delete layer": "Slet lag",
    "Delete this feature": "Slet dette objekt",
    "Delete this property on all the features": "Slet denne egenskab på alle objekter",
    "Delete this shape": "Slet denne figur",
    "Delete this vertex (Alt+Click)": "Slet denne vertex (Alt+Click)",
    "Directions from here": "Kørselsvejledning herfra",
    "Display measure": "Vis opmåling",
    "Display on load": "Vis ved indlæsning",
    "Download": "Download",
    "Download data": "Download data",
    "Drag to reorder": "Træk for at ændre rækkefølge",
    "Draw a line": "Tegn en linje",
    "Draw a marker": "Tegn en markør",
    "Draw a polygon": "Tegn en polygon",
    "Draw a polyline": "Tegn en polygonlinje",
    "Dynamic": "Dynamisk",
    "Dynamic properties": "Dynamiske egenskaber",
    "Edit": "Redigering",
    "Edit feature's layer": "Rediger objekts lag",
    "Edit map properties": "Rediger kortegenskaber",
    "Edit map settings": "Rediger kortindstillinger",
    "Edit properties in a table": "Rediger egenskaberne i en tabel",
    "Edit this feature": "Rediger dette objekt",
    "Embed and share this map": "Indlejr og del dette kort",
    "Embed the map": "Indlejring af kortet",
    "Empty": "Tomt",
    "Error in the tilelayer URL": "Fejl i fliselags-URL'en",
    "Error while fetching {url}": "Fejl ved hentning af {url}",
    "Exit Fullscreen": "Afslut fuldskærm",
    "Extract shape to separate feature": "Udtræk figur for at adskille objekt",
    "Fetch data each time map view changes.": "Hent data hver gang kortvisningen ændres.",
    "Filter keys": "Filternøgler",
    "Format": "Format",
    "From zoom": "Fra zoom",
    "Go to «{feature}»": "Gå til \"{feature}\"",
    "Heatmap intensity property": "Heatmaps intensitetsegenskaber",
    "Heatmap radius": "Heatmaps radius",
    "Help": "Hjælp",
    "Hide controls": "Skjul kontroller",
    "Home": "Hjem",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hvor meget polylinjen skal forenkles på hvert zoomniveau (mere = bedre ydeevne og jævnere udseende, mindre = mere præcist)",
    "If false, the polygon will act as a part of the underlying map.": "Hvis falsk så vil polygonen opfører sig som en del af det underliggende kort.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe med brugerdefineret højde (i px): {{{http://iframe.url.com|højde}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe med tilpasset højde og bredde (i px): {{{http://iframe.url.com|højde*bredde}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Billede med tilpasset bredde (i px): {{http://image.url.com|bredde}}",
    "Image: {{http://image.url.com}}": "Billede:  {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Importer data",
    "Import in a new layer": "Importerer i et nyt lag",
    "Imports all umap data, including layers and settings.": "Importerer alle umapdata, inklusiv lag og indstillinger,",
    "Include full screen link?": "Inkluder fuldskærmslink?",
    "Interaction options": "Interaktionsindstillinger",
    "Invalid umap data": "Ugyldige umapdata",
    "Invalid umap data in {filename}": "Ugydige umapdata i {filename}",
    "Keep current visible layers": "Behold nuværende synlige lag",
    "Latitude": "Længdegrader",
    "Layer": "Lag",
    "Layer properties": "Lags egenskaber",
    "Licence": "Licens",
    "Limit bounds": "Afgræsning",
    "Link to…": "Link til…",
    "Link with text: [[http://example.com|text of the link]]": "Link med tekst: [[http://example.com|linktekst]]",
    "Long credits": "Lang kreditering",
    "Longitude": "Breddegrader",
    "Make main shape": "Gør til hovedfigur",
    "Manage layers": "Håndter lag",
    "Map background credits": "Baggrundskortkreditering",
    "Map has been attached to your account": "Kortet er blevet knyttet til din konto",
    "Map has been saved!": "Kortet er blevet gemt!",
    "Map user content has been published under licence": "Kortbrugerindholdet er udgivet under licensen",
    "Map's editors": "Korts redaktører",
    "Map's owner": "Korts ejer",
    "Merge lines": "Flet linjer",
    "More controls": "Vis flere kontroller",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Skal være en gyldig CSS-værdi (fx: DarkBlue eller #123456)",
    "No licence has been set": "Ingen licens angivet",
    "No results": "Ingen resultater",
    "Only visible features will be downloaded.": "Kun synlige objekter vil blive downloadet.",
    "Open download panel": "Åbn downloadpanel",
    "Open link in…": "Åbn link i…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Åbn dette kort i en korteditor for at levere mere nøjagtige data til OpenStreetMap",
    "Optional intensity property for heatmap": "Valgfri intensitetsegenskaber for heatmap",
    "Optional. Same as color if not set.": "Valgfrit. Samme som farve hvis ikke opsat.",
    "Override clustering radius (default 80)": "Overskriv klyngeradius (standard 80)",
    "Override heatmap radius (default 25)": "Overskriv heatmapradius (standard 25)",
    "Please be sure the licence is compliant with your use.": "Sørg for at licensen tillader din anvendelse.",
    "Please choose a format": "Vælg et format",
    "Please enter the name of the property": "Angiv egenskabens navn",
    "Please enter the new name of this property": "Angiv egenskabens nye navn",
    "Problem in the response": "Problem med svaret",
    "Problem in the response format": "Problem med svarformatet",
    "Properties imported:": "Egenskaber importeret:",
    "Provide an URL here": "Indsæt en URL her",
    "Proxy request": "Proxyforespørgsel",
    "Remote data": "Fjernudbudte data",
    "Remove shape from the multi": "Fjern figur fra multi",
    "Rename this property on all the features": "Omdøb denne egenskab på alle objekter",
    "Replace layer content": "Erstat lags indhold",
    "Restore this version": "Genskab denne version",
    "Save": "Gem",
    "Save anyway": "Gem alligevel",
    "Save current edits": "Gem nuværende redigeringer",
    "Save this center and zoom": "Gem med dette center og zoom",
    "Save this location as new feature": "Gem denne placering som et nyt objekt",
    "Search a place name": "Søg efter et stednavn",
    "Search location": "Søg efter placering",
    "See all": "Se alle",
    "See data layers": "Se datalag",
    "See full screen": "Se i fuld skærm",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Sæt den til false, for at skjule dette lag fra slideshowet, databrowseren, popupnavigeringen…",
    "Shape properties": "Figuregenskaber",
    "Short URL": "Kort URL",
    "Short credits": "Kort kreditering",
    "Show/hide layer": "Vis/skjul lag",
    "Simple link: [[http://example.com]]": "Simpelt link: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Sort key": "Sorteringsnøgle",
    "Split line": "Opsplit linje",
    "Start a hole here": "Start et hul her",
    "Start editing": "Start redigering",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop redigering",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Understøttet skema",
    "Supported variables that will be dynamically replaced": "Understøttede variabler som vil blive dynamisk erstattet",
    "TMS format": "TMS-format",
    "Text color for the cluster label": "Tekstfarve for klyngelabel",
    "Text formatting": "Tekstformatering",
    "To use if remote server doesn't allow cross domain (slower)": "Anvendes hvis fjernserver ikke tillader krydsdomæne (langsommere)",
    "To zoom": "For at zoome",
    "Transfer shape to edited feature": "Overfør figur til redigeret objekt",
    "Transform to lines": "Transformer til linjer",
    "Transform to polygon": "Transformer til polygon",
    "Type of layer": "Lagtype",
    "Unable to detect format of file {filename}": "Kunne ikke genkende formatet på filen {filename}",
    "Untitled layer": "Unavngivet lag",
    "Untitled map": "Unavngivet kort",
    "Update permissions": "Opdater tilladelser",
    "Update permissions and editors": "Opdater indstillinger og redaktører",
    "Url": "URL",
    "Use current bounds": "Brug nuværende grænser",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Brug pladsholdere med objektegenskaberne mellem tuborgklammer, fx &#123;navn&#125;, så vil de dynamatisk blive erstattet med de tilhørende værdier.",
    "User content credits": "Brugerindhold-kreditering",
    "User interface options": "Brugergrænsefladeindstillinger",
    "Versions": "Versioner",
    "View Fullscreen": "Fuldskærmsvisning",
    "Where do we go from here?": "Hvor skal vi hen herfra?",
    "Whether to display or not polygons paths.": "Hvorvidt der vises eller ikke vises polygonstier.",
    "Whether to fill polygons with color.": "Hvorvidt polygoner udfyldes med farve.",
    "Who can edit": "Hvem kan redigere",
    "Who can view": "Hvem kan se",
    "Will be displayed in the bottom right corner of the map": "Vil blive vist i kortets nederste højre hjørne",
    "Will be visible in the caption of the map": "Vil være synlig i tekstfeltet på kortet",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ups! Det ser ud til at nogen har rettet i dataene. Du kan gemme alligevel, men det vil overskrive andres ændringer.",
    "Zoom in": "Zoom ind",
    "Zoom level for automatic zooms": "Zoomniveau for automatisk zooming",
    "Zoom out": "Zoom ud",
    "Zoom to layer extent": "Zoom til lagudvidelse",
    "Zoom to the next": "Zoom til næste",
    "Zoom to the previous": "Zoom til forrige",
    "Zoom to this feature": "Zoom til dette objekt",
    "Zoom to this place": "Zoom til dette sted",
    "attribution": "navngivelse",
    "by": "af",
    "display name": "visningsnavn",
    "height": "højde",
    "licence": "licens",
    "max East": "max øst",
    "max North": "max nord",
    "max South": "max syd",
    "max West": "max vest",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "næste",
    "previous": "forrige",
    "width": "bredde",
    "{count} errors during import: {message}": "{count} fejl under import: {message}",
    "Measure distances": "Opmål afstande",
    "NM": "NM",
    "kilometers": "kilometer",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "sømil",
    "1 day": "1 dag",
    "1 hour": "1 time",
    "5 min": "5 min",
    "Cache proxied request": "Forespørgsel i proxycache",
    "No cache": "Ingen cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (stor)",
    "Popup content style": "Popupindholdsstil",
    "Popup shape": "Popupfacon",
    "Skipping unknown geometry.type: {type}": "Springer over ukendt geometry.type: {type}",
    "Optional.": "Valgfrit.",
    "Paste your data here": "Indsæt dine data her",
    "Please save the map first": "Gem først kortet",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("da", locale)
L.setLocale("da")
