const locale = {
    "Allow scroll wheel zoom?": "Επιτρέπεται κύλιση εστίασης",
    "Automatic": "Αυτόματα",
    "Ball": "Καρφίτσα",
    "Cancel": "Άκυρο",
    "Caption": "Λεζάντα",
    "Choose the data format": "Επιλογή μορφοποίησης δεδομένων",
    "Choose the layer of the feature": "Επιλέξτε το επίπεδο του στοιχείου",
    "Circle": "Κύκλος",
    "Clustered": "Σύμπλεγμα",
    "Data browser": "Περιηγητής δεδομένων",
    "Default": "Προεπιλογή",
    "Default zoom level": "Προεπιλεγμένο επίπεδο μεγέθυνσης",
    "Default: name": "Προεπιλογή: Όνομα",
    "Display label": "Εμφάνιση ετικέτας",
    "Display the control to open OpenStreetMap editor": "Εμφάνιση εικονιδίου επεξεργασίας OpenStreetMap",
    "Display the data layers control": "Εμφάνιση εικονιδίου επιπέδων με δεδομένα",
    "Display the embed control": "Εμφάνιση εικονιδίου διαμοιρασμού",
    "Display the fullscreen control": "Εμφάνιση εικονιδίου πλήρους οθόνης",
    "Display the locate control": "Εμφάνιση εικονιδίου γεωεντοπισμού",
    "Display the measure control": "Εμφάνιση εικονιδίου μέτρησης",
    "Display the search control": "Εμφάνιση εικονιδίου αναζήτησης",
    "Display the tile layers control": "Εμφάνιση εικονιδίου αλλαγής υποβάθρων",
    "Display the zoom control": "Εμφάνιση εικονιδίου εστίασης",
    "Do you want to display a caption bar?": "Εμφάνιση λεζάντας",
    "Do you want to display a minimap?": "Εμφάνιση χάρτη προσανατολισμού",
    "Do you want to display a panel on load?": "Εμφάνιση καρτέλας κατά την φόρτωση",
    "Do you want to display popup footer?": "Εμφάνιση αναδυόμενου υποσέλιδου",
    "Do you want to display the scale control?": "Εμφάνιση κλίμακας",
    "Do you want to display the «more» control?": "Εμφάνιση περισσότερων επιλογών",
    "Drop": "Σταγόνα",
    "GeoRSS (only link)": "GeoRSS (μόνο σύνδεσμος)",
    "GeoRSS (title + image)": "GeoRSS (τίτλος + εικόνα)",
    "Heatmap": "Χάρτης θερμότητας",
    "Icon shape": "Μορφή εικονιδίου",
    "Icon symbol": "Σύμβολο εικονιδίου",
    "Inherit": "Κληρονομημένο",
    "Label direction": "Κατεύθυνση ετικέτας",
    "Label key": "Κλειδί ετικέτας",
    "Labels are clickable": "Οι ετικέτες είναι ενεργές",
    "None": "Κανένα",
    "On the bottom": "Στο κάτω μέρος",
    "On the left": "Στο αριστερό μέρος",
    "On the right": "Στο δεξί μέρος",
    "On the top": "Στο πάνω μέρος",
    "Popup content template": "Αναδυόμενο πρότυπο περιεχομένου",
    "Side panel": "Πλευρική εργαλειοθήκη",
    "Simplify": "Απλοποίηση",
    "Table": "Πίνακας",
    "always": "πάντα",
    "clear": "Εκκαθάριση",
    "collapsed": "Κατέρρευσε",
    "color": "Χρώμα",
    "dash array": "Διάταξη παύλας",
    "define": "Ορισμός",
    "description": "Περιγραφή",
    "expanded": "Αναπτυγμένος",
    "fill": "Γέμισμα",
    "fill color": "Χρώμα γεμίσματος",
    "fill opacity": "Αδιαφάνεια γεμίσματος",
    "hidden": "Απόκρυψη",
    "iframe": "iframe",
    "inherit": "Κληρονομημένο",
    "name": "Όνομα",
    "never": "Ποτέ",
    "new window": "Νέο Παράθυρο",
    "no": "όχι",
    "on hover": "Με αιώρηση",
    "opacity": "Αδιαφάνεια",
    "parent window": "Γονικό παράθυρο",
    "stroke": "Πινέλο",
    "weight": "Βάρος",
    "yes": "ναι",
    "{delay} seconds": "{delay} δευτερόλεπτα",
    "# one hash for main heading": "# για επικεφαλίδα πρώτου επιπέδου",
    "## two hashes for second heading": "## για επικεφαλίδα δευτέρου επιπέδου",
    "### three hashes for third heading": "### για επικεφαλίδα τρίτου επιπέδου",
    "**double star for bold**": "**διπλό αστερίσκο για έντονα**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Μια λίστα αριθμών διαχωρισμένων με κόμμα που καθορίζει το μοτίβο της παύλας. Π.χ.: \"5, 10, 15\".",
    "About": "Σχετικά",
    "Action not allowed :(": "Μη επιτρεπόμενη ενέργεια :(",
    "Activate slideshow mode": "Ενεργοποίηση λειτουργίας παρουσίασης",
    "Add a layer": "Προσθήκη επιπέδου",
    "Add a line to the current multi": "Προσθήκη γραμμής στο παρόν πολυδεδομένο",
    "Add a new property": "Προσθήκη νέας ιδιότητας",
    "Add a polygon to the current multi": "Προσθήκη πολυγώνου στο παρόν πολυδεδομένο",
    "Advanced actions": "Εξειδικευμένες ενέργειες",
    "Advanced properties": "Εξειδικευμένες ιδιότητες",
    "All properties are imported.": "Όλες οι ιδιότητες έχουν εισαχθεί",
    "Allow interactions": "Επιτρέπονται αλληλεπιδράσεις",
    "An error occured": "Παρουσιάστηκε σφάλμα",
    "Are you sure you want to cancel your changes?": "Θέλετε σίγουρα να ακυρώσετε τις αλλαγές σας;",
    "Are you sure you want to clone this map and all its datalayers?": "Θέλετε σίγουρα να κλωνοποιηθεί αυτός ο χάρτης και όλα τα επίπεδα δεδομένων του;",
    "Are you sure you want to delete the feature?": "Θέλετε σίγουρα να διαγράφει αυτό το στοιχείο;",
    "Are you sure you want to delete this layer?": "Θέλετε σίγουρα να διαγράφει αυτό το επιπέδο;",
    "Are you sure you want to delete this map?": "Θέλετε σίγουρα να διαγράφει αυτός ο χάρτης;",
    "Are you sure you want to delete this property on all the features?": "Θέλετε σίγουρα να διαγράφει αυτή η ιδιότητα από όλα τα στοιχεία;",
    "Are you sure you want to restore this version?": "Θέλετε σίγουρα να γίνει επαναφορά αυτής της έκδοσης;",
    "Attach the map to my account": "Σύνδεση του χάρτη με τον λογαριασμό μου",
    "Auto": "Αυτόματα",
    "Autostart when map is loaded": "Αυτόματη έναρξη με την φόρτωση του χάρτη",
    "Bring feature to center": "Κεντράρισμα του στοιχείου",
    "Browse data": "Περιήγηση δεδομένων",
    "Cancel edits": "Ακύρωση επεξεργασίας",
    "Center map on your location": "Κεντράρισμα του χάρτη στην τοποθεσία σας",
    "Change map background": "Αλλαγή υποβάθρου του χάρτη",
    "Change tilelayers": "Αλλαγή χαρτογραφικού υπόβαθρου",
    "Choose a preset": "Επιλογή προκαθορισμένου",
    "Choose the format of the data to import": "Επιλέξτε τη μορφοποίηση των δεδομένων που θα εισαχθούν",
    "Choose the layer to import in": "Επιλέξτε το επίπεδο στο οποίο θα η εισαγωγή",
    "Click last point to finish shape": "Πατήστε στο τελευταίο σημείο για να ολοκληρωθεί το σχήμα",
    "Click to add a marker": "Πατήστε για την εισαγωγή σημείου",
    "Click to continue drawing": "Πατήστε για συνέχεια σχεδίασης",
    "Click to edit": "Πατήστε για επεξεργασία",
    "Click to start drawing a line": "Πατήστε για έναρξη σχεδιασμού γραμμής",
    "Click to start drawing a polygon": "Πατήστε για έναρξη σχεδιασμού πολυγώνου",
    "Clone": "Κλωνοποίηση",
    "Clone of {name}": "Κλωνοποίηση του {name}",
    "Clone this feature": "Κλωνοποίηση αυτού του στοιχείου",
    "Clone this map": "Κλωνοποίηση αυτού του χάρτη",
    "Close": "Κλείσιμο",
    "Clustering radius": "Ακτίνα συμπλέγματος",
    "Comma separated list of properties to use when filtering features": "Λίστα ιδιοτήτων διαχωρισμένων με κόμμα για χρήση κατά το φιλτράρισμα των στοιχείων",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Τιμές διαχωρισμένες με κόμμα, tab ή άνω τελεία. Εννοείται και η μορφή SRS WGS84. Εισάγονται μόνο γεωμετρίες σημείων. Η διαδικασία εισαγωγής ελέγχει τις επικεφαλίδες των στηλών για τις ενδείξεις «lat» και «lon» στην αρχή της επικεφαλίδας και κάνει διάκριση πεζών - κεφαλαίων γραμμάτων. Όλες οι άλλες στήλες εισάγονται ως ιδιότητες.",
    "Continue line": "Συνέχεια γραμμής",
    "Continue line (Ctrl+Click)": "Συνέχεια γραμμής (Ctrl+Click)",
    "Coordinates": "Συντεταγμένες",
    "Credits": "Εύσημα",
    "Current view instead of default map view?": "Τρέχουσα προβολή χάρτη αντί της προεπιλεγμένης",
    "Custom background": "Προσαρμοσμένο υπόβαθρο",
    "Data is browsable": "Τα δεδομένα είναι περιηγήσιμα",
    "Default interaction options": "Αλληλεπίδραση",
    "Default properties": "Προεπιλεγμένες ιδιότητες",
    "Default shape properties": "Ιδιότητες σχημάτων",
    "Define link to open in a new window on polygon click.": "Προσδιορισμός συνδέσμου για άνοιγμα σε νέο παράθυρο με κλικ στο πολύγωνο",
    "Delay between two transitions when in play mode": "Καθυστέρηση μεταξύ μεταβάσεων κατά την παρουσίαση",
    "Delete": "Διαγραφή",
    "Delete all layers": "Διαγραφή όλων των επιπέδων",
    "Delete layer": "Διαγραφή επιπέδου",
    "Delete this feature": "Διαγραφή αυτού του στοιχείου",
    "Delete this property on all the features": "Διαγραφή αυτής της ιδιότητας από όλα τα στοιχεία",
    "Delete this shape": "Διαγραφή σχήματος",
    "Delete this vertex (Alt+Click)": "Διαγραφή αυτής της κορυφής (Alt+Click)",
    "Directions from here": "Κατευθύνσεις από εδώ",
    "Display measure": "Εμφάνιση μέτρησης",
    "Display on load": "Εμφάνιση κατά την φόρτωση",
    "Download": "Λήψη",
    "Download data": "Λήψη δεδομένων",
    "Drag to reorder": "Σύρετε για αναδιάταξη",
    "Draw a line": "Σχεδιασμός γραμμής",
    "Draw a marker": "Σχεδιασμός σημείου",
    "Draw a polygon": "Σχεδιασμός πολυγώνου",
    "Draw a polyline": "Σχεδιασμός σύνθετης γραμμής",
    "Dynamic": "Δυναμική",
    "Dynamic properties": "Δυναμικές ιδιότητες",
    "Edit": "Επεξεργασία",
    "Edit feature's layer": "Επεξεργασία επιπέδου του στοιχείου",
    "Edit map properties": "Επεξεργασία ιδιοτήτων χάρτη",
    "Edit map settings": "Επεξεργασία ρυθμίσεων χάρτη",
    "Edit properties in a table": "Επεξεργασία ιδιοτήτων σε πίνακα",
    "Edit this feature": "Επεξεργασία αυτού του στοιχείου",
    "Embed and share this map": "Ένθεση και διαμοιρασμός του χάρτη",
    "Embed the map": "Ένθεση του χάρτη",
    "Empty": "Κενό",
    "Error in the tilelayer URL": "Σφάλμα συνδέσμου υποβάθρου",
    "Error while fetching {url}": "Σφάλμα κατά την ανάκτηση {url}",
    "Exit Fullscreen": "Κλείσιμο πλήρους οθόνης",
    "Extract shape to separate feature": "Εξαγωγή σχήματος σε ξεχωριστό στοιχείο",
    "Fetch data each time map view changes.": "Ανάκτηση δεδομένων κάθε φορά που αλλάζει η προβολή του χάρτη.",
    "Filter keys": "Βασικά φίλτρα",
    "Format": "Μορφοποίηση",
    "From zoom": "Από εστίαση",
    "Go to «{feature}»": "Μετάβαση στο «{feature}»",
    "Heatmap intensity property": "Ένταση του χάρτη εγγύτητας",
    "Heatmap radius": "Ακτίνα του χάρτη εγγύτητας",
    "Help": "Βοήθεια",
    "Hide controls": "Απόκρυψη εργαλείων ελέγχου",
    "Home": "Αρχική",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Πόσο απλοποιείται η συνθέτη γραμμή σε κάθε επίπεδο εστίασης (περισσότερο = καλύτερη απόδοση και ομαλότερη εμφάνιση, λιγότερο = περισσότερη ακρίβεια)",
    "If false, the polygon will act as a part of the underlying map.": "Αν είναι απενεργοποιημένο, το πολύγωνο θα συμπεριφέρεται ως μέρος του υποκείμενου χάρτη.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe με προσαρμοσμένο ύψος (σε px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe με προσαρμοσμένο ύψος και πλάτος (σε px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Εικόνα με προσαρμοσμένο πλάτος (σε px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Εικόνα: {{http://image.url.com}}",
    "Import": "Εισαγωγή",
    "Import data": "Εισαγωγή δεδομένων",
    "Import in a new layer": "Εισαγωγή σε νέο επίπεδο",
    "Imports all umap data, including layers and settings.": "Εισάγει όλα τα δεδομένα umap, μαζί με τα επίπεδα και τις ρυθμίσεις.",
    "Include full screen link?": "Συμπερίληψη συνδέσμου πλήρους οθόνης;",
    "Interaction options": "Επιλογές αλληλεπίδρασης",
    "Invalid umap data": "Μη έγκυρα δεδομένα umap",
    "Invalid umap data in {filename}": "Μη έγκυρα δεδομένα στο αρχείο {filename}",
    "Keep current visible layers": "Διατήρηση τρεχουσών ορατών επιπέδων",
    "Latitude": "Γεωγραφικό πλάτος",
    "Layer": "Επίπεδο",
    "Layer properties": "Ιδιότητες επιπέδου",
    "Licence": "Άδεια",
    "Limit bounds": "Περιορισμός ορίων",
    "Link to…": "Σύνδεση με...",
    "Link with text: [[http://example.com|text of the link]]": "Σύνδεση με κείμενο: [[http://example.com|text του συνδέσμου]]",
    "Long credits": "Αναλυτικές πιστώσεις",
    "Longitude": "Γεωγραφικό μήκος",
    "Make main shape": "Ορίστε το ως κύριο σχήμα",
    "Manage layers": "Διαχείριση επιπέδων",
    "Map background credits": "Πιστοποιητικά υποβάθρου του χάρτη",
    "Map has been attached to your account": "Ο χάρτης έχει συνδεθεί με τον λογαριασμό σας",
    "Map has been saved!": "Ο χάρτης έχει αποθηκευτεί!",
    "Map user content has been published under licence": "Το περιεχόμενο του χάρτη έχει δημοσιευτεί με συγκεκριμένη άδεια",
    "Map's editors": "Συντάκτες",
    "Map's owner": "Ιδιοκτησία",
    "Merge lines": "Συγχώνευση γραμμών",
    "More controls": "Περισσότερα εργαλεία ελέγχου",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Πρέπει να είναι έγκυρη τιμή CSS (π.χ.: DarkBlue ή #123456)",
    "No licence has been set": "Δεν έχει οριστεί άδεια χρήσης",
    "No results": "Δεν υπάρχουν αποτελέσματα",
    "Only visible features will be downloaded.": "Θα γίνει λήψη μόνο των ορατών στοιχείων",
    "Open download panel": "Ανοίξτε το πλαίσιο λήψης",
    "Open link in…": "Άνοιγμα συνδέσμου σε…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Ανοίξτε τον χάρτη σε έναν επεξεργαστή χαρτών για να παρέχετε πιο ακριβή δεδομένα στο OpenStreetMap",
    "Optional intensity property for heatmap": "Προαιρετική ιδιότητα έντασης για τον χάρτη εγγύτητας",
    "Optional. Same as color if not set.": "Προαιρετικό. Ίδιο με το χρώμα αν δεν οριστεί.",
    "Override clustering radius (default 80)": "Παράκαμψη ακτίνας συμπλέγματος (προεπιλογή 80)",
    "Override heatmap radius (default 25)": "Παράκαμψη ακτίνας χάρτη εγγύτητας (προεπιλογή 25)",
    "Please be sure the licence is compliant with your use.": "Παρακαλώ βεβαιωθείτε ότι η άδεια είναι σύμφωνη με την χρήση σας",
    "Please choose a format": "Παρακαλώ επιλέξτε μια μορφοποίηση",
    "Please enter the name of the property": "Παρακαλώ εισαγάγετε το όνομα της ιδιότητας",
    "Please enter the new name of this property": "Παρακαλώ εισαγάγετε το νέο όνομα αυτής της ιδιότητας",
    "Problem in the response": "Πρόβλημα στην απόκριση",
    "Problem in the response format": "Πρόβλημα στη μορφοποίηση απόκρισης",
    "Properties imported:": "Ιδιότητες που έχουν εισαχθεί:",
    "Provide an URL here": "Δώστε έναν σύνδεσμο εδώ",
    "Proxy request": "Αίτημα απομακρυσμένου διαμεσολαβητή",
    "Remote data": "Απομακρυσμένα δεδομένα",
    "Remove shape from the multi": "Αφαίρεση σχήματος από πολυδεδομένο",
    "Rename this property on all the features": "Μετονομασία αυτής της ιδιότητας σε όλα τα στοιχεία",
    "Replace layer content": "Αντικατάσταση περιεχομένου του επιπέδου",
    "Restore this version": "Επαναφορά αυτής της έκδοσης",
    "Save": "Αποθήκευση",
    "Save anyway": "Αποθήκευση οπωσδήποτε",
    "Save current edits": "Αποθήκευση τρέχουσας επεξεργασίας",
    "Save this center and zoom": "Αποθήκευση αυτής της προβολής με το συγκεκριμένο κεντράρισμα και το επίπεδο εστίασης.",
    "Save this location as new feature": "Αποθήκευση αυτής της τοποθεσίας ως νέο στοιχείο",
    "Search a place name": "Αναζήτηση τοποθεσίας",
    "Search location": "Αναζήτηση τοποθεσίας",
    "See all": "Εμφάνιση όλων",
    "See data layers": "Εμφάνιση επιπέδων δεδομένων",
    "See full screen": "Εμφάνιση πλήρους οθόνης",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Απενεργοποίηση εάν επιθυμείτε την απόκρυψη του επιπέδου κατά την προβολή των διαφανειών, την περιήγηση δεδομένων, την αναδυόμενη πλοήγηση...",
    "Shape properties": "Ιδιότητες σχήματος",
    "Short URL": "Σύντομος σύνδεσμος",
    "Short credits": "Εύσημα εν συντομία",
    "Show/hide layer": "Εμφάνιση/απόκρυψη επιπέδου",
    "Simple link: [[http://example.com]]": "Απλός σύνδεσμος: [[http://example.com]]",
    "Slideshow": "Παρουσίαση",
    "Sort key": "Κλειδί ταξινόμησης",
    "Split line": "Διαίρεση γραμμής",
    "Start a hole here": "Δημιουργία κενής περιοχής εδώ",
    "Start editing": "Έναρξη επεξεργασίας",
    "Start slideshow": "Έναρξη παρουσίασης",
    "Stop editing": "Τερματισμός επεξεργασίας",
    "Stop slideshow": "Τερματισμός παρουσίασης",
    "Supported scheme": "Υποστηριζόμενο σχέδιο",
    "Supported variables that will be dynamically replaced": "Υποστηριζόμενες μεταβλητές που θα αντικατασταθούν δυναμικά",
    "TMS format": "Μορφοποίηση TMS",
    "Text color for the cluster label": "Χρώμα κειμένου για την ετικέτα συμπλέγματος",
    "Text formatting": "Μορφοποίηση κειμένου",
    "To use if remote server doesn't allow cross domain (slower)": "Για χρήση εάν ο απομακρυσμένος διακομιστής δεν επιτρέπει cross domain (πιο αργή)",
    "To zoom": "Για εστίαση",
    "Transfer shape to edited feature": "Μεταφορά σχήματος σε επεξεργασμένο στοιχείο",
    "Transform to lines": "Μετασχηματισμός σε γραμμές",
    "Transform to polygon": "Μετασχηματισμός σε πολύγωνο",
    "Type of layer": "Τύπος επιπέδου",
    "Unable to detect format of file {filename}": "Δεν είναι δυνατή η αναγνώριση της μορφοποίησης του αρχείου {filename}",
    "Untitled layer": "Επίπεδο χωρίς όνομα",
    "Untitled map": "Χάρτης χωρίς όνομα",
    "Update permissions": "Ενημέρωση δικαιωμάτων χάρτη",
    "Update permissions and editors": "Ενημέρωση δικαιωμάτων και συντακτών",
    "Url": "Σύνδεσμος",
    "Use current bounds": "Χρήση τρεχόντων ορίων",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Χρησιμοποιήστε σύμβολα υποκατάστασης με τις ιδιότητες του στοιχείου μεταξύ αγκυλών, π.χ. &#123;name&#125;, θα αντικατασταθούν δυναμικά από τις αντίστοιχες τιμές.",
    "User content credits": "Εύσημα περιεχομένου χρήστη",
    "User interface options": "Περιβάλλον χρήστη",
    "Versions": "Εκδόσεις",
    "View Fullscreen": "Προβολή πλήρους οθόνης",
    "Where do we go from here?": "Πού πάμε από εδώ;",
    "Whether to display or not polygons paths.": "Εάν πρόκειται να εμφανίσετε ή όχι μονοπάτια πολυγώνων.",
    "Whether to fill polygons with color.": "Εάν πρόκειται να γεμίσετε πολύγωνα με χρώμα.",
    "Who can edit": "Επεξεργασία",
    "Who can view": "Προβολή",
    "Will be displayed in the bottom right corner of the map": "Θα εμφανιστεί στην κάτω δεξιά γωνία του χάρτη",
    "Will be visible in the caption of the map": "Θα είναι ορατό στη λεζάντα του χάρτη",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Οπς! Κάποιος άλλος φαίνεται πως έχει επεξεργαστεί τα δεδομένα. Μπορείτε να αποθηκεύσετε ούτως ή άλλως, αλλά αυτό θα διαγράψει τις αλλαγές που έγιναν από άλλους.",
    "Zoom in": "Μεγέθυνση",
    "Zoom level for automatic zooms": "Επίπεδο εστίασης για αυτόματες μεγεθύνσεις/σμικρύνσεις",
    "Zoom out": "Σμίκρυνση",
    "Zoom to layer extent": "Εστίαση στο χώρο κάλυψης του επίπεδου",
    "Zoom to the next": "Εστίαση στο επόμενο",
    "Zoom to the previous": "Εστίαση στο προηγούμενο",
    "Zoom to this feature": "Εστίαση σε αυτό το στοιχείο",
    "Zoom to this place": "Εστίαση σε αυτή την τοποθεσία",
    "attribution": "Αναφορά",
    "by": "από",
    "display name": "Όνομα που εμφανίζεται",
    "height": "Ύψος",
    "licence": "Άδεια",
    "max East": "Μέγιστο ανατολικά",
    "max North": "Μέγιστο βόρεια",
    "max South": "Μέγιστο νότια",
    "max West": "Μέγιστο δυτικά",
    "max zoom": "Μέγιστη εστίαση",
    "min zoom": "Ελάχιστη εστίαση",
    "next": "Επόμενο",
    "previous": "Προηγούμενο",
    "width": "Πλάτος",
    "{count} errors during import: {message}": "{count} σφάλματα κατά την εισαγωγή: {message}",
    "Measure distances": "Μέτρηση αποστάσεων",
    "NM": "ΝΜ",
    "kilometers": "Χιλιόμετρα",
    "km": "χμ.",
    "mi": "μλ.",
    "miles": "Μίλια",
    "nautical miles": "Ναυτικά μίλια",
    "1 day": "1 μέρα",
    "1 hour": "1 ώρα",
    "5 min": "5 λεπτά",
    "Cache proxied request": "Αίτημα μεσολάβησης προσωρινής μνήμης",
    "No cache": "Δεν υπάρχει προσωρινή μνήμη",
    "Popup": "Αναδυόμενο",
    "Popup (large)": "Αναδυόμενο (μεγάλο)",
    "Popup content style": "Στυλ περιεχομένου αναδυόμενου",
    "Popup shape": "Σχήμα αναδυόμενου",
    "Skipping unknown geometry.type: {type}": "Παράλειψη άγνωστου geometry.type: {type}",
    "Optional.": "Προαιρετικό",
    "Paste your data here": "Επικόλληση των δεδομένων σας εδώ",
    "Please save the map first": "Παρακαλώ αποθηκεύστε τον χάρτη πρώτα",
    "Feature identifier key": "Κλειδί αναγνώρισης στοιχείου",
    "Open current feature on load": "Άνοιγμα τρέχοντος στοιχείου κατά τη φόρτωση",
    "Permalink": "Μόνιμος σύνδεσμος",
    "The name of the property to use as feature unique identifier.": "Το όνομα της ιδιότητας που θα χρησιμοποιείται ως μοναδικό αναγνωριστικό.",
    "Do you want to display caption menus?": "Θέλετε να εμφανίζονται τα μενού των λεζαντών;",
    "Example: key1,key2,key3": "Παράδειγμα: key1,key2,key3",
    "Invalid latitude or longitude": "Μη έγκυρο γεωγραφικό πλάτος ή μήκος",
    "Invalide property name: {name}": "Μη έγκυρο όνομα ιδιότητας: {name}",
    "Permanent credits": "Μόνιμα εύσημα",
    "Permanent credits background": "Φόντο μόνιμων ευσήμων",
    "Select data": "Επιλογή δεδομένων",
    "Will be permanently visible in the bottom left corner of the map": "Θα είναι μόνιμα ορατό στην κάτω αριστερή γωνία του χάρτη.",
    "{area}&#8239;acres": "{area}&#8239;έικρ",
    "{area}&#8239;ha": "{area}&#8239;εκτάρια",
    "{area}&#8239;m&sup2;": "{area}&#8239;μέτρα&sup2;",
    "{area}&#8239;mi&sup2;": "{area}&#8239;μίλια&sup2;",
    "{area}&#8239;yd&sup2;": "{area}&#8239;γιάρδες&sup2;",
    "{distance}&#8239;NM": "{distance}&#8239;ναυτικά μίλια",
    "{distance}&#8239;km": "{distance}&#8239;χιλιόμετρα",
    "{distance}&#8239;m": "{distance}&#8239;μέτρα",
    "{distance}&#8239;miles": "{distance}&#8239;μίλια",
    "{distance}&#8239;yd": "{distance}&#8239;γιάρδες",
    " (area: {measure})": "(περιοχή: {measure})",
    " (length: {measure})": "(μήκος: {measure})",
    "Animated transitions": "Κινούμενες μεταβάσεις",
    "Background overlay url": "Διεύθυνση URL επικάλυψης φόντου",
    "Custom overlay": "Προσαρμοσμένη επικάλυψη",
    "Display the star map button": "Εμφάνιση του κουμπιού για χάρτη με αστέρι",
    "Error in the overlay URL": "Σφάλμα στη διεύθυνση URL επικάλυψης",
    "Map has been starred": "Ο χάρτης έχει επισημανθεί με αστέρι",
    "Map has been unstarred": "Το αστέρι αφαιρέθηκε από τον χάρτη",
    "Opacity": "Αδιαφάνεια",
    "Star this map": "Τοποθέτηση αστεριού σε αυτόν τον χάρτη",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Το σύμβολο μπορεί να είναι είτε χαρακτήρας unicode είτε URL. Μπορείτε να χρησιμοποιήσετε ιδιότητες χαρακτηριστικών ως μεταβλητές: π.χ.: με \"http://myserver.org/images/{name}.png\", η μεταβλητή {name} θα αντικατασταθεί από την τιμή \"name\" του κάθε δείκτη.",
    "Direct link": "Απευθείας σύνδεσμος",
    "Export options": "Εξαγωγή ιδιοτήτων",
    "The zoom and center have been modified.": "Η εστίαση και το κέντρο έχουν τροποποιηθεί.",
    "Congratulations, your map has been created!": "Συγχαρητήρια, ο χάρτης σας δημιουργήθηκε!",
    "Copy link": "Αντιγραφή συνδέσμου",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Ο μυστικός σύνδεσμος επεξεργασίας αντιγράφηκε στο πρόχειρο!",
    "Send me the link": "Στείλε μου τον σύνδεσμο",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Ο χάρτης σας δημιουργήθηκε! Καθώς δεν είστε συνδεδεμένοι, εδώ είναι ο μυστικός σύνδεσμός σας για να επεξεργαστείτε τον χάρτη. Κρατήστε τον ασφαλή:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- για οριζόντιο χάρακα",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Μεγέθυνση στα δεδομένα",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("el", locale)
L.setLocale("el")
