const locale = {
    "Allow scroll wheel zoom?": "Leyfa aðdrátt með skrunhjóli?",
    "Automatic": "Sjálfvirkt",
    "Ball": "Kúla",
    "Cancel": "Hætta við",
    "Caption": "Skýringatexti",
    "Choose the data format": "Veldu gagnasnið",
    "Choose the layer of the feature": "Veldu lagið með fitjunni",
    "Circle": "Hringur",
    "Clustered": "Í klösum",
    "Data browser": "Gagnavafri",
    "Default": "Sjálfgefið",
    "Default zoom level": "Sjálfgefið aðdráttarstig",
    "Default: name": "Sjálfgefið: nafn",
    "Display label": "Birta skýringu",
    "Display the control to open OpenStreetMap editor": "Birta hnapp til að opna OpenStreetMap-ritill",
    "Display the data layers control": "Birta hnapp fyrir gagnalög",
    "Display the embed control": "Birta hnapp fyrir ígræðslukóða",
    "Display the fullscreen control": "Birta hnapp fyrir skjáfylli",
    "Display the locate control": "Birta staðsetningarhnapp",
    "Display the measure control": "Birta mælihnapp",
    "Display the search control": "Birta leitarhnapp",
    "Display the tile layers control": "Birta hnapp fyrir kortatíglalög",
    "Display the zoom control": "Birta aðdráttarhnapp",
    "Do you want to display a caption bar?": "Viltu birta skjástiku með skýringatexta?",
    "Do you want to display a minimap?": "Viltu birta yfirlitskort?",
    "Do you want to display a panel on load?": "Viltu birta hliðarspjald við innhleðslu?",
    "Do you want to display popup footer?": "Viltu birta síðufót sem sprettglugga?",
    "Do you want to display the scale control?": "Viltu birta kvarðahnapp?",
    "Do you want to display the «more» control?": "Viltu birta hnapp fyrir «meira»?",
    "Drop": "Dropi",
    "GeoRSS (only link)": "GeoRSS (aðeins tengill)",
    "GeoRSS (title + image)": "GeoRSS (titill + mynd)",
    "Heatmap": "Hitakort",
    "Icon shape": "Lögun Táknmyndar",
    "Icon symbol": "Myndtákn",
    "Inherit": "Erfa",
    "Label direction": "Stefna skýringar",
    "Label key": "Lykill skýringar",
    "Labels are clickable": "Hægt er að smella á skýringar",
    "None": "Ekkert",
    "On the bottom": "Neðst",
    "On the left": "Vinstra megin",
    "On the right": "Hægra megin",
    "On the top": "Efst",
    "Popup content template": "Sniðmát efnis í sprettglugga",
    "Side panel": "Hliðarspjald",
    "Simplify": "Einfalda",
    "Table": "Tafla",
    "always": "alltaf",
    "clear": "hreinsa",
    "collapsed": "samfallið",
    "color": "litur",
    "dash array": "strikafylki",
    "define": "skilgreina",
    "description": "lýsing",
    "expanded": "útliðað",
    "fill": "fylling",
    "fill color": "fyllilitur",
    "fill opacity": "ógegnsæi fyllingar",
    "hidden": "falið",
    "iframe": "iFrame",
    "inherit": "erfa",
    "name": "heiti",
    "never": "aldrei",
    "new window": "nýr gluggi",
    "no": "nei",
    "on hover": "við yfirsvif",
    "opacity": "ógegnsæi",
    "parent window": "yfirgluggi",
    "stroke": "strik",
    "weight": "þykkt",
    "yes": "já",
    "{delay} seconds": "{delay} sekúndur",
    "# one hash for main heading": "# eitt myllumerki fyrir aðalfyrirsögn",
    "## two hashes for second heading": "## tvö myllumerki fyrir aðra fyrirsögn",
    "### three hashes for third heading": "### þrjú myllumerki fyrir þriðju fyrirsögn",
    "**double star for bold**": "**tvöföld stjarna/margföldun fyrir feitletrað**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Kommu-aðgreindur listi með tölum sem skilgreina strikamynstur. Til dæmis: \"5, 10, 15\".",
    "About": "Um hugbúnaðinn",
    "Action not allowed :(": "Þessi aðgerð er ekki leyfð :(",
    "Activate slideshow mode": "Virkja skyggnusýningarham",
    "Add a layer": "Bæta við lagi",
    "Add a line to the current multi": "Bæta línu við fyrirliggjandi hóp",
    "Add a new property": "Bæta við nýju eigindi",
    "Add a polygon to the current multi": "Bæta marghyrningi við fyrirliggjandi hóp",
    "Advanced actions": "Ítarlegri aðgerðir",
    "Advanced properties": "Ítarlegir eiginleikar",
    "All properties are imported.": "Öll eigindi voru flutt inn.",
    "Allow interactions": "Leyfa gagnvirkni",
    "An error occured": "Villa kom upp",
    "Are you sure you want to cancel your changes?": "Ertu viss um að þú viljir hætta við breytingarnar þínar?",
    "Are you sure you want to clone this map and all its datalayers?": "Ertu viss um að þú viljir klóna þetta kort og öll gagnalög þess?",
    "Are you sure you want to delete the feature?": "Ertu viss um að þú viljir eyða fitjunni?",
    "Are you sure you want to delete this layer?": "Ertu viss um að þú viljir eyða þessu lagi?",
    "Are you sure you want to delete this map?": "Ertu viss um að þú viljir eyða þessu korti?",
    "Are you sure you want to delete this property on all the features?": "Ertu viss um að þú viljir eyða þessu eigindi á öllum fitjum?",
    "Are you sure you want to restore this version?": "Ertu viss um að vilja endurheimta þessa útgáfu?",
    "Attach the map to my account": "Tengja kortið við notandaaðganginn minn",
    "Auto": "Sjálfvirkt",
    "Autostart when map is loaded": "Sjálfræsa þegar korti er hlaðið inn",
    "Bring feature to center": "Færa fitju að miðju",
    "Browse data": "Skoða gögn",
    "Cancel edits": "Hætta við breytingar",
    "Center map on your location": "Miðjusetja kortið á staðsetningu þína",
    "Change map background": "Breyta bakgrunni landakorts",
    "Change tilelayers": "Skipta um kortatíglalög",
    "Choose a preset": "Veldu forstillingu",
    "Choose the format of the data to import": "Veldu snið á gögnum sem á að flytja inn",
    "Choose the layer to import in": "Veldu lagið sem á að flytja inn í",
    "Click last point to finish shape": "Smelltu á síðasta punktinn til að ljúka lögun",
    "Click to add a marker": "Smella til að bæta við kortamerki",
    "Click to continue drawing": "Smelltu til að halda áfram að teikna",
    "Click to edit": "Smelltu til að breyta",
    "Click to start drawing a line": "Smelltu til að byrja að teikna línu",
    "Click to start drawing a polygon": "Smelltu til að byrja að teikna fláka (marghyrning)",
    "Clone": "Klóna",
    "Clone of {name}": "Klónað afrit af {name}",
    "Clone this feature": "Klóna þessa fitju",
    "Clone this map": "Klóna þetta landakort",
    "Close": "Loka",
    "Clustering radius": "Radíus klasa",
    "Comma separated list of properties to use when filtering features": "Kommu-aðgreindur listi yfir eigindi sem notaður er við síun fitja",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Gildi aðgreind með kommu, dálkmerki (tab) eða semíkommu. Miðað við SRS hnattviðmið WGS84. Einungis punktalaganir (geometries) eru fluttar inn. Við innflutning er skoðað í fyrirsögnum dálka hvort minnst sé á «lat» eða «lon» í byrjun fyrirsagna, óháð há-/lágstöfum. Allir aðrir dálkar eru fluttir inn sem eigindi.",
    "Continue line": "Halda áfram með línu",
    "Continue line (Ctrl+Click)": "Halda áfram með línu (Ctrl+Smella)",
    "Coordinates": "Hnit",
    "Credits": "Framlög",
    "Current view instead of default map view?": "Fyrirliggjandi sýn í stað sjálfgefinnar kortasýnar?",
    "Custom background": "Sérsniðinn bakgrunnur",
    "Data is browsable": "Gögn eru vafranleg",
    "Default interaction options": "Sjálfgefnir valkostir gagnvirkni",
    "Default properties": "Sjálfgefnir eiginleikar",
    "Default shape properties": "Sjálfgefnir eiginleikar lögunar",
    "Define link to open in a new window on polygon click.": "Skilgreindu tengil til að opna í nýjum glugga þegar smellt er á marghyrning.",
    "Delay between two transitions when in play mode": "Hlé milli tveggja millifærslna í afspilunarham",
    "Delete": "Eyða",
    "Delete all layers": "Eyða öllum lögum",
    "Delete layer": "Eyða lagi",
    "Delete this feature": "Eyða þessari fitju",
    "Delete this property on all the features": "Eyða þessu eigindi á öllum fitjum",
    "Delete this shape": "Eyða þessari lögun",
    "Delete this vertex (Alt+Click)": "Eyða þessum brotpunkti (Alt+Smella)",
    "Directions from here": "Leiðir héðan",
    "Display measure": "Birta lengdarmæli",
    "Display on load": "Birta við innhleðslu",
    "Download": "Sækja",
    "Download data": "Sækja gögn",
    "Drag to reorder": "Draga til að endurraða",
    "Draw a line": "Teikna línu",
    "Draw a marker": "Teikna kortamerki",
    "Draw a polygon": "Teikna fláka (marghyrning)",
    "Draw a polyline": "Teikna fjölpunktalínu (polyline)",
    "Dynamic": "Breytilegt",
    "Dynamic properties": "Breytilegir eiginleikar",
    "Edit": "Breyta",
    "Edit feature's layer": "Breyta lagi fitjunnar",
    "Edit map properties": "Breyta eiginleikum korts",
    "Edit map settings": "Breyta stillingum korts",
    "Edit properties in a table": "Breyta eigindum í töflu",
    "Edit this feature": "Breyta þessari fitju",
    "Embed and share this map": "Setja inn á vefsíðu og deila þessu korti",
    "Embed the map": "Setja landakortið inn á vefsíðu",
    "Empty": "Tómt",
    "Error in the tilelayer URL": "Villa í slóð kortatíglalags",
    "Error while fetching {url}": "Villa við að sækja {url}",
    "Exit Fullscreen": "Hætta í skjáfylli",
    "Extract shape to separate feature": "Flytja lögun í aðskilda fitju",
    "Fetch data each time map view changes.": "Sækja gögn í hvert skipti sem kortasýn breytist",
    "Filter keys": "Sía lykla",
    "Format": "Snið",
    "From zoom": "Frá aðdráttarstigi",
    "Go to «{feature}»": "Fara á «{feature}»",
    "Heatmap intensity property": "Styrkeigindi fyrir hitakort",
    "Heatmap radius": "Radíus hitakorts",
    "Help": "Hjálp",
    "Hide controls": "Fela hnappa",
    "Home": "Heim",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hve mikið eigi að einfalda fjölpunktalínu á hverju aðdráttarstigi (meira = betri afköst og mýkra útlit, minna = nákvæmara)",
    "If false, the polygon will act as a part of the underlying map.": "Ef þetta er ósatt, mun marghyrningurinn verða hluti af undirliggjandi korti.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe með sérsniðinni hæð (í mynddílum/px): {{{http://iframe.url.com|hæð}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe með sérsniðinni hæð og breidd (í mynddílum/px): {{{http://iframe.url.com|hæð*breidd}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Mynd með sérsniðinni breidd (í mynddílum): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Mynd: {{http://image.url.com}}",
    "Import": "Flytja inn",
    "Import data": "Flytja inn gögn",
    "Import in a new layer": "Flytja inn í nýtt lag",
    "Imports all umap data, including layers and settings.": "Flytur inn öll umap-gögn, þar með talin lög og stillingar.",
    "Include full screen link?": "Hafa með tengil á að fylla skjá?",
    "Interaction options": "Valkostir gagnvirkni",
    "Invalid umap data": "Ógild umap-gögn",
    "Invalid umap data in {filename}": "Ógild umap-gögn í {filename}",
    "Keep current visible layers": "Halda fyrirliggjandi sýnilegum lögum",
    "Latitude": "Breiddargráða",
    "Layer": "Lag",
    "Layer properties": "Eiginleikar lags",
    "Licence": "Notkunarleyfi",
    "Limit bounds": "Mörk útjaðars",
    "Link to…": "Tengja við…",
    "Link with text: [[http://example.com|text of the link]]": "Tengill með texta: [[http://example.com|texti tengils]]",
    "Long credits": "Lengra um framlög",
    "Longitude": "Lengdargráða",
    "Make main shape": "Gera að aðallögun",
    "Manage layers": "Sýsla með lög",
    "Map background credits": "Þakkir vegna bakgrunnsmyndar:",
    "Map has been attached to your account": "Kortið hefur verið tengt við notandaaðganginn þinn",
    "Map has been saved!": "Landakortið hefur verið vistað!",
    "Map user content has been published under licence": "Kortagögn notandans eru gefin út með notkunarleyfinu",
    "Map's editors": "Ritstjórar korts",
    "Map's owner": "Eigandi korts",
    "Merge lines": "Sameina línur",
    "More controls": "Fleiri hnappar",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Verður að vera gilt CSS-gildi (t.d.: DarkBlue eða #123456)",
    "No licence has been set": "Ekkert notkunarleyfi hefur verið sett",
    "No results": "Engar niðurstöður",
    "Only visible features will be downloaded.": "Aðeins verður náð í sýnilegar fitjur.",
    "Open download panel": "Opna niðurhalsspjald",
    "Open link in…": "Opna tengil í…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Opna umfang þessa korts í kortavinnsluforriti til að gefa nákvæmari kortagögn til OpenStreetMap",
    "Optional intensity property for heatmap": "Valfrjálst styrkeigindi fyrir hitakort",
    "Optional. Same as color if not set.": "Valfrjálst. Sama og litur ef ekkert er skilgreint.",
    "Override clustering radius (default 80)": "Nota annan radíus klösunar (sjálfgefið 80)",
    "Override heatmap radius (default 25)": "Nota annan radíus hitakorts (sjálfgefið 25)",
    "Please be sure the licence is compliant with your use.": "Gakktu úr skugga um að notkunarleyfið samsvari notkunasviði þínu.",
    "Please choose a format": "Veldu snið",
    "Please enter the name of the property": "Settu inn heiti á eigindið",
    "Please enter the new name of this property": "Settu inn nýja heitið á þetta eigindi",
    "Problem in the response": "Vandamál í svarinu",
    "Problem in the response format": "Vandamál með snið svarsins",
    "Properties imported:": "Innflutt eigindi:",
    "Provide an URL here": "Gefðu hér upp URL-slóð",
    "Proxy request": "Beiðni frá milliþjóni",
    "Remote data": "Fjartengd gögn",
    "Remove shape from the multi": "Fjarlægja lögun úr hópnum",
    "Rename this property on all the features": "Endurnefna þetta eigindi á öllum fitjum",
    "Replace layer content": "Skipta út innihaldi lagsins",
    "Restore this version": "Endurheimta þessa útgáfu",
    "Save": "Vista",
    "Save anyway": "Vista samt",
    "Save current edits": "Vista fyrirliggjandi breytingar",
    "Save this center and zoom": "Vista þessa miðju og aðdrátt",
    "Save this location as new feature": "Vista þessa staðsetningu sem nýja fitju",
    "Search a place name": "Leita að staðarheiti",
    "Search location": "Leita að staðsetningu",
    "See all": "Sjá allt",
    "See data layers": "Skoða gagnalög",
    "See full screen": "Fylla skjáinn",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Settu þetta sem ósatt til að fela þetta lag úr skyggnusýningu, gagnavafranum, sprettleiðsögn…",
    "Shape properties": "Eiginleikar lögunar",
    "Short URL": "Stytt slóð",
    "Short credits": "Stutt um framlög",
    "Show/hide layer": "Birta/Fela lag",
    "Simple link: [[http://example.com]]": "Einfaldur tengill: [[http://example.com]]",
    "Slideshow": "Skyggnusýning",
    "Sort key": "Röðunarlykill",
    "Split line": "Skipta línu",
    "Start a hole here": "Byrja holu hér",
    "Start editing": "Hefja breytingar",
    "Start slideshow": "Hefja skyggnusýningu",
    "Stop editing": "Hætta breytingum",
    "Stop slideshow": "Stöðva skyggnusýningu",
    "Supported scheme": "Stutt skema",
    "Supported variables that will be dynamically replaced": "Studdar breytur sem verður skipt út eftir þörfum",
    "TMS format": "TMS-snið",
    "Text color for the cluster label": "Litur á texta fyrir skýringu á klasa",
    "Text formatting": "Snið á texta",
    "To use if remote server doesn't allow cross domain (slower)": "Nota ef fjartengdur þjónn leyfir ekki millivísanir léna (hægvirkara)",
    "To zoom": "Í aðdrátt",
    "Transfer shape to edited feature": "Flytja lögun í breyttu fitjuna",
    "Transform to lines": "Umbreyta í línur",
    "Transform to polygon": "Umbreyta í fláka/marghyrning",
    "Type of layer": "Tegund lags",
    "Unable to detect format of file {filename}": "Tókst ekki að ákvarða sniðið á skránni {filename}",
    "Untitled layer": "Ónefnt lag",
    "Untitled map": "Ónefnt landakort",
    "Update permissions": "Uppfæra heimildir",
    "Update permissions and editors": "Uppfæra heimildir og ritstjóra",
    "Url": "Slóð",
    "Use current bounds": "Nota fyrirliggjandi útjaðar",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Notaðu frátökutákn með eigindum fitja innan sviga, t.d. &#123;nafn&#125;, þeim verður skipt út eftir þörfum fyrir samsvarandi gildi.",
    "User content credits": "Framlög notanda á efni",
    "User interface options": "Valkostir notendaviðmóts",
    "Versions": "Útgáfur",
    "View Fullscreen": "Fylla skjáinn",
    "Where do we go from here?": "Hvert förum við héðan?",
    "Whether to display or not polygons paths.": "Hvort birta eigi ferla fláka/marghyrninga.",
    "Whether to fill polygons with color.": "Hvort eigi að fylla fláka með lit.",
    "Who can edit": "Hverjir geta breytt",
    "Who can view": "Hverjir geta skoðað",
    "Will be displayed in the bottom right corner of the map": "Verður birt niðri í hægra horni kortsins",
    "Will be visible in the caption of the map": "Verður sýnilegt í skýringatexta kortsins",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Úbbs! Það lítur út fyrir að einhver annar hafi breytt gögnunum. Þú getur samt vistað, en það mun hreinsa út breytingarnar sem hinn aðilinn gerði.",
    "Zoom in": "Renna að",
    "Zoom level for automatic zooms": "Aðdráttarstig fyrir sjálfvirkan aðdrátt",
    "Zoom out": "Renna frá",
    "Zoom to layer extent": "Renna að útjöðrum lags",
    "Zoom to the next": "Aðdráttur að næsta",
    "Zoom to the previous": "Aðdráttur á fyrra",
    "Zoom to this feature": "Aðdráttur að þessari fitju",
    "Zoom to this place": "Aðdráttur á þennan stað",
    "attribution": "tilvísun í höfund/a",
    "by": "eftir",
    "display name": "birtingarnafn",
    "height": "hæð",
    "licence": "notkunarleyfi",
    "max East": "Hám. austur",
    "max North": "Hám. norður",
    "max South": "Hám. suður",
    "max West": "Hám. vestur",
    "max zoom": "Hám. aðdráttur",
    "min zoom": "lágm. aðdráttur",
    "next": "næsta",
    "previous": "fyrra",
    "width": "breidd",
    "{count} errors during import: {message}": "{count} villur við innflutning: {message}",
    "Measure distances": "Mæla vegalengdir",
    "NM": "Sjómílur",
    "kilometers": "kílómetrar",
    "km": "km",
    "mi": "mi",
    "miles": "mílur",
    "nautical miles": "sjómílur",
    "1 day": "1 dagur",
    "1 hour": "1 klukkustund",
    "5 min": "5 mín",
    "Cache proxied request": "Setja milliþjónabeiðnir í skyndiminni",
    "No cache": "Ekkert biðminni",
    "Popup": "Sprettgluggi",
    "Popup (large)": "Sprettgluggi (stór)",
    "Popup content style": "Stíll efnis í sprettglugga",
    "Popup shape": "Lögun sprettglugga",
    "Skipping unknown geometry.type: {type}": "Sleppi óþekktu geometry.type: {type}",
    "Optional.": "Valfrjálst.",
    "Paste your data here": "Límdu gögnin þín hér",
    "Please save the map first": "Vistaðu fyrst kortið",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("is", locale)
L.setLocale("is")
