const locale = {
    "Allow scroll wheel zoom?": "Допусти увећање зумом миша",
    "Automatic": "Аутоматско",
    "Ball": "Лопта",
    "Cancel": "Откажи",
    "Caption": "Напомена",
    "Choose the data format": "Одабери формат датума",
    "Choose the layer of the feature": "Одабери лејер",
    "Circle": "Круг",
    "Clustered": "Груписање",
    "Data browser": "Претражи податке",
    "Default": "Фабричка подешавања",
    "Default zoom level": "Подразумевани ниво зумирања",
    "Default: name": "Фабричко: Име",
    "Display label": "Прикажи ознаку",
    "Display the control to open OpenStreetMap editor": "Прикажи контролу да бисте отворили  OpenStreetMap уређивач",
    "Display the data layers control": "Прикажи контролу слојева података",
    "Display the embed control": "Прикажи уграђену контролу",
    "Display the fullscreen control": "Прикажи контроле пуног режима",
    "Display the locate control": "Прикажи контролу лоцирања",
    "Display the measure control": "Прикажи контролу мере",
    "Display the search control": "Прикажи контроле претраге",
    "Display the tile layers control": "Прикажи контроле лејера",
    "Display the zoom control": "Прикажи контроле зумирања",
    "Do you want to display a caption bar?": "Да ли желите да прикажете траку натписа?",
    "Do you want to display a minimap?": "Желите ли приказати малу карту?",
    "Do you want to display a panel on load?": "Да ли желите да прикажете панел при учитавању?",
    "Do you want to display popup footer?": "Желите ли приказати скочни прозор у подножју?",
    "Do you want to display the scale control?": "Да ли желите да прикажете размеру?",
    "Do you want to display the «more» control?": "Да ли желите да прикажете контролу «више»?",
    "Drop": "Избаци",
    "GeoRSS (only link)": "GeoRSS (само линк)",
    "GeoRSS (title + image)": "GeoRSS (наслов+ слика)",
    "Heatmap": "Heatmap",
    "Icon shape": "Облик иконе",
    "Icon symbol": "Икона симбола",
    "Inherit": "Наслеђено",
    "Label direction": "Смер ознаке",
    "Label key": "Кључ ознаке",
    "Labels are clickable": "На ознаке је могуће кликнути",
    "None": "Ништа",
    "On the bottom": "На дну",
    "On the left": "На лево",
    "On the right": "На десно",
    "On the top": "На врху",
    "Popup content template": "Шаблон за садржај искачућег прозора",
    "Side panel": "Бочни панел",
    "Simplify": "Поједноставити",
    "Table": "Табела",
    "always": "увек",
    "clear": "очисти",
    "collapsed": "срушено",
    "color": "боја",
    "dash array": "цртица низ",
    "define": "дефиниши",
    "description": "опис",
    "expanded": "проширен",
    "fill": "испуна",
    "fill color": "боја испуне",
    "fill opacity": "прозирност испуне",
    "hidden": "сакриј",
    "iframe": "облик",
    "inherit": "наследити",
    "name": "име",
    "never": "никад",
    "new window": "нови прозор",
    "no": "не",
    "on hover": "на лебдећи",
    "opacity": "прозирност",
    "parent window": "искачући прозор",
    "stroke": "линија",
    "weight": "дебљина",
    "yes": "да",
    "{delay} seconds": "{губици} секунди",
    "# one hash for main heading": "# једна тараба за главни наслов",
    "## two hashes for second heading": "## две тарабе за поднаслов",
    "### three hashes for third heading": "### три тарабе за под-поднаслова",
    "**double star for bold**": "** две звезвдице за подебљање слова**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Списак бројева одвојених зарезом који дефинише образац цртице цртице. Нпр .: \"5, 10, 15\".",
    "About": "Више о",
    "Action not allowed :(": "Акција није дозвољена :(",
    "Activate slideshow mode": "Активирајте режим презентације",
    "Add a layer": "Додај лејер",
    "Add a line to the current multi": "Додајте линију тренутном мулти",
    "Add a new property": "Додајте нови ентитет",
    "Add a polygon to the current multi": "Додајте полигон тренутном мулти",
    "Advanced actions": "Напредне акције",
    "Advanced properties": "Напредне поставке",
    "All properties are imported.": "Све поставке су увезене",
    "Allow interactions": "Дозволи интеракције",
    "An error occured": "Догодила се грешка",
    "Are you sure you want to cancel your changes?": "Да ли сте сигурне да желите да откажете промене?",
    "Are you sure you want to clone this map and all its datalayers?": "Да ли сте сигурни да желите да умножите мапу и све податке на њој?",
    "Are you sure you want to delete the feature?": "Да ли сте сигурни да желите да обришете елемент?",
    "Are you sure you want to delete this layer?": "Да ли сте сигурни да желите да обришете лејер?",
    "Are you sure you want to delete this map?": "Да ли сте сигурни да желите да обришете мапу?",
    "Are you sure you want to delete this property on all the features?": "Јесте ли сигурни да желите да избришете овај ентитет на свим функцијама?",
    "Are you sure you want to restore this version?": "Јесте ли сигурни да желите да вратите ову верзију?",
    "Attach the map to my account": "Закачи мапу на мој налог.",
    "Auto": "Аутоматски",
    "Autostart when map is loaded": "Аутоматски покрени када се мапа учита",
    "Bring feature to center": "Центрирај елемент",
    "Browse data": "Претражи податке",
    "Cancel edits": "Откажи промене",
    "Center map on your location": "Центрирај мапу на основу локације",
    "Change map background": "Промени позадину карте",
    "Change tilelayers": "Промени наслов лејера",
    "Choose a preset": "Изаберите претходно подешавање",
    "Choose the format of the data to import": "Изаберите формат података за увоз",
    "Choose the layer to import in": "Одабери лејер за увоз",
    "Click last point to finish shape": "Кликните на последњу тачку да бисте довршили облик",
    "Click to add a marker": "Клик за додавање ознаке",
    "Click to continue drawing": "Клик да наставите са цртањем",
    "Click to edit": "Клик за уређивање",
    "Click to start drawing a line": "Клик да започнете цртање линије",
    "Click to start drawing a polygon": "Клик да започнете цртање површине",
    "Clone": "Клон",
    "Clone of {name}": "Клон од {име}",
    "Clone this feature": "Дуплирај елемент",
    "Clone this map": "Дуплирај мапу",
    "Close": "Затвори",
    "Clustering radius": "Радијус кластера",
    "Comma separated list of properties to use when filtering features": "Својства која су одвојена зарезима која се користе за филтрирање функција",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Вредности одвојене зарезима, табом или новим редом. Подразумева се SRS WGS84. Увозе се само тачке геометрије. Увоз ће погледати заглавља ступаца за било које спомињање «лат» и «лон» на почетку заглавља, осетљив на велика и мала слова. Све друге колоне се увозе као својства.",
    "Continue line": "Наставите линију",
    "Continue line (Ctrl+Click)": "Наставите линију(Ctrl+Click)",
    "Coordinates": "Координате",
    "Credits": "Заслуга",
    "Current view instead of default map view?": "Тренутни приказ уместо подразумеваног приказа мапе?",
    "Custom background": "Одаберите позадину",
    "Data is browsable": "Подаци се могу прегледати",
    "Default interaction options": "Подразумеване могућности интеракције",
    "Default properties": "Фабричке вредности",
    "Default shape properties": "Подразумевана својства облика",
    "Define link to open in a new window on polygon click.": "Дефинишите везу за отварање у новом прозору на клику полигона.",
    "Delay between two transitions when in play mode": "Одгода између два прелаза у режиму репродукције",
    "Delete": "Обриши",
    "Delete all layers": "Обриши све лејере",
    "Delete layer": "Обриши лејер",
    "Delete this feature": "Обриши елемент",
    "Delete this property on all the features": "Обриши наведени ентитет на свим функцијама",
    "Delete this shape": "Обриши облик",
    "Delete this vertex (Alt+Click)": "Обриши овај врх (Alt+Click)",
    "Directions from here": "Упутства одавде",
    "Display measure": "Мера приказа",
    "Display on load": "Приказ при учитавању",
    "Download": "Преузимање",
    "Download data": "Преузимање података",
    "Drag to reorder": "Превуците за промену редоследа",
    "Draw a line": "Цртање линије",
    "Draw a marker": "Цртање ознаке",
    "Draw a polygon": "Цртање површине",
    "Draw a polyline": "Цртање изломљене линије",
    "Dynamic": "Динамично",
    "Dynamic properties": "Динамично подешавање",
    "Edit": "Уређивање",
    "Edit feature's layer": "Уређивање елемента одабраног лејера",
    "Edit map properties": "Уређивање мапе",
    "Edit map settings": "Уређивање више опција мапе",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Уређивање елемента",
    "Embed and share this map": "Embed and share this map",
    "Embed the map": "Embed the map",
    "Empty": "Empty",
    "Error in the tilelayer URL": "Error in the tilelayer URL",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Умањи увећање",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Format": "Формат",
    "From zoom": "From zoom",
    "Go to «{feature}»": "Go to «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "Помоћ",
    "Hide controls": "Сакриј контроле",
    "Home": "Почетна страна",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Увоз",
    "Import data": "Увоз података",
    "Import in a new layer": "Увези у новом лејеру",
    "Imports all umap data, including layers and settings.": "Увези све податке из мапе, укључујући лејере и подешавања",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Опција интеракције",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "Лејер",
    "Layer properties": "Layer properties",
    "Licence": "Лиценца",
    "Limit bounds": "Limit bounds",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Линк са текстом [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Мапа је сачувана!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Уређивачи мапе",
    "Map's owner": "Власник мапе",
    "Merge lines": "Merge lines",
    "More controls": "Више опција",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Лиценца није постављена",
    "No results": "Нема резултата",
    "Only visible features will be downloaded.": "Само видљиви лејери ће бити скинути.",
    "Open download panel": "Отвори прозор са скидање",
    "Open link in…": "Отвори линк у...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Молимо Вас уверите се да је лиценца компатибилна.",
    "Please choose a format": "Молимо Вас одаберите формат",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Problem in the response": "Problem in the response",
    "Problem in the response format": "Проблем у препознавању формата",
    "Properties imported:": "Properties imported:",
    "Provide an URL here": "Упишите URL",
    "Proxy request": "Proxy request",
    "Remote data": "Remote data",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Сачувај",
    "Save anyway": "Сачувај",
    "Save current edits": "Сачувај тренутна подешавања",
    "Save this center and zoom": "Сачувај подешавања центра и увећања",
    "Save this location as new feature": "Сачувај локацију као нови елемент",
    "Search a place name": "Претражи локацију",
    "Search location": "Претражи локацију",
    "See all": "Види све",
    "See data layers": "Прикажи унесене податке",
    "See full screen": "Увећана слика",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Својства облика",
    "Short URL": "Кратки URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Прикажи/сакриј лејер",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Започни уређивање",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Заустави уређивања",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Увећај",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Безимени лејер",
    "Untitled map": "Безимена мапа",
    "Update permissions": "Ажурирај дозволе",
    "Update permissions and editors": "Ажурирај дозволе и уреднике",
    "Url": "URL",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Заслуге за садржај",
    "User interface options": "User interface options",
    "Versions": "Versions",
    "View Fullscreen": "Прикажи увећано",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "Zoom in": "Увећај",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Умањи",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Увећај одабрано",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "висина",
    "licence": "лиценца",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "максимално увећање",
    "min zoom": "минимално увећање",
    "next": "следеће",
    "previous": "претходно",
    "width": "дебљина",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "километри",
    "km": "km",
    "mi": "mi",
    "miles": "миље",
    "nautical miles": "наутичке миље",
    "1 day": "1 дан",
    "1 hour": "1 сат",
    "5 min": "5 минута",
    "Cache proxied request": "Cache proxied request",
    "No cache": "Нема кеша",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Искачући стил",
    "Popup shape": "Искачући облик",
    "Skipping unknown geometry.type: {type}": "Прескакање непознате геометрије.type: {type}",
    "Optional.": "Опционо",
    "Paste your data here": "Прикачите Ваше податке овде",
    "Please save the map first": "Молимо Вас сачувајте мапу претходно",
    "Feature identifier key": "Тастер идентификатора функцијеFeature identifier key",
    "Open current feature on load": "Отворите тренутну функцију при учитавању",
    "Permalink": "Трајни линк",
    "The name of the property to use as feature unique identifier.": "Назив својства који се користи као јединствени идентификатор функције.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("sr", locale)
L.setLocale("sr")
