const locale = {
    "Allow scroll wheel zoom?": "Aotren ar zoum gant ar rodell?",
    "Automatic": "Emgefreek",
    "Ball": "Spilhenn",
    "Cancel": "Nullañ",
    "Caption": "Alc'hwez",
    "Choose the data format": "Diuzañ furmad ar roadennoù",
    "Choose the layer of the feature": "Diuzañ gwiskad an elfenn",
    "Circle": "Kelc'h",
    "Clustered": "Clustered",
    "Data browser": "Furchal ar roadennoù",
    "Default": "Dre ziouer",
    "Default zoom level": "Live zoum dre ziouer",
    "Default: name": "Dre ziouer: anv",
    "Display label": "Diskouez un dikedenn",
    "Display the control to open OpenStreetMap editor": "Diskwel an afell evit digeriñ an aozer OpenStreetMap",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Diskwel an afell \"enframmañ\"",
    "Display the fullscreen control": "Diskwel an afell \"skramm a-bezh\"",
    "Display the locate control": "Diskwel an afell \"lec'hiañ\"",
    "Display the measure control": "Diskwel an afell muzuliañ",
    "Display the search control": "Diskwel an afell \"klask\"",
    "Display the tile layers control": "Diskwel an afell \"cheñch foñs ar gartenn\"",
    "Display the zoom control": "Diskwel an afelloù \"zoumañ\" ha \"dizoumañ\"",
    "Do you want to display a caption bar?": "Diskwel ur varrenn alc'hwez?",
    "Do you want to display a minimap?": "Diskwel ur gartennig evit en em lec'hiañ?",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "Diskwel an diflugell e traoñ ar bajenn?",
    "Do you want to display the scale control?": "Diskwel skeul ar gartenn?",
    "Do you want to display the «more» control?": "Diskwel an afell \"muioc'h\"?",
    "Drop": "Takenn",
    "GeoRSS (only link)": "GeoRSS (liamm hepken)",
    "GeoRSS (title + image)": "GeoRSS (titl + skeudenn)",
    "Heatmap": "Kartenn dermek",
    "Icon shape": "Furm an ikon",
    "Icon symbol": "Arouez an ikon",
    "Inherit": "Heritañ",
    "Label direction": "Durc'hadur an dikedenn",
    "Label key": "Alc'hwez an dikedenn",
    "Labels are clickable": "An dikedennoù a c'haller klikañ",
    "None": "Hini ebet",
    "On the bottom": "D'an traoñ",
    "On the left": "A-gleiz",
    "On the right": "A-zehoù",
    "On the top": "D'an nec'h",
    "Popup content template": "Popup content template",
    "Side panel": "Panell gostez",
    "Simplify": "Eeunaat",
    "Table": "Taolenn",
    "always": "bepred",
    "clear": "skarzhañ",
    "collapsed": "serret",
    "color": "liv",
    "dash array": "Barrennoùigoù",
    "define": "termenañ",
    "description": "deskrivadur",
    "expanded": "digor",
    "fill": "leuniañ",
    "fill color": "liv leuniañ",
    "fill opacity": "demerez al leuniañ",
    "hidden": "kuzhet",
    "iframe": "iframe",
    "inherit": "heritañ",
    "name": "anv",
    "never": "morse",
    "new window": "prenestr nevez",
    "no": "ket",
    "on hover": "on hover",
    "opacity": "demerez",
    "parent window": "prenestr kar",
    "stroke": "tres",
    "weight": "tevder",
    "yes": "ya",
    "{delay} seconds": "{delay} segondenn",
    "# one hash for main heading": "# un diezenn evit an titl pennañ",
    "## two hashes for second heading": "## div ziezenn evit an eil titl",
    "### three hashes for third heading": "### teir diezenn evit an trede titl",
    "**double star for bold**": "**div steredennig evit tevaat**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Diwar-benn",
    "Action not allowed :(": "N'oc'h ket aotreet d'ober-se :(",
    "Activate slideshow mode": "Gweredekaat ar mod diaporama",
    "Add a layer": "Ouzhpennañ ur gwiskad",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Ouzhpennañ ur perzh nevez",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Oberoù araokaet",
    "Advanced properties": "Perzhioù araokaet",
    "All properties are imported.": "Enporzhiet eo bet an holl berzhioù.",
    "Allow interactions": "Aotren an etreoberiadennoù",
    "An error occured": "Ur fazi ez eus bet",
    "Are you sure you want to cancel your changes?": "Ha sur oc'h e faot deoc'h nullañ ho kemmoù?",
    "Are you sure you want to clone this map and all its datalayers?": "Ha sur oc'h e faot deoc'h arredaoliñ ar gartenn-mañ hag he holl wiskadoù roadennoù?",
    "Are you sure you want to delete the feature?": "Ha sur oc'h e faot deoc'h dilemel an elfenn-mañ?",
    "Are you sure you want to delete this layer?": "Ha sur oc'h e faot deoc'h dilemel ar gwiskad-mañ?",
    "Are you sure you want to delete this map?": "Ha sur oc'h e faot deoc'h dilemel ar gartenn-mañ?",
    "Are you sure you want to delete this property on all the features?": "Ha sur oc'h a faot deoc'h lemel ar perzh-mañ diwar an holl elfennoù?",
    "Are you sure you want to restore this version?": "Ha sur oc'h e faot deoc'h adsevel ar stumm-mañ?",
    "Attach the map to my account": "Stagañ ar gartenn d'am c'hont",
    "Auto": "Emgefre",
    "Autostart when map is loaded": "Loc'hañ pa vez karget ar gartenn",
    "Bring feature to center": "Kreizañ ar gartenn war an elfenn-mañ",
    "Browse data": "Furchal ar roadennoù",
    "Cancel edits": "Nullañ ar c'hemmoù",
    "Center map on your location": "Kreizañ ar gartenn war al lec'h m'emaoc'h",
    "Change map background": "Cheñch foñs ar gartenn",
    "Change tilelayers": "Cheñch foñs ar gartenn",
    "Choose a preset": "Diuzañ ur rakdibab",
    "Choose the format of the data to import": "Diuzañ furmad ar roadennoù da enporzhiañ",
    "Choose the layer to import in": "Diuzañ ar gwiskad evit enporzhiañ e-barzh",
    "Click last point to finish shape": "Klikañ war ar poent diwezhañ evit echuiñ an tres",
    "Click to add a marker": "Klikañ evit ouzhpennañ ur valizenn",
    "Click to continue drawing": "Klikañ evit kenderc'hel da dresañ",
    "Click to edit": "Klikañ evit aozañ",
    "Click to start drawing a line": "Klikañ evit tresañ ul linenn",
    "Click to start drawing a polygon": "Klikañ evit tresañ ul lieskorn",
    "Clone": "Arredaoliñ",
    "Clone of {name}": "Eilenn eus {name}",
    "Clone this feature": "Arredaoliñ an elfenn-mañ",
    "Clone this map": "Arredaoliñ ar gartenn-mañ",
    "Close": "Serriñ",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Kenderc'hel al linenn",
    "Continue line (Ctrl+Click)": "Kenderc'hel al linenn (Reol+Klikañ)",
    "Coordinates": "Daveennoù",
    "Credits": "Kredadoù",
    "Current view instead of default map view?": "Gwel a-vremañ e-lec'h ar gwel dre ziouer?",
    "Custom background": "Foñs personelaet",
    "Data is browsable": "Ar roadennoù a c'haller merdeiñ",
    "Default interaction options": "Dibarzhioù etreoberiañ dre ziouer",
    "Default properties": "Perzhioù dre ziouer",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Dale etre daou dremen pa vez e mod lenn",
    "Delete": "Dilemel",
    "Delete all layers": "Dilemel kement gwiskad",
    "Delete layer": "Dilemel ar gwiskad",
    "Delete this feature": "Dilemel an elfenn-mañ",
    "Delete this property on all the features": "Dilemel ar perzh-mañ",
    "Delete this shape": "Dilemel an tres-mañ",
    "Delete this vertex (Alt+Click)": "Dilemel ar poent-mañ (Erl+Klik)",
    "Directions from here": "Heñchadurioù adalek amañ",
    "Display measure": "Diskouez ar muzulioù",
    "Display on load": "Diskwel en ur gargañ",
    "Download": "Pellgargañ",
    "Download data": "Pellgargañ ar roadennoù",
    "Drag to reorder": "Riklañ evit adurzhiañ",
    "Draw a line": "Tresañ ul linenn",
    "Draw a marker": "Ouzhpennañ ur valizenn",
    "Draw a polygon": "Tresañ ul lieskorn",
    "Draw a polyline": "Tresañ ul linenn",
    "Dynamic": "Buhezek",
    "Dynamic properties": "Perzhioù buhezek",
    "Edit": "Aozañ",
    "Edit feature's layer": "Kemmañ gwiskad an elfenn",
    "Edit map properties": "Aozañ perzhioù ar gartenn",
    "Edit map settings": "Kemmañ arventennoù ar gartenn",
    "Edit properties in a table": "Aozañ ar perzhioù en un daolenn",
    "Edit this feature": "Kemmañ an elfenn-mañ",
    "Embed and share this map": "Ezporzhiañ ha rannañ ar gartenn",
    "Embed the map": "Enframmañ ar gartenn",
    "Empty": "Goullonderiñ",
    "Error in the tilelayer URL": "Ur fazi zo en URL foñs ar gartenn",
    "Error while fetching {url}": "Ur fazi ez eus bet en ur c'hervel an URL {url}",
    "Exit Fullscreen": "Kuitaat ar mod skramm a-bezh",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Format": "Furmad",
    "From zoom": "Adalek ar zoum",
    "Go to «{feature}»": "Mont da «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Skin ar gartenn dermek",
    "Help": "Skoazell",
    "Hide controls": "Kuzhat ar binvioù",
    "Home": "Degemer",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe gant uhelder personelaet (e pikselioù): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe gant mentoù personelaet (e pikselioù): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Skeudenn gant ledander personelaet (e pikselioù): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Skeudenn: {{http://image.url.com}}",
    "Import": "Enporzhiañ",
    "Import data": "Enporzhiañ roadennoù",
    "Import in a new layer": "Enporzhiañ ur gwiskad nevez",
    "Imports all umap data, including layers and settings.": "Enporzhiañ holl roadennoù ar gartenn, ar gwiskadoù hag an arventennoù en o zouez.",
    "Include full screen link?": "Lakaat ul liamm \"skramm a-bezh\" e-barzh?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Roadennoù umap direizh",
    "Invalid umap data in {filename}": "Roadennoù umap direizh e-barzh {filename}",
    "Keep current visible layers": "Derc'hel ar gwiskadoù a c'haller gwelet bremañ",
    "Latitude": "Ledred",
    "Layer": "Gwiskad",
    "Layer properties": "Perzhioù ar gwiskad",
    "Licence": "Aotre-implijout",
    "Limit bounds": "Bevennoù geografek",
    "Link to…": "Liamm etrezek...",
    "Link with text: [[http://example.com|text of the link]]": "Liamm gant testenn: [[http://skouer.bzh|testenn al liamm]]",
    "Long credits": "Kredadoù hir",
    "Longitude": "Hedred",
    "Make main shape": "Tres pennañ",
    "Manage layers": "Merañ ar gwiskadoù",
    "Map background credits": "Kredadoù foñs ar gartenn",
    "Map has been attached to your account": "Staget eo bet ar gartenn d'ho kont",
    "Map has been saved!": "Enrollet eo bet ar gartenn!",
    "Map user content has been published under licence": "Endalc'had ar gartenn zo bet embannet gant an aotre-implijout",
    "Map's editors": "Aozerien ar gartenn",
    "Map's owner": "Perc'henner ar gartenn",
    "Merge lines": "Kendeuziñ al linennoù",
    "More controls": "Binvioù all",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Rankout a ra bezañ un talvoud CSS reizh (da sk.: DarkBlue pe #123456)",
    "No licence has been set": "Aotre-implijout ebet bet termenet",
    "No results": "Disoc'h ebet",
    "Only visible features will be downloaded.": "An elfennoù hewel hepken a vo pellgarget.",
    "Open download panel": "Digeriñ prenestr ar pellgargadurioù",
    "Open link in…": "Digeriñ al liamm e...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Diret. Al liv pennañ a vo implijet ma ne vez ket termenet.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Gwiriit m'az oc'h aotreet da implijout ar roadennoù-mañ mar plij.",
    "Please choose a format": "Diuzit ur furmad mar plij",
    "Please enter the name of the property": "Enankit anv ar perzh mar plij",
    "Please enter the new name of this property": "Enankit anv nevez ar perzh-mañ mar plij",
    "Problem in the response": "Kudenn e respont ar servijer",
    "Problem in the response format": "Kudenn gant furmadiñ ar respont",
    "Properties imported:": "Perzhioù enporzhiet:",
    "Provide an URL here": "Pourchas un URL amañ",
    "Proxy request": "Reked proksi",
    "Remote data": "Rouedadoù a-bell",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Adenvel ar perzh-mañ",
    "Replace layer content": "Erlec'hiañ endalc'had ar gwiskad",
    "Restore this version": "Adsevel ar stumm-mañ?",
    "Save": "Enrollañ",
    "Save anyway": "Enrollañ evelkent",
    "Save current edits": "Enrollañ ar c'hemmoù a-vremañ ",
    "Save this center and zoom": "Save this center and zoom",
    "Save this location as new feature": "Enrollañ al lec'h-mañ evel un elfenn nevez",
    "Search a place name": "Klask un anv-lec'h ",
    "Search location": "Klask ul lec'h",
    "See all": "Gwelet pep tra",
    "See data layers": "Diskouez ar gwiskadoù",
    "See full screen": "Gwelet e skramm a-bezh",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Diweredekaat evit kuzhat ar gwiskad-mañ ouzh an diaporama, ar merdeer roadennoù...",
    "Shape properties": "Perzhioù ar furm",
    "Short URL": "URL berr",
    "Short credits": "Kredadoù berr",
    "Show/hide layer": "Diskouez/kuzhat ar gwiskad",
    "Simple link: [[http://example.com]]": "Liamm eeun: [[http://skouer.bzh]]",
    "Slideshow": "Diaporama",
    "Sort key": "Sort key",
    "Split line": "Disrannañ al linenn",
    "Start a hole here": "Ouzhpennañ un toull e-barzh",
    "Start editing": "Kregiñ da aozañ",
    "Start slideshow": "Lenn",
    "Stop editing": "Paouez da aozañ",
    "Stop slideshow": "Ehan",
    "Supported scheme": "Steuñv skoret",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "TMS format": "Furmad TMS",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Furmaozañ an destenn",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Betek ar zoum",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Treiñ da linennoù",
    "Transform to polygon": "Treiñ d'ul lieskorn",
    "Type of layer": "Seurt ar gwiskad",
    "Unable to detect format of file {filename}": "N'haller ket anavezout furmad ar restr {filename}",
    "Untitled layer": "Gwiskad hep anv",
    "Untitled map": "Kartenn hep anv",
    "Update permissions": "Kemmañ an aotreoù",
    "Update permissions and editors": "Kemmañ an aotreoù hag an aozerien",
    "Url": "URL",
    "Use current bounds": "Implij ar gwel a-vremañ",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Kredadoù evit danvez an implijer",
    "User interface options": "Dibarzhioù etrefas an implijer",
    "Versions": "Stummoù",
    "View Fullscreen": "Mont e mod skramm a-bezh",
    "Where do we go from here?": "Dre belec'h ez eomp adalek amañ?",
    "Whether to display or not polygons paths.": "Diskouez trolinennoù al lieskornoù",
    "Whether to fill polygons with color.": "Leuniañ al lieskornoù gant liv",
    "Who can edit": "Piv a c'hall aozañ",
    "Who can view": "Piv a c'hall gwelet",
    "Will be displayed in the bottom right corner of the map": "Diskwelet e vo e traoñ a-zehoù ar gartenn",
    "Will be visible in the caption of the map": "Gwelus e vo en alc'hwez ar gartenn",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Chaous! Seblant a ra ez eus bet kemmet ar gartenn gant unan bennak all. Gallout a rit enrollañ koulskoude, kollet e vo e roadennoù avat.",
    "Zoom in": "Zoumañ",
    "Zoom level for automatic zooms": "Live ar zoum emgefreek",
    "Zoom out": "Dizoumañ",
    "Zoom to layer extent": "Zoumañ evit gwelet ar gwiskad en e bezh",
    "Zoom to the next": "War-lerc'h",
    "Zoom to the previous": "Kent",
    "Zoom to this feature": "Zoumañ war an elfenn-mañ",
    "Zoom to this place": "Zoumañ war al lec'h-mañ",
    "attribution": "deroadur",
    "by": "gant",
    "display name": "anv diskwel",
    "height": "uhelder",
    "licence": "aotre-implijout",
    "max East": "bevenn reterañ",
    "max North": "bevenn norzhañ",
    "max South": "bevenn suañ",
    "max West": "bevenn gornôgañ",
    "max zoom": "zoum brasañ",
    "min zoom": "zoum bihanañ",
    "next": "war-lerc'h",
    "previous": "kent",
    "width": "ledander",
    "{count} errors during import: {message}": "{count} fazi zo bet en ur enporzhiañ: {message}",
    "Measure distances": "Muzuliañ pellderioù",
    "NM": "NM",
    "kilometers": "kilometroù",
    "km": "km",
    "mi": "mi",
    "miles": "miltirioù",
    "nautical miles": "milmorioù",
    "1 day": "1 deiz",
    "1 hour": "1 eur",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Diflugell",
    "Popup (large)": "Diflugell (vras)",
    "Popup content style": "Neuz endalc'had an diflugell",
    "Popup shape": "Stumm an diflugell",
    "Skipping unknown geometry.type: {type}": "Tremen e-bioù tikedenn geometry.type dianav: {type}",
    "Optional.": "Diret.",
    "Paste your data here": "Pegit ho roadennoù amañ",
    "Please save the map first": "Ret eo deoc'h enrollañ ar gartenn da gentañ",
    "Feature identifier key": "Alc'hwez anaout un elfenn",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Liamm pad",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Diskwel lañser an alc'hwezioù?",
    "Example: key1,key2,key3": "Skouer: key1,key2,key3",
    "Invalid latitude or longitude": "Hedred pe ledred direizh",
    "Invalide property name: {name}": "Anv ar perzh direizh: {name}",
    "Permanent credits": "Kredadoù padus",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Diuzañ ar roadennoù",
    "Will be permanently visible in the bottom left corner of the map": "Diskwel dalc'hmat e traoñ a-gleiz ar gartenn",
    "{area}&#8239;acres": "{area} erv",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miltir",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(gorread: {measure})",
    " (length: {measure})": "(pellder: {measure})",
    "Animated transitions": "Tremenoù buhezek",
    "Background overlay url": "URL ar foñs",
    "Custom overlay": "Gwiskad personelaet",
    "Display the star map button": "Diskouez an afell evit spilhennañ ar gartenn",
    "Error in the overlay URL": "URL foñs ar gartenn direizh",
    "Map has been starred": "Spilhennet eo bet ar gartenn",
    "Map has been unstarred": "Dispilhennet eo bet ar gartenn",
    "Opacity": "Demerez",
    "Star this map": "Spilhennañ ar gartenn-mañ",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Liamm eeun",
    "Export options": "Dibarzhioù ezporzhiañ",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Gourc'hemennoù, ho kartenn zo bet krouet!",
    "Copy link": "Eilañ an ere",
    "Email": "Postel",
    "Secret edit link copied to clipboard!": "Liamm aozañ kuzh eilet er golver!",
    "Send me the link": "Kas al liamm din",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Krouet eo bet ho kartenn! Peogwir n'oc'h ket kevreet, setu al liamm kuzh evit aozañ ar gartenn diwezhatoc'h, diwallit mat anezhañ !",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Gweredekaat ar mod aozañ (⇧+Click)",
    "icon opacity": "Demerez an ikon",
    "*single star for italic*": "*ur steredennig simpl evit italek*",
    "--- for a horizontal rule": "--- evit ul linenn-disparti a-blaen",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Gwel dre ziouer",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Perzhioù an elfenn",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Elfenn diwezhañ",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "Lec'hiadur an implijer",
    "Visibility: {status}": "Gwelusted: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Gwiriañ an URL",
    "Add": "Ouzhpennañ",
    "Change": "Kemmañ",
    "Powered by uMap": "Lusket gant uMap",
    "Search": "Klask",
    "Datalayers": "Gwiskadoù",
    "Secret edit link:": "Liamm aozañ kuzh:",
    "Who can edit \"{layer}\"": "Piv a c'hall aozañ \"{layer}\"",
    "Current map view": "Listenn an objedoù a c'haller gwelet",
    "Filter": "Silañ",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Keitpell",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Sturlevr",
    "Number of desired classes (default 5)": "Niver a renkadoù hoc'h eus c'hoant (5 dre ziouer)",
    "Quantiles": "Kwantiloù",
    "Show this layer in the caption": "Diskouez ar gwiskad-mañ en alc'hwez",
    "Back to preview": "Distreiñ d'ar rakwel",
    "Drawing": "Tres",
    "Edit the title of the map": "Kemmañ titl ar gartenn",
    "Go to the homepage": "Mont d'ar bajenn degemer",
    "Switch to edit mode": "Mod aozañ",
    "Update who can see and edit the map": "Termenañ piv a c'hall gwelet ha kemmañ ar gartenn",
    "View": "Gwelet",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("br", locale)
L.setLocale("br")
