const locale = {
    "Allow scroll wheel zoom?": "是否允许滚轮缩放？",
    "Automatic": "Automatic",
    "Ball": "Ball",
    "Cancel": "取消",
    "Caption": "Caption",
    "Choose the data format": "选择数据格式",
    "Choose the layer of the feature": "选择要素的图层",
    "Circle": "圆",
    "Clustered": "Clustered",
    "Data browser": "数据浏览器",
    "Default": "默认",
    "Default zoom level": "Default zoom level",
    "Default: name": "默认：名称",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "是否想显示鹰眼图？",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "你是否想要显示页脚？",
    "Do you want to display the scale control?": "是否显示比例尺控件？",
    "Do you want to display the «more» control?": "是否显示 «more» 控件？",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (only link)",
    "GeoRSS (title + image)": "GeoRSS (title + image)",
    "Heatmap": "Heatmap",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "继承",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "空",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popup content template",
    "Side panel": "Side panel",
    "Simplify": "Simplify",
    "Table": "表格",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "颜色",
    "dash array": "dash array",
    "define": "define",
    "description": "描述",
    "expanded": "expanded",
    "fill": "填充",
    "fill color": "填充色",
    "fill opacity": "透明",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "inherit",
    "name": "名称",
    "never": "never",
    "new window": "new window",
    "no": "否",
    "on hover": "on hover",
    "opacity": "不透明度",
    "parent window": "parent window",
    "stroke": "画笔",
    "weight": "weight",
    "yes": "是",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# 一个井号表示一级标题",
    "## two hashes for second heading": "## 两个井号表示二级标题",
    "### three hashes for third heading": "### 三个井号表示三级标题",
    "**double star for bold**": "**两个星号表示粗体**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "关于",
    "Action not allowed :(": "操作不允许",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "增加图层",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "添加属性",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "高级操作",
    "Advanced properties": "高级属性",
    "All properties are imported.": "属性已导入。",
    "Allow interactions": "Allow interactions",
    "An error occured": "发生错误",
    "Are you sure you want to cancel your changes?": "是否确定取消改变？",
    "Are you sure you want to clone this map and all its datalayers?": "是否确定复制这个地图及其所有数据图层?",
    "Are you sure you want to delete the feature?": "是否确定删除该要素？",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "是否确定删除地图？",
    "Are you sure you want to delete this property on all the features?": "是否确定删除全部要素的该属性？",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "自动",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "移到以对象为中心",
    "Browse data": "浏览数据",
    "Cancel edits": "取消编辑",
    "Center map on your location": "Center map on your location",
    "Change map background": "改变地图背景",
    "Change tilelayers": "改变瓦片图层",
    "Choose a preset": "Choose a preset",
    "Choose the format of the data to import": "选择导入的数据格式",
    "Choose the layer to import in": "选择导入的图层",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Click to add a marker",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone": "复制",
    "Clone of {name}": "Clone of {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "复制地图",
    "Close": "关闭",
    "Clustering radius": "聚类半径",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Continue line",
    "Continue line (Ctrl+Click)": "Continue line (Ctrl+Click)",
    "Coordinates": "坐标",
    "Credits": "Credits",
    "Current view instead of default map view?": "使用当前视口替换默认地图视口？",
    "Custom background": "自定义背景",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "默认属性",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "删除",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "删除对象",
    "Delete this property on all the features": "删除全部要素的该属性",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "方向",
    "Display measure": "Display measure",
    "Display on load": "加载时显示",
    "Download": "Download",
    "Download data": "下载数据",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "画线",
    "Draw a marker": "画标记",
    "Draw a polygon": "画多边形",
    "Draw a polyline": "画线",
    "Dynamic": "动态",
    "Dynamic properties": "Dynamic properties",
    "Edit": "编辑",
    "Edit feature's layer": "编辑要素图层",
    "Edit map properties": "编辑地图属性",
    "Edit map settings": "编辑地图设置",
    "Edit properties in a table": "在表格中编辑属性",
    "Edit this feature": "编辑该要素",
    "Embed and share this map": "嵌入与分享地图",
    "Embed the map": "嵌入地图",
    "Empty": "空",
    "Error in the tilelayer URL": "瓦片图层URL错误",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Format": "格式",
    "From zoom": "From zoom",
    "Go to «{feature}»": "转到«{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "帮助",
    "Hide controls": "隐藏控件",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "图片: {{http://image.url.com}}",
    "Import": "导入",
    "Import data": "导入数据",
    "Import in a new layer": "导入一个新图层",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "纬度",
    "Layer": "图层",
    "Layer properties": "Layer properties",
    "Licence": "许可证",
    "Limit bounds": "限制外包框",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Link with text: [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "经度",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "更多控件",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Only visible features will be downloaded.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Please be sure the licence is compliant with your use.",
    "Please choose a format": "请选择一种格式",
    "Please enter the name of the property": "请输入属性名称",
    "Please enter the new name of this property": "请输入属性的新名称",
    "Problem in the response": "响应错误",
    "Problem in the response format": "响应内容格式问题",
    "Properties imported:": "Properties imported:",
    "Provide an URL here": "提供URL",
    "Proxy request": "Proxy request",
    "Remote data": "远程数据",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "重命名全部要素的该属性",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "保存",
    "Save anyway": "Save anyway",
    "Save current edits": "保存当前编辑内容",
    "Save this center and zoom": "保存地图中心与比例尺",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "See all": "查看全部",
    "See data layers": "See data layers",
    "See full screen": "全屏",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Short URL",
    "Short credits": "Short credits",
    "Show/hide layer": "显示/隐藏图层",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Slideshow": "幻灯秀",
    "Sort key": "Sort key",
    "Split line": "打断线",
    "Start a hole here": "Start a hole here",
    "Start editing": "开始编辑",
    "Start slideshow": "开始幻灯秀",
    "Stop editing": "结束编辑",
    "Stop slideshow": "结束幻灯秀",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "TMS format": "TMS格式",
    "Text color for the cluster label": "标注文本颜色",
    "Text formatting": "文本格式",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "放大",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "转换为线",
    "Transform to polygon": "转换为多边形",
    "Type of layer": "图层类型",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "未命名图层",
    "Untitled map": "未命名地图",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "更新权限与编辑员",
    "Url": "Url",
    "Use current bounds": "使用当前范围",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "用户内容信用",
    "User interface options": "用户接口选项",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "Zoom in": "缩小",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "放大",
    "Zoom to layer extent": "缩放到图层范围",
    "Zoom to the next": "下一个",
    "Zoom to the previous": "上一个",
    "Zoom to this feature": "缩放到该对象",
    "Zoom to this place": "Zoom to this place",
    "attribution": "属性",
    "by": "by",
    "display name": "显示名称",
    "height": "高",
    "licence": "licence",
    "max East": "东",
    "max North": "北",
    "max South": "南",
    "max West": "西",
    "max zoom": "最大缩放等级",
    "min zoom": "最小缩放等级",
    "next": "next",
    "previous": "previous",
    "width": "宽",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Optional.",
    "Paste your data here": "Paste your data here",
    "Please save the map first": "Please save the map first",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("zh", locale)
L.setLocale("zh")
