const locale = {
    "Allow scroll wheel zoom?": "Voleu permetre el zoom amb la roda de desplaçament?",
    "Automatic": "Automatic",
    "Ball": "Bola",
    "Cancel": "Cancel·la",
    "Caption": "Llegenda",
    "Choose the data format": "Trieu el format de dades",
    "Choose the layer of the feature": "Trieu la capa de la característica",
    "Circle": "Cercle",
    "Clustered": "Clustered",
    "Data browser": "Data browser",
    "Default": "Per defecte",
    "Default zoom level": "Default zoom level",
    "Default: name": "Default: name",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Voleu mostrar la barra de llegenda?",
    "Do you want to display a minimap?": "Voleu mostrar un minimapa?",
    "Do you want to display a panel on load?": "Voleu mostrar el quandre en carregar?",
    "Do you want to display popup footer?": "Voleu mostrar un peu emergent?",
    "Do you want to display the scale control?": "Voleu mostrar el control d'escala?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "Deixar",
    "GeoRSS (only link)": "GeoRSS (només enllaç)",
    "GeoRSS (title + image)": "GeoRSS (títol i imatge)",
    "Heatmap": "Heatmap",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Hereta",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Cap",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popup content template",
    "Side panel": "Side panel",
    "Simplify": "Simplify",
    "Table": "Taula",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "color",
    "dash array": "dash array",
    "define": "define",
    "description": "descripció",
    "expanded": "expanded",
    "fill": "emplena",
    "fill color": "emplena el color",
    "fill opacity": "opacitat d'emplenament",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "heretat",
    "name": "nom",
    "never": "never",
    "new window": "new window",
    "no": "no",
    "on hover": "en passar per sobre",
    "opacity": "opacitat",
    "parent window": "parent window",
    "stroke": "stroke",
    "weight": "pes",
    "yes": "sí",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# one hash for main heading",
    "## two hashes for second heading": "## dos coixinets per a capçalera secundària",
    "### three hashes for third heading": "### three hashes for third heading",
    "**double star for bold**": "**doble asteric per a negreta**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Quant a",
    "Action not allowed :(": "Acció no permesa :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Afegeix una capa",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Opcions avançades",
    "Advanced properties": "Propietats avançades",
    "All properties are imported.": "S'han importat totes les propietats",
    "Allow interactions": "Allow interactions",
    "An error occured": "S'ha produït un error",
    "Are you sure you want to cancel your changes?": "Esteu segur de voler cancel·lar els canvis?",
    "Are you sure you want to clone this map and all its datalayers?": "Esteu segur de voler clonar aquest mapa i totes les capes de dades?",
    "Are you sure you want to delete the feature?": "Segur que voleu suprimir la característica?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Esteu segur de voler suprimir aquest mapa?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Adjunta el mapa al meu compte",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Explora les dades",
    "Cancel edits": "Cancel·la les edicions",
    "Center map on your location": "Centra el mapa a la vostra ubicació",
    "Change map background": "Canvia el fons del mapa",
    "Change tilelayers": "Canvia les capes de tessel·les",
    "Choose a preset": "Choose a preset",
    "Choose the format of the data to import": "Trieu el format de les dades a importar",
    "Choose the layer to import in": "Trieu la capa que on voleu importar",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Feu clic per a afegir una marca",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone": "Clona",
    "Clone of {name}": "Clona de {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Clona aquest mapa",
    "Close": "Tanca",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Continue line",
    "Continue line (Ctrl+Click)": "Continue line (Ctrl+Click)",
    "Coordinates": "Coordenades",
    "Credits": "Crèdits",
    "Current view instead of default map view?": "Voleu la visualització actual en comptes de la visualització predeterminada?",
    "Custom background": "Fons personalitzat",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Propietats predeterminades",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Suprimeix",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Suprimeix aquesta característica",
    "Delete this property on all the features": "Suprimeix aquesta propietat a totes les característiques",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Directions from here": "Direccions des d'aquí",
    "Display measure": "Display measure",
    "Display on load": "Mostrar en carregar",
    "Download": "Baixa",
    "Download data": "Baixa les dades",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Dibuixa una línia",
    "Draw a marker": "Dibuixa un marcador",
    "Draw a polygon": "Dibuixa un polígon",
    "Draw a polyline": "Dibuixa una polilínia",
    "Dynamic": "Dinàmic",
    "Dynamic properties": "Dynamic properties",
    "Edit": "Edita",
    "Edit feature's layer": "Edita la capa de la característica",
    "Edit map properties": "Edita les propietats del mapa",
    "Edit map settings": "Edita els paràmetres del mapa",
    "Edit properties in a table": "Edita les propietats en una taula",
    "Edit this feature": "Edita aquesta característica",
    "Embed and share this map": "Incrusta i comparteix aquest mapa",
    "Embed the map": "Incrusta el mapa",
    "Empty": "Buit",
    "Error in the tilelayer URL": "Hi ha un error en l'URL de la cap de tessel·les",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Format": "Format",
    "From zoom": "Del zoom",
    "Go to «{feature}»": "Vés a «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "Ajuda",
    "Hide controls": "Amaga els controls",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imatge amb amplada personalitzada (en px): {{http://imatge.url.com|amplada}}",
    "Image: {{http://image.url.com}}": "Imatge: {{http://imatge.url.com}}",
    "Import": "Importa",
    "Import data": "Importa dades",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Voleu incloure l'enllaç a pantalla completa?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitud",
    "Layer": "Capa",
    "Layer properties": "Layer properties",
    "Licence": "Llicència",
    "Limit bounds": "Límits",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Enllaceu amb el text:  [[http://exemple.com|text de l'enllaç]]",
    "Long credits": "Long credits",
    "Longitude": "Longitud",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Crèdits del fons del mapa",
    "Map has been attached to your account": "El mapa s'ha adjuntat al vostre compte",
    "Map has been saved!": "S'ha desat el mapa!",
    "Map user content has been published under licence": "El contingut de l'usuari del mapa s'ha publicat sota la llicència",
    "Map's editors": "Editors del mapa",
    "Map's owner": "Propietari del mapa",
    "Merge lines": "Merge lines",
    "More controls": "Més controls",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Only visible features will be downloaded.",
    "Open download panel": "Obre el tauler de baixada",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Opcional. El mateix color si no s'estableix.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Assegureu-vos que la llicència és compatible amb l'ús que en feu.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Introduïu el nom de la propietat",
    "Please enter the new name of this property": "Introduïu el nom d'aquesta propietat",
    "Problem in the response": "Hi ha un problema en la resposta",
    "Problem in the response format": "Hi ha un problema en el format de resposta",
    "Properties imported:": "Propietats importades:",
    "Provide an URL here": "Proporcioneu un URL aquí",
    "Proxy request": "Petició proxy",
    "Remote data": "Dades remotes",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Canvia el nom d'aquesta propietat en totes les característiques",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Desa",
    "Save anyway": "Desa-ho igualment",
    "Save current edits": "Desa les edicions actuals",
    "Save this center and zoom": "Desa aquest centre i escala",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Cerca un nom de lloc",
    "Search location": "Search location",
    "See all": "See all",
    "See data layers": "Mostra les capes de dades",
    "See full screen": "Mostra-ho a pantalla completa",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "URL curt",
    "Short credits": "Short credits",
    "Show/hide layer": "Mostra/amaga la capa",
    "Simple link: [[http://example.com]]": "Enllaç simple: [[http://exemple.com]]",
    "Slideshow": "Presentació",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Inicia l'edició",
    "Start slideshow": "Inicia la presentació",
    "Stop editing": "Atura l'edició",
    "Stop slideshow": "Atura la presentació",
    "Supported scheme": "Esquema suportat",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "TMS format": "Format TMS",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Format del text",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "A l'escala",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transforma a línies",
    "Transform to polygon": "Transforma a polígon",
    "Type of layer": "Tipus de capa",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Capa sense títol",
    "Untitled map": "Mapa sense títol",
    "Update permissions": "Actualitza els permisos",
    "Update permissions and editors": "Actualitza els permisos i editors",
    "Url": "URL",
    "Use current bounds": "Usa els límits actuals",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Crèdits dels continguts de l'usuari",
    "User interface options": "Opcions de la interfície d'usuari",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "On anem des d'aquí?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Qui pot editar",
    "Who can view": "Qui pot visualitzar",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "Zoom in": "Apropa't",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Allunya't",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Fes zoom a aquesta característica",
    "Zoom to this place": "Zoom to this place",
    "attribution": "atribució",
    "by": "per",
    "display name": "mostra el nom",
    "height": "alçada",
    "licence": "llicència",
    "max East": "Est màxim",
    "max North": "Nord màxim",
    "max South": "Sud màxim",
    "max West": "Oest màxim",
    "max zoom": "escala màxima",
    "min zoom": "escala mínima",
    "next": "next",
    "previous": "previous",
    "width": "amplada",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Mesura distàncies",
    "NM": "NM",
    "kilometers": "quilòmetres",
    "km": "km",
    "mi": "mi",
    "miles": "milles",
    "nautical miles": "miles nàutiques",
    "1 day": "1 dia",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "Cache proxied request": "Petició proxy en memòria cau",
    "No cache": "Sense memòria cau",
    "Popup": "Finestra emergent",
    "Popup (large)": "Finestra emergent (gran)",
    "Popup content style": "Estil del contingut de la finestra emergent",
    "Popup shape": "Forma de la finestra emergent",
    "Skipping unknown geometry.type: {type}": "S'està ometent el tipus de geometria desconegut: {type}",
    "Optional.": "Opcional.",
    "Paste your data here": "Enganxeu les dades aquí",
    "Please save the map first": "Abans deseu el mapa",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} milles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Transicions animades",
    "Background overlay url": "URL de superposició del fons",
    "Custom overlay": "Superposició personalitzada",
    "Display the star map button": "Mostra el botó per a destacar el mapa",
    "Error in the overlay URL": "S'ha produït un error en l'URL de superposició",
    "Map has been starred": "El mapa s'ha destacat",
    "Map has been unstarred": "El mapa ja no està destacat",
    "Opacity": "Opacitat",
    "Star this map": "Destaca aquest mapa",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "El símbol pot ser qualsevol caràcter Unicode o un URL. Podeu usar propietats de característiques com a variables. P. ex:  amb \"http://elmeuservidor.org/imatges/{nom}.png\", la variable {nom} se substituirà amb el valor de \"nom\" de cada marcador.",
    "Direct link": "Enllaç directe",
    "Export options": "Opcions d'exportació",
    "The zoom and center have been modified.": "L'escala i el centre s'han modificat.",
    "Congratulations, your map has been created!": "Enhorabona, s'ha creat el mapa!",
    "Copy link": "Copia l'enllaç",
    "Email": "Envia per correu electrònic",
    "Secret edit link copied to clipboard!": "L'enllaç secret s'ha copiat al porta-retalls!",
    "Send me the link": "Envia'm aquest enllaç",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "S'ha creat el vostre mapa! Com que no heu iniciat sessió, aquí teniu l'enllaç secret per a editar-lo. Conserveu-lo en un lloc segur:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Llista separada per comes de les propietats a usar per a les característiques d'ordenació. Per a invertir l'ordre, afegiu un signe menys (-) abans. P. ex. lamevaclau, -unaslatraclau",
    "Toggle edit mode (⇧+Click)": "Activa o desactiva el mode d'edició (⇧+clic)",
    "icon opacity": "opacitat de la icona",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("ca", locale)
L.setLocale("ca")
