const locale = {
    "Allow scroll wheel zoom?": "לאפשר תקריב עם גלגלת העכבר?",
    "Automatic": "אוטומטי",
    "Ball": "כדור",
    "Cancel": "ביטול",
    "Caption": "כותרת",
    "Choose the data format": "נא לבחור את מבנה הנתונים",
    "Choose the layer of the feature": "נא לבחור את שכבת התכונה",
    "Circle": "עיגול",
    "Clustered": "בקבוצה",
    "Data browser": "דפדפן נתונים",
    "Default": "בררת מחדל",
    "Default zoom level": "רמת תקריב כבררת מחדל",
    "Default: name": "בררת מחדל: שם",
    "Display label": "הצגת תווית",
    "Display the control to open OpenStreetMap editor": "יש להציג את הפקד לפתיחת העורך של OpenStreetMap",
    "Display the data layers control": "הצגת פקד שכבות הנתונים",
    "Display the embed control": "הצגת פקד ההטמעה",
    "Display the fullscreen control": "הצגת פקד מסך מלא",
    "Display the locate control": "הצגת פקד האיתור",
    "Display the measure control": "הצגת פקד המדידה",
    "Display the search control": "הצגת פקד החיפוש",
    "Display the tile layers control": "הצגת פקד שכבת האריחים",
    "Display the zoom control": "הצגת פקד התקריב",
    "Do you want to display a caption bar?": "להציג פס כותרת?",
    "Do you want to display a minimap?": "להציג מפה ממוזערת?",
    "Do you want to display a panel on load?": "להציג לוח צד בטעינה?",
    "Do you want to display popup footer?": "להציג כותרת תחתונה קופצת?",
    "Do you want to display the scale control?": "להציג את פקד קנה המידה?",
    "Do you want to display the «more» control?": "להציג את הפקד „עוד”?",
    "Drop": "נעץ",
    "GeoRSS (only link)": "GeoRSS (קישור בלבד)",
    "GeoRSS (title + image)": "GeoRSS (כותרת + תמונה)",
    "Heatmap": "מפת חום",
    "Icon shape": "צורת סמל",
    "Icon symbol": "סמן סמל",
    "Inherit": "ירושה",
    "Label direction": "כיוון התווית",
    "Label key": "מפתח תווית",
    "Labels are clickable": "התוויות זמינות ללחיצה",
    "None": "ללא",
    "On the bottom": "בתחתית",
    "On the left": "משמאל",
    "On the right": "מימין",
    "On the top": "מלמעלה",
    "Popup content template": "תבנית תוכן מוקפצת",
    "Side panel": "לוח צד",
    "Simplify": "פישוט",
    "Table": "טבלה",
    "always": "תמיד",
    "clear": "למחוק",
    "collapsed": "מצומצם",
    "color": "צבע",
    "dash array": "סדרה של מקפים",
    "define": "הגדרה",
    "description": "תיאור",
    "expanded": "מורחב",
    "fill": "מילוי",
    "fill color": "צבע מילוי",
    "fill opacity": "אטימות מילוי",
    "hidden": "מוסתר",
    "iframe": "מסגרת פנימית",
    "inherit": "ירושה",
    "name": "שם",
    "never": "מעולם לא",
    "new window": "חלון חדש",
    "no": "לא",
    "on hover": "בריחוף מעל",
    "opacity": "אטימות",
    "parent window": "חלון הורה",
    "stroke": "לוכסן",
    "weight": "משקל",
    "yes": "כן",
    "{delay} seconds": "{delay} שניות",
    "# one hash for main heading": "# סולמית אחת לכותרת ראשית",
    "## two hashes for second heading": "## שתי סולמיות לכותרת מסדר שני",
    "### three hashes for third heading": "### שלוש סולמיות לכותרת מסדר שלישי",
    "**double star for bold**": "**כוכבית כפולה להדגשה**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "רשימה מופרדת בפסיקים של מספרים שמגדירים את תבנית הלוכסנים והמקפים. למשל: „5, 10, 15”.",
    "About": "על אודות",
    "Action not allowed :(": "הפעולה אסורה :(",
    "Activate slideshow mode": "הפעלת מצב מצגת",
    "Add a layer": "הוספת שכבה",
    "Add a line to the current multi": "הוספת קו לרב המצולעים הנוכחי",
    "Add a new property": "הוספת מאפיין חדש",
    "Add a polygon to the current multi": "הוספת מצולע לרב המצולעים הנוכחי",
    "Advanced actions": "פעולות מתקדמות",
    "Advanced properties": "מאפיינים מתקדמים",
    "All properties are imported.": "כל המאפיינים ייובאו.",
    "Allow interactions": "לאפשר אינטראקציות",
    "An error occured": "אירעה שגיאה",
    "Are you sure you want to cancel your changes?": "לבטל את השינויים שלך?",
    "Are you sure you want to clone this map and all its datalayers?": "לשכפל את המפה הזאת ואת כל שכבות הנתונים שלה?",
    "Are you sure you want to delete the feature?": "למחוק את התכונה הזו?",
    "Are you sure you want to delete this layer?": "למחוק את השכבה הזו?",
    "Are you sure you want to delete this map?": "למחוק את המפה הזו?",
    "Are you sure you want to delete this property on all the features?": "למחוק את המאפיין הזה מכל התכונות?",
    "Are you sure you want to restore this version?": "לשחזר את הגרסה הזו?",
    "Attach the map to my account": "הצמדת מפה לחשבון שלי",
    "Auto": "אוטומטית",
    "Autostart when map is loaded": "להתחיל אוטומטית עם טעינת המפה",
    "Bring feature to center": "הבאת התכונה למרכז",
    "Browse data": "עיון בנתונים",
    "Cancel edits": "ביטול עריכות",
    "Center map on your location": "מרכוז המפה על המיקום שלך",
    "Change map background": "החלפת רקע המפה",
    "Change tilelayers": "החלפת שכבות אריחים",
    "Choose a preset": "נא לבחור ערכה",
    "Choose the format of the data to import": "נא לבחור את תצורת הנתונים לייבוא",
    "Choose the layer to import in": "נא לבחור את השכבה אליה יתבצע הייבוא",
    "Click last point to finish shape": "יש ללחוץ על הנקודה האחרונה כדי לסיים את הצורה",
    "Click to add a marker": "יש ללחוץ כדי להוסיף סמן",
    "Click to continue drawing": "יש ללחוץ כדי להמשיך בציור",
    "Click to edit": "יש ללחוץ כדי לערוך",
    "Click to start drawing a line": "יש ללחוץ כדי להתחיל לצייר קו",
    "Click to start drawing a polygon": "יש ללחוץ כדי להתחיל לצייר מצולע",
    "Clone": "שכפול",
    "Clone of {name}": "שכפול של {name}",
    "Clone this feature": "שכפול התכונה הזו",
    "Clone this map": "שכפול המפה הזו",
    "Close": "סגירה",
    "Clustering radius": "רדיוס קיבוץ",
    "Comma separated list of properties to use when filtering features": "רשימת מאפיינים מופרדת בפסיקים לשימוש בעת סינון תכונות",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "ערכים מופרדים בפסיקים, טאבים או נקודה פסיק. עם רמיזה ל־SRS WGS84. רק גואמטריית נקודות מייובאת. הייבוא יסתכל על כותרות העמודות לאיתור אזכורים של „lat” (קו רוחב) ו־„lon” (קו אורך) בתחילת הכותרת, לא משנה אותיות קטנות/גדולות. כל שאר העמודות ייובאו כמאפיינים.",
    "Continue line": "להמשיך את הקו",
    "Continue line (Ctrl+Click)": "להמשיך את הקו ‪(Ctrl+לחיצה)",
    "Coordinates": "נקודות ציון",
    "Credits": "תודות",
    "Current view instead of default map view?": "התצוגה הנוכחית במקום תצוגת בררת המחדל של המפה?",
    "Custom background": "רקע בהתאמה אישית",
    "Data is browsable": "הנתונים זמינים לעיון",
    "Default interaction options": "אפשרויות אינטראקציה כבררת מחדל",
    "Default properties": "מאפיינים כבררת מחדל",
    "Default shape properties": "מאפייני צורה כבררת מחדל",
    "Define link to open in a new window on polygon click.": "יש להגדיר קישור לפתיחה בחלון חדש עם לחיצה על מצולע.",
    "Delay between two transitions when in play mode": "השהיה בין שתי העברות כשמדובר במצב משחק",
    "Delete": "מחיקה",
    "Delete all layers": "מחיקת כל השכבות",
    "Delete layer": "מחיקת שכבה",
    "Delete this feature": "מחיקת התכונה הזו",
    "Delete this property on all the features": "מחיקת המאפיין הזה מכל התכונות",
    "Delete this shape": "מחיקת הצורה הזו",
    "Delete this vertex (Alt+Click)": "מחיקת הקודקוד הזה ‪(Alt+לחיצה)",
    "Directions from here": "הכוונה מכאן",
    "Display measure": "הצגת מדידה",
    "Display on load": "הצגה עם הטעינה",
    "Download": "הורדה",
    "Download data": "נתונים שהתקבלו",
    "Drag to reorder": "יש לגרור כדי לסדר מחדש",
    "Draw a line": "ציור קו",
    "Draw a marker": "ציור סמן",
    "Draw a polygon": "ציור מצולע",
    "Draw a polyline": "ציור קו שבור",
    "Dynamic": "דינמי",
    "Dynamic properties": "מאפיינים דינמיים",
    "Edit": "עריכה",
    "Edit feature's layer": "עריכת שכבת התכונה",
    "Edit map properties": "עריכת מאפייני מפה",
    "Edit map settings": "עריכת הגדרות מפה",
    "Edit properties in a table": "עריכת מאפיינים בטבלה",
    "Edit this feature": "עריכת תכונה זו",
    "Embed and share this map": "הטמעה ושיתוף מפה זו",
    "Embed the map": "הטמעת המפה",
    "Empty": "לרוקן",
    "Error in the tilelayer URL": "שגיאה בכתובת שכבת האריחים",
    "Error while fetching {url}": "שגיאה בקבלת {url}",
    "Exit Fullscreen": "יציאה ממסך מלא",
    "Extract shape to separate feature": "יש לחלץ צורה כדי להפריד תכונה",
    "Fetch data each time map view changes.": "לקבל נתונים בכל פעם שתצוגת המפה משתנה.",
    "Filter keys": "סינון מפתחות",
    "Format": "תצורה",
    "From zoom": "מרמת תקריב",
    "Go to «{feature}»": "מעבר אל «{feature}»",
    "Heatmap intensity property": "מאפיין עצמת מפת חום",
    "Heatmap radius": "רדיוס מפת חום",
    "Help": "עזרה",
    "Hide controls": "הסתרת פקדים",
    "Home": "בית",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "כמה לפשט את הקו השבור בכל רמת תקריב (יותר = ביצועים משופרים ומראה חלק יותר, פחות = דיוק גבוה יותר)",
    "If false, the polygon will act as a part of the underlying map.": "אם שקר, המצולע יתנהג כחלק מהמפה שמתחת.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "מסגרת פנימית עם גובה מותאם (בפיקסלים): {{{http://iframe.url.com|גובה}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "מסגרת פנימית עם גובה ורוחב מותאמים (בפיקסלים): {{{http://iframe.url.com|גובה*רוחב}}}",
    "Iframe: {{{http://iframe.url.com}}}": "מסגרת פנימית: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "תמונה עם רוחב מותאם (בפיקסלים): {{http://image.url.com|רוחב}}",
    "Image: {{http://image.url.com}}": "תמונה: {{http://image.url.com}}",
    "Import": "ייבוא",
    "Import data": "ייבוא נתונים",
    "Import in a new layer": "ייבוא לשכבה חדשה",
    "Imports all umap data, including layers and settings.": "יבוצע ייבוא של כל הנתונים של umap לרבות שכבות והגדרות.",
    "Include full screen link?": "לכלול קישור למסך מלא?",
    "Interaction options": "אפשרויות אינטראקציה",
    "Invalid umap data": "נתוני umap שגויים",
    "Invalid umap data in {filename}": "נתוני umap שגויים בתוך {filename}",
    "Keep current visible layers": "להשאיר את השכבות שגלויות כרגע",
    "Latitude": "קו רוחב",
    "Layer": "שכבה",
    "Layer properties": "מאפייני שכבה",
    "Licence": "רישיון",
    "Limit bounds": "גבולות חוסמים",
    "Link to…": "קישור אל…",
    "Link with text: [[http://example.com|text of the link]]": "קישור עם טקסט: [[http://example.com|הטקסט של הקישור]]",
    "Long credits": "תודות ארוכות",
    "Longitude": "קו אורך",
    "Make main shape": "להפוך לצורה עיקרית",
    "Manage layers": "ניהול שכבות",
    "Map background credits": "תודות על רקע המפה",
    "Map has been attached to your account": "המפה הוצמדה לחשבון שלך",
    "Map has been saved!": "המפה נשמרה!",
    "Map user content has been published under licence": "תוכן המשתמש של המפה פורסם תחת רישיון",
    "Map's editors": "עורכי המפה",
    "Map's owner": "בעלי המפה",
    "Merge lines": "מיזוג קווים",
    "More controls": "פקדים נוספים",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "חייב להיות ערך CSS תקני (למשל: DarkBlue או #123456)",
    "No licence has been set": "לא הוגדר רישיון",
    "No results": "אין תוצאות",
    "Only visible features will be downloaded.": "רק תכונות גלויות תתקבלנה.",
    "Open download panel": "פתיחת לוח הורדות",
    "Open link in…": "פתיחת קישור עם…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "פתיחת היקף מפה זו בעורך מפות כדי לספק נתונים מדויקים יותר ל־OpenStreetMap",
    "Optional intensity property for heatmap": "מאפיין עצמה כרשות למפת חום",
    "Optional. Same as color if not set.": "רשות. כנ״ל לגבי צבע אם לא הוגדר.",
    "Override clustering radius (default 80)": "דריסת רדיוס הקבוצה (בררת המחדל היא 80)",
    "Override heatmap radius (default 25)": "דריסת רדיוס מפת החום (בררת המחדל היא 25)",
    "Please be sure the licence is compliant with your use.": "נא לוודא שהרישיון תואם לשימוש שלך.",
    "Please choose a format": "נא לבחור תבנית",
    "Please enter the name of the property": "נא למלא את שם המאפיין",
    "Please enter the new name of this property": "נא למלא את השם החדש של המאפיין הזה",
    "Problem in the response": "בעיה בתגובה",
    "Problem in the response format": "בעיה במבנה התגובה",
    "Properties imported:": "יובאו מאפיינים:",
    "Provide an URL here": "נא לספק כאן כתובת",
    "Proxy request": "בקשת מתווך",
    "Remote data": "נתונים מרוחקים",
    "Remove shape from the multi": "הסרת צורת מרב מצולעים",
    "Rename this property on all the features": "לשנות את המאפיין הזה בכל התכונות",
    "Replace layer content": "החלפת תוכן השכבה",
    "Restore this version": "שחזור הגרסה הזו",
    "Save": "לשמור",
    "Save anyway": "לשמור בכל זאת",
    "Save current edits": "לשמור את העריכות הנוכחיות",
    "Save this center and zoom": "לשמור את המרכז הזה ולהתקרב",
    "Save this location as new feature": "לשמור את המיקום הזה כתכונה חדשה",
    "Search a place name": "חיפוש שם מקום",
    "Search location": "חיפוש מיקום",
    "See all": "להציג הכול",
    "See data layers": "להציג שכבות נתונים",
    "See full screen": "הצגת מסך מלא",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "יש להגדיר לשקר כדי להסתיר את השכבה הזאת מהמצגת, דפדפן הנתונים, הניווט המוקפץ…",
    "Shape properties": "מאפייני צורה",
    "Short URL": "כתובת מקוצרת",
    "Short credits": "תודות מקוצרות",
    "Show/hide layer": "הצגת/הסתרת שכבה",
    "Simple link: [[http://example.com]]": "קישור פשוט: [[http://example.com]]",
    "Slideshow": "מצגת",
    "Sort key": "מפתח סידור",
    "Split line": "פיצול קו",
    "Start a hole here": "להתחיל חור מכאן",
    "Start editing": "התחלת עריכה",
    "Start slideshow": "התחלת מצגת",
    "Stop editing": "הפסקת עריכה",
    "Stop slideshow": "הפסקת מצגת",
    "Supported scheme": "סכמה נתמכת",
    "Supported variables that will be dynamically replaced": "משתנים נתמכים שיוחלפו באופן דינמי",
    "TMS format": "מבנה TMS",
    "Text color for the cluster label": "צבע טקסט לתווית הקבוצה",
    "Text formatting": "עיצוב טקסט",
    "To use if remote server doesn't allow cross domain (slower)": "יש להשתמש אם השרת המרוחק לא מאפשר קישור בין שמות תחומים (Cross Origin - אטי יותר)",
    "To zoom": "לתקריב",
    "Transfer shape to edited feature": "המרת צורה לתכונה לעריכה",
    "Transform to lines": "המרה לקווים",
    "Transform to polygon": "המרה למצולע",
    "Type of layer": "סוג שכבה",
    "Unable to detect format of file {filename}": "לא ניתן לזהות את מבנה הקובץ {filename}",
    "Untitled layer": "שכבה ללא שם",
    "Untitled map": "מפה ללא שם",
    "Update permissions": "עדכון הרשאות",
    "Update permissions and editors": "עדכון הרשאות ועורכים",
    "Url": "כתובת",
    "Use current bounds": "להשתמש בגבולות הנוכחיים",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "ניתן להשתמש בממלאי מקום למאפייני תכונות בתוך סוגריים, למשל: &#123;name&#125;, הם יוחלפו דינמית בערכים המתאימים.",
    "User content credits": "תודות על תוכן המשתמש",
    "User interface options": "אפשרויות מנשק משתמש",
    "Versions": "גרסאות",
    "View Fullscreen": "הצגה במסך מלא",
    "Where do we go from here?": "לאן מתקדמים מכאן?",
    "Whether to display or not polygons paths.": "האם להציג נתיבי מצולעים או לא.",
    "Whether to fill polygons with color.": "האם למלא מצולעים בצבע.",
    "Who can edit": "למי יש אפשרות לערוך",
    "Who can view": "למי יש אפשרות לצפות",
    "Will be displayed in the bottom right corner of the map": "יוצג בפינה הימנית התחתונה של המפה",
    "Will be visible in the caption of the map": "יופיע בכותרת המפה",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "אופסי! מישהו ערך את הנתונים שלך. עדיין ניתן לשמור אבל זה עשוי למחוק את השינויים שאחרים עשו.",
    "Zoom in": "התקרבות",
    "Zoom level for automatic zooms": "רמת תקריב לתקריבים אוטומטיים",
    "Zoom out": "התרחקות",
    "Zoom to layer extent": "התמקדות על היקף השכבה",
    "Zoom to the next": "התמקדות על הבא",
    "Zoom to the previous": "התמקדות על הקודם",
    "Zoom to this feature": "התמקדות על תכונה זו",
    "Zoom to this place": "התמקדות על המקום הזה",
    "attribution": "ייחוס",
    "by": "מאת",
    "display name": "שם תצוגה",
    "height": "גובה",
    "licence": "רישיון",
    "max East": "מזרח מרבי",
    "max North": "צפון מרבי",
    "max South": "דרום מרבי",
    "max West": "מערב מרבי",
    "max zoom": "תקריב מרבי",
    "min zoom": "תקריב מזערי",
    "next": "הבא",
    "previous": "הקודם",
    "width": "רוחב",
    "{count} errors during import: {message}": "{count} שגיאות במהלך הייבוא: {message}",
    "Measure distances": "מדידת מרחקים",
    "NM": "מיילים ימיים",
    "kilometers": "קילומטרים",
    "km": "ק״מ",
    "mi": "מייל",
    "miles": "מיילים",
    "nautical miles": "מיילים ימיים",
    "1 day": "יום",
    "1 hour": "שעה",
    "5 min": "5 דקות",
    "Cache proxied request": "שמירת בקשות שעברו דרך המתווך במטמון",
    "No cache": "אין מטמון",
    "Popup": "חלונית מוקפצת",
    "Popup (large)": "חלונית מוקפצת (גדולה)",
    "Popup content style": "סגנון תוכן חלונית מוקפצת",
    "Popup shape": "צורת חלונית מוקפצת",
    "Skipping unknown geometry.type: {type}": "יתבצע דילוג על geometry.type לא ידוע: {type}",
    "Optional.": "רשות.",
    "Paste your data here": "נא להדביק את הנתונים שלך כאן",
    "Please save the map first": "נא לשמור את המפה קודם",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("he", locale)
L.setLocale("he")
