const locale = {
    "Allow scroll wheel zoom?": "Permitir zoom com roda do rato?",
    "Automatic": "Automático",
    "Ball": "Bola",
    "Cancel": "Cancelar",
    "Caption": "Cabeçalho",
    "Choose the data format": "Escolha o formato dos dados",
    "Choose the layer of the feature": "Escolha a camada do elemento",
    "Circle": "Círculo",
    "Clustered": "Agregado",
    "Data browser": "Navegador de dados",
    "Default": "Padrão",
    "Default zoom level": "Nível de aproximação padrão",
    "Default: name": "Padrão: nome",
    "Display label": "Mostrar etiqueta",
    "Display the control to open OpenStreetMap editor": "Mostrar o controlo para abrir o editor OpenStreetMap",
    "Display the data layers control": "Mostrar o controlo das camadas de dados",
    "Display the embed control": "Mostrar o controlo de embeber",
    "Display the fullscreen control": "Mostrar o controlo de ecrã total",
    "Display the locate control": "Mostrar o controlo de localizar",
    "Display the measure control": "Mostrar o controlo de medição",
    "Display the search control": "Mostrar o controlo de pesquisa",
    "Display the tile layers control": "Mostrar o controlo de camadas de telas",
    "Display the zoom control": "Mostrar o controlo de aproximar e afastar (zoom)",
    "Do you want to display a caption bar?": "Mostrar uma barra de cabeçalho?",
    "Do you want to display a minimap?": "Pretende mostrar um mini-mapa?",
    "Do you want to display a panel on load?": "Mostrar um painel ao carregar?",
    "Do you want to display popup footer?": "Pretende mostrar um popup no rodapé?",
    "Do you want to display the scale control?": "Pretende mostrar o controlo de escala?",
    "Do you want to display the «more» control?": "Mostrar o botão «mostrar mais botões»?",
    "Drop": "Comum",
    "GeoRSS (only link)": "GeoRSS (apenas o link)",
    "GeoRSS (title + image)": "GeoRSS (título + imagem)",
    "Heatmap": "Mapa térmico",
    "Icon shape": "Forma do ícone",
    "Icon symbol": "Símbolo do ícone",
    "Inherit": "Herdado",
    "Label direction": "Direção da etiqueta",
    "Label key": "Chave da etiqueta",
    "Labels are clickable": "Etiquetas são clicáveis",
    "None": "Nenhum",
    "On the bottom": "No fundo",
    "On the left": "Na esquerda",
    "On the right": "Na direita",
    "On the top": "No topo",
    "Popup content template": "Modelo de conteúdo do popup",
    "Side panel": "Painel lateral",
    "Simplify": "Simplificar",
    "Table": "Tabela",
    "always": "sempre",
    "clear": "limpar",
    "collapsed": "colapsado",
    "color": "cor",
    "dash array": "série de traços",
    "define": "definir",
    "description": "descrição",
    "expanded": "expandido",
    "fill": "preenchimento",
    "fill color": "cor do preenchimento",
    "fill opacity": "opacidade do preenchimento",
    "hidden": "oculto",
    "iframe": "iframe",
    "inherit": "herdado",
    "name": "nome",
    "never": "nunca",
    "new window": "nova janela",
    "no": "não",
    "on hover": "cursor por cima",
    "opacity": "opacidade",
    "parent window": "janela pai",
    "stroke": "traço",
    "weight": "espessura",
    "yes": "sim",
    "{delay} seconds": "{delay} segundos",
    "# one hash for main heading": "# um cardinal para o cabeçalho principal",
    "## two hashes for second heading": "## dois cardinais para o segundo cabeçalho",
    "### three hashes for third heading": "### três cardinais para o terceiro cabeçalho",
    "**double star for bold**": "**dois asteriscos duplos para negrito**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Lista de números separada por vírgulas que define o padrão do traço. Por exemplo \"5, 10, 15\".",
    "About": "Sobre",
    "Action not allowed :(": "Ação não permitida :(",
    "Activate slideshow mode": "Ativar modo de apresentação",
    "Add a layer": "Adicionar camada",
    "Add a line to the current multi": "Adicionar uma linha para o multi atual",
    "Add a new property": "Adicionar uma nova propriedade",
    "Add a polygon to the current multi": "Adicionar um polígono para o multi atual",
    "Advanced actions": "Ações avançadas",
    "Advanced properties": "Propriedades avançadas",
    "All properties are imported.": "Foram importadas todas as propriedades.",
    "Allow interactions": "Permitir interações",
    "An error occured": "Ocorreu um erro",
    "Are you sure you want to cancel your changes?": "Tem a certeza que quer cancelar as suas alterações?",
    "Are you sure you want to clone this map and all its datalayers?": "Tem a certeza que quer clonar este mapa, incluindo todas as camadas de dados?",
    "Are you sure you want to delete the feature?": "Tem a certeza que quer eliminar o elemento?",
    "Are you sure you want to delete this layer?": "Tem a certeza que quer eliminar esta camada?",
    "Are you sure you want to delete this map?": "Tem a certeza que quer eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "Tem a certeza que quer eliminar esta propriedade em todos os elementos?",
    "Are you sure you want to restore this version?": "Tem a certeza que quer restaurar esta versão?",
    "Attach the map to my account": "Anexar o mapa à minha conta",
    "Auto": "Auto",
    "Autostart when map is loaded": "iniciar ao abrir o mapa",
    "Bring feature to center": "Centrar elemento",
    "Browse data": "Explorar dados",
    "Cancel edits": "Cancelar edições",
    "Center map on your location": "Centrar mapa na sua localização",
    "Change map background": "Mudar fundo do mapa",
    "Change tilelayers": "Alterar camadas de telas",
    "Choose a preset": "Escolha um modelo",
    "Choose the format of the data to import": "Escolha o formato dos dados para importação",
    "Choose the layer to import in": "Escolha a camada para destino da importação",
    "Click last point to finish shape": "Clique no último ponto para terminar a forma geométrica",
    "Click to add a marker": "Clique para adicionar um marcador",
    "Click to continue drawing": "Clique para continuar a desenhar",
    "Click to edit": "Clique para editar",
    "Click to start drawing a line": "Clique para começar a desenhar uma linha",
    "Click to start drawing a polygon": "Clique para começar a desenhar um polígono",
    "Clone": "Clonar",
    "Clone of {name}": "Clone de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Close": "Fechar",
    "Clustering radius": "Raio do aglomerado",
    "Comma separated list of properties to use when filtering features": "Lista separada por vírgulas de propriedades a usar ao filtrar elementos",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por vírgula, tabulação ou ponto-e-vírgula. É implícito\n o sistema de referência espacial WGS84. Apenas são importadas as \ngeometrias de ponto. A importação irá ver se aparece no cabeçalho das \ncolunas «lat» e «lon», ignorando diferença de maiúsculas e minúsculas. \nTodas a outras colunas são importadas como propriedades.",
    "Continue line": "Continuar linha",
    "Continue line (Ctrl+Click)": "Continuar linnha (Ctrl+Clique)",
    "Coordinates": "Coordenadas",
    "Credits": "Créditos",
    "Current view instead of default map view?": "Vista atual e não a vista padrão do mapa?",
    "Custom background": "Fundo personalizado",
    "Data is browsable": "Os dados são navegáveis",
    "Default interaction options": "Opções padrão de interação",
    "Default properties": "Propriedades padrão",
    "Default shape properties": "Propriedades padrão de formas geométricas",
    "Define link to open in a new window on polygon click.": "Definir link para abrir numa nova janela ao clicar no polígono.",
    "Delay between two transitions when in play mode": "Atraso entre 2 transições ao reproduzir a apresentação",
    "Delete": "Eliminar",
    "Delete all layers": "Eliminar todas as camadas",
    "Delete layer": "Eliminar camada",
    "Delete this feature": "Eliminar este elemento",
    "Delete this property on all the features": "Eliminar esta propriedade em todos os elementos",
    "Delete this shape": "Eliminar esta forma geométrica",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+Clique)",
    "Directions from here": "Direções a partir daqui",
    "Display measure": "Mostrar medição",
    "Display on load": "Mostrar ao carregar",
    "Download": "Descarregar",
    "Download data": "Descarregar dados",
    "Drag to reorder": "Arrastar para reordenar",
    "Draw a line": "Desenhar uma linha",
    "Draw a marker": "Desenhar um marco",
    "Draw a polygon": "Desenhar um polígono",
    "Draw a polyline": "Desenhar uma polilinha",
    "Dynamic": "Dinâmico",
    "Dynamic properties": "Propriedades dinâmicas",
    "Edit": "Editar",
    "Edit feature's layer": "Editar camada do elemento",
    "Edit map properties": "Editar propriedades do mapa",
    "Edit map settings": "Editar definições do mapa",
    "Edit properties in a table": "Editar propriedades numa tabela",
    "Edit this feature": "Editar este elemento",
    "Embed and share this map": "Exportar e partilhar este mapa",
    "Embed the map": "Embeber o mapa",
    "Empty": "Vazio",
    "Error in the tilelayer URL": "Erro no URL de telas",
    "Error while fetching {url}": "Erro ao processar {url}",
    "Exit Fullscreen": "Sair de Ecrã Total",
    "Extract shape to separate feature": "Extrair forma geométrica para separar o elemento",
    "Fetch data each time map view changes.": "Processar dados cada vez que o mapa é alterado.",
    "Filter keys": "Filtrar chaves",
    "Format": "Formato",
    "From zoom": "Do zoom",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propriedade da intensidade do mapa térmico",
    "Heatmap radius": "Raio do mapa térmico",
    "Help": "Ajuda",
    "Hide controls": "Ocultar controlos",
    "Home": "Início",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Por quanto simplificar a polilinha em cada nível de aproximação (mais = melhor desempenho e aspeto mais suave, menos = mais preciso)",
    "If false, the polygon will act as a part of the underlying map.": "Se desativado, o polígono agirá como parte do mapa de baixo.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe com altura personalizada (em px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe com altura e largura personalizados (em px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imagem com largura personalizada (em px): {{http://imagem.url.com|largura}}",
    "Image: {{http://image.url.com}}": "Imagem: {{http://image.url.com}}",
    "Import": "Importar",
    "Import data": "Importar dados",
    "Import in a new layer": "Importar uma nova camada",
    "Imports all umap data, including layers and settings.": "Importa todos os dados uMap, incluindo camadas e definições.",
    "Include full screen link?": "Incluir link de encrã total?",
    "Interaction options": "Opções de interação",
    "Invalid umap data": "Dados uMap inválidos",
    "Invalid umap data in {filename}": "Dados uMap inválidos em {filename}",
    "Keep current visible layers": "Manter camadas atualmente visíveis",
    "Latitude": "Latitude",
    "Layer": "Camada",
    "Layer properties": "Propriedades da camada",
    "Licence": "Licença",
    "Limit bounds": "Extremos dos limites",
    "Link to…": "Link para...",
    "Link with text: [[http://example.com|text of the link]]": "Link com texto: [[http://example.com|texto do link]]",
    "Long credits": "Créditos por extenso",
    "Longitude": "Longitude",
    "Make main shape": "Fazer forma geométrica principal",
    "Manage layers": "Gerir camadas",
    "Map background credits": "Créditos do fundo do mapa",
    "Map has been attached to your account": "O mapa foi anexado à sua conta",
    "Map has been saved!": "O mapa foi gravado!",
    "Map user content has been published under licence": "O conteúdo do mapa foi publicado sob a licença",
    "Map's editors": "Editores do mapa",
    "Map's owner": "Proprietário do mapa",
    "Merge lines": "Fundir linhas",
    "More controls": "Mais controlos",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Tem de ser um valor CSS válido (p.ex.: DarkBlue ou #123456)",
    "No licence has been set": "Não foi definida nenhuma licença",
    "No results": "Sem resultados",
    "Only visible features will be downloaded.": "Apenas os elementos visíveis serão descarregados.",
    "Open download panel": "Abrir painel de descarregar",
    "Open link in…": "Abrir link numa...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abrir esta região do mapa num editor de mapas para fornecer dados mais precisos ao OpenStreetMap",
    "Optional intensity property for heatmap": "Propriedade opcional da intensidade do mapa térmico",
    "Optional. Same as color if not set.": "Opcional. Igual à cor se não for definido.",
    "Override clustering radius (default 80)": "Sobrepor raio do aglomerado (padrão 80)",
    "Override heatmap radius (default 25)": "Sobrepor raio do mapa térmico (padrão 80)",
    "Please be sure the licence is compliant with your use.": "Por favor tenha a certeza que a utilização está conforme a licença.",
    "Please choose a format": "Por favor escolha um formato",
    "Please enter the name of the property": "Por favor introduza o nome da propriedade",
    "Please enter the new name of this property": "Por favor introduza um novo nome desta propriedade",
    "Problem in the response": "Problema na resposta do servidor",
    "Problem in the response format": "Problema no formato da resposta",
    "Properties imported:": "Propriedades importadas:",
    "Provide an URL here": "Forneça um URL aqui",
    "Proxy request": "Pedido proxy",
    "Remote data": "Dados remotos",
    "Remove shape from the multi": "Remover forma do multi",
    "Rename this property on all the features": "Alterar nome desta propriedade em todos os elementos",
    "Replace layer content": "Substituir o conteúdo da camada",
    "Restore this version": "Restaurar esta versão",
    "Save": "Gravar",
    "Save anyway": "Gravar mesmo assim",
    "Save current edits": "Gravar edições atuais",
    "Save this center and zoom": "Gravar este centro e aproximar",
    "Save this location as new feature": "Gravar esta localização como novo elemento",
    "Search a place name": "Procurar por um local",
    "Search location": "Procurar localização",
    "See all": "Ver tudo",
    "See data layers": "Ver camadas de dados",
    "See full screen": "Ver em ecrã total",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Defina como falso para ocultar esta camada da apresentação de slides, o navegador de dados e da navegação do popup…",
    "Shape properties": "Propriedades de formas geométricas",
    "Short URL": "URL curto",
    "Short credits": "Créditos resumidos",
    "Show/hide layer": "Mostrar/ocultar camada",
    "Simple link: [[http://example.com]]": "Link simples: [[http://example.com]]",
    "Slideshow": "Apresentação",
    "Sort key": "Chave de ordenação",
    "Split line": "Linha de separação",
    "Start a hole here": "Começar um buraco aqui",
    "Start editing": "Começar a editar",
    "Start slideshow": "Iniciar apresentação",
    "Stop editing": "Parar edição",
    "Stop slideshow": "Parar apresentação",
    "Supported scheme": "Esquema suportado",
    "Supported variables that will be dynamically replaced": "Variáveis suportadas que serão substituídas de forma dinâmica",
    "TMS format": "Formato TMS",
    "Text color for the cluster label": "Cor do texto para a etiqueta do aglomerado",
    "Text formatting": "Formatação do texto",
    "To use if remote server doesn't allow cross domain (slower)": "Para usar caso o servidor remoto não permitir domínios cruzados (mais lento)",
    "To zoom": "Ao zoom",
    "Transfer shape to edited feature": "Transferir a forma geométrica para o elemento editado",
    "Transform to lines": "Transformar em linha",
    "Transform to polygon": "Transformar em polígono",
    "Type of layer": "Tipo de camada",
    "Unable to detect format of file {filename}": "Não foi possível detetar o formato do ficheiro {filename}",
    "Untitled layer": "Camada sem nome",
    "Untitled map": "Mapa sem nome",
    "Update permissions": "Permissões de atualização",
    "Update permissions and editors": "Alterar permisões e editores",
    "Url": "URL",
    "Use current bounds": "Usar extremos atuais",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use espaços reservados como propriedades de elementos entre parêntesis. Por ex. &#123;nome&#125; e serão substituídos pelos valores correspondentes.",
    "User content credits": "Créditos do conteúdo do utilizador",
    "User interface options": "Opções da interface de utilizador",
    "Versions": "Versões",
    "View Fullscreen": "Ver em Ecrã Total",
    "Where do we go from here?": "Para onde vamos a partir daqui?",
    "Whether to display or not polygons paths.": "Se mostrar ou não os caminhos dos polígonos.",
    "Whether to fill polygons with color.": "Se mostrar ou não os polígonos preenchidos a cor.",
    "Who can edit": "Quem pode editar",
    "Who can view": "Quem pode ver",
    "Will be displayed in the bottom right corner of the map": "Será mostrado no fundo à direita do mapa",
    "Will be visible in the caption of the map": "Será visível no cabeçalho do mapa",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ops! Parece que alguém editou os dados. Pode gravar mesmo assim, mas isso irá eliminar as alterações feitas por outros.",
    "Zoom in": "Aproximar",
    "Zoom level for automatic zooms": "Nível de aproximação para aproximações automáticas",
    "Zoom out": "Afastar",
    "Zoom to layer extent": "Aproximar ao tamanho da camada",
    "Zoom to the next": "Aproximar para o seguinte",
    "Zoom to the previous": "Aproximar para o anterior",
    "Zoom to this feature": "Aproximar a este elemento",
    "Zoom to this place": "Aproximar para este local",
    "attribution": "atribuição",
    "by": "por",
    "display name": "mostrar nome",
    "height": "altura",
    "licence": "licença",
    "max East": "Este máx.",
    "max North": "Norte máx.",
    "max South": "Sul máx.",
    "max West": "Oeste máx.",
    "max zoom": "aproximação máxima",
    "min zoom": "aproximação mínima",
    "next": "seguinte",
    "previous": "anterior",
    "width": "largura",
    "{count} errors during import: {message}": "{count} erros ao importar: {message}",
    "Measure distances": "Medir distâncias",
    "NM": "NM",
    "kilometers": "quilómetros",
    "km": "km",
    "mi": "mi",
    "miles": "milhas",
    "nautical miles": "milhas náuticas",
    "1 day": "1 dia",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "Cache proxied request": "Pedido cache com proxy",
    "No cache": "Sem cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (largo)",
    "Popup content style": "Estilo do conteúdo do popup",
    "Popup shape": "Forma do popup",
    "Skipping unknown geometry.type: {type}": "A ignorar tipo de geometria desconhecido: {type}",
    "Optional.": "Opcional.",
    "Paste your data here": "Cole aqui os seus dados",
    "Please save the map first": "Por favor primeiro grave o mapa",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("pt", locale)
L.setLocale("pt")
