const locale = {
    "Allow scroll wheel zoom?": "Benarkan zum dengan roda tatal?",
    "Automatic": "Automatik",
    "Ball": "Bola",
    "Cancel": "Batal",
    "Caption": "Keterangan",
    "Choose the data format": "Pilih format data",
    "Choose the layer of the feature": "Pilih lapisan bagi sifat",
    "Circle": "Bulatan",
    "Clustered": "Berkelompok",
    "Data browser": "Pelayar data",
    "Default": "Lalai",
    "Default zoom level": "Tahap zum lalai",
    "Default: name": "Lalai: nama",
    "Display label": "Label paparan",
    "Display the control to open OpenStreetMap editor": "Paparkan kawalan untuk buka penyunting OpenStreetMap",
    "Display the data layers control": "Paparkan kawalan lapisan data",
    "Display the embed control": "Paparkan kawalan benaman",
    "Display the fullscreen control": "Paparkan kawalan skrin penuh",
    "Display the locate control": "Paparkan kawalan kesan kedudukan",
    "Display the measure control": "Paparkan kawalan pengukuran",
    "Display the search control": "Paparkan kawalan carian",
    "Display the tile layers control": "Paparkan kawalan lapisan jubin",
    "Display the zoom control": "Paparkan kawalan zum",
    "Do you want to display a caption bar?": "Adakah anda ingin paparkan bar keterangan?",
    "Do you want to display a minimap?": "Adakah anda ingin paparkan peta mini?",
    "Do you want to display a panel on load?": "Adakah anda ingin paparkan panel ketika dimuatkan?",
    "Do you want to display popup footer?": "Adakah anda ingin paparkan pengaki timbul?",
    "Do you want to display the scale control?": "Adakah anda ingin paparkan kawalan skala?",
    "Do you want to display the «more» control?": "Adakah anda ingin paparkan kawalan «lebih lagi»?",
    "Drop": "Jatuhkan",
    "GeoRSS (only link)": "GeoRSS (pautan sahaja)",
    "GeoRSS (title + image)": "GeoRSS (tajuk + imej)",
    "Heatmap": "Peta tompokan",
    "Icon shape": "Bentuk ikon",
    "Icon symbol": "Simbol ikon",
    "Inherit": "Warisi",
    "Label direction": "Arah label",
    "Label key": "Kekunci label",
    "Labels are clickable": "Label boleh diklik",
    "None": "Tiada",
    "On the bottom": "Di bawah",
    "On the left": "Di kiri",
    "On the right": "Di kanan",
    "On the top": "Di atas",
    "Popup content template": "Templat kandungan tetingkap timbul",
    "Side panel": "Panel sisi",
    "Simplify": "Permudahkan",
    "Table": "Meja",
    "always": "sentiasa",
    "clear": "kosongkan",
    "collapsed": "dijatuhkan",
    "color": "warna",
    "dash array": "tatasusunan sengkang",
    "define": "takrif",
    "description": "keterangan",
    "expanded": "dikembangkan",
    "fill": "diisi",
    "fill color": "warna isian",
    "fill opacity": "kelegapan isian",
    "hidden": "disembunyikan",
    "iframe": "iframe",
    "inherit": "warisi",
    "name": "nama",
    "never": "tidak pernah",
    "new window": "tetingkap baharu",
    "no": "tidak",
    "on hover": "ketika dilalukan tetikus",
    "opacity": "kelegapan",
    "parent window": "tetingkap induk",
    "stroke": "lejang",
    "weight": "tebal",
    "yes": "ya",
    "{delay} seconds": "{delay} saat",
    "# one hash for main heading": "# satu tanda pagar untuk tajuk utama",
    "## two hashes for second heading": "## dua tanda pagar untuk tajuk kedua",
    "### three hashes for third heading": "### tiga tanda pagar untuk tajuk ketiga",
    "**double star for bold**": "**bintang berganda untuk tulisan tebal**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Senarai berpisahkan koma bagi nombor yang menentukan corak sengkang lejang. Cth.: \"5, 10, 15\".",
    "About": "Perihalan",
    "Action not allowed :(": "Tindakan tidak dibenarkan :(",
    "Activate slideshow mode": "Aktifkan mod persembahan slaid",
    "Add a layer": "Tambah lapisan",
    "Add a line to the current multi": "Tambah garisan ke multi semasa",
    "Add a new property": "Tambah ciri-ciri baharu",
    "Add a polygon to the current multi": "Tambah poligon ke multi semasa",
    "Advanced actions": "Tindakan lanjutan",
    "Advanced properties": "Ciri-ciri lanjutan",
    "All properties are imported.": "Semua ciri-ciri telah diimport.",
    "Allow interactions": "Benarkan interaksi",
    "An error occured": "Telah berlakunya ralat",
    "Are you sure you want to cancel your changes?": "Adakah anda ingin membatalkan perubahan anda?",
    "Are you sure you want to clone this map and all its datalayers?": "Adakah anda ingin klon peta ini serta semua lapisan datanya?",
    "Are you sure you want to delete the feature?": "Adakah anda ingin memadamkan sifat-sifat dipilih?",
    "Are you sure you want to delete this layer?": "Adakah anda ingin memadamkan lapisan ini?",
    "Are you sure you want to delete this map?": "Adakah anda ingin memadamkan peta ini?",
    "Are you sure you want to delete this property on all the features?": "Adakah anda ingin memadamkan ciri-ciri ini di kesemua sifat-sifat?",
    "Are you sure you want to restore this version?": "Adakah anda ingin memulihkan versi ini?",
    "Attach the map to my account": "Lampirkan peta ke akaun saya",
    "Auto": "Auto",
    "Autostart when map is loaded": "Automula apabila peta dimuatkan",
    "Bring feature to center": "Bawa sifat ke tengah",
    "Browse data": "Layari data",
    "Cancel edits": "Batalkan suntingan",
    "Center map on your location": "Ketengahkan peta ke kedudukan anda",
    "Change map background": "Tukar latar belakang peta",
    "Change tilelayers": "Tukar lapisan jubin",
    "Choose a preset": "Pilih pratetapan",
    "Choose the format of the data to import": "Pilih format data yang ingin diimport",
    "Choose the layer to import in": "Pilih lapisan untuk diimport",
    "Click last point to finish shape": "Klik titik akhir untuk lengkapkan bentuk",
    "Click to add a marker": "Klik untuk tambahkan penanda",
    "Click to continue drawing": "Klik untuk terus melukis",
    "Click to edit": "Klik untuk menyunting",
    "Click to start drawing a line": "Klik untuk mula melukis garisan",
    "Click to start drawing a polygon": "Klik untuk mula melukis poligon",
    "Clone": "Klon",
    "Clone of {name}": "Klon {name}",
    "Clone this feature": "Klon sifat ini",
    "Clone this map": "Klon peta ini",
    "Close": "Tutup",
    "Clustering radius": "Jejari kelompok",
    "Comma separated list of properties to use when filtering features": "Senarai berpisahkan koma bagi ciri-ciri untuk digunakan ketika menapis sifat",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Nilai dipisahkan dengan koma, tab atau koma bertitik. SRS WGS84 diimplikasikan. Hanya geometri Titik diimport. Import akan lihat pada kepala lajur untuk sebarang sebutan «lat» dan «lon» di bahagian permulaan pengepala, tak peka besar huruf. Kesemua lajur lain diimport sebagai ciri-ciri.",
    "Continue line": "Garis sambung",
    "Continue line (Ctrl+Click)": "Garis sambung (Ctrl+Klik)",
    "Coordinates": "Koordinat",
    "Credits": "Penghargaan",
    "Current view instead of default map view?": "Pandangan semasa menggantikan pandangan peta lalai?",
    "Custom background": "Latar belakang tersuai",
    "Data is browsable": "Data boleh layar",
    "Default interaction options": "Pilihan interaksi lalai",
    "Default properties": "Ciri-ciri lalai",
    "Default shape properties": "Ciri-ciri bentuk lalai",
    "Define link to open in a new window on polygon click.": "Tetapkan pautan untuk buka dalam tetingkap baharu apabila poligon diklik",
    "Delay between two transitions when in play mode": "Lengah di antara dua transisi apabila dalam mod main",
    "Delete": "Padam",
    "Delete all layers": "Padam semua lapisan",
    "Delete layer": "Padam lapisan",
    "Delete this feature": "Padam sifat ini",
    "Delete this property on all the features": "Padam ciri-ciri ini di kesemua sifat-sifat",
    "Delete this shape": "Padam bentuk ini",
    "Delete this vertex (Alt+Click)": "Padam bucu ini (Alt+Klik)",
    "Directions from here": "Arah dari sini",
    "Display measure": "Paparkan ukuran",
    "Display on load": "Paparkan semasa dimuatkan",
    "Download": "Muat turun",
    "Download data": "Muat turun data",
    "Drag to reorder": "Seret untuk susun semula",
    "Draw a line": "Lukis garisan",
    "Draw a marker": "Lukis penanda",
    "Draw a polygon": "Lukis poligon",
    "Draw a polyline": "Lukis poligaris",
    "Dynamic": "Dinamik",
    "Dynamic properties": "Ciri-ciri dinamik",
    "Edit": "Sunting",
    "Edit feature's layer": "Sunting lapisan sifat",
    "Edit map properties": "Sunting ciri-ciri peta",
    "Edit map settings": "Sunting tetapan peta",
    "Edit properties in a table": "Sunting ciri-ciri dalam jadual",
    "Edit this feature": "Sunting sifat ini",
    "Embed and share this map": "Benam dan kongsi peta ini",
    "Embed the map": "Benamkan peta",
    "Empty": "Kosongkan",
    "Error in the tilelayer URL": "Ralat dalam URL lapisan jubin",
    "Error while fetching {url}": "Ralat ketika mengambil {url}",
    "Exit Fullscreen": "Keluar Skrin Penuh",
    "Extract shape to separate feature": "Sarikan bentuk untuk memisahkan sifat",
    "Fetch data each time map view changes.": "Ambil data setiap kali pandangan peta berubah.",
    "Filter keys": "Kekunci tapisan",
    "Format": "Format",
    "From zoom": "Dari zum",
    "Go to «{feature}»": "Pergi ke «{feature}»",
    "Heatmap intensity property": "Ciri-ciri keamatan peta tompokan",
    "Heatmap radius": "Jejari peta tompokan",
    "Help": "Bantuan",
    "Hide controls": "Sembunyikan kawalan",
    "Home": "Laman utama",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Berapa banyak untuk dipermudahkan bagi poligaris di setiap tahap zum (lebih banyak = lebih tinggi prestasi dan rupa lebih halus, lebih sedikit = lebih tepat)",
    "If false, the polygon will act as a part of the underlying map.": "Jika salah, poligon akan bertindak sebagai sebahagian daripada peta di bawah.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe dengan tinggi tersuai (dalam px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe dengan tinggi dan lebar tersuai (dalam px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imej dengan lebar tersuai (dalam px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Imej: {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Import data",
    "Import in a new layer": "Import ke lapisan baharu",
    "Imports all umap data, including layers and settings.": "Import semua data umap, termasuk lapisan dan tetapan.",
    "Include full screen link?": "Sertakan pautan skrin penuh?",
    "Interaction options": "Pilihan interaksi",
    "Invalid umap data": "Data umap tidak sah",
    "Invalid umap data in {filename}": "Data umap tidak sah dalam {filename}",
    "Keep current visible layers": "Kekalkan lapisan yang kelihatan sekarang",
    "Latitude": "Latitud",
    "Layer": "Lapisan",
    "Layer properties": "Ciri-ciri lapisan",
    "Licence": "Lesen",
    "Limit bounds": "Had batas",
    "Link to…": "Pautkan ke…",
    "Link with text: [[http://example.com|text of the link]]": "Pautkan dengan tulisan: [[http://example.com|tulisan pautan]]",
    "Long credits": "Penghargaan penuh",
    "Longitude": "Longitud",
    "Make main shape": "Buatkan bentuk utama",
    "Manage layers": "Urus lapisan",
    "Map background credits": "Penghargaan latar belakang peta",
    "Map has been attached to your account": "Peta telah dilampirkan ke akaun anda",
    "Map has been saved!": "Peta telah disimpan!",
    "Map user content has been published under licence": "Kandungan pengguna peta telah diterbitkan di bawah lesen",
    "Map's editors": "Penyunting peta",
    "Map's owner": "Pemilik peta",
    "Merge lines": "Gabungkan garisan",
    "More controls": "Lebih banyak kawalan",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Mestilah nilai CSS yang sah (cth.: DarkBlue atau #123456)",
    "No licence has been set": "Tiada lesen ditetapkan",
    "No results": "Tiada hasil",
    "Only visible features will be downloaded.": "Hanya sifat kelihatan sahaja akan dimuat turun.",
    "Open download panel": "Buka panel muat turun",
    "Open link in…": "Buka pautan dalam…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Buka takat peta ini dalam penyunting peta untuk menyediakan data yang lebih tepat ke OpenStreetMap",
    "Optional intensity property for heatmap": "Ciri-ciri keamatan pilihan untuk peta tompokan",
    "Optional. Same as color if not set.": "Pilihan. Sama seperti warna jika tidak ditetapkan.",
    "Override clustering radius (default 80)": "Menggantikan jejari kelompok (nilai lalai 80)",
    "Override heatmap radius (default 25)": "Menggantikan jejari peta tompokan (nilai lalai 25)",
    "Please be sure the licence is compliant with your use.": "Sila pastikan lesen menurut kegunaan anda.",
    "Please choose a format": "Sila pilih format",
    "Please enter the name of the property": "Sila masukkan nama ciri-ciri",
    "Please enter the new name of this property": "Sila masukkan nama baharu bagi ciri-ciri ini",
    "Problem in the response": "Masalah dalam tindak balas",
    "Problem in the response format": "Masalah dalam format tindak balas",
    "Properties imported:": "Ciri-ciri diimport:",
    "Provide an URL here": "Sediakan URL di sini",
    "Proxy request": "Permintaan proksi",
    "Remote data": "Data jarak jauh",
    "Remove shape from the multi": "Buang bentuk daripada multi",
    "Rename this property on all the features": "Namakan semula ciri-ciri ini di kesemua sifat-sifat",
    "Replace layer content": "Gantikan kandungan lapisan",
    "Restore this version": "Pulihkan versi ini",
    "Save": "Simpan",
    "Save anyway": "Simpan juga apa pun",
    "Save current edits": "Simpan suntingan semasa",
    "Save this center and zoom": "Simpan kedudukan tengah dan zum ini",
    "Save this location as new feature": "Simpan kedudukan ini sebagai sifat baharu",
    "Search a place name": "Cari nama tempat",
    "Search location": "Kedudukan carian",
    "See all": "Lihat semua",
    "See data layers": "Lihat lapisan data",
    "See full screen": "Lihat skrin penuh",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Tetapkan ke salah untuk menyembunyikan lapisan ini daripada persembahan slaid, pelayar data, navigasi timbul…",
    "Shape properties": "Ciri-ciri bentuk",
    "Short URL": "URL pendek",
    "Short credits": "Penghargaan pendek",
    "Show/hide layer": "Tunjuk/sembunyi lapisan",
    "Simple link: [[http://example.com]]": "Pautan ringkas: [[http://example.com]]",
    "Slideshow": "Persembahan slaid",
    "Sort key": "Kekunci isihan",
    "Split line": "Garisan pemisah",
    "Start a hole here": "Mulakan lubang di sini",
    "Start editing": "Mula menyunting",
    "Start slideshow": "Mulakan persembahan slaid",
    "Stop editing": "Berhenti menyunting",
    "Stop slideshow": "Berhenti persembahan slaid",
    "Supported scheme": "Skema disokong",
    "Supported variables that will be dynamically replaced": "Pemboleh ubah disokong yang akan digantikan secara dinamik",
    "TMS format": "Format TMS",
    "Text color for the cluster label": "Warna tulisan label kelompok",
    "Text formatting": "Format tulisan",
    "To use if remote server doesn't allow cross domain (slower)": "Untuk digunakan jika pelayan jarak jauh tidak benarkan rentang domain (lebih perlahan)",
    "To zoom": "Untuk zum",
    "Transfer shape to edited feature": "Pindah bentuk ke sifat yang disunting",
    "Transform to lines": "Jelmakan menjadi garisan",
    "Transform to polygon": "Jelmakan menjadi poligon",
    "Type of layer": "Jenis lapisan",
    "Unable to detect format of file {filename}": "Tidak mampu mengesan format fail {filename}",
    "Untitled layer": "Lapisan tanpa tajuk",
    "Untitled map": "Peta tanpa tajuk",
    "Update permissions": "Kemas kini kebenaran",
    "Update permissions and editors": "Kemas kini kebenaran dan penyunting",
    "Url": "Url",
    "Use current bounds": "Guna batas semasa",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Guna pemegang tempat dengan ciri-ciri sifat di antara tanda kurung dakap, spt. &#123;name&#125;, mereka akan digantikan dengan nilai yang berkenaan secara dinamiknya.",
    "User content credits": "Penghargaan kandungan pengguna",
    "User interface options": "Pilihan antara muka pengguna",
    "Versions": "Versi",
    "View Fullscreen": "Lihat Skrin Penuh",
    "Where do we go from here?": "Ke mana kita pergi dari sini?",
    "Whether to display or not polygons paths.": "Sama ada ingin paparkan laluan poligon ataupun tidak.",
    "Whether to fill polygons with color.": "Sama ada ingin isikan poligon dengan warna.",
    "Who can edit": "Siapa boleh sunting",
    "Who can view": "Siapa boleh lihat",
    "Will be displayed in the bottom right corner of the map": "Akan dipaparkan di bucu kanan bawah peta",
    "Will be visible in the caption of the map": "Akan kelihatan dalam keterangan peta",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Alamak! Nampaknya orang lain telah menyunting data. Anda boleh simpan juga, tetapi ini akan memadam perubahan yang dibuat oleh orang lain.",
    "Zoom in": "Zum masuk",
    "Zoom level for automatic zooms": "Tahap zum bagi zum automatik",
    "Zoom out": "Zum keluar",
    "Zoom to layer extent": "Zum ke batas lapisan",
    "Zoom to the next": "Zum ke seterusnya",
    "Zoom to the previous": "Zum ke sebelumnya",
    "Zoom to this feature": "Zum ke sifat ini",
    "Zoom to this place": "Zum ke tempat ini",
    "attribution": "atribusi",
    "by": "oleh",
    "display name": "nama paparan",
    "height": "tinggi",
    "licence": "lesen",
    "max East": "Timur maksimum",
    "max North": "Utara maksimum",
    "max South": "Selatan maksimum",
    "max West": "Barat maksimum",
    "max zoom": "zum maksimum",
    "min zoom": "zum minimum",
    "next": "seterusnya",
    "previous": "sebelumnya",
    "width": "lebar",
    "{count} errors during import: {message}": "{count} ralat ketika import: {message}",
    "Measure distances": "Ukur jarak",
    "NM": "NM",
    "kilometers": "kilometer",
    "km": "km",
    "mi": "bt",
    "miles": "batu",
    "nautical miles": "batu nautika",
    "1 day": "1 hari",
    "1 hour": "1 jam",
    "5 min": "5 minit",
    "Cache proxied request": "Cache permintaan diproksi",
    "No cache": "Tiada cache",
    "Popup": "Tetingkap timbul",
    "Popup (large)": "Tetingkap timbul (besar)",
    "Popup content style": "Gaya kandungan tetingkap timbul",
    "Popup shape": "Bentuk tetingkap timbul",
    "Skipping unknown geometry.type: {type}": "Melangkau jenis geometri tidak diketahui: {type}",
    "Optional.": "Pilihan.",
    "Paste your data here": "Tampalkan data anda di sini",
    "Please save the map first": "Sila simpan peta terlebih dahulu",
    "Feature identifier key": "Kekunci pengenalpastian sifat",
    "Open current feature on load": "Buka sifat semasa ketika dimuatkan",
    "Permalink": "Pautan kekal",
    "The name of the property to use as feature unique identifier.": "Nama ciri-ciri untuk digunakan sebagai pengenalpastian unik sifat.",
    "Do you want to display caption menus?": "Adakah anda ingin paparkan menu keterangan?",
    "Example: key1,key2,key3": "Contoh: kekunci1,kekunci2,kekunci3",
    "Invalid latitude or longitude": "Latitud atau longitud tidak sah",
    "Invalide property name: {name}": "Nama ciri tidak sah: {name}",
    "Permanent credits": "Penghargaan kekal",
    "Permanent credits background": "Latar penghargaan kekal",
    "Select data": "Pilih data",
    "Will be permanently visible in the bottom left corner of the map": "Akan dipaparkan secara kekal di bucu kiri bawah peta",
    "{area}&#8239;acres": "{area} ekar",
    "{area}&#8239;ha": "{area} hektar",
    "{area}&#8239;m&sup2;": "{area} meter&sup2;",
    "{area}&#8239;mi&sup2;": "{area} batu&sup2;",
    "{area}&#8239;yd&sup2;": "{area} ela&sup2;",
    "{distance}&#8239;NM": "{distance} batu nautika",
    "{distance}&#8239;km": "{distance} kilometer",
    "{distance}&#8239;m": "{distance} meter",
    "{distance}&#8239;miles": "{distance} batu",
    "{distance}&#8239;yd": "{distance} ela",
    " (area: {measure})": "(kawasan: {measure})",
    " (length: {measure})": "(panjang: {measure})",
    "Animated transitions": "Transisi beranimasi",
    "Background overlay url": "URL tindihan atas latar belakang",
    "Custom overlay": "Tindihan atas tersuai",
    "Display the star map button": "Paparkan butang tanda bintang peta",
    "Error in the overlay URL": "Ralat dalam URL tindihan atas",
    "Map has been starred": "Peta telah ditandai bintang",
    "Map has been unstarred": "Peta telah dinyahtandai bintang",
    "Opacity": "Kelegapan",
    "Star this map": "Tandai bintang peta ini",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Simbol boleh jadi aksara unicode atau URL. Anda boleh gunakan ciri-ciri sifat sebagai pemboleh ubah: cth.: dengan \"http://myserver.org/images/{name}.png\", pemboleh ubah {name} akan digantikan dengan nilai \"name\" bagi setiap penanda.",
    "Direct link": "Pautan terus",
    "Export options": "Pilihan eksport",
    "The zoom and center have been modified.": "Zum dan kedudukan tengah telah diubah suai.",
    "Congratulations, your map has been created!": "Tahniah, peta anda telah berjaya dicipta!",
    "Copy link": "Salin pautan",
    "Email": "E-mel",
    "Secret edit link copied to clipboard!": "Pautan suntingan rahsia telah disalin ke papan keratan!",
    "Send me the link": "Hantarkan pautan kepada saya",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Peta anda telah berjaya dicipta! Memandangkan anda tidak log masuk, ini pautan rahsia anda untuk menyunting peta, sila simpannya dengan selamat:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Senarai ciri-ciri untuk digunakan bagi sifat isihan, dipisahkan dengan koma. Untuk mengundur isihan, letak tanda tolak (-) sebelumnya. Cth. kekuncisaya,-kekuncilain.",
    "Toggle edit mode (⇧+Click)": "Togol mod suntingan (⇧+Klik)",
    "icon opacity": "kelegapan ikon",
    "*single star for italic*": "*bintang tunggal untuk tulisan condong*",
    "--- for a horizontal rule": "--- untuk garis melintang",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "Nama bagi ciri untuk digunakan sebagai label sifat (cth.: \"nom\"). Anda juga boleh gunakan ciri-ciri dalam kurungan dakap untuk guna lebih daripada satu ciri atau untuk gabung dengan kandungan statik (cth.: \"{name} di {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Senarai berpisahkan koma bagi ciri-ciri untuk digunakan ketika menggelintar faset (cth.: kekuncisaya,kekuncilain). Untuk mengawal label, tambahkannya selepas tanda | (cth.: kekuncisaya|Kekunci Saya,kekuncilain|Kekunci Lain)",
    "Default view": "Paparan lalai",
    "Facet keys": "Kekunci faset",
    "Facet search": "Gelintaran faset",
    "Feature properties": "Ciri-ciri sifat",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Ada isu ketika mencapai URL tersebut (masalah rangkaian atau perlindungan CORS): {url}",
    "Latest feature": "Sifat terbaru",
    "No results for these facets": "Tiada hasil bagi faset ini",
    "Saved center and zoom": "Kedudukan tengah dan zum telah disimpan",
    "User location": "Kedudukan pengguna",
    "Visibility: {status}": "Kebolehlihatan: {status}",
    "Fit all data": "Sesuaikan semua data",
    "Verify remote URL": "Sahkan URL jarak jauh",
    "Add": "Tambah",
    "Change": "Tukar",
    "Powered by uMap": "Dikuasakan oleh uMap",
    "Search": "Cari",
    "Datalayers": "Lapisan data",
    "Secret edit link:": "Pautan suntingan rahsia:",
    "Who can edit \"{layer}\"": "Siapa boleh sunting \"{layer}\"",
    "Current map view": "Paparan peta semasa",
    "Filter": "Tapis",
    "Choropleth": "Koroplet",
    "Choropleth breakpoints": "Titik putus koroplet",
    "Choropleth classes": "Kelas koroplet",
    "Choropleth color palette": "Palet warna koroplet",
    "Choropleth mode": "Mod koroplet",
    "Choropleth property value": "Nilai ciri koroplet",
    "Comma separated list of numbers, including min and max values.": "Senarai nombor, dipisahkan dengan koma, termasuk nilai minimum dan maksimum.",
    "Equidistant": "Sama jarak",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "Cara K",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Jumlah kelas yang diingini (lalainya 5)",
    "Quantiles": "Kuantil",
    "Show this layer in the caption": "Tunjuk lapisan ini dalam keterangan",
    "Back to preview": "Kembali ke pralihat",
    "Drawing": "Lukisan",
    "Edit the title of the map": "Sunting tajuk peta",
    "Go to the homepage": "Pergi ke halaman utama",
    "Switch to edit mode": "Tukar ke mod suntingan",
    "Update who can see and edit the map": "Kemas kini siapa boleh lihat dan sunting peta",
    "View": "Lihat",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("ms", locale)
L.setLocale("ms")
