const locale = {
    "Allow scroll wheel zoom?": "Zoomen mit dem Mausrad erlauben?",
    "Automatic": "Automatisch",
    "Ball": "Stecknadel",
    "Cancel": "Abbrechen",
    "Caption": "Überschrift",
    "Choose the data format": "Wähle das Datenformat",
    "Choose the layer of the feature": "Wähle die Ebene für das Element",
    "Circle": "Kreis",
    "Clustered": "Gruppiert",
    "Data browser": "Datenbrowser",
    "Default": "Standard",
    "Default zoom level": "Standard-Zoomstufe",
    "Default: name": "Standard: Name",
    "Display label": "Beschriftung anzeigen",
    "Display the control to open OpenStreetMap editor": "Den Button zum OpenStreetMap-Editor anzeigen",
    "Display the data layers control": "Datenebenensteuerung anzeigen",
    "Display the embed control": "Eingebettete Steuerung anzeigen",
    "Display the fullscreen control": "Vollbildsteuerung anzeigen",
    "Display the locate control": "Den Ortungsbutton anzeigen.",
    "Display the measure control": "Messsteuerung anzeigen",
    "Display the search control": "Suchsteuerung anzeigen",
    "Display the tile layers control": "Kachelebenensteuerung anzeigen",
    "Display the zoom control": "Zoomsteuerung anzeigen",
    "Do you want to display a caption bar?": "Möchtest du eine Überschrift (Fußzeile) anzeigen?",
    "Do you want to display a minimap?": "Möchtest du eine Übersichtskarte anzeigen?",
    "Do you want to display a panel on load?": "Möchtest du beim Seitenaufruf eine Seitenleiste anzeigen?",
    "Do you want to display popup footer?": "Möchtest du eine Fußzeile im Popup anzeigen?",
    "Do you want to display the scale control?": "Möchtest du die Maßstabsleiste anzeigen?",
    "Do you want to display the «more» control?": "Möchtest du die „Mehr“-Schaltfläche anzeigen?",
    "Drop": "Tropfen",
    "GeoRSS (only link)": "GeoRSS (nur Link)",
    "GeoRSS (title + image)": "GeoRSS (Titel + Bild)",
    "Heatmap": "Heatmap",
    "Icon shape": "Bildzeichenform",
    "Icon symbol": "Bildzeichensymbol",
    "Inherit": "erben",
    "Label direction": "Beschriftungsrichtung",
    "Label key": "Anzeigeschlüssel",
    "Labels are clickable": "Beschriftungen sind klickbar",
    "None": "Keine",
    "On the bottom": "An der Unterseite",
    "On the left": "An der linken Seite",
    "On the right": "An der rechten Seite",
    "On the top": "An der Oberseite",
    "Popup content template": "Popup Vorlage",
    "Side panel": "Seitenleiste",
    "Simplify": "Vereinfachen",
    "Table": "Tabelle",
    "always": "immer",
    "clear": "leeren",
    "collapsed": "eingeklappt",
    "color": "Farbe",
    "dash array": "Linienart",
    "define": "festlegen",
    "description": "Beschreibung",
    "expanded": "ausgeklappt",
    "fill": "Füllung",
    "fill color": "Farbe der Füllung",
    "fill opacity": "Deckkraft der Füllung",
    "hidden": "ausgeblendet",
    "iframe": "iframe",
    "inherit": "erben",
    "name": "Name",
    "never": "nie",
    "new window": "neues Fenster",
    "no": "Nein",
    "on hover": "beim Draufzeigen",
    "opacity": "Deckkraft",
    "parent window": "übergeordnetes Fenster",
    "stroke": "Umrisslinie",
    "weight": "Stärke",
    "yes": "Ja",
    "{delay} seconds": "{delay} Sekunden",
    "# one hash for main heading": "# Eine Raute für große Überschrift",
    "## two hashes for second heading": "## Zwei Rauten für mittlere Überschrift",
    "### three hashes for third heading": "### Drei Rauten für kleine Überschrift",
    "**double star for bold**": "**Zwei Sterne für Fett**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Eine kommagetrente Zahlenfolge, die die Linienart (Strichmuster) der Kontur definiert, z. B.: \"5, 10, 15\".",
    "About": "Über",
    "Action not allowed :(": "Aktion nicht erlaubt :(",
    "Activate slideshow mode": "Diashowmodus aktivieren",
    "Add a layer": "Ebene hinzufügen",
    "Add a line to the current multi": "Linie zur vorhandene Gruppe hinzufügen",
    "Add a new property": "Ein Merkmal hinzufügen",
    "Add a polygon to the current multi": "Fläche zur vorhandene Gruppe hinzufügen",
    "Advanced actions": "Erweiterte Aktionen",
    "Advanced properties": "Erweiterte Eigenschaften",
    "All properties are imported.": "Alle Merkmale wurden importiert.",
    "Allow interactions": "Interaktionen erlauben",
    "An error occured": "Es ist ein Fehler aufgetreten.",
    "Are you sure you want to cancel your changes?": "Willst du deine Änderungen wirklich abbrechen?",
    "Are you sure you want to clone this map and all its datalayers?": "Möchtest du die Karte und ihre Datenebenen wirklich duplizieren?",
    "Are you sure you want to delete the feature?": "Möchtest du dieses Element wirklich löschen?",
    "Are you sure you want to delete this layer?": "Bist du sicher, dass du diese Ebene löschen willst?",
    "Are you sure you want to delete this map?": "Willst du diese Karte wirklich löschen?",
    "Are you sure you want to delete this property on all the features?": "Bist du sicher, dass du dieses Merkmal bei allen Elementen löschen willst?",
    "Are you sure you want to restore this version?": "Bist du sicher, dass du diese Version wiederherstellen willst?",
    "Attach the map to my account": "Die Karte meinem Benutzerkonto zuordnen",
    "Auto": "Automatisch",
    "Autostart when map is loaded": "Automatischer Start, wenn Karte geladen ist",
    "Bring feature to center": "Auf Element zentrieren",
    "Browse data": "Daten anzeigen",
    "Cancel edits": "Bearbeitungen abbrechen",
    "Center map on your location": "Die Karte auf deinen Standort ausrichten",
    "Change map background": "Hintergrundkarte ändern",
    "Change tilelayers": "Kachelebenen ändern",
    "Choose a preset": "Wähle eine Vorlage",
    "Choose the format of the data to import": "Wähle das Datenformat für den Import",
    "Choose the layer to import in": "Wähle die Ebene, in die importiert werden soll",
    "Click last point to finish shape": "Klicke den letzten Punkt an, um die Form abzuschließen",
    "Click to add a marker": "Klicke, um einen Marker hinzuzufügen",
    "Click to continue drawing": "Klicke, um weiter zu zeichnen",
    "Click to edit": "Zum Bearbeiten klicken",
    "Click to start drawing a line": "Klicke, um eine Linie zu zeichnen",
    "Click to start drawing a polygon": "Klicke, um eine Fläche zu zeichnen",
    "Clone": "Duplizieren",
    "Clone of {name}": "Duplikat von {name}",
    "Clone this feature": "Dieses Element duplizieren",
    "Clone this map": "Dupliziere diese Karte",
    "Close": "Schließen",
    "Clustering radius": "Gruppierungsradius",
    "Comma separated list of properties to use when filtering features": "Kommagetrennte Liste der Merkmale, welche beim Filtern von Elementen verwendet werden sollen",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma-, Tabulator-, oder Semikolongetrennte Werte. SRS WGS84 ist impliziert. Nur Punktgeometrien werden importiert. Beim Import wird nach Spaltenüberschriften mit jeder Nennung von „lat“ und „lon“ am Anfang der Überschrift gesucht (ohne Beachtung von Groß-/Kleinschreibung). Alle anderen Spalten werden als Merkmale importiert.",
    "Continue line": "Linie fortführen",
    "Continue line (Ctrl+Click)": "Linie weiterzeichnen (Strg+Klick)",
    "Coordinates": "Koordinaten",
    "Credits": "Credits",
    "Current view instead of default map view?": "Aktuelle Kartenansicht anstatt der Standard-Kartenansicht verwenden?",
    "Custom background": "Benutzerdefinierter Hintergrund",
    "Data is browsable": "Daten sind durchsuchbar",
    "Default interaction options": "Standard-Interaktionsoptionen",
    "Default properties": "Standardeigenschaften",
    "Default shape properties": "Standard-Formeigenschaften",
    "Define link to open in a new window on polygon click.": "Definiere einen externen Link, der sich beim Klick auf die Fläche in einem neuen Fenster öffnet.",
    "Delay between two transitions when in play mode": "Verzögerung zwischen zwei Übergängen im Abspielmodus",
    "Delete": "Löschen",
    "Delete all layers": "Alle Ebenen löschen",
    "Delete layer": "Ebene löschen",
    "Delete this feature": "Dieses Element löschen",
    "Delete this property on all the features": "Dieses Merkmal bei allen Elementen löschen",
    "Delete this shape": "Diese Form löschen",
    "Delete this vertex (Alt+Click)": "Diesen Eckpunkt löschen (Alt+Klick)",
    "Directions from here": "Route von hier",
    "Display measure": "Display measure",
    "Display on load": "Beim Seitenaufruf anzeigen.",
    "Download": "Herunterladen",
    "Download data": "Daten herunterladen",
    "Drag to reorder": "Ziehen zum Neuanordnen",
    "Draw a line": "Eine Linie zeichnen",
    "Draw a marker": "Einen Marker zeichnen",
    "Draw a polygon": "Eine Fläche zeichnen",
    "Draw a polyline": "Eine Linie zeichnen",
    "Dynamic": "Dynamisch",
    "Dynamic properties": "Dynamische Merkmale",
    "Edit": "Bearbeiten",
    "Edit feature's layer": "Elementebene bearbeiten",
    "Edit map properties": "Karteneigenschaften bearbeiten",
    "Edit map settings": "Karteneinstellungen bearbeiten",
    "Edit properties in a table": "Merkmale in einer Tabelle bearbeiten",
    "Edit this feature": "Dieses Element bearbeiten",
    "Embed and share this map": "Teile und binde diese Karte ein.",
    "Embed the map": "Karte einbinden",
    "Empty": "Leeren",
    "Error in the tilelayer URL": "Fehler in der Kachelebenen-URL",
    "Error while fetching {url}": "Fehler beim Abrufen von {url}",
    "Exit Fullscreen": "Vollbild beenden",
    "Extract shape to separate feature": "Form als separates Element extrahieren",
    "Fetch data each time map view changes.": "Daten jedes Mal abrufen, wenn sich die Kartenansicht ändert.",
    "Filter keys": "Schlüssel filtern",
    "Format": "Format",
    "From zoom": "Von Zoomstufe",
    "Go to «{feature}»": "Zu „{feature}“ wechseln",
    "Heatmap intensity property": "Heatmap-Intensität",
    "Heatmap radius": "Radius der Heatmap",
    "Help": "Hilfe",
    "Hide controls": "Schaltflächen ausblenden",
    "Home": "Startseite",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Wie stark Linien mit jeder Zoomstufe vereinfacht werden (mehr = bessere Performance und glatteres Aussehen, weniger = präziser)",
    "If false, the polygon will act as a part of the underlying map.": "Wenn auf Nein gesetzt, dann verhält sich die Fläche als Teil der hinterlegten Karte.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe mit benutzerdefinierter Höhe (in Pixel): {{{http://iframe.url.com|Höhe}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe mit benutzerdefinierter Höhe und Breite (in Pixel): {{{http://iframe.url.com|Höhe*Breite}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Bild mit benutzerdefinierter Breite (in Pixel): {{http://bild.url.com|Breite}}",
    "Image: {{http://image.url.com}}": "Bild: {{http://bild.url.com}}",
    "Import": "Importieren",
    "Import data": "Daten importieren",
    "Import in a new layer": "In eine neue Ebene importieren",
    "Imports all umap data, including layers and settings.": "Importiert alle uMap-Daten inklusive Ebenen und Einstellungen",
    "Include full screen link?": "Link für Vollbildanzeige einbeziehen?",
    "Interaction options": "Interaktionsoptionen",
    "Invalid umap data": "Ungütige uMap-Daten",
    "Invalid umap data in {filename}": "Ungültige uMap-Daten in {filename}",
    "Keep current visible layers": "Aktuell eingeblendete Ebenen übernehmen?",
    "Latitude": "Geogr. Breite",
    "Layer": "Ebene",
    "Layer properties": "Ebeneneigenschaften",
    "Licence": "Lizenz",
    "Limit bounds": "Kartenverschiebung begrenzen",
    "Link to…": "Verlinke zu...",
    "Link with text: [[http://example.com|text of the link]]": "Link mit Text: [[http://beispiel.com|Text für den Link]]",
    "Long credits": "Lange Credits",
    "Longitude": "Geogr. Länge",
    "Make main shape": "Hauptform erstellen",
    "Manage layers": "Ebenen verwalten",
    "Map background credits": "Credits der Hintergrundkarte",
    "Map has been attached to your account": "Die Karte wurde deinem Benutzerkonto zugeordnet.",
    "Map has been saved!": "Karte gespeichert!",
    "Map user content has been published under licence": "Der Benutzerinhalt wurde veröffentlicht unter der Lizenz",
    "Map's editors": "Kartenbearbeiter",
    "Map's owner": "Karteneigentümer",
    "Merge lines": "Linien zusammenführen",
    "More controls": "Mehr Schaltflächen",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Muss ein gültiger CSS-Wert sein (z.B.: DarkBlue oder #123456)",
    "No licence has been set": "Keine Lizenz ausgewählt",
    "No results": "Keine Ergebnisse",
    "Only visible features will be downloaded.": "Es werden nur die sichtbaren Elemente heruntergeladen.",
    "Open download panel": "Herunterladeleiste öffnen",
    "Open link in…": "Link öffnen in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Diesen Kartenauschnitt in einem Karten-Editor öffnen, um genauere Daten für OpenStreetMap bereitzustellen.",
    "Optional intensity property for heatmap": "Optionale Intensitätseigenschaft für die Heatmap",
    "Optional. Same as color if not set.": "Optional. Gleich wie Farbe, falls nicht ausgefüllt.",
    "Override clustering radius (default 80)": "Gruppierungsradius überschreiben (Standard: 80)",
    "Override heatmap radius (default 25)": "Heatmap-Radius überschreiben (Standard: 25)",
    "Please be sure the licence is compliant with your use.": "Stelle bitte sicher, dass die Lizenz mit deiner Verwendung kompatibel ist.",
    "Please choose a format": "Bitte wähle ein Format",
    "Please enter the name of the property": "Bitte gib den Namen des Merkmals ein",
    "Please enter the new name of this property": "Bitte gib den neuen Namen des Merkmals ein",
    "Problem in the response": "Fehlerhafte Serverantwort",
    "Problem in the response format": "Ungültiges Format der Serverantwort",
    "Properties imported:": "Importierte Merkmale:",
    "Provide an URL here": "Hier eine URL angeben",
    "Proxy request": "Proxyanforderung",
    "Remote data": "Ausgelagerte Daten",
    "Remove shape from the multi": "Form aus der Gruppe löschen",
    "Rename this property on all the features": "Dieses Merkmal bei allen Elementen umbenennen",
    "Replace layer content": "Ebeneninhalt ersetzen",
    "Restore this version": "Diese Version wiederherstellen",
    "Save": "Speichern",
    "Save anyway": "Trotzdem speichern",
    "Save current edits": "Aktuelle Änderungen speichern",
    "Save this center and zoom": "Aktuelle Position und Zoomstufe speichern",
    "Save this location as new feature": "Diesen Ort als neues Element speichern",
    "Search a place name": "Einen Ortsnamen suchen",
    "Search location": "Ort suchen",
    "See all": "Alle anzeigen",
    "See data layers": "Datenebenen ansehen",
    "See full screen": "Vollbildanzeige",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Setze es auf Nein, um diese Ebene in der Diashow, im Datenbrowser, in der Popup-Navigation,... auszublenden.",
    "Shape properties": "Formeigenschaften",
    "Short URL": "Kurze URL",
    "Short credits": "Kurze Credits",
    "Show/hide layer": "Ebene einblenden/ausblenden",
    "Simple link: [[http://example.com]]": "Einfacher Link: [[http://beispiel.com]]",
    "Slideshow": "Diashow",
    "Sort key": "Sortierschlüssel",
    "Split line": "Linie teilen",
    "Start a hole here": "Hier ein Loch beginnen",
    "Start editing": "Mit der Bearbeitung beginnen",
    "Start slideshow": "Diashow starten",
    "Stop editing": "Bearbeitung beenden",
    "Stop slideshow": "Diashow beenden",
    "Supported scheme": "Unterstütztes Schema",
    "Supported variables that will be dynamically replaced": "Unterstützte Variablen, die dynamisch ersetzt werden",
    "TMS format": "TMS-Format",
    "Text color for the cluster label": "Textfarbe für die Gruppierungsbezeichnung",
    "Text formatting": "Textformatierung",
    "To use if remote server doesn't allow cross domain (slower)": "Anzuwenden, wenn der Zielserver kein Cross Origin Resource Sharing (CORS) erlaubt (langsamer).",
    "To zoom": "Bis Zoomstufe",
    "Transfer shape to edited feature": "Form in bearbeitetes Element überführen",
    "Transform to lines": "In Linien umwandeln",
    "Transform to polygon": "In Fläche umwandeln",
    "Type of layer": "Ebenentyp",
    "Unable to detect format of file {filename}": "Format der Datei {filename} kann nicht erkannt werden",
    "Untitled layer": "Unbenannte Ebene",
    "Untitled map": "Unbenannte Karte",
    "Update permissions": "Berechtigungen aktualisieren",
    "Update permissions and editors": "Berechtigungen und Bearbeiter ändern",
    "Url": "URL",
    "Use current bounds": "Nutze aktuelle Kartenansicht",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Nutze Platzhalter mit Elementmerkmalen innerhalb der Klammern, z.B. &#123;name&#125;, sie werden dynamisch durch die entsprechenden Werte ersetzt.",
    "User content credits": "Credits der Benutzerinhalte",
    "User interface options": "Einstellungen Benutzeroberfläche",
    "Versions": "Versionen",
    "View Fullscreen": "Vollbild ansehen",
    "Where do we go from here?": "Wie geht es weiter?",
    "Whether to display or not polygons paths.": "Umrisslinie von Flächen anzeigen oder nicht anzeigen.",
    "Whether to fill polygons with color.": "Ob Flächen mit Farbe gefüllt werden.",
    "Who can edit": "Wer darf bearbeiten",
    "Who can view": "Wer darf betrachten",
    "Will be displayed in the bottom right corner of the map": "Wird in rechten unteren Ecke der Karte angezeigt",
    "Will be visible in the caption of the map": "Wird in der Überschrift der Karte angezeigt",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Hoppla! Jemand anders hat die Daten bearbeitet. Du kannst trotzdem speichern, von anderen vorgenommene Änderungen werden dabei aber gelöscht.",
    "Zoom in": "Hineinzoomen",
    "Zoom level for automatic zooms": "Zommstufe für automatischen Zoom",
    "Zoom out": "Herauszoomen",
    "Zoom to layer extent": "Auf Ebenenausdehnung zoomen",
    "Zoom to the next": "Zum nächsten zoomen",
    "Zoom to the previous": "Zum vorherigen zoomen",
    "Zoom to this feature": "Auf dieses Element zoomen",
    "Zoom to this place": "Auf diesen Ort zoomen",
    "attribution": "Copyright-Hinweis",
    "by": "von",
    "display name": "Namen anzeigen",
    "height": "Höhe",
    "licence": "Lizenz",
    "max East": "Östliche Begrenzung",
    "max North": "Nördliche Begrenzung",
    "max South": "Südliche Begrenzung",
    "max West": "Westliche Begrenzung",
    "max zoom": "höchste Zoomstufe",
    "min zoom": "kleinste Zoomstufe",
    "next": "weiter",
    "previous": "zurück",
    "width": "Breite",
    "{count} errors during import: {message}": "{count} Fehler während des Imports: {message}",
    "Measure distances": "Abstände messen",
    "NM": "NM",
    "kilometers": "Kilometer",
    "km": "km",
    "mi": "mi",
    "miles": "Meilen",
    "nautical miles": "Nautische Meilen",
    "1 day": "1 Tag",
    "1 hour": "1 Stunde",
    "5 min": "5 min",
    "Cache proxied request": "Proxycache-Anfrage",
    "No cache": "Kein Cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (groß)",
    "Popup content style": "Popupinhaltstil",
    "Popup shape": "Popupform",
    "Skipping unknown geometry.type: {type}": "Überspringe unbekannten Geometrietyp: {type}",
    "Optional.": "Optional.",
    "Paste your data here": "Füge deine Daten hier ein",
    "Please save the map first": "Bitte zuerst die Karte speichern",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Möchtest du Beschriftungsmenüs anzeigen?",
    "Example: key1,key2,key3": "Beispiel: key1,key2,key3",
    "Invalid latitude or longitude": "Ungültiger Längen- oder Breitengrad",
    "Invalide property name: {name}": "Ungültiger Eigenschaftsname: {name}",
    "Permanent credits": "Dauerhafte Danksagung",
    "Permanent credits background": "Dauerhafte Danksagung im Hintergrund",
    "Select data": "Wähle Daten aus",
    "Will be permanently visible in the bottom left corner of the map": "Wird in der unteren linken Ecke der Karte permanent sichtbar sein",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Deckkraft",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direktlink",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Glückwunsch, deine Karte wurde erstellt!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("de", locale)
L.setLocale("de")
