const locale = {
    "Allow scroll wheel zoom?": "Abilitare la rotellina del mouse per lo zoom?",
    "Automatic": "Automatico",
    "Ball": "Palla",
    "Cancel": "Annulla",
    "Caption": "Didascalia",
    "Choose the data format": "Scegli il formato dati",
    "Choose the layer of the feature": "Scegli il layer dell'oggetto",
    "Circle": "Cerchio",
    "Clustered": "Raggruppata",
    "Data browser": "Visualizza i dati",
    "Default": "Predefinito",
    "Default zoom level": "Livello di zoom predefinito",
    "Default: name": "Predefinito: nome",
    "Display label": "Mostra etichetta",
    "Display the control to open OpenStreetMap editor": "Mostra il controllo per aprire l'editor di OpenStreetMap",
    "Display the data layers control": "Mostra il controllo dei dati per i layer",
    "Display the embed control": "Visualizza il controllo per l'incorporamento",
    "Display the fullscreen control": "Visualizza il controllo di schermo intero",
    "Display the locate control": "Visualizza il controllo di localizzazione",
    "Display the measure control": "Visualizza il controllo di misurazione",
    "Display the search control": "Visualizza il controllo di ricerca",
    "Display the tile layers control": "Visualizza il controllo del livello delle tile",
    "Display the zoom control": "Visualizza il controllo di zoom",
    "Do you want to display a caption bar?": "Visualizzare una didascalia?",
    "Do you want to display a minimap?": "Visualizzare una mappa panoramica?",
    "Do you want to display a panel on load?": "Visualizza un panello al caricamento?",
    "Do you want to display popup footer?": "Visualizzare la finestra di popup a piè pagina?",
    "Do you want to display the scale control?": "Visualizzare la scala?",
    "Do you want to display the «more» control?": "Vuoi visualizzare il controllo \"altro\"?",
    "Drop": "Goccia",
    "GeoRSS (only link)": "GeoRSS (solo il link)",
    "GeoRSS (title + image)": "GeoRSS (titolo + immagine)",
    "Heatmap": "Mappa di densità (heatmap)",
    "Icon shape": "Forma dell'icona",
    "Icon symbol": "Simbolo dell'icona",
    "Inherit": "Eredita",
    "Label direction": "Direzione dell'etichetta",
    "Label key": "Campo etichetta",
    "Labels are clickable": "Etichette cliccabili",
    "None": "Nulla",
    "On the bottom": "In basso",
    "On the left": "A sinistra",
    "On the right": "A destra",
    "On the top": "In alto",
    "Popup content template": "Modello del contenuto del popup",
    "Side panel": "Pannello laterale",
    "Simplify": "Semplifica",
    "Table": "Tabella",
    "always": "sempre",
    "clear": "pulisci",
    "collapsed": "contratto",
    "color": "colore",
    "dash array": "tratteggio",
    "define": "definisci",
    "description": "descrizione",
    "expanded": "espanso",
    "fill": "riempimento",
    "fill color": "colore di riempimento",
    "fill opacity": "opacità riempimento",
    "hidden": "nascosto",
    "iframe": "iframe",
    "inherit": "eredita",
    "name": "nome",
    "never": "mai",
    "new window": "nuova finestra",
    "no": "non",
    "on hover": "in sovrimpressione",
    "opacity": "opacità",
    "parent window": "finestra di origine",
    "stroke": "tratto",
    "weight": "peso",
    "yes": "sì",
    "{delay} seconds": "{ritardo} secondi",
    "# one hash for main heading": "# un cancelleto per l'intestazione principale",
    "## two hashes for second heading": "## due cancelletti per le intestazioni di secondo livello",
    "### three hashes for third heading": "### tre cancelletti per intestazione di terzo livello",
    "**double star for bold**": "**due asterischi per il testo marcato**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista di numeri separati da virgola che definisce lo schema del tratto e del trattino. Es.: \"5, 10, 15\".",
    "About": "Informazioni",
    "Action not allowed :(": "Azione non permessa :(",
    "Activate slideshow mode": "Attiva la modalità presentazione",
    "Add a layer": "Aggiungi un layer",
    "Add a line to the current multi": "Aggiungi una linea a quelle correnti",
    "Add a new property": "Aggiungi una nuova proprietà",
    "Add a polygon to the current multi": "Aggiungi un poligono a quell correnti",
    "Advanced actions": "Azioni avanzate",
    "Advanced properties": "Proprietà avanzate",
    "All properties are imported.": "Tutte le proprietà sono state importate.",
    "Allow interactions": "Permetti interazioni",
    "An error occured": "Si è verificato un errore",
    "Are you sure you want to cancel your changes?": "Vuoi realmente annullare le modifiche fatte?",
    "Are you sure you want to clone this map and all its datalayers?": "Confermi di duplicare questa mappa e tutti i suoi livelli?",
    "Are you sure you want to delete the feature?": "Si è sicuri di voler cancellare questo oggetto?",
    "Are you sure you want to delete this layer?": "Si è certi di volere eliminare questo livello?",
    "Are you sure you want to delete this map?": "Si è certi di voler eliminare questa mappa?",
    "Are you sure you want to delete this property on all the features?": "Si è sicuri di voler cancellare questa proprietà per tutti gli oggetti?",
    "Are you sure you want to restore this version?": "Si vuole veramente ripristinare questa versione?",
    "Attach the map to my account": "Collega la mappa al mio account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Partenza automatica una volta che la mappa è stata caricata",
    "Bring feature to center": "Porta l'oggetto al centro",
    "Browse data": "Visualizza i dati",
    "Cancel edits": "Annulla le modifiche",
    "Center map on your location": "Centra la mappa sulla tua posizione",
    "Change map background": "Cambia la mappa di sfondo",
    "Change tilelayers": "Cambia i livelli di sfondo",
    "Choose a preset": "Seleziona una preimpostazione",
    "Choose the format of the data to import": "Seleziona il formato dei dati da importare",
    "Choose the layer to import in": "Seleziona su quale livello fare l'importazione",
    "Click last point to finish shape": "Click su ultimo punto per completare la geometria",
    "Click to add a marker": "Clicca per aggiungere un marcatore",
    "Click to continue drawing": "Clic per continuare a disegnare",
    "Click to edit": "Clic per la modifica",
    "Click to start drawing a line": "Clic per iniziare a disegnare una linea",
    "Click to start drawing a polygon": "Clicca per iniziare a disegnare un poligono",
    "Clone": "Clona",
    "Clone of {name}": "Clone di {name}",
    "Clone this feature": "Duplica questo oggetto",
    "Clone this map": "Duplica questa mappa",
    "Close": "Chiudi",
    "Clustering radius": "Raggio del raggruppamento",
    "Comma separated list of properties to use when filtering features": "Lista di proprietà separate da virgola da utilizzare per filtrare gli oggetti",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valori separati da virgola, tabulatore o punto e virgola. Il sistema di riferimento spaziale implementato è WGS84. Vengono importati solo punti. La funzione di importazione va a cercare nell'intestazione le colonne  «lat» e «lon» indifferentemente se scritte in maiuscolo o minuscolo. Tutte le altre colonne sono importate come proprietà.",
    "Continue line": "Linea continua",
    "Continue line (Ctrl+Click)": "Continua linea (Ctrl+Click)",
    "Coordinates": "Coordinate",
    "Credits": "Ringraziamenti",
    "Current view instead of default map view?": "Vista attuale invece che quella della mappa preimpostata?",
    "Custom background": "Sfondo personalizzato",
    "Data is browsable": "I dati sono consultabili",
    "Default interaction options": "Opzioni di interazione predefinite",
    "Default properties": "Proprietà preimpostate",
    "Default shape properties": "Proprietà predefinite della forma",
    "Define link to open in a new window on polygon click.": "Definisci un link d'aprire in una nuova finestra al clic sul poligono.",
    "Delay between two transitions when in play mode": "Ritardo tra le due transizioni in modalità di riproduzione",
    "Delete": "Cancella",
    "Delete all layers": "Elimina tutti i layer",
    "Delete layer": "Elimina layer",
    "Delete this feature": "Cancella questo oggetto",
    "Delete this property on all the features": "Cancella questa proprietà in tutti gli oggetti",
    "Delete this shape": "Cancella questa forma",
    "Delete this vertex (Alt+Click)": "Elimina questo vertice (Alt+Clic)",
    "Directions from here": "Indicazioni stradali da qui",
    "Display measure": "Calcola le distanze",
    "Display on load": "Mostra al caricamento",
    "Download": "Download",
    "Download data": "Download dei dati",
    "Drag to reorder": "Trascina per riordinare",
    "Draw a line": "Disegna una linea",
    "Draw a marker": "Aggiungi un marcatore",
    "Draw a polygon": "Disegna un poligono",
    "Draw a polyline": "Disegna una polilinea",
    "Dynamic": "Dinamico",
    "Dynamic properties": "Proprietà dinamiche",
    "Edit": "Modifica",
    "Edit feature's layer": "Modifica gli oggetti del layer",
    "Edit map properties": "Modifica le proprietà della mappa",
    "Edit map settings": "Modifica le impostazioni della mappa",
    "Edit properties in a table": "Modifica le proprietà in una tabella",
    "Edit this feature": "Modifica quest'oggetto",
    "Embed and share this map": "Includi e condividi questa mappa",
    "Embed the map": "Includi la mappa",
    "Empty": "Vuoto",
    "Error in the tilelayer URL": "Errore nell'URL nel servizio di tile",
    "Error while fetching {url}": "Errore nel nel recupero da {url}",
    "Exit Fullscreen": "Esci da Schermo intero",
    "Extract shape to separate feature": "Dividi la geometria in oggetti separati",
    "Fetch data each time map view changes.": "Recupera i dati ad ogni cambio della visualizzazione della mappa.",
    "Filter keys": "Filtro sui campi",
    "Format": "Formato",
    "From zoom": "Dallo zoom",
    "Go to «{feature}»": "Vai a «{feature}»",
    "Heatmap intensity property": "Proprietà intensità mappa di densità",
    "Heatmap radius": "Raggio mappa di densità",
    "Help": "Aiuto",
    "Hide controls": "Nascondi controlli",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Quanto vuoi semplificare la polilinea per ogni zoom (più = maggiori performance a aspetto più semplificato, meno = maggior dettaglio)",
    "If false, the polygon will act as a part of the underlying map.": "Se falso, il poligono agirà come parte della mappa sottostante.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altezza (in px) personalizzata: {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con altezza e larghezza personalizzata (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Immagine con larghezza personalizzata (width) (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Immagini: {{http://image.url.com}}",
    "Import": "Importa",
    "Import data": "Importa dati",
    "Import in a new layer": "Importa in un nuovo layer",
    "Imports all umap data, including layers and settings.": "importa tutti i dati di umap compresi layer e le impostazioni",
    "Include full screen link?": "inserire link per la vista a schemo intero?",
    "Interaction options": "Opzioni di interazione",
    "Invalid umap data": "dati di umap non validi",
    "Invalid umap data in {filename}": "dati umap non validi nel file {filename}",
    "Keep current visible layers": "Mantieni i layer attualmente visibili",
    "Latitude": "Latitudine",
    "Layer": "Layer",
    "Layer properties": "Proprietà del layer",
    "Licence": "Licenza",
    "Limit bounds": "Limiti di confine",
    "Link to…": "Link a…",
    "Link with text: [[http://example.com|text of the link]]": "Link con testo: [[http://example.com|testo del link]]",
    "Long credits": "Ringraziamenti estesi",
    "Longitude": "Longitudine",
    "Make main shape": "Genera geometria generale",
    "Manage layers": "Gestisci layer",
    "Map background credits": "Riconoscimenti per la mappa di sfondo",
    "Map has been attached to your account": "La mappa è stata associata al tuo account",
    "Map has been saved!": "La mappa è stata salvata",
    "Map user content has been published under licence": "I contenuti della mappa sono rilasciati secondo la licenza",
    "Map's editors": "Contributori alla mappa",
    "Map's owner": "Proprietario della mappa",
    "Merge lines": "Unisci linee",
    "More controls": "Maggiori controlli",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Deve avere un valore CSS valido (es.: DarkBlue o #123456)",
    "No licence has been set": "Non è ancora stata impostata una licenza",
    "No results": "Nessun risultato",
    "Only visible features will be downloaded.": "Saranno scaricate solo gli oggetti visibili.",
    "Open download panel": "Apri il pannello di download",
    "Open link in…": "Apri link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Apri quest'area della mappa nell'editor in modo da fornire dati più accurati in OpenStreeetMap",
    "Optional intensity property for heatmap": "Proprietà opzionale per la mappa di densità",
    "Optional. Same as color if not set.": "Opzionale. Stesso colore se non assegnato.",
    "Override clustering radius (default 80)": "Sovrascrivi raggio di raggruppamento (predefinito 80)",
    "Override heatmap radius (default 25)": "Sovrascrivi raggio mappa di intensità (predefinito 25)",
    "Please be sure the licence is compliant with your use.": "Si prega di verificare che la licenza è compatibile con quella in uso.",
    "Please choose a format": "Scegliere un formato",
    "Please enter the name of the property": "Inserire il nome della proprietà",
    "Please enter the new name of this property": "Inserire il nuovo nome per questa proprietà",
    "Problem in the response": "Problema nella risposta",
    "Problem in the response format": "Problema nel formato della risposta",
    "Properties imported:": "Proprietà importate:",
    "Provide an URL here": "Aggiungi una URL qui",
    "Proxy request": "Richiesta proxy",
    "Remote data": "Dati remoti",
    "Remove shape from the multi": "Rimuovi geometria dalle altre",
    "Rename this property on all the features": "Rinomina questa proprietà in tutti gli oggetti",
    "Replace layer content": "Sostituisci il contenuto del layer",
    "Restore this version": "Ripristina questa versione",
    "Save": "Salva",
    "Save anyway": "Salva comunque",
    "Save current edits": "Salva le modifiche effettuate",
    "Save this center and zoom": "Salva il centro e lo zoom",
    "Save this location as new feature": "Salva questa posizione come nuovo oggetto",
    "Search a place name": "Cerca il nome di un luogo",
    "Search location": "Cerca un luogo",
    "See all": "Vedi tutto",
    "See data layers": "Vedi i layer di dati",
    "See full screen": "Visualizza a schermo intero",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Impostalo su false per nascondere questo layer dalla presentazione, dal browser dati, dalla navigazione popup...",
    "Shape properties": "Proprietà della geometria",
    "Short URL": "URL breve",
    "Short credits": "Mostra i ringraziamenti",
    "Show/hide layer": "Mostra/nascondi layer",
    "Simple link: [[http://example.com]]": "Link semplice: [[http://example.com]]",
    "Slideshow": "Presentazione",
    "Sort key": "Campo di ordinamento",
    "Split line": "Dividi linea",
    "Start a hole here": "Comincia un buco qui",
    "Start editing": "Avvia modifica",
    "Start slideshow": "Avvia presentazione",
    "Stop editing": "Ferma la modifica",
    "Stop slideshow": "Ferma presentazione",
    "Supported scheme": "Schema supportato",
    "Supported variables that will be dynamically replaced": "Variabili supportate che verranno cambiate dinamicamente",
    "TMS format": "formato TMS",
    "Text color for the cluster label": "Colore di testo per l'etichetta del raggruppamento",
    "Text formatting": "Formattazione testo",
    "To use if remote server doesn't allow cross domain (slower)": "Da utilizzare se il server remoto non permette l'accesso incrociato ai domini (lento)",
    "To zoom": "Allo zoom",
    "Transfer shape to edited feature": "Trasforma la geometria in un oggetto modificabile",
    "Transform to lines": "Trasforma in linee",
    "Transform to polygon": "Trasforma in poligono",
    "Type of layer": "Tipo di layer",
    "Unable to detect format of file {filename}": "Impossibile individuare il formato del file {filename}",
    "Untitled layer": "Layer senza nome",
    "Untitled map": "Mappa senza nome",
    "Update permissions": "Aggiorna autorizzazioni",
    "Update permissions and editors": "Cambia i permessi e i contributori",
    "Url": "Url",
    "Use current bounds": "Utilizza l'area in uso",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Specificando le proprietà dell'oggetto attraverso le parentesi graffe es. &#123;name&#125; queste saranno automaticamente sostituite con i valori corrispondenti",
    "User content credits": "Riconoscimenti ai contenuti utente",
    "User interface options": "Opzioni interfaccia utente",
    "Versions": "Versioni",
    "View Fullscreen": "Visualizza a schermo intero",
    "Where do we go from here?": "Da dove ci spostiamo da qui?",
    "Whether to display or not polygons paths.": "Indica se visualizzare o meno i lati dei poligoni.",
    "Whether to fill polygons with color.": "Indica se riempire i poligoni con il colore.",
    "Who can edit": "Chi può modificare",
    "Who can view": "Chi può vedere",
    "Will be displayed in the bottom right corner of the map": "Sarà visualizzato in un angolo in basso a destra sulla mappa",
    "Will be visible in the caption of the map": "Sarà visibile nella didascalia della mappa",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "OPS! Qualcun altro sembra aver modificato i dati. È possibile comunque salvare, ma questo cancellerà le modifiche apportate da altri.",
    "Zoom in": "Ingrandisci",
    "Zoom level for automatic zooms": "Livelli di zoom per zoom automatici",
    "Zoom out": "Rimpicciolisci",
    "Zoom to layer extent": "Zoom alla larghezza massima del layer",
    "Zoom to the next": "Zoom sul prossimo",
    "Zoom to the previous": "Zoom sul precedente",
    "Zoom to this feature": "Zoom su questo oggetto",
    "Zoom to this place": "Zoom in questo posto",
    "attribution": "attribuzione",
    "by": "di",
    "display name": "visualizza il nome",
    "height": "altezza",
    "licence": "licenza",
    "max East": "max Est",
    "max North": "max Nord",
    "max South": "max Sud",
    "max West": "max Ovest",
    "max zoom": "zoom massimo",
    "min zoom": "zoom minimo",
    "next": "prossimo",
    "previous": "precedente",
    "width": "larghezza",
    "{count} errors during import: {message}": "{count} errori durante l'importazione: {message}",
    "Measure distances": "Misura le distanze",
    "NM": "NM",
    "kilometers": "chilometri",
    "km": "km",
    "mi": "mi",
    "miles": "miglia",
    "nautical miles": "miglia nautiche",
    "1 day": "1 giorno",
    "1 hour": "1 ora",
    "5 min": "5 min",
    "Cache proxied request": "Usa la cache per le richieste proxy",
    "No cache": "Nessuna cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (grande)",
    "Popup content style": "Stile del contenuto del Popup",
    "Popup shape": "Forma del Popup",
    "Skipping unknown geometry.type: {type}": "Salta le geometrie sconosciute di tipo: {type}",
    "Optional.": "Opzionale.",
    "Paste your data here": "Incolla i tuoi dati qui",
    "Please save the map first": "Per favore prima salva la mappa",
    "Feature identifier key": "Campo di identificativo dell'oggetto",
    "Open current feature on load": "Apri l'oggetto attuale al caricamento",
    "Permalink": "Link permanente",
    "The name of the property to use as feature unique identifier.": "Nome della proprietà da utilizzare come identificatore univoco per ogni oggetto.",
    "Do you want to display caption menus?": "Si vuole visualizzare le etichette dei menu? ",
    "Example: key1,key2,key3": "Esempio: campo1,campo2,campo3",
    "Invalid latitude or longitude": "Latitudine o longitudine non corrette",
    "Invalide property name: {name}": "nome della proprietà non corretta: {name}",
    "Permanent credits": "Ringraziamenti permanenti",
    "Permanent credits background": "Sfondo ringraziamenti permanenti",
    "Select data": "Seleziona i dati",
    "Will be permanently visible in the bottom left corner of the map": "Sarà permanentemente visibile nell'angolo in basso a sinistra della mappa",
    "{area}&#8239;acres": "{area} acri",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miglia",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Transizioni animate",
    "Background overlay url": "URL sfondo in sovrapposizione",
    "Custom overlay": "Sovrapposizione personalizzata",
    "Display the star map button": "Visualizza il pulsante per aggiungere una mappa come speciale",
    "Error in the overlay URL": "Errore nell'URL della sovrapposizione",
    "Map has been starred": "La mappa è stata contrassegnata come speciale",
    "Map has been unstarred": "La mappa è stata rimossa dalle speciali",
    "Opacity": "Opacità",
    "Star this map": "Segna come mappa speciale",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Il simbolo può essere un carattere Unicode o un URL. Puoi utilizzare le proprietà dell'oggetto come variabili: es.: con \"http://myserver.org/images/{name}.png\", la variabile {name} verrà sostituita dal valore \"name\" di ciascun marcatore.",
    "Direct link": "Link diretto",
    "Export options": "Opzioni per l'esportazione",
    "The zoom and center have been modified.": "Lo zoom e il centro sono stati modificati",
    "Congratulations, your map has been created!": "Complimenti, la tua mappa è stata creata!!!",
    "Copy link": "Copia link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Link della modifica segreta copiato in memoria!",
    "Send me the link": "Inviami il link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "La tua mappa è stata creata! Dato che non hai effettuato l'accesso, eccoti il link segreto per modificare la mappa, da tenere al sicuro:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Elenco di proprietà separate da virgole da utilizzare per l'ordinamento degli oggetti. Per invertire l'ordinamento, inserire prima un segno meno (-). Per esempio. miocampo-altrocampo.",
    "Toggle edit mode (⇧+Click)": "Attiva/disattiva la modalità di modifica (⇧+clic)",
    "icon opacity": "opacità dell'incona",
    "*single star for italic*": "*un solo asterisco per il corsivo*",
    "--- for a horizontal rule": "--- per una linea orizzontale",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "Il nome della proprietà da utilizzare come etichetta  (es.: \"nome\"). Puoi anche essere utilizzata una proprietà tra parentesi per usarne più di una o combinarle con contenuto statico (ad esempio: \"{nome} in {luogo}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Elenco separato da virgole di proprietà da utilizzare per la ricerca a faccette (es.: miocampo,altrocampo). Per personalizzare l'etichetta va messo un | subito dopo  (es.: miocampo|Il mio campo, altrocampo|Altro campo)",
    "Default view": "Vista predefinita",
    "Facet keys": "Campi delle faccette",
    "Facet search": "Faccetta di ricerca",
    "Feature properties": "Proprietà dell'oggetto",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Problema nel raggiungimento dell'URL (problema di rete o protezione CORS): {url}",
    "Latest feature": "Ultimo oggetto",
    "No results for these facets": "Nessun risultato trovato per queste faccette",
    "Saved center and zoom": "Centro e zoom salvati",
    "User location": "Posizione dell'utente",
    "Visibility: {status}": "Visibilità: {status}",
    "Fit all data": "Adatta tutti i dati",
    "Verify remote URL": "Verifica URL remota",
    "Add": "Aggiungi",
    "Change": "Cambia",
    "Powered by uMap": "Alimentato da uMap",
    "Search": "Ricerca",
    "Datalayers": "Strati di dati",
    "Secret edit link:": "Link segreto per editare:",
    "Who can edit \"{layer}\"": "Chi può editare \"{layer}\"",
    "Current map view": "Vista corrente della mappa",
    "Filter": "Filtra",
    "Choropleth": "Coropletica",
    "Choropleth breakpoints": "Punti di interruzione coropletici",
    "Choropleth classes": "Classi coropletiche",
    "Choropleth color palette": "Palett dei colori coropletici",
    "Choropleth mode": "Modo coropletico",
    "Choropleth property value": "Valore della proprietà coropletica",
    "Comma separated list of numbers, including min and max values.": "Lista dei numeri separati da virgola, che includono i valori minimi e massimi",
    "Equidistant": "Equidistante",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manuale",
    "Number of desired classes (default 5)": "Numero di classi desiderate (default 5)",
    "Quantiles": "Quantili",
    "Show this layer in the caption": "Mostra questo livello nella didascalia",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("it", locale)
L.setLocale("it")
