const locale = {
    "Allow scroll wheel zoom?": "Luba hiirerullikuga suurendamine?",
    "Automatic": "Automaatne",
    "Ball": "Nööpnõel",
    "Cancel": "Loobu",
    "Caption": "Legend",
    "Choose the data format": "Vali andmevorming",
    "Choose the layer of the feature": "Vali elemendi kiht",
    "Circle": "Ring",
    "Clustered": "Klasterdatud",
    "Data browser": "Andmete sirvimine",
    "Default": "Vaikesäte",
    "Default zoom level": "Vaikimisi suurendusaste",
    "Default: name": "Vaikimisi: name",
    "Display label": "Kuva silt",
    "Display the control to open OpenStreetMap editor": "Kuva OpenStreetMap'i redaktori avamise nupp",
    "Display the data layers control": "Kuva andmekihtide nupp",
    "Display the embed control": "Kuva jagamise nupp",
    "Display the fullscreen control": "Kuva täisekraani nupp",
    "Display the locate control": "Kuva asukoha määramise nupp",
    "Display the measure control": "Kuva mõõtmise nupp",
    "Display the search control": "Kuva otsingunupp",
    "Display the tile layers control": "Kuva tausta vahetamise nupp",
    "Display the zoom control": "Kuva suurendamise nupp",
    "Do you want to display a caption bar?": "Kas soovid kuvada tiitelriba?",
    "Do you want to display a minimap?": "Kas soovid kuvada minikaarti?",
    "Do you want to display a panel on load?": "Kas soovid kuvada külgpaneeli laadimisel?",
    "Do you want to display popup footer?": "Kas soovid kuvada hüpikjalust?",
    "Do you want to display the scale control?": "Kas soovid kuvada mõõtkava?",
    "Do you want to display the «more» control?": "Kas soovid kuvada nuppu «rohkem»?",
    "Drop": "Tilk",
    "GeoRSS (only link)": "GeoRSS (ainult link)",
    "GeoRSS (title + image)": "GeoRSS (pealkiri + pilt)",
    "Heatmap": "Soojuskaart",
    "Icon shape": "Ikooni kuju",
    "Icon symbol": "Ikooni sümbol",
    "Inherit": "Päri",
    "Label direction": "Sildi suund",
    "Label key": "Sildi võti",
    "Labels are clickable": "Silte saab klõpsata",
    "None": "Mitte midagi",
    "On the bottom": "All",
    "On the left": "Vasakul",
    "On the right": "Paremal",
    "On the top": "Ülal",
    "Popup content template": "Hüpiku mall",
    "Side panel": "Külgpaneel",
    "Simplify": "Lihtsustamine",
    "Table": "Tabel",
    "always": "alati",
    "clear": "tühjenda",
    "collapsed": "ahendatud",
    "color": "Värv",
    "dash array": "katkendjoon",
    "define": "määra",
    "description": "kirjeldus",
    "expanded": "laiendatud",
    "fill": "täide",
    "fill color": "täitevärv",
    "fill opacity": "täite läbipaistvus",
    "hidden": "peidetud",
    "iframe": "iframe",
    "inherit": "päri",
    "name": "nimi",
    "never": "mitte kunagi",
    "new window": "uus aken",
    "no": "ei",
    "on hover": "ülelibistamisel",
    "opacity": "läbipaistvus",
    "parent window": "emaaken",
    "stroke": "piirjoon",
    "weight": "jämedus",
    "yes": "jah",
    "{delay} seconds": "{delay} sekundit",
    "# one hash for main heading": "# üks trell põhipealkirja jaoks",
    "## two hashes for second heading": "## kaks trelli teise pealkirja jaoks",
    "### three hashes for third heading": "### kolm trelli kolmanda pealkirja jaoks",
    "**double star for bold**": "**kaks tärni paksu kirja jaoks**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Komaga eraldatud numbriloend, mis määrab katkendjoone mustri, nt \"5, 10, 15\".",
    "About": "Teave",
    "Action not allowed :(": "Tegevus pole lubatud :(",
    "Activate slideshow mode": "Aktiveeri slaidiesitluse režiim",
    "Add a layer": "Lisa kiht",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Lisa uus omadus",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Täiendavad tegevused",
    "Advanced properties": "Täiendavad omadused",
    "All properties are imported.": "Kõik omadused imporditi.",
    "Allow interactions": "Luba interaktsioonid",
    "An error occured": "Ilmnes viga",
    "Are you sure you want to cancel your changes?": "Oled sa kindel, et soovid muudatustest loobuda?",
    "Are you sure you want to clone this map and all its datalayers?": "Oled sa kindel, et soovid kopeerida seda kaarti ja kõiki selle andmekihte?",
    "Are you sure you want to delete the feature?": "Oled sa kindel, et soovid seda elementi kustutada?",
    "Are you sure you want to delete this layer?": "Oled sa kindel, et soovid seda kihti kustutada?",
    "Are you sure you want to delete this map?": "Oled sa kindel, et soovid seda kaarti kustutada?",
    "Are you sure you want to delete this property on all the features?": "Oled sa kindel, et soovid kõigi elementide juurest selle omaduse kustutada?",
    "Are you sure you want to restore this version?": "Oled sa kindel, et soovid taastada selle versiooni?",
    "Attach the map to my account": "Manusta kaart minu kontole",
    "Auto": "Auto",
    "Autostart when map is loaded": "Automaatne käivitus kaardi laadimisel",
    "Bring feature to center": "Sea element keskpunktiks",
    "Browse data": "Andmete sirvimine",
    "Cancel edits": "Loobu muudatustest",
    "Center map on your location": "Sea oma asukoht keskpunktiks",
    "Change map background": "Vaheta kaardi taust",
    "Change tilelayers": "Vaheta kaardi taust",
    "Choose a preset": "Vali algseade",
    "Choose the format of the data to import": "Vali importimise andmevorming",
    "Choose the layer to import in": "Vali kiht, millesse importida",
    "Click last point to finish shape": "Klõpsa kujundi lõpetamiseks viimasel punktil",
    "Click to add a marker": "Klõpsa markeri lisamiseks",
    "Click to continue drawing": "Klõpsa joonistamise jätkamiseks",
    "Click to edit": "Klõpsa muutmiseks",
    "Click to start drawing a line": "Klõpsa joone alustamiseks",
    "Click to start drawing a polygon": "Klõpsa hulknurga alustamiseks",
    "Clone": "Kopeeri",
    "Clone of {name}": "{name} koopia",
    "Clone this feature": "Kopeeri seda elementi",
    "Clone this map": "Kopeeri seda kaarti",
    "Close": "Sulge",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Jätka joont",
    "Continue line (Ctrl+Click)": "Jätka joont (Ctrl+Klõps)",
    "Coordinates": "Koordinaadid",
    "Credits": "Õigused",
    "Current view instead of default map view?": "Praegune vaade vaikimisi vaate asemel?",
    "Custom background": "Kohandatud taust",
    "Data is browsable": "Andmed on sirvitavad",
    "Default interaction options": "Interaktsiooni vaikesuvandid",
    "Default properties": "Vaikeomadused",
    "Default shape properties": "Kujundi vaikeomadused",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Kustuta",
    "Delete all layers": "Kustuta kõik kihid",
    "Delete layer": "Kustuta kiht",
    "Delete this feature": "Kustuta see element",
    "Delete this property on all the features": "Kustuta see omadus kõigi elementide juures",
    "Delete this shape": "Kustuta see kujund",
    "Delete this vertex (Alt+Click)": "Kustuta see tipp (Alt+Klõps)",
    "Directions from here": "Juhised siit",
    "Display measure": "Kuva suurus",
    "Display on load": "Kuva laadimisel",
    "Download": "Laadi alla",
    "Download data": "Laadi andmed alla",
    "Drag to reorder": "Lohista ümberreastamiseks",
    "Draw a line": "Joonista joon",
    "Draw a marker": "Lisa marker",
    "Draw a polygon": "Joonista hulknurk",
    "Draw a polyline": "Draw a polyline",
    "Dynamic": "Dünaamiline",
    "Dynamic properties": "Dünaamilised omadused",
    "Edit": "Muuda",
    "Edit feature's layer": "Muuda elemendi kihti",
    "Edit map properties": "Muuda kaardi omadusi",
    "Edit map settings": "Muuda kaardi seadeid",
    "Edit properties in a table": "Muuda omadusi tabelis",
    "Edit this feature": "Muuda seda elementi",
    "Embed and share this map": "Manusta ja jaga seda kaarti",
    "Embed the map": "Manusta kaart",
    "Empty": "Tühjenda",
    "Error in the tilelayer URL": "Vigane tausta URL",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Välju täisekraanist",
    "Extract shape to separate feature": "Ekstrakti kujund eraldi elemendiks",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filtri võtmed",
    "Format": "Vorming",
    "From zoom": "Suurendusastmest",
    "Go to «{feature}»": "Mine «{feature}» juurde",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Soojuskaardi raadius",
    "Help": "Abi",
    "Hide controls": "Peida juhtnupud",
    "Home": "Avaleht",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe kohandatud kõrgusega (pikslites): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe kohandatud kõrguse ja laiusega (pikslites): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Pilt kohandatud laiusega (pikslites): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Pilt: {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Impordi andmed",
    "Import in a new layer": "Impordi uuele kihile",
    "Imports all umap data, including layers and settings.": "Impordib kõik uMapi andmed, k.a kihid ja seaded.",
    "Include full screen link?": "Lisa täisekraani link?",
    "Interaction options": "Interaktsiooni suvandid",
    "Invalid umap data": "Vigased uMapi andmed",
    "Invalid umap data in {filename}": "Vigased uMapi andmed failis {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Laius",
    "Layer": "Kiht",
    "Layer properties": "Kihi omadused",
    "Licence": "Litsents",
    "Limit bounds": "Määra piirid",
    "Link to…": "Lingi…",
    "Link with text: [[http://example.com|text of the link]]": "Link tekstiga: [[http://example.com|lingi tekst]]",
    "Long credits": "Long credits",
    "Longitude": "Pikkus",
    "Make main shape": "Muuda peamiseks kujundiks",
    "Manage layers": "Halda kihte",
    "Map background credits": "Kaardi tausta õigused",
    "Map has been attached to your account": "Kaart on lisatud kontole",
    "Map has been saved!": "Kaart on salvestatud!",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Kaardi toimetajad",
    "Map's owner": "Kaardi omanik",
    "Merge lines": "Ühenda jooned",
    "More controls": "Rohkem juhtnuppe",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Peab olema kehtiv CSS väärtus (nt DarkBlue või #123456)",
    "No licence has been set": "Litsentsi pole määratud",
    "No results": "Tulemused puuduvad",
    "Only visible features will be downloaded.": "Alla laaditakse ainult nähtavad elemendid",
    "Open download panel": "Ava allalaadimise aken",
    "Open link in…": "Ava link...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Valikuline. Sama mis värv, kui pole määratud teisiti",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Please be sure the licence is compliant with your use.": "Please be sure the licence is compliant with your use.",
    "Please choose a format": "Vali palun vorming",
    "Please enter the name of the property": "Sisesta palun omaduse nimi",
    "Please enter the new name of this property": "Sisesta palun selle omaduse uus nimi",
    "Problem in the response": "Problem in the response",
    "Problem in the response format": "Problem in the response format",
    "Properties imported:": "Imporditud omadused:",
    "Provide an URL here": "Lisage siia URL",
    "Proxy request": "Proxy request",
    "Remote data": "Kaugandmed",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Asenda kihi sisu",
    "Restore this version": "Taasta see versioon",
    "Save": "Salvesta",
    "Save anyway": "Salvesta sellegipoolest",
    "Save current edits": "Salvesta praegused muudatused",
    "Save this center and zoom": "Salvesta see keskpunkt ja suurendus",
    "Save this location as new feature": "Salvesta see asukoht uue elemendina",
    "Search a place name": "Kohanime otsing",
    "Search location": "Asukoha otsing",
    "See all": "Näita kõiki",
    "See data layers": "Näita andmekihte",
    "See full screen": "Täisekraanvaade",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Kujundi omadused",
    "Short URL": "Lühilink",
    "Short credits": "Short credits",
    "Show/hide layer": "Näita/peida kiht",
    "Simple link: [[http://example.com]]": "Link: [[http://example.com]]",
    "Slideshow": "Slaidiprogramm",
    "Sort key": "Sorteerimise võti",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Alusta muutmist",
    "Start slideshow": "Alusta slaidiprogrammi",
    "Stop editing": "Lõpeta muutmine",
    "Stop slideshow": "Lõpeta slaidiprogramm",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "TMS format": "TMS vorming",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Tekstivorming",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Suurendusastmeni",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Muuda joonteks",
    "Transform to polygon": "Muuda hulknurgaks",
    "Type of layer": "Kihitüüp",
    "Unable to detect format of file {filename}": "{filename} failivormingu tuvastamine ebaõnnestus",
    "Untitled layer": "Nimeta kiht",
    "Untitled map": "Nimeta kaart",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Update permissions and editors",
    "Url": "URL",
    "Use current bounds": "Kasuta praegust vaadet",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Kasutaja sisu õigused",
    "User interface options": "Kasutajaliidese suvandid",
    "Versions": "Versioonid",
    "View Fullscreen": "Täisekraanivaade",
    "Where do we go from here?": "Kuhu läheb siit edasi?",
    "Whether to display or not polygons paths.": "Hulknurga piirjoonte näitamine.",
    "Whether to fill polygons with color.": "Hulknurkade täitmine värviga.",
    "Who can edit": "Muutmisõigus",
    "Who can view": "Vaatamisõigus",
    "Will be displayed in the bottom right corner of the map": "Kuvatakse kaardi alumises paremas nurgas",
    "Will be visible in the caption of the map": "Nähtav kaardi legendil",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "Zoom in": "Suurenda",
    "Zoom level for automatic zooms": "Suurendusaste automaatse suurenduse korral",
    "Zoom out": "Vähenda",
    "Zoom to layer extent": "Suurenda kihi ulatuseni",
    "Zoom to the next": "Järgmine",
    "Zoom to the previous": "Eelmine",
    "Zoom to this feature": "Zoom to this feature",
    "Zoom to this place": "Suurenda selle kohani",
    "attribution": "attribution",
    "by": "autorilt",
    "display name": "display name",
    "height": "kõrgus",
    "licence": "litsents",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "suurim suurendusaste",
    "min zoom": "vähim suurendusaste",
    "next": "edasi",
    "previous": "tagasi",
    "width": "laius",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Vahemaade mõõtmine",
    "NM": "NM",
    "kilometers": "kilomeetrid",
    "km": "km",
    "mi": "mi",
    "miles": "miilid",
    "nautical miles": "meremiilid",
    "1 day": "1 päev",
    "1 hour": "1 tund",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Hüpik",
    "Popup (large)": "Hüpik (suur)",
    "Popup content style": "Hüpiku sisu stiil",
    "Popup shape": "Hüpiku kuju",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Optional.": "Valikuline.",
    "Paste your data here": "Kleebi oma andmed siia",
    "Please save the map first": "Salvesta palun enne kaart",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Püsilink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("et", locale)
L.setLocale("et")
