const locale = {
    "Allow scroll wheel zoom?": "Pozwalać na przybliżanie kółkiem?",
    "Automatic": "Automatyczny",
    "Ball": "Pinezka",
    "Cancel": "Anuluj",
    "Caption": "Podpis",
    "Choose the data format": "Wybierz format danych",
    "Choose the layer of the feature": "Wybierz warstwę obiektu",
    "Circle": "Kółko",
    "Clustered": "Zgrupowane",
    "Data browser": "Przeglądanie danych",
    "Default": "Domyślne",
    "Default zoom level": "Domyślne przybliżenie",
    "Default: name": "Domyślnie: name",
    "Display label": "Wyświetl etykietę",
    "Display the control to open OpenStreetMap editor": "Wyświetlaj panel otwierający edytor OSM",
    "Display the data layers control": "Wyświetlaj panel warstw z danymi",
    "Display the embed control": "Wyświetlaj panel sterujący osadzaniem",
    "Display the fullscreen control": "Wyświetlaj panel widoku pełnoekranowego",
    "Display the locate control": "Wyświetlaj panel lokalizacji",
    "Display the measure control": "Wyświetlaj panel miarek",
    "Display the search control": "Wyświetlaj panel wyszukiwania",
    "Display the tile layers control": "Wyświetlaj panel warstw kafelków",
    "Display the zoom control": "Wyświetlaj panel sterujący powiększeniem",
    "Do you want to display a caption bar?": "Wyświetlać pasek z nagłówkiem?",
    "Do you want to display a minimap?": "Wyświetlać minimapę?",
    "Do you want to display a panel on load?": "Wyświetlać panel po załadowaniu?",
    "Do you want to display popup footer?": "Wyświetlać stopkę dymku?",
    "Do you want to display the scale control?": "Wyświetlać kontrolkę ze skalą?",
    "Do you want to display the «more» control?": "Wyświetlać „więcej kontrolek”?",
    "Drop": "Kropla",
    "GeoRSS (only link)": "GeoRSS (tylko link)",
    "GeoRSS (title + image)": "GeoRSS (tytuł i obrazek)",
    "Heatmap": "Mapa cieplna",
    "Icon shape": "Kształt ikony",
    "Icon symbol": "Symbol ikony",
    "Inherit": "Dziedziczne",
    "Label direction": "Kierunek etykiety",
    "Label key": "Klucz etykiety",
    "Labels are clickable": "Etykiety są klikalne",
    "None": "Brak",
    "On the bottom": "Na dole",
    "On the left": "Po lewej",
    "On the right": "Po prawej",
    "On the top": "Na górze",
    "Popup content template": "Szablon treści dymku",
    "Side panel": "Panel boczny",
    "Simplify": "Uprość",
    "Table": "Tabela",
    "always": "zawsze",
    "clear": "wyczyść",
    "collapsed": "zwinięty",
    "color": "kolor",
    "dash array": "przerywana linia",
    "define": "określ",
    "description": "opis",
    "expanded": "rozwinięty",
    "fill": "wypełnienie",
    "fill color": "kolor wypełnienia",
    "fill opacity": "stopień wypełnienia",
    "hidden": "ukryte",
    "iframe": "iframe",
    "inherit": "dziedziczny",
    "name": "nazwa",
    "never": "nigdy",
    "new window": "nowe okno",
    "no": "nie",
    "on hover": "po najechaniu",
    "opacity": "przeźroczystość",
    "parent window": "to samo okno",
    "stroke": "obramowanie",
    "weight": "waga",
    "yes": "tak",
    "{delay} seconds": "{delay} sekund",
    "# one hash for main heading": "# jeden krzyżyk – nagłówek pierwszego poziomu",
    "## two hashes for second heading": "## dwa krzyżyki – nagłówek drugiego poziomu",
    "### three hashes for third heading": "### trzy krzyżyki – nagłówek trzeciego poziomu",
    "**double star for bold**": "**podwójna gwiazdka do pogrubienia**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Rozdzielona przecinkami lista liczb, która definiuje wzór kreski linii, np. „5, 10, 15”.",
    "About": "Informacje",
    "Action not allowed :(": "Operacja niedozwolona :(",
    "Activate slideshow mode": "Aktywuj pokaz slajdów",
    "Add a layer": "Dodaj warstwę",
    "Add a line to the current multi": "Dodaj linię do wybranego obszaru",
    "Add a new property": "Dodaj nową właściwość",
    "Add a polygon to the current multi": "Dodaj wielobok do wybranego obszaru",
    "Advanced actions": "Zaawansowane operacje",
    "Advanced properties": "Zaawansowane właściwości",
    "All properties are imported.": "Importowane są wszystkie właściwości.",
    "Allow interactions": "Zezwalaj na interakcję",
    "An error occured": "Wystąpił błąd",
    "Are you sure you want to cancel your changes?": "Na pewno chcesz porzucić swoje zmiany?",
    "Are you sure you want to clone this map and all its datalayers?": "Na pewno chcesz sklonować tę mapę razem z jej warstwami?",
    "Are you sure you want to delete the feature?": "Na pewno chcesz usunąć ten obiekt?",
    "Are you sure you want to delete this layer?": "Na pewno chcesz usunąć tę warstwę?",
    "Are you sure you want to delete this map?": "Na pewno chcesz usunąć tą mapę?",
    "Are you sure you want to delete this property on all the features?": "Na pewno chcesz usunąć tę właściwość we wszystkich obiektach?",
    "Are you sure you want to restore this version?": "Na pewno chcesz przywrócić tę wersję?",
    "Attach the map to my account": "Dołącz mapę do mojego konta",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart po załadowaniu mapy",
    "Bring feature to center": "Przenieś obiekt do środka",
    "Browse data": "Przeglądaj dane",
    "Cancel edits": "Anuluj edycje",
    "Center map on your location": "Wyśrodkuj mapę na twojej lokalizacji",
    "Change map background": "Zmień podkład mapy",
    "Change tilelayers": "Zmień podkład",
    "Choose a preset": "Wybierz szablon",
    "Choose the format of the data to import": "Wybierz format importowanych danych",
    "Choose the layer to import in": "Wybierz warstwę docelową",
    "Click last point to finish shape": "Kliknij ostatni punkt, aby zakończyć rysowanie",
    "Click to add a marker": "Kliknij, aby dodać znacznik",
    "Click to continue drawing": "Kliknij, aby kontynuować rysowanie",
    "Click to edit": "Kliknij, aby edytować",
    "Click to start drawing a line": "Kliknij, aby zacząć rysować linię",
    "Click to start drawing a polygon": "Kliknij, aby zacząć rysować obszar",
    "Clone": "Klonuj",
    "Clone of {name}": "Sklonowane z {name}",
    "Clone this feature": "Sklonuj ten obiekt",
    "Clone this map": "Sklonuj mapę",
    "Close": "Zamknij",
    "Clustering radius": "Promień grupowania",
    "Comma separated list of properties to use when filtering features": "Lista właściwości oddzielona przecinkiem do używania przy sortowaniu obiektów",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Wartości powinny być oddzielone przecinkiem, średnikiem lub znakiem tabulacji. Układ współrzędnych WGS84 jest wymagany. Tylko geometrie typu punkt zostaną zaimportowane. Import sprawdzi nagłówki kolumn czy zawierają „lat” i „lon” na początku nagłówka, wielkość liter nie ma znaczenia. Wszystkie inne kolumny zostaną zaimportowane jako właściwości tych punktów.",
    "Continue line": "Kontynuuj linię",
    "Continue line (Ctrl+Click)": "Kontynuuj linię (Ctrl+Klik)",
    "Coordinates": "Współrzędne",
    "Credits": "Źródło",
    "Current view instead of default map view?": "Obecny widok mapy zamiast domyślnego?",
    "Custom background": "Własne tło",
    "Data is browsable": "Dane można przeglądać",
    "Default interaction options": "Domyślne ustawienia interakcji",
    "Default properties": "Domyślne właściwości",
    "Default shape properties": "Domyślne właściwości kształtu",
    "Define link to open in a new window on polygon click.": "Ustaw odnośnik, który otworzy się w nowym oknie po kliknięciu wielokąta.",
    "Delay between two transitions when in play mode": "Opóźnienie pomiędzy dwoma przejściami w trybie odtwarzania",
    "Delete": "Usuń",
    "Delete all layers": "Usuń wszystkie warstwy",
    "Delete layer": "Usuń warstwę",
    "Delete this feature": "Usuń ten obiekt",
    "Delete this property on all the features": "Usuń tę właściwość ze wszystkich obiektów",
    "Delete this shape": "Usuń tę figurę",
    "Delete this vertex (Alt+Click)": "Usuń ten wierzchołek (Alt+Klik)",
    "Directions from here": "Kierunki stąd",
    "Display measure": "Wyświetl pomiar",
    "Display on load": "Wyświetl przy ładowaniu",
    "Download": "Pobieranie",
    "Download data": "Pobierz dane",
    "Drag to reorder": "Przeciągnij, by zmienić kolejność",
    "Draw a line": "Rysuj linię",
    "Draw a marker": "Dodaj znacznik",
    "Draw a polygon": "Rysuj obszar",
    "Draw a polyline": "Rysuj linię",
    "Dynamic": "Dynamiczne",
    "Dynamic properties": "Właściwości dynamiczne",
    "Edit": "Edytuj",
    "Edit feature's layer": "Edytuj warstwę z obiektami",
    "Edit map properties": "Edytuj właściwości mapy",
    "Edit map settings": "Edytuj ustawienia mapy",
    "Edit properties in a table": "Edytuj właściwości w tabeli",
    "Edit this feature": "Edytuj ten obiekt",
    "Embed and share this map": "Osadź i udostępnij tę mapę",
    "Embed the map": "Osadź mapę na stronie",
    "Empty": "Wyczyść",
    "Error in the tilelayer URL": "Błąd w adresie URL podkładu",
    "Error while fetching {url}": "Błąd wczytywania {url}",
    "Exit Fullscreen": "Zamknij pełny ekran",
    "Extract shape to separate feature": "Wydziel figurę jako odrębny obiekt",
    "Fetch data each time map view changes.": "Załaduj dane za każdym razem, gdy zmienia się widok mapy.",
    "Filter keys": "Klucze filtrów",
    "Format": "Format",
    "From zoom": "Od przybliżenia",
    "Go to «{feature}»": "Idź do „{feature}”",
    "Heatmap intensity property": "Intensywność mapy cieplnej",
    "Heatmap radius": "Promień mapy cieplnej",
    "Help": "Pomoc",
    "Hide controls": "Ukryj przyciski",
    "Home": "Strona główna",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Jak bardzo uprościć obszar na każdym poziomie przybliżenia (więcej = większa wydajność i gładki wygląd, mniej = większa dokładność)",
    "If false, the polygon will act as a part of the underlying map.": "Jeżeli fałsz, wielokąt będzie zachowywał się jak część mapy zasadniczej.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Ramka z podaną wysokością (w pikselach) {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Ramka z podaną wysokością i szerokością (w pikselach): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Ramka: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Obrazek z własną szerokością (w pikselach) {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Obrazek: {{http://image.url.com}}",
    "Import": "Importuj",
    "Import data": "Importuj dane",
    "Import in a new layer": "Importuj do nowej warstwy",
    "Imports all umap data, including layers and settings.": "Import wszystkich danych umap, razem z warstwami i ustawieniami.",
    "Include full screen link?": "Dołączyć link do pełnego ekranu?",
    "Interaction options": "Opcje interakcji",
    "Invalid umap data": "Niepoprawne dane umap",
    "Invalid umap data in {filename}": "Niepoprawne dane umap w {filename}",
    "Keep current visible layers": "Zachowaj obecnie widoczne warstwy",
    "Latitude": "Szerokość geograficzna",
    "Layer": "Warstwa",
    "Layer properties": "Ustawienia warstwy",
    "Licence": "Licencja",
    "Limit bounds": "Limit granic",
    "Link to…": "Łącze do...",
    "Link with text: [[http://example.com|text of the link]]": "Link z tekstem: [[http://example.com|tekst]]",
    "Long credits": "Długie źródło",
    "Longitude": "Długość geograficzna",
    "Make main shape": "Narysuj główny kształt",
    "Manage layers": "Zarządzaj warstwami",
    "Map background credits": "Źródło tła mapy",
    "Map has been attached to your account": "Mapa została dołączona do twojego konta",
    "Map has been saved!": "Mapa została zapisana!",
    "Map user content has been published under licence": "Zawartość mapy użytkownika została opublikowana pod licencją",
    "Map's editors": "Edytorzy mapy",
    "Map's owner": "Właściciel mapy",
    "Merge lines": "Połącz linie",
    "More controls": "Więcej przycisków",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Musi być prawidłową wartością CSS (np. DarkBlue lub #123456)",
    "No licence has been set": "Nie wybrano licencji",
    "No results": "Brak wyników",
    "Only visible features will be downloaded.": "Tylko widoczne obiekty zostaną pobrane.",
    "Open download panel": "Otwórz panel pobierania",
    "Open link in…": "Otwieraj odnośnik w...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otwórz ten zakres mapy w edytorze, by wprowadzić do OpenStreetMap dokładniejsze dane",
    "Optional intensity property for heatmap": "Opcjonalna intensywność mapy cieplnej",
    "Optional. Same as color if not set.": "Opcjonalne. Taki sam jak kolor, jeśli nie podano.",
    "Override clustering radius (default 80)": "Nadpisz promień grupowania (domyślnie 80)",
    "Override heatmap radius (default 25)": "Nadpisz promień mapy cieplnej (domyślnie 25)",
    "Please be sure the licence is compliant with your use.": "Upewnij się, że korzystanie z tych danych jest zgodne z licencją.",
    "Please choose a format": "Wybierz format",
    "Please enter the name of the property": "Podaj nazwę właściwości",
    "Please enter the new name of this property": "Podaj nową nazwę tej właściwości",
    "Problem in the response": "Problem z odpowiedzią",
    "Problem in the response format": "Problem z formatem odpowiedzi",
    "Properties imported:": "Importowane właściwości:",
    "Provide an URL here": "Wprowadź tutaj adres URL",
    "Proxy request": "Żądanie proxy",
    "Remote data": "Zdalne dane",
    "Remove shape from the multi": "Usuń figurę z wybranego obszaru",
    "Rename this property on all the features": "Zmień nazwę tej właściwości we wszystkich obiektach",
    "Replace layer content": "Zamień zawartość warstwy",
    "Restore this version": "Przywróć tę wersję",
    "Save": "Zapisz",
    "Save anyway": "Zapisz mimo wszystko",
    "Save current edits": "Zapisz obecne edycje",
    "Save this center and zoom": "Zapisz obecną pozycję i przybliżenie",
    "Save this location as new feature": "Zapisz to miejsce jako nowy obiekt",
    "Search a place name": "Szukaj nazwy miejsca",
    "Search location": "Znajdź miejsce",
    "See all": "Pokaż wszystko",
    "See data layers": "Zobacz wszystkie warstwy danych",
    "See full screen": "Pełny ekran",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Ustaw „OFF”, żeby ukryć tę warstwę z pokazu slajdów, przeglądarki danych i okienek nawigacji.",
    "Shape properties": "Właściwości kształtu",
    "Short URL": "Krótki adres URL",
    "Short credits": "Krótkie źródło",
    "Show/hide layer": "Pokaż/ukryj warstwę",
    "Simple link: [[http://example.com]]": "Prosty link: [[http://example.com]]",
    "Slideshow": "Pokaz slajdów",
    "Sort key": "Klucz sortowania",
    "Split line": "Podziel linię",
    "Start a hole here": "Zacznij dziurę tutaj",
    "Start editing": "Rozpocznij edycję",
    "Start slideshow": "Rozpocznij pokaz",
    "Stop editing": "Zakończ edycję",
    "Stop slideshow": "Zakończ pokaz",
    "Supported scheme": "Obsługiwany schemat",
    "Supported variables that will be dynamically replaced": "Obsługiwane zmienne zostaną dynamicznie zamienione",
    "TMS format": "Format TMS",
    "Text color for the cluster label": "Kolor tekstu etykiety grupy",
    "Text formatting": "Formatowanie tekstu",
    "To use if remote server doesn't allow cross domain (slower)": "Używaj, jeśli zdalny serwer nie zezwala na cross domain (wolne)",
    "To zoom": "Przybliżać",
    "Transfer shape to edited feature": "Dołącz figurę do edytowanego obiektu",
    "Transform to lines": "Przekształć na linie",
    "Transform to polygon": "Przekształć w wielokąt",
    "Type of layer": "Typ warstwy",
    "Unable to detect format of file {filename}": "Nie można wykryć formatu pliku {filename}",
    "Untitled layer": "Warstwa bez nazwy",
    "Untitled map": "Mapa bez nazwy",
    "Update permissions": "Zaktualizuj uprawnienia",
    "Update permissions and editors": "Aktualizuj uprawnienia i edytorów",
    "Url": "Adres URL",
    "Use current bounds": "Użyj bieżących granic",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Użyj nazw pól z właściwości obiektu w klamrach, np. &#123;name&#125;. Zostaną automatycznie zastąpione przez odpowiadające im wartości.",
    "User content credits": "Źródło treści użytkownika",
    "User interface options": "Opcje interfejsu",
    "Versions": "Wersje",
    "View Fullscreen": "Włącz tryb pełnoekranowy",
    "Where do we go from here?": "Gdzie można stąd pojechać?",
    "Whether to display or not polygons paths.": "Czy wyświetlać obrysy obszarów.",
    "Whether to fill polygons with color.": "Czy wypełniać obszary kolorem.",
    "Who can edit": "Kto może edytować",
    "Who can view": "Kto może zobaczyć",
    "Will be displayed in the bottom right corner of the map": "Będzie wyświetlone w prawym dolnym rogu mapy",
    "Will be visible in the caption of the map": "Będzie widoczne w nagłówku mapy",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ups! Ktoś jeszcze edytował dane. Możesz mimo wszystko zapisać, ale to usunie zmiany dokonane przez innych.",
    "Zoom in": "Przybliż",
    "Zoom level for automatic zooms": "Poziom automatycznych przybliżeń",
    "Zoom out": "Oddal",
    "Zoom to layer extent": "Przybliż do warstwy",
    "Zoom to the next": "Przybliż do następnego",
    "Zoom to the previous": "Przybliż do poprzedniego",
    "Zoom to this feature": "Przybliż do tego obiektu",
    "Zoom to this place": "Przybliż do tego miejsca",
    "attribution": "oznaczenie autorstwa",
    "by": " ",
    "display name": "wyświetl nazwę",
    "height": "wysokość",
    "licence": "licencja",
    "max East": "granica wschodnia",
    "max North": "granica północna",
    "max South": "granica południowa",
    "max West": "granica zachodnia",
    "max zoom": "maksymalne powiększenie",
    "min zoom": "minimalne powiększenie",
    "next": "następne",
    "previous": "poprzednie",
    "width": "szerokość",
    "{count} errors during import: {message}": "{count} błędów podczas importu: {message}",
    "Measure distances": "Pomiar odległości",
    "NM": "NM",
    "kilometers": "kilometry",
    "km": "km",
    "mi": "mi",
    "miles": "mile",
    "nautical miles": "mile morskie",
    "1 day": "1 dzień",
    "1 hour": "1 godzina",
    "5 min": "5 minut",
    "Cache proxied request": "Zapytanie pośredniczące pamięci podręcznej",
    "No cache": "Brak pamięci podręcznej",
    "Popup": "Wyskakujące okienko",
    "Popup (large)": "Wyskakujące okienko (duże)",
    "Popup content style": "Styl zawartości wyskakującego okienka",
    "Popup shape": "Kształt wyskakującego okienka",
    "Skipping unknown geometry.type: {type}": "Pomijanie nieznanego rodzaju geometrii: {type}",
    "Optional.": "Opcjonalnie.",
    "Paste your data here": "Wklej tutaj swoje dane",
    "Please save the map first": "Prosimy najpierw zapisać mapę",
    "Feature identifier key": "Klucz identyfikacyjny obiektu",
    "Open current feature on load": "Otwórz bieżący obiekt po załadowaniu",
    "Permalink": "Bezpośredni odnośnik.",
    "The name of the property to use as feature unique identifier.": "Nazwa właściwości używana jako unikalny identyfikator obiektu.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} akrów",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} jardów kwadratowych",
    "{distance}&#8239;NM": "{distance} Mm",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{odległość} m",
    "{distance}&#8239;miles": "{odległość} mil",
    "{distance}&#8239;yd": "{odległość} jardów",
    " (area: {measure})": "(obszar: {measure})",
    " (length: {measure})": "(długość: {measure})",
    "Animated transitions": "Animowane przejścia",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Mapa została oznaczona gwiazdką",
    "Map has been unstarred": "Mapa została usunięta z oznaczonych gwiazdką",
    "Opacity": "Nieprzezroczystość",
    "Star this map": "Oznacz mapę gwiazdką",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Bezpośredni link",
    "Export options": "Eksportuj opcje",
    "The zoom and center have been modified.": "Przybliżenie i pozycja zostały zmienione.",
    "Congratulations, your map has been created!": "Gratulacje, twoja mapa została utworzona!",
    "Copy link": "Skopiuj link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Tajny odnośnik do edycji skopiowany do schowka!",
    "Send me the link": "Wyślij mi link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Przełącz tryb edycji (Shift+Klik)",
    "icon opacity": "nieprzezroczystość ikony",
    "*single star for italic*": "*pojedyncza gwiazdka dla kursywy*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Domyślny widok",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "Brak wyników dla tych aspektów",
    "Saved center and zoom": "Zapisano pozycję i przybliżenie",
    "User location": "Lokalizacja użytkownika",
    "Visibility: {status}": "Widoczność: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Zweryfikuj zdalny URL",
    "Add": "Dodawać",
    "Change": "Zmiana",
    "Powered by uMap": "Napędzane przez uMap",
    "Search": "Szukaj",
    "Datalayers": "Warstwy danych",
    "Secret edit link:": "Sekretny odnośnik edycji:",
    "Who can edit \"{layer}\"": "Kto może edytować \"{layer}\"",
    "Current map view": "Bieżący widok mapy",
    "Filter": "Filtr",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Pokaż tę warstwę w podpisie",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("pl", locale)
L.setLocale("pl")
