const locale = {
    "Allow scroll wheel zoom?": "Permitir o achegamento ca roda do rato?",
    "Automatic": "Automático",
    "Ball": "Bóla",
    "Cancel": "Desbotar",
    "Caption": "Subtítulo",
    "Choose the data format": "Escoller o formato de datos",
    "Choose the layer of the feature": "Escoller a capa do elemento",
    "Circle": "Círculo",
    "Clustered": "Agrupados",
    "Data browser": "Procurador de datos",
    "Default": "Por defecto",
    "Default zoom level": "Nivel do achegamento predeterminado",
    "Default: name": "Por defecto: nome",
    "Display label": "Amosar etiqueta",
    "Display the control to open OpenStreetMap editor": "Amosar o control para abrir o editor do OpenStreetMap",
    "Display the data layers control": "Amosar o control da capa de datos",
    "Display the embed control": "Amosar o control de incrustado",
    "Display the fullscreen control": "Amosar o control de pantalla completa",
    "Display the locate control": "Amosar o control de ubicación",
    "Display the measure control": "Amosar o control de medida",
    "Display the search control": "Amosar o control de procura",
    "Display the tile layers control": "Amosar o control de capas de teselas",
    "Display the zoom control": "Amosar o control de achegamento",
    "Do you want to display a caption bar?": "Desexas amosar a barra de subtítulos?",
    "Do you want to display a minimap?": "Desexas amosar un minimapa?",
    "Do you want to display a panel on load?": "Desexas amosar un panel ó cargar?",
    "Do you want to display popup footer?": "Desexas amosar a xanela emerxente no pé de páxina?",
    "Do you want to display the scale control?": "Desexas amosar o control de escala?",
    "Do you want to display the «more» control?": "Desexas amosar o control «máis»?",
    "Drop": "Marcaxe",
    "GeoRSS (only link)": "GeoRSS (só ligazón)",
    "GeoRSS (title + image)": "GeoRSS (título + imaxe)",
    "Heatmap": "Mapa de calor",
    "Icon shape": "Forma da icona",
    "Icon symbol": "Símbolo da icona",
    "Inherit": "Herdar",
    "Label direction": "Dirección da etiqueta",
    "Label key": "Etiqueta da clave",
    "Labels are clickable": "Labels are clickable",
    "None": "Ningún",
    "On the bottom": "Na parte de embaixo",
    "On the left": "Á esquerda",
    "On the right": "Á dereita",
    "On the top": "Na parte de enriba",
    "Popup content template": "Padrón do contido da xanela emerxente",
    "Side panel": "Lapela lateral",
    "Simplify": "Simplificar",
    "Table": "Táboa",
    "always": "sempre",
    "clear": "limpar",
    "collapsed": "agochado",
    "color": "cor",
    "dash array": "matriz de guións",
    "define": "define",
    "description": "descrición",
    "expanded": "expandido",
    "fill": "rechear",
    "fill color": "cor de recheo",
    "fill opacity": "rechear a opacidade",
    "hidden": "agochar",
    "iframe": "iframe",
    "inherit": "herdar",
    "name": "nome",
    "never": "nunca",
    "new window": "nova xanela",
    "no": "non",
    "on hover": "ó pasar o rato por riba",
    "opacity": "opacidade",
    "parent window": "xanela pai ou principal",
    "stroke": "trazo",
    "weight": "peso",
    "yes": "si",
    "{delay} seconds": "{delay} segundos",
    "# one hash for main heading": "# un cancelo para a cabeceira principal",
    "## two hashes for second heading": "## dous cancelos para a cabeceira secundaria",
    "### three hashes for third heading": "### tres cancelos para a cabeceira terciaria",
    "**double star for bold**": "**dous asteriscos para pór negriña**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Unha listaxe separada por vírgulas que define o patrón de trazos de guión. Ex.: \"5, 10, 15\".",
    "About": "Acerca de",
    "Action not allowed :(": "Acción non permitida :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Engadir unha capa",
    "Add a line to the current multi": "Engadir unha liña para o multi actual",
    "Add a new property": "Engadir unha nova propiedade",
    "Add a polygon to the current multi": "Enhadir un polígono para o multi actual",
    "Advanced actions": "Accións avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "All properties are imported.": "Tódalas propiedades son importadas.",
    "Allow interactions": "Permitir interaccións",
    "An error occured": "Ocorreu un erro",
    "Are you sure you want to cancel your changes?": "Estás na certeza de que desexas desbotar as túas mudanzas?",
    "Are you sure you want to clone this map and all its datalayers?": "Estás na certeza de que desexas clonar este mapa e tódalas súas capas de datos?",
    "Are you sure you want to delete the feature?": "Estás na certeza de que desexas eliminar este elemento?",
    "Are you sure you want to delete this layer?": "Estás na certeza de que desexas eliminar esta capa?",
    "Are you sure you want to delete this map?": "Estás na certeza de que desexas eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "Estás na certeza de que desexas eliminar esta propiedade en tódolos elementos?",
    "Are you sure you want to restore this version?": "Estás na certeza de que desexas restabelecer esta versión?",
    "Attach the map to my account": "Adxuntar o mapa á miña conta",
    "Auto": "Automático",
    "Autostart when map is loaded": "Autocomezar cando o mapa estea cargado",
    "Bring feature to center": "Levar o elemento ó centro",
    "Browse data": "Navegar polos datos",
    "Cancel edits": "Desbotar as edicións",
    "Center map on your location": "Centrar o mapa na túa ubicación",
    "Change map background": "Mudar o mapa do fondo",
    "Change tilelayers": "Mudar as capas de teselas",
    "Choose a preset": "Escoller un predefinido",
    "Choose the format of the data to import": "Escoller o formato dos datos a importar",
    "Choose the layer to import in": "Escoller a capa á que se importa",
    "Click last point to finish shape": "Preme no derradeiro punto para rematar a forma",
    "Click to add a marker": "Preme para engadir unha marcaxe",
    "Click to continue drawing": "Preme para seguir debuxando",
    "Click to edit": "Preme para editar",
    "Click to start drawing a line": "Preme para comezar a debuxar unha liña",
    "Click to start drawing a polygon": "Preme para comezar a debuxar un polígono",
    "Clone": "Clonar",
    "Clone of {name}": "Clonado de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Close": "Pechar",
    "Clustering radius": "Raio de agrupamento",
    "Comma separated list of properties to use when filtering features": "Listaxe de propiedades separado por comas para empregar a filtraxe de elementos",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Liña continua",
    "Continue line (Ctrl+Click)": "Liña continua (Ctrl+Clic)",
    "Coordinates": "Coordenadas",
    "Credits": "Cretos",
    "Current view instead of default map view?": "Vista actual en troques da vista predeterminada?",
    "Custom background": "Fondo persoalizado",
    "Data is browsable": "Os datos son navegábeis",
    "Default interaction options": "Opcións de interacción predeterminados",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de formas predeterminados",
    "Define link to open in a new window on polygon click.": "Defina unha ligazón para abrir nunha nova xanela ó premer no polígono.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Eliminar",
    "Delete all layers": "Eliminar tódalas capas",
    "Delete layer": "Eliminar capa",
    "Delete this feature": "Eliminar este elemento",
    "Delete this property on all the features": "Eliminar esta propiedade en tódolos elementos",
    "Delete this shape": "Eliminar esta forma",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+Clic)",
    "Directions from here": "Direccións dende aquí",
    "Display measure": "Amosar medida",
    "Display on load": "Amosar ó cargar",
    "Download": "Baixar",
    "Download data": "Baixar datos",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a line": "Debuxa unha liña",
    "Draw a marker": "Debuxa unha marcaxe",
    "Draw a polygon": "Debuxa un polígono",
    "Draw a polyline": "Debuxa unha liña múltiple",
    "Dynamic": "Dinámico",
    "Dynamic properties": "Propiedades dinámicas",
    "Edit": "Editar",
    "Edit feature's layer": "Editar a capa do elemento",
    "Edit map properties": "Editar as propiedades do mapa",
    "Edit map settings": "Editar axustes do mapa",
    "Edit properties in a table": "Editar propiedades nunha táboa",
    "Edit this feature": "Editar este elemento",
    "Embed and share this map": "Incorporar e compartir este mapa",
    "Embed the map": "Incorporar o mapa",
    "Empty": "Baleirar",
    "Error in the tilelayer URL": "Erro na URL da capa de teselas",
    "Error while fetching {url}": "Erro ó recuperar {url}",
    "Exit Fullscreen": "Saír da pantalla completa",
    "Extract shape to separate feature": "Extraer a forma ó elemento separado",
    "Fetch data each time map view changes.": "Obter os datos cada vez que a vista do mapa muda.",
    "Filter keys": "Claves de filtrado",
    "Format": "Formato",
    "From zoom": "Dende o achegamento",
    "Go to «{feature}»": "Ir cara «{feature}»",
    "Heatmap intensity property": "Propiedade intensidade do mapa de calor",
    "Heatmap radius": "Raio do mapa de calor",
    "Help": "Axuda",
    "Hide controls": "Agochar os controis",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Canto se simplificará a polilínea en cada nivel de achegamento (máis = mellor comportamento e aparencia máis feble, menos = máis preciso)",
    "If false, the polygon will act as a part of the underlying map.": "Se é falso, o polígono actuará coma un anaco do mapa subxacente.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altura persoalizada (en píxeles): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con alto e ancho (en px) persoalizado: {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imaxe con anchura persoalizada (en píxeles): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Imaxe: {{http://image.url.com}}",
    "Import": "Importar",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar nunha nova capa",
    "Imports all umap data, including layers and settings.": "Importar tódolos datos do umap, incluíndo capas e axustes.",
    "Include full screen link?": "Engadir a ligazón de pantalla completa?",
    "Interaction options": "Opcións de interacción",
    "Invalid umap data": "Dato umap non válido",
    "Invalid umap data in {filename}": "Dato umap non válido en {filename}",
    "Keep current visible layers": "Gardar capas visíbeis actuais",
    "Latitude": "Latitude",
    "Layer": "Capa",
    "Layer properties": "Propiedades da capa",
    "Licence": "Licenza",
    "Limit bounds": "Limitar os límites",
    "Link to…": "Ligazón cara...",
    "Link with text: [[http://example.com|text of the link]]": "Ligazón con texto: [[http://example.com|text of the link]]",
    "Long credits": "Cretos longos",
    "Longitude": "Lonxitude",
    "Make main shape": "Facer a forma principal",
    "Manage layers": "Xestionar capas",
    "Map background credits": "Cretos do mapa de fondo",
    "Map has been attached to your account": "O mapa adxuntouse á súa conta",
    "Map has been saved!": "Gardouse o mapa!",
    "Map user content has been published under licence": "O contido do mapa do usuario foi publicado baixo a licenza",
    "Map's editors": "Editores do mapa",
    "Map's owner": "Dono do mapa",
    "Merge lines": "Combinar liñas",
    "More controls": "Máis controis",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Ten que ser un valor CSS válido (por ex.: DarkBlue ou #123456)",
    "No licence has been set": "Ningunha licenza foi estabelecida",
    "No results": "Sen resultados",
    "Only visible features will be downloaded.": "Só os elementos visíbeis baixaranse.",
    "Open download panel": "Abrir a lapela de descarga",
    "Open link in…": "Abrir ligazón en...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abre a extensión deste mapa nun editor de mapas para fornecer datos máis precisos ó OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedade de intensidade opcional para o mapa de calor",
    "Optional. Same as color if not set.": "Opcional. A mesma cor se non se estabelece.",
    "Override clustering radius (default 80)": "Sobrescribir o raio de agrupamento (predeterminado 80)",
    "Override heatmap radius (default 25)": "Sobreescribir o raio do mapa de calor (predeterminado 25)",
    "Please be sure the licence is compliant with your use.": "Coide de que a licenza sexa compatíbel co emprego que lle vai a dár.",
    "Please choose a format": "Escolle un formato",
    "Please enter the name of the property": "Insira o nome da propiedade",
    "Please enter the new name of this property": "Insira o novo nome desta propiedade",
    "Problem in the response": "Problema na resposta",
    "Problem in the response format": "Problema co formato de resposta",
    "Properties imported:": "Propiedades importadas:",
    "Provide an URL here": "Forneza unha URL aquí",
    "Proxy request": "Petición a proxy",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Eliminar a forma do 'multi'",
    "Rename this property on all the features": "Renomear esta propiedade en tódolos elementos",
    "Replace layer content": "Substitúe o contido da capa",
    "Restore this version": "Restabelecer esta versión",
    "Save": "Gardar",
    "Save anyway": "Gardar de todos xeitos",
    "Save current edits": "Gardar as edicións actuais",
    "Save this center and zoom": "Gardar este centrado e achegamento",
    "Save this location as new feature": "Gardar esta ubicación coma novo elemento",
    "Search a place name": "Procurar o nome dun lugar",
    "Search location": "Procurar localización",
    "See all": "Ollar todo",
    "See data layers": "Ollar capas de datos",
    "See full screen": "Ollar pantalla completa",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Axústeo a falso para agochar esta capa da presentación ('slideshow'), o navegador de datos, a navegación da xanela emerxente...",
    "Shape properties": "Propiedades da forma",
    "Short URL": "URL curta",
    "Short credits": "Cretos curtos",
    "Show/hide layer": "Amosar/agochar capa",
    "Simple link: [[http://example.com]]": "Ligazón sinxela: [[http://example.com]]",
    "Slideshow": "Presentación",
    "Sort key": "Orde da clave",
    "Split line": "Liña de división",
    "Start a hole here": "Comezar un burato aquí",
    "Start editing": "Comezar a editar",
    "Start slideshow": "Comezar presentación",
    "Stop editing": "Deter a edición",
    "Stop slideshow": "Deter a presentación",
    "Supported scheme": "Esquema suportado",
    "Supported variables that will be dynamically replaced": "Variábeis suportadas que serán substituídas de xeito dinámico",
    "TMS format": "formato TMS",
    "Text color for the cluster label": "Cor do texto para a etiqueta clúster",
    "Text formatting": "Formato do texto",
    "To use if remote server doesn't allow cross domain (slower)": "Para empregar se o servidor remoto non permite dominios cruzados (máis amodo)",
    "To zoom": "Para o achegamento",
    "Transfer shape to edited feature": "Transferir a forma ó elemento editada",
    "Transform to lines": "Transformar a liñas",
    "Transform to polygon": "Transformar a polígono",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "Non se pode detectar o formato de ficheiro {filename}",
    "Untitled layer": "Capa sen título",
    "Untitled map": "Mapa sen título",
    "Update permissions": "Actualizar permisos",
    "Update permissions and editors": "Actualizar permisos e editores",
    "Url": "Url",
    "Use current bounds": "Empregar os límites actuais",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Empregar marcaxes de posición con propiedades do elemento entre paréntesis, exemplo &#123;name&#125;, serán substituídos de xeito dinámico polos valores correspondentes.",
    "User content credits": "Cretos do contido do usuario",
    "User interface options": "Opcións da interface de usuario",
    "Versions": "Versións",
    "View Fullscreen": "Ollar en pantalla completa",
    "Where do we go from here?": "Onde vamos a partir daquí?",
    "Whether to display or not polygons paths.": "Se desexas amosar ou non as rutas dos polígonos.",
    "Whether to fill polygons with color.": "Se desexas rechear os polígonos con cor.",
    "Who can edit": "Quen pode editar",
    "Who can view": "Quen pode ollar",
    "Will be displayed in the bottom right corner of the map": "Amosarase na esquina inferior esquerda do mapa",
    "Will be visible in the caption of the map": "Será visíbel no subtítulo do mapa",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Vaites! Alguén semella que editou os datos. Podes gardar de todos xeitos, pero isto vai eliminar as mudanzas feitas por outros.",
    "Zoom in": "Achegar",
    "Zoom level for automatic zooms": "Nivel de achegamento para achegamentos automáticos",
    "Zoom out": "Afastar",
    "Zoom to layer extent": "Achegar ó nivel da capa",
    "Zoom to the next": "Achegar ó seguinte",
    "Zoom to the previous": "Achegar ó anterior",
    "Zoom to this feature": "Achegar a este elemento",
    "Zoom to this place": "Achegar a este lugar",
    "attribution": "atribución",
    "by": "por",
    "display name": "amosar o nome",
    "height": "altura",
    "licence": "licenza",
    "max East": "máximo Leste",
    "max North": "máximo Norte",
    "max South": "máximo Sul",
    "max West": "máximo Oeste",
    "max zoom": "achegamento máximo",
    "min zoom": "achegamento mínimo",
    "next": "seguinte",
    "previous": "anterior",
    "width": "ancho",
    "{count} errors during import: {message}": "{count} erros durante a importación: {message}",
    "Measure distances": "Medir distancias",
    "NM": "NM",
    "kilometers": "quilómetros",
    "km": "km",
    "mi": "mi",
    "miles": "millas",
    "nautical miles": "millas náuticas",
    "1 day": "1 día",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "Cache proxied request": "Solicitude de proxy da caché",
    "No cache": "Sen caché",
    "Popup": "Xanela emerxente",
    "Popup (large)": "Xanela emerxente (grande)",
    "Popup content style": "Estilo do contido da xanela emerxente",
    "Popup shape": "Forma da xanela emerxente",
    "Skipping unknown geometry.type: {type}": "Brincando tipo descoñecido geometry.type: {type}",
    "Optional.": "Opcional.",
    "Paste your data here": "Pega os teus datos aquí",
    "Please save the map first": "Por favor garda o mapa primeiro",
    "Feature identifier key": "Feature identifier key",
    "Open current feature on load": "Open current feature on load",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("gl", locale)
L.setLocale("gl")
