<div class="wrapper">
  <div class="row">
    {% if messages %}
      <ul class="messages">
        {% for message in messages %}
          <li {% if message.tags %}class="{{ message.tags }}"{% endif %}>{{ message }}</li>
        {% endfor %}
      </ul>
    {% endif %}
  </div>
</div>
