const locale = {
    "Allow scroll wheel zoom?": "آیا به زوم چرخ اسکرول اجازه داده شود؟",
    "Automatic": "خودکار",
    "Ball": "توپ",
    "Cancel": "انصراف",
    "Caption": "زیرنویس",
    "Choose the data format": "قالب داده را انتخاب کنید",
    "Choose the layer of the feature": "لایه ویژگی را انتخاب کنید",
    "Circle": "دایره",
    "Clustered": "خوشه ای",
    "Data browser": "مرورگر داده",
    "Default": "پیش فرض",
    "Default zoom level": "سطح بزرگنمایی پیش فرض",
    "Default: name": "پیش فرض: نام",
    "Display label": "برچسب نمایش",
    "Display the control to open OpenStreetMap editor": "کنترل را برای باز کردن ویرایشگر اوپن‌استریت‌مپ نمایش دهید",
    "Display the data layers control": "نمایش کنترل لایه های داده",
    "Display the embed control": "نمایش کنترل جاسازی",
    "Display the fullscreen control": "نمایش کنترل تمام صفحه",
    "Display the locate control": "کنترل مکان یابی را نمایش دهید",
    "Display the measure control": "نمایش کنترل اندازه گیری",
    "Display the search control": "نمایش کنترل جستجو",
    "Display the tile layers control": "نمایش لایه های کنترل کاشی",
    "Display the zoom control": "نمایش کنترل زوم",
    "Do you want to display a caption bar?": "آیا می خواهید نوار زیرنویس نشان داده شود؟",
    "Do you want to display a minimap?": "آیا می خواهید حداقل نقشه را نمایش دهید؟",
    "Do you want to display a panel on load?": "آیا می خواهید یک صفحه را در حالت بارگذاری نمایش دهید؟",
    "Do you want to display popup footer?": "آیا می خواهید پاورقی نمایش داده شود؟",
    "Do you want to display the scale control?": "آیا می خواهید کنترل مقیاس را نمایش دهید؟",
    "Do you want to display the «more» control?": "آیا می خواهید کنترل «بیشتر» را نمایش دهید؟",
    "Drop": "رها کردن",
    "GeoRSS (only link)": "GeoRSS (فقط لینک)",
    "GeoRSS (title + image)": "GeoRSS (عنوان + تصویر)",
    "Heatmap": "نقشه حرارت و گرما",
    "Icon shape": "شکل نماد",
    "Icon symbol": "آیکون نماد",
    "Inherit": "ارث بری",
    "Label direction": "جهت برچسب",
    "Label key": "کلید برچسب",
    "Labels are clickable": "برچسب ها قابل کلیک هستند",
    "None": "هیچکدام",
    "On the bottom": "در انتها",
    "On the left": "در سمت چپ",
    "On the right": "در سمت راست",
    "On the top": "در بالا",
    "Popup content template": "قالب محتوای بازشو",
    "Side panel": "پنل کناری",
    "Simplify": "ساده کنید",
    "Table": "جدول",
    "always": "همیشه",
    "clear": "روشن/شفاف",
    "collapsed": "فرو ریخت",
    "color": "رنگ",
    "dash array": "آرایه خط تیره",
    "define": "تعريف كردن",
    "description": "شرح",
    "expanded": "منبسط",
    "fill": "پر کردن",
    "fill color": "پر کردن رنگ",
    "fill opacity": "تاری/کِدِری را پر کنید",
    "hidden": "پنهان",
    "iframe": "iframe",
    "inherit": "به ارث می برند",
    "name": "نام",
    "never": "هرگز",
    "new window": "پنجره جدید",
    "no": "نه",
    "on hover": "روی شناور",
    "opacity": "تاری/کِدِری",
    "parent window": "پنجره والدین",
    "stroke": "سکته",
    "weight": "وزن/سنگینی",
    "yes": "بله",
    "{delay} seconds": "{تاخیر} ثانیه",
    "# one hash for main heading": "# یک هشتگ برای عنوان اصلی",
    "## two hashes for second heading": "## دو هشتگ برای عنوان دوم",
    "### three hashes for third heading": "### سه هشتگ برای عنوان سوم",
    "**double star for bold**": "** دو ستاره برای پررنگ **",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "لیستی از اعداد جدا شده با کاما که الگوی خط تیره را مشخص می کند. مثال: \"5 ، 10 ، 15\".",
    "About": "درباره",
    "Action not allowed :(": "اقدام مجاز نیست :(",
    "Activate slideshow mode": "حالت نمایش اسلاید را فعال کنید",
    "Add a layer": "یک لایه اضافه کنید",
    "Add a line to the current multi": "یک خط به مولتی فعلی اضافه کنید",
    "Add a new property": "یک ویژگی جدید اضافه کنید",
    "Add a polygon to the current multi": "چند ضلعی را به مولتی فعلی اضافه کنید",
    "Advanced actions": "اقدامات پیشرفته",
    "Advanced properties": "خواص پیشرفته",
    "All properties are imported.": "همه املاک وارد شده است",
    "Allow interactions": "اجازه تعامل دهید",
    "An error occured": "خطایی رخ داد",
    "Are you sure you want to cancel your changes?": "آیا مطمئن هستید که می خواهید تغییرات خود را لغو کنید؟",
    "Are you sure you want to clone this map and all its datalayers?": "آیا مطمئن هستید که می خواهید این نقشه و همه فهرست داده های آن را شبیه سازی کنید؟",
    "Are you sure you want to delete the feature?": "آیا مطمئن هستید که می خواهید ویژگی را حذف کنید؟",
    "Are you sure you want to delete this layer?": "آیا مطمئن هستید که می خواهید این لایه را حذف کنید؟",
    "Are you sure you want to delete this map?": "آیا مطمئن هستید که می خواهید این نقشه را حذف کنید؟",
    "Are you sure you want to delete this property on all the features?": "آیا مطمئن هستید که می خواهید این ویژگی را در همه ویژگی ها حذف کنید؟",
    "Are you sure you want to restore this version?": "آیا مطمئن هستید که می خواهید این نسخه را بازیابی کنید؟",
    "Attach the map to my account": "نقشه را به حساب من وصل کنید",
    "Auto": "خودکار",
    "Autostart when map is loaded": "هنگام بارگیری، نقشه خودکار را راه اندازی کنید",
    "Bring feature to center": "ویژگی را به مرکز بیاورید",
    "Browse data": "مرور داده ها",
    "Cancel edits": "لغو ویرایش ها",
    "Center map on your location": "نقشه مرکز بر روی موقعیت مکانی شما",
    "Change map background": "تغییر پس زمینه نقشه",
    "Change tilelayers": "کاشی های کاری را تغییر دهید",
    "Choose a preset": "از پیش تعیین شده را انتخاب کنید",
    "Choose the format of the data to import": "قالب داده را برای وارد کردن انتخاب کنید",
    "Choose the layer to import in": "لایه ای را برای وارد کردن انتخاب کنید",
    "Click last point to finish shape": "برای پایان دادن به شکل روی آخرین نقطه کلیک کنید",
    "Click to add a marker": "برای افزودن نشانگر کلیک کنید",
    "Click to continue drawing": "برای ادامه ترسیم کلیک کنید",
    "Click to edit": "برای ویرایش کلیک کنید",
    "Click to start drawing a line": "برای شروع رسم خط کلیک کنید",
    "Click to start drawing a polygon": "برای شروع ترسیم چند ضلعی کلیک کنید",
    "Clone": "شبیه سازی / کلون",
    "Clone of {name}": "شبیه سازی {name}",
    "Clone this feature": "این ویژگی را شبیه سازی کنید",
    "Clone this map": "شبیه سازی این نقشه",
    "Close": "بستن",
    "Clustering radius": "شعاع خوشه بندی",
    "Comma separated list of properties to use when filtering features": "لیستی از خواص جدا شده با کاما برای فیلتر کردن ویژگی ها",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "مقادیر جدا شده با کاما، برگه یا نیمه کولون. SRS WGS84 ضمنی است. فقط هندسه نقطه وارد می شود. واردات به سربرگهای ستون برای ذکر هرگونه عبارت «lat» و «lon» در ابتدای سرصفحه، بدون حساس به حروف، نگاه می کند. همه ستون های دیگر به عنوان ویژگی وارد می شوند.",
    "Continue line": "ادامه خط",
    "Continue line (Ctrl+Click)": "ادامه خط (Ctrl+Click)",
    "Coordinates": "مختصات",
    "Credits": "اعتبار",
    "Current view instead of default map view?": "نمای فعلی به جای نمای نقشه پیش فرض؟",
    "Custom background": "پس زمینه سفارشی",
    "Data is browsable": "داده ها قابل مرور هستند",
    "Default interaction options": "گزینه های پیش فرض تعامل",
    "Default properties": "خواص پیش فرض",
    "Default shape properties": "ویژگی های شکل پیش فرض",
    "Define link to open in a new window on polygon click.": "پیوندی را باز کنید که در یک پنجره جدید با کلیک چند ضلعی باز می شود.",
    "Delay between two transitions when in play mode": "تأخیر بین دو انتقال در حالت پخش",
    "Delete": "حذف",
    "Delete all layers": "حذف همه لایه ها",
    "Delete layer": "حذف لایه",
    "Delete this feature": "این ویژگی را حذف کنید",
    "Delete this property on all the features": "این ویژگی را در همه ویژگی ها حذف کنید",
    "Delete this shape": "این شکل را حذف کنید",
    "Delete this vertex (Alt+Click)": "حذف این راس (Alt+Click)",
    "Directions from here": "مسیرها از اینجا",
    "Display measure": "اندازه نمایش",
    "Display on load": "نمایش روی بارگذاری",
    "Download": "دانلود",
    "Download data": "دانلود داده",
    "Drag to reorder": "برای مرتب سازی دیگر بکشید",
    "Draw a line": "یک خط بکش",
    "Draw a marker": "یک نشانگر بکشید",
    "Draw a polygon": "چند ضلعی بکشید",
    "Draw a polyline": "چند خطی بکشید",
    "Dynamic": "پویا",
    "Dynamic properties": "خواص پویا",
    "Edit": "ویرایش",
    "Edit feature's layer": "لایه ویژگی را ویرایش کنید",
    "Edit map properties": "ویرایش ویژگی های نقشه",
    "Edit map settings": "ویرایش تنظیمات نقشه",
    "Edit properties in a table": "ویژگی ها را در یک جدول ویرایش کنید",
    "Edit this feature": "این ویژگی را ویرایش کنید",
    "Embed and share this map": "این نقشه را جاسازی کرده و به اشتراک بگذارید",
    "Embed the map": "نقشه را جاسازی کنید",
    "Empty": "خالی",
    "Error in the tilelayer URL": "خطا در آدرس اینترنتی لایه کاشی",
    "Error while fetching {url}": "خطا هنگام واکشی {آدرس اینترنتی}",
    "Exit Fullscreen": "خروج از تمام صفحه",
    "Extract shape to separate feature": "استخراج شکل به ویژگی جدا",
    "Fetch data each time map view changes.": "هر بار که نمای نقشه تغییر می کند، داده ها را واکشی کنید.",
    "Filter keys": "کلیدهای فیلتر",
    "Format": "قالب",
    "From zoom": "از زوم",
    "Go to «{feature}»": "به «{ویژگی}» بروید",
    "Heatmap intensity property": "ویژگی شدت حرارت",
    "Heatmap radius": "شعاع نقشه حرارتی",
    "Help": "راهنما",
    "Hide controls": "مخفی کردن کنترل ها",
    "Home": "خانه",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "چقدر می توان چند خطی را در هر سطح بزرگنمایی ساده کرد (بیشتر = عملکرد بهتر و ظاهر صاف، کمتر = دقیق تر)",
    "If false, the polygon will act as a part of the underlying map.": "اگر نادرست باشد، چند ضلعی به عنوان بخشی از نقشه زیرین عمل می کند.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe با ارتفاع سفارشی (بر حسب px):{{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "iframe با ارتفاع و عرض سفارشی (بر حسب px):{{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "تصویر با عرض سفارشی (بر حسب px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "تصویر: {{http://image.url.com}}",
    "Import": "وارد كردن",
    "Import data": "وارد كردن داده",
    "Import in a new layer": "وارد کردن در یک لایه جدید",
    "Imports all umap data, including layers and settings.": "همه داده های umap ، از جمله لایه ها و تنظیمات را وارد می کند.",
    "Include full screen link?": "پیوند تمام صفحه را شامل می شود؟",
    "Interaction options": "گزینه های تعامل",
    "Invalid umap data": "داده های umap نامعتبر است",
    "Invalid umap data in {filename}": "داده های umap نامعتبر در {نام فایل}",
    "Keep current visible layers": "لایه های قابل مشاهده فعلی را حفظ کنید",
    "Latitude": "عرض جغرافیایی",
    "Layer": "لایه",
    "Layer properties": "خواص لایه",
    "Licence": "مجوز",
    "Limit bounds": "محدودیت ها را محدود کنید",
    "Link to…": "پیوند به…",
    "Link with text: [[http://example.com|text of the link]]": "پیوند با متن: [[http://example.com|text of the link]]",
    "Long credits": "اعتبارات طولانی",
    "Longitude": "عرض جغرافیایی",
    "Make main shape": "شکل اصلی را ایجاد کنید",
    "Manage layers": "لایه ها را مدیریت کنید",
    "Map background credits": "اعتبار پس زمینه نقشه",
    "Map has been attached to your account": "نقشه به حساب شما پیوست شده است",
    "Map has been saved!": "نقشه ذخیره شد!",
    "Map user content has been published under licence": "محتوای کاربر نقشه، تحت مجوز منتشر شده است",
    "Map's editors": "ویرایشگران نقشه",
    "Map's owner": "مالک نقشه",
    "Merge lines": "ادغام خطوط",
    "More controls": "کنترل های بیشتر",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "باید یک مقدار CSS معتبر باشد (به عنوان مثال: DarkBlue یا #123456)",
    "No licence has been set": "هیچ مجوزی تنظیم نشده است",
    "No results": "بدون نتیجه",
    "Only visible features will be downloaded.": "فقط ویژگی های قابل مشاهده بارگیری می شوند.",
    "Open download panel": "باز کردن پنل بارگیری",
    "Open link in…": "باز کردن پیوند در…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "این محدوده نقشه را در ویرایشگر نقشه باز کنید تا داده های دقیق تری در اوپن‌استریت‌مپ ارائه شود",
    "Optional intensity property for heatmap": "ویژگی های اختیاری شدت برای نقشه حرارتی",
    "Optional. Same as color if not set.": "اختیاری. اگر تنظیم نشده باشد همان رنگ است.",
    "Override clustering radius (default 80)": "نادیده گرفتن شعاع خوشه بندی (پیش فرض 80)",
    "Override heatmap radius (default 25)": "لغو شعاع نقشه حرارتی (پیش فرض 25)",
    "Please be sure the licence is compliant with your use.": "لطفاً مطمئن شوید مجوز با استفاده شما مطابقت دارد.",
    "Please choose a format": "لطفاً یک قالب را انتخاب کنید",
    "Please enter the name of the property": "لطفاً نام ملک را وارد کنید",
    "Please enter the new name of this property": "لطفا نام جدید این ملک را وارد کنید",
    "Problem in the response": "مشکل در پاسخگویی",
    "Problem in the response format": "مشکل در قالب پاسخگویی",
    "Properties imported:": "خواص وارد شده:",
    "Provide an URL here": "در اینجا آدرس اینترنتی ارائه دهید",
    "Proxy request": "درخواست پروکسی",
    "Remote data": "داده های از راه دور",
    "Remove shape from the multi": "حذف شکل از مولتی",
    "Rename this property on all the features": "نام این ویژگی را در همه ویژگی ها تغییر دهید",
    "Replace layer content": "جایگزینی محتوای لایه",
    "Restore this version": "این نسخه را بازیابی کنید",
    "Save": "ذخیره",
    "Save anyway": "به هر حال ذخیره کنید",
    "Save current edits": "ویرایش های فعلی را ذخیره کنید",
    "Save this center and zoom": "این مرکز را ذخیره کرده و بزرگنمایی کنید",
    "Save this location as new feature": "این مکان را به عنوان ویژگی جدید ذخیره کنید",
    "Search a place name": "نام مکان را جستجو کنید",
    "Search location": "مکان را جستجو کنید",
    "See all": "همه را ببین",
    "See data layers": "لایه های داده را مشاهده کنید",
    "See full screen": "تمام صفحه را مشاهده کنید",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "آن را روی غلط/false تنظیم کنید تا این لایه از نمایش اسلاید، مرورگر داده، ناوبری بازشو پنهان شود…",
    "Shape properties": "ویژگی های شکل",
    "Short URL": "آدرس اینترنتی کوتاه",
    "Short credits": "اعتبار کوتاه مدت",
    "Show/hide layer": "نمایش/مخفی کردن لایه",
    "Simple link: [[http://example.com]]": "پیوند ساده: [[http://example.com]]",
    "Slideshow": "نمایش اسلاید",
    "Sort key": "کلید مرتب سازی",
    "Split line": "خط تقسیم",
    "Start a hole here": "از اینجا یک حفره شروع کنید",
    "Start editing": "ویرایش را شروع کنید",
    "Start slideshow": "شروع نمایش اسلاید",
    "Stop editing": "ویرایش را متوقف کنید",
    "Stop slideshow": "نمایش اسلاید را متوقف کنید",
    "Supported scheme": "طرح پشتیبانی شده",
    "Supported variables that will be dynamically replaced": "متغیرهای پشتیبانی شده که به صورت پویا جایگزین می شوند",
    "TMS format": "قالب TMS",
    "Text color for the cluster label": "رنگ متن برای برچسب خوشه",
    "Text formatting": "قالب بندی متن",
    "To use if remote server doesn't allow cross domain (slower)": "برای استفاده در صورت عدم دسترسی سرور از راه دور به دامنه (کندتر)",
    "To zoom": "زوم",
    "Transfer shape to edited feature": "انتقال شکل به ویژگی ویرایش شده",
    "Transform to lines": "تبدیل به خطوط",
    "Transform to polygon": "تبدیل به چند ضلعی",
    "Type of layer": "نوع لایه",
    "Unable to detect format of file {filename}": "تشخیص قالب فایل {نام فایل} امکان پذیر نیست",
    "Untitled layer": "لایه بدون عنوان",
    "Untitled map": "نقشه بدون عنوان",
    "Update permissions": "مجوزها را به روز کنید",
    "Update permissions and editors": "مجوزها و ویرایشگران را به روز کنید",
    "Url": "آدرس اینترنتی",
    "Use current bounds": "از مرزهای فعلی استفاده کنید",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "از متغیرهایی با ویژگی های ویژگی بین براکت ها استفاده کنید ، به عنوان مثال. &#123;name&#125;، آنها به طور پویا با مقادیر مربوطه جایگزین می شوند.",
    "User content credits": "اعتبار محتوای کاربر",
    "User interface options": "گزینه های رابط کاربر",
    "Versions": "نسخه ها",
    "View Fullscreen": "مشاهده تمام صفحه",
    "Where do we go from here?": "از اینجا به کجا می رویم؟",
    "Whether to display or not polygons paths.": "اینکه آیا مسیرهای چند ضلعی نمایش داده شود یا خیر.",
    "Whether to fill polygons with color.": "این که چند ضلعی ها را با رنگ پر کنیم یا خیر.",
    "Who can edit": "چه کسی می تواند ویرایش کند",
    "Who can view": "چه کسی می تواند مشاهده کند",
    "Will be displayed in the bottom right corner of the map": "در گوشه سمت راست پایین نقشه نمایش داده می شود",
    "Will be visible in the caption of the map": "در زیرنویس نقشه قابل مشاهده خواهد بود",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "وای! به نظر می رسد شخص دیگری داده ها را ویرایش کرده است. در هر صورت می توانید ذخیره کنید، اما با این کار تغییرات ایجاد شده توسط دیگران پاک می شود.",
    "Zoom in": "بزرگنمایی",
    "Zoom level for automatic zooms": "سطح زوم برای بزرگنمایی خودکار",
    "Zoom out": "کوچک نمایی",
    "Zoom to layer extent": "تا اندازه لایه بزرگنمایی کنید",
    "Zoom to the next": "روی بعدی زوم کنید",
    "Zoom to the previous": "روی قبلی بزرگنمایی کنید",
    "Zoom to this feature": "روی این ویژگی بزرگنمایی کنید",
    "Zoom to this place": "روی این مکان بزرگنمایی کنید",
    "attribution": "انتساب",
    "by": "بوسیله",
    "display name": "نام نمایشی",
    "height": "ارتفاع",
    "licence": "مجوز",
    "max East": "حداکثر شرقی",
    "max North": "حداکثر شمالی",
    "max South": "حداکثر جنوبی",
    "max West": "حداکثر غربی",
    "max zoom": "حداکثر بزرگنمایی",
    "min zoom": "حداقل بزرگنمایی",
    "next": "بعد",
    "previous": "قبل",
    "width": "عرض",
    "{count} errors during import: {message}": "{شمردن} خطاها هنگام وارد کردن: {پیام}",
    "Measure distances": "فاصله ها را اندازه گیری کنید",
    "NM": "NM",
    "kilometers": "کیلومتر",
    "km": "کیلومتر",
    "mi": "مایل",
    "miles": "مایل ها",
    "nautical miles": "مایل دریایی",
    "1 day": "1 روز",
    "1 hour": "1 ساعت",
    "5 min": "5 دقیقه",
    "Cache proxied request": "درخواست پراکسی حافظه پنهان",
    "No cache": "بدون حافظه پنهان",
    "Popup": "پنجره بازشو",
    "Popup (large)": "پنجره بازشو (بزرگ)",
    "Popup content style": "سبک محتوای بازشو",
    "Popup shape": "شکل پنجره بازشو",
    "Skipping unknown geometry.type: {type}": "رد شدن از geometry.type ناشناخته: {نوع}",
    "Optional.": "اختیاری.",
    "Paste your data here": "اطلاعات و داده های خود را اینجا بچسبانید",
    "Please save the map first": "لطفاً ابتدا نقشه را ذخیره کنید",
    "Feature identifier key": "کلید شناسایی ویژگی",
    "Open current feature on load": "باز کردن ویژگی فعلی هنگام بارگیری",
    "Permalink": "پیوند ثابت",
    "The name of the property to use as feature unique identifier.": "نام ویژگی برای استفاده به عنوان شناسه منحصر به فرد ویژگی.",
    "Do you want to display caption menus?": "آیا می‌خواهید منوهای زیرنویس نشان داده شود؟",
    "Example: key1,key2,key3": "به عنوان مثال: کلید 1، کلید 2، کلید 3",
    "Invalid latitude or longitude": "طول یا عرض جغرافیایی نامعتبر است",
    "Invalide property name: {name}": "نام دارایی معتبر نیست: {name}",
    "Permanent credits": "اعتبارات دائمی",
    "Permanent credits background": "پیشینه اعتبارات دائمی",
    "Select data": "داده‌ها را انتخاب کنید",
    "Will be permanently visible in the bottom left corner of the map": "برای همیشه در گوشه سمت چپ پایین نقشه قابل مشاهده خواهد بود",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("fa_IR", locale)
L.setLocale("fa_IR")
