/* Variables and Mixins */
/* Generic L.Toolbar */
.leaflet-toolbar-0 {
  list-style: none;
  padding-left: 0;
  box-shadow: 0 1px 5px rgba(0, 0, 0, 0.65);
}
.leaflet-toolbar-0 > li {
  position: relative;
}
.leaflet-toolbar-0 > li > .leaflet-toolbar-icon {
  display: block;
  width: 26px;
  height: 26px;
  line-height: 26px;
  margin-right: 0;
  padding-right: 0;
  border-right: 0;
  text-align: center;
  text-decoration: none;
  background-color: #ffffff;
}
.leaflet-toolbar-0 > li > .leaflet-toolbar-icon:hover {
  background-color: #f4f4f4;
}
.leaflet-toolbar-0 .leaflet-toolbar-1 {
  display: none;
  list-style: none;
}
.leaflet-toolbar-tip-container {
  margin: 0 auto;
  height: 12px;
  position: relative;
  overflow: hidden;
}
.leaflet-toolbar-tip {
  width: 12px;
  height: 12px;
  margin: -6px auto 0;
  background-color: #ffffff;
  box-shadow: 0 1px 5px rgba(0, 0, 0, 0.65);
  -webkit-transform: rotate(45deg);
      -ms-transform: rotate(45deg);
          transform: rotate(45deg);
}
/* L.Toolbar.Control */
.leaflet-control-toolbar {
  /* Secondary Toolbar */
}
.leaflet-control-toolbar > li > .leaflet-toolbar-icon {
  border-bottom: 1px solid #ccc;
}
.leaflet-control-toolbar > li:first-child > .leaflet-toolbar-icon {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}
.leaflet-control-toolbar > li:last-child > .leaflet-toolbar-icon {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
  border-bottom-width: 0;
}
.leaflet-control-toolbar .leaflet-toolbar-1 {
  margin: 0;
  padding: 0;
  position: absolute;
  left: 26px;
  /* leaflet-draw-toolbar.left + leaflet-draw-toolbar.width */
  top: 0;
  white-space: nowrap;
  height: 26px;
}
.leaflet-control-toolbar .leaflet-toolbar-1 > li {
  display: inline-block;
}
.leaflet-control-toolbar .leaflet-toolbar-1 > li > .leaflet-toolbar-icon {
  display: block;
  background-color: #919187;
  border-left: 1px solid #aaa;
  color: #fff;
  font: 11px/19px "Helvetica Neue", Arial, Helvetica, sans-serif;
  line-height: 26px;
  text-decoration: none;
  padding-left: 10px;
  padding-right: 10px;
  height: 26px;
}
.leaflet-control-toolbar .leaflet-toolbar-1 > li > .leaflet-toolbar-icon:hover {
  background-color: #a0a098;
}
/* L.Toolbar.Popup */
.leaflet-popup-toolbar {
  position: relative;
}
.leaflet-popup-toolbar > li {
  float: left;
}
.leaflet-popup-toolbar > li:first-child > .leaflet-toolbar-icon {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
.leaflet-popup-toolbar > li:last-child > .leaflet-toolbar-icon {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  border-bottom-width: 0;
}
.leaflet-popup-toolbar .leaflet-toolbar-1 {
  position: absolute;
  top: 26px;
  left: 0;
  padding-left: 0;
}
.leaflet-popup-toolbar .leaflet-toolbar-1 > li > .leaflet-toolbar-icon {
  position: relative;
  float: left;
  width: 26px;
  height: 26px;
}
