const locale = {
    "Allow scroll wheel zoom?": "Zoomen met scrollwieltje toestaan?",
    "Automatic": "Automatisch",
    "Ball": "Kopspeld",
    "Cancel": "Annuleren",
    "Caption": "Hoofding",
    "Choose the data format": "Gegevensformaat selecteren",
    "Choose the layer of the feature": "Kies de laag van het object",
    "Circle": "Cirkel",
    "Clustered": "Bij elkaar gevoegd",
    "Data browser": "Data browser",
    "Default": "Standaard",
    "Default zoom level": "Standaard schaalniveau",
    "Default: name": "Standaard: naam",
    "Display label": "Toon het label",
    "Display the control to open OpenStreetMap editor": "Toon OpenStreetMap editor knop",
    "Display the data layers control": "Toon data lagen knop",
    "Display the embed control": "Toon inbedden knop",
    "Display the fullscreen control": "Toon volledig scherm knop",
    "Display the locate control": "Toon lokaliseer mij knop",
    "Display the measure control": "Toon meetinstrument knop",
    "Display the search control": "Toon zoeken knop",
    "Display the tile layers control": "Toon achtergrondlagen knop",
    "Display the zoom control": "Toon zoom knop",
    "Do you want to display a caption bar?": "Wil je een hoofding tonen?",
    "Do you want to display a minimap?": "Wil je een minikaartje tonen?",
    "Do you want to display a panel on load?": "Wil je een zijpaneel tonen als de kaart geladen wordt?",
    "Do you want to display popup footer?": "Wil je een popup-footer tonen?",
    "Do you want to display the scale control?": "Wil je het schaal-besturingselement tonen?",
    "Do you want to display the «more» control?": "Wil je de knop «meer» laten zien?",
    "Drop": "Druppel",
    "GeoRSS (only link)": "GeoRSS (enkel link)",
    "GeoRSS (title + image)": "GeoRSS (titel + afbeelding)",
    "Heatmap": "Hittekaart",
    "Icon shape": "Vorm van het icoon",
    "Icon symbol": "Symbool voor het icoon",
    "Inherit": "Overerving",
    "Label direction": "Richting van het label",
    "Label key": "Attribuut als label",
    "Labels are clickable": "Labels kunnen aangeklikt worden",
    "None": "Geen",
    "On the bottom": "Aan de onderkant",
    "On the left": "Aan de linkerkant",
    "On the right": "Aan de rechterkant",
    "On the top": "Aan de bovenkant",
    "Popup content template": "Template voor de popup",
    "Side panel": "Zijpaneel",
    "Simplify": "Vereenvoudig",
    "Table": "Tabel",
    "always": "altijd",
    "clear": "wis",
    "collapsed": "dichtgeklapt",
    "color": "kleur",
    "dash array": "soort stippellijn",
    "define": "definieer",
    "description": "beschrijving",
    "expanded": "opengeklapt",
    "fill": "opvullen",
    "fill color": "opvulkleur",
    "fill opacity": "(on)doorzichtigheid van inkleuring",
    "hidden": "verborgen",
    "iframe": "iframe",
    "inherit": "overerven",
    "name": "naam",
    "never": "nooit",
    "new window": "nieuw venster",
    "no": "neen",
    "on hover": "als de muis erover gaat",
    "opacity": "ondoorzichtigheid",
    "parent window": "bovenliggend venster",
    "stroke": "omlijnde vlakken",
    "weight": "lijndikte",
    "yes": "ja",
    "{delay} seconds": "{delay} seconden",
    "# one hash for main heading": "# een hekje voor koptekst 1",
    "## two hashes for second heading": "## twee hekjes voor koptekst 2",
    "### three hashes for third heading": "### drie hekjes voor koptekst 3",
    "**double star for bold**": "** Twee sterretjes voor vet **",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Een lijst getallen, gescheiden door komma's, die het streepjespatroon definiëren. Vb: \"5, 10, 15\".",
    "About": "Over",
    "Action not allowed :(": "Handeling niet toegestaan :(",
    "Activate slideshow mode": "Activeer slidshow modus",
    "Add a layer": "Laag toevoegen",
    "Add a line to the current multi": "Voeg een lijn toe aan de huidige multilijn",
    "Add a new property": "Voeg een nieuwe eigenschap toe",
    "Add a polygon to the current multi": "Voeg een nieuwe polygoon toe aan de huidige multipolygoon",
    "Advanced actions": "Geavanceerde acties",
    "Advanced properties": "Geavanceerde eigenschappen",
    "All properties are imported.": "Alle eigenschappen zijn geïmporteerd",
    "Allow interactions": "Sta interactie toe",
    "An error occured": "Er is een fout opgetreden",
    "Are you sure you want to cancel your changes?": "Weet je zeker dat je je wijzigingen wil annuleren?",
    "Are you sure you want to clone this map and all its datalayers?": "Weet je zeker dat je deze kaart en alle gegevenslagen wil klonen?",
    "Are you sure you want to delete the feature?": "Weet je zeker dat je het object wil verwijderen?",
    "Are you sure you want to delete this layer?": "Weet je zeker dat je deze laag wil verwijderen?",
    "Are you sure you want to delete this map?": "Weet je zeker dat je deze kaart wilt verwijderen?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Weet je zeker dat je deze versie wilt terugzetten?",
    "Attach the map to my account": "Voeg de kaart toe aan mijn account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart als kaart wordt geladen",
    "Bring feature to center": "Object in het midden zetten",
    "Browse data": "Gegevens doorbladeren",
    "Cancel edits": "Bewerkingen annuleren",
    "Center map on your location": "Centreer kaart op je locatie",
    "Change map background": "Verander kaartachtergrond",
    "Change tilelayers": "Andere kaartachtergrond instellen",
    "Choose a preset": "Kies een voorkeuzeinstelling",
    "Choose the format of the data to import": "Kies het formaat van de te importeren gegevens",
    "Choose the layer to import in": "Kies de laag om in te importeren",
    "Click last point to finish shape": "Klik op het laatste punt om de vorm af te maken",
    "Click to add a marker": "Klik om een punt toe te voegen",
    "Click to continue drawing": "Klik om te blijven tekenen",
    "Click to edit": "Klik om te bewerken",
    "Click to start drawing a line": "Klik om een lijn te beginnen tekenen",
    "Click to start drawing a polygon": "Klik om een polygoon te beginnen tekenen",
    "Clone": "Klonen",
    "Clone of {name}": "Kloon van {name}",
    "Clone this feature": "Kloon dit object",
    "Clone this map": "Deze kaart klonen",
    "Close": "Sluit",
    "Clustering radius": "Doorsnede voor clusteren",
    "Comma separated list of properties to use when filtering features": "Komma-gescheiden lijst van eigenschappen die gebruikt worden om te filteren",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma-, tabulator- of puntkomma-gescheiden waardes, SRS WGS84 wordt verondersteld. Enkel puntgeometrieën worden geïmporteerd. Bij het importeren wordt gekeken naar kolomkoppen die met «lat» of «lon» beginnen. Alle andere kolommen worden als eigenschappen geïmporteerd",
    "Continue line": "Ga door met deze lijn",
    "Continue line (Ctrl+Click)": "Ga door met deze lijn (Ctrl+Klik)",
    "Coordinates": "Coördinaten",
    "Credits": "Bronvermelding",
    "Current view instead of default map view?": "Huidig zicht in plaats van standaard kaartaanzicht",
    "Custom background": "Eigen achtergrond",
    "Data is browsable": "Data kan verkend worden",
    "Default interaction options": "Standaard interactie-opties",
    "Default properties": "Standaardeigenschappen",
    "Default shape properties": "Standaard vorm eigenschappen",
    "Define link to open in a new window on polygon click.": "Stel outputlink in om een nieuw venster te openen wanneer polygoon wordt aangeklikt",
    "Delay between two transitions when in play mode": "Pauze tussen twee transities wanneer in afspeel-modus",
    "Delete": "Verwijderen",
    "Delete all layers": "Verwijder alle lagen",
    "Delete layer": "Verwijder laag",
    "Delete this feature": "Dit object verwijderen",
    "Delete this property on all the features": "Verwijder deze eigenschap bij alle objecten",
    "Delete this shape": "Verwijder deze vorm",
    "Delete this vertex (Alt+Click)": "Verwijder dit knooppunt (Alt+Click)",
    "Directions from here": "Wegbeschrijving vanaf hier",
    "Display measure": "Toon meting",
    "Display on load": "Tonen bij laden",
    "Download": "Downloaden",
    "Download data": "Gegevens downloaden",
    "Drag to reorder": "Sleep om de volgorde te wijzigen",
    "Draw a line": "Teken een lijn",
    "Draw a marker": "Teken een punt",
    "Draw a polygon": "Teken een veelhoek",
    "Draw a polyline": "Teken een lijn",
    "Dynamic": "Dynamisch",
    "Dynamic properties": "Dynamische eigenschappen",
    "Edit": "Bewerken",
    "Edit feature's layer": "Objectlaag bewerken",
    "Edit map properties": "Kaarteigenschappen wijzigen",
    "Edit map settings": "Kaartinstellingen aanpassen",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Dit object bewerken",
    "Embed and share this map": "Deze kaart insluiten en delen",
    "Embed the map": "Kaart inbedden",
    "Empty": "Leeg",
    "Error in the tilelayer URL": "Er is een fout opgetreden met de achtergrondtegels",
    "Error while fetching {url}": "Fout bij ophalen {url}",
    "Exit Fullscreen": "Verlaat volledig scherm",
    "Extract shape to separate feature": "Verplaats deze vorm naar een eigen object",
    "Fetch data each time map view changes.": "Haal data op elke keer het kaartaanzicht verandert",
    "Filter keys": "Filter op sleutel",
    "Format": "Formaat",
    "From zoom": "Van zoom",
    "Go to «{feature}»": "Ga naar «{feature}»",
    "Heatmap intensity property": "Eigenschap die intensiteit van de heatmap bepaalt",
    "Heatmap radius": "Doorsnede van de heatmap",
    "Help": "Help",
    "Hide controls": "Verberg besturingselementen",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Graad van vereenvoudiging van een veelhoek, per zoomniveau. (Hogere waarde = betere prestaties, lagere waarde = getrouwere precisie)",
    "If false, the polygon will act as a part of the underlying map.": "Indien onwaar ('false'), dan zal de polygoon deel uitmaken van de onderliggende kaart",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe met gespecifieerde hoogte (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe met gespecifieerde hoogte en breedte (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Beeld met standaardbreedte (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Afbeelding: {{http://image.url.com}}",
    "Import": "Importeer",
    "Import data": "Gegevens importeren",
    "Import in a new layer": "Importeer in een nieuwe laag",
    "Imports all umap data, including layers and settings.": "Importeert alle umap gegevens, inclusief lagen en instellingen",
    "Include full screen link?": "Link voor volledig scherm meegeven?",
    "Interaction options": "Opties voor interactie",
    "Invalid umap data": "Incorrecte umap data",
    "Invalid umap data in {filename}": "Incorrecte umap data in {filename}",
    "Keep current visible layers": "Behoud de lagen die nu zichtbaar zijn",
    "Latitude": "Breedtegraad",
    "Layer": "Laag",
    "Layer properties": "Laag eigenschappen",
    "Licence": "Licentie",
    "Limit bounds": "Gebied begrenzen",
    "Link to…": "Link naar…",
    "Link with text: [[http://example.com|text of the link]]": "Link met tekst: [[http://example.com|text of the link]]",
    "Long credits": "Lange bronvermelding",
    "Longitude": "Lengtegraad",
    "Make main shape": "Maak hoofd-vorm",
    "Manage layers": "Manage layers",
    "Map background credits": "Bronvermelding kaartachtergrond",
    "Map has been attached to your account": "Kaart werd toegevoegd aan je account",
    "Map has been saved!": "De kaart is bewaard!",
    "Map user content has been published under licence": "Inhoud toegevoegd aan deze kaart wordt gepubliceerd onder deze licentievoorwaarden",
    "Map's editors": "Bewerkers van de kaart",
    "Map's owner": "Eigenaar van de kaart",
    "Merge lines": "Lijnen samenvoegen",
    "More controls": "Meer instelknoppen",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Dit moet een geldige CSS-waarde zijn (vb.: DarkBlue of #123456)",
    "No licence has been set": "Er is geen licentie ingesteld",
    "No results": "Geen resultaten",
    "Only visible features will be downloaded.": "Enkel zichtbare objecten zullen worden geëxporteerd",
    "Open download panel": "Open downloads",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open dit gedeelte van de kaart in een editor, zodat u de kaartgegeven in Openstreetmap zelf kan bijwerken.",
    "Optional intensity property for heatmap": "Optionele eigenschap om voor intensiteit van de heatmap te gebruiken",
    "Optional. Same as color if not set.": "Optioneel. Gelijk aan kleur indien niet ingesteld",
    "Override clustering radius (default 80)": "Andere clustering doorsnede gebruiken (standaard80)",
    "Override heatmap radius (default 25)": "Andere heatmap doorsnede gebruiken (standaard 25)",
    "Please be sure the licence is compliant with your use.": "Zorg er aub voor dat je je aan de licentievoorwaarden houdt",
    "Please choose a format": "Kies een formaat",
    "Please enter the name of the property": "Vul de naam in van de eigenschap",
    "Please enter the new name of this property": "Vul de nieuwe naam in van de eigenschap",
    "Problem in the response": "Probleem met het antwoord gekregen van de server",
    "Problem in the response format": "Probleem met het formaat van het antwoord van de server",
    "Properties imported:": "Geïmporteerde eigenschappen:",
    "Provide an URL here": "Geef hier een URL-adres op",
    "Proxy request": "Proxy request",
    "Remote data": "Data van elders",
    "Remove shape from the multi": "Verwijder de vorm uit de multi",
    "Rename this property on all the features": "Wijzig de naam van deze eigenschap over al de objecten",
    "Replace layer content": "Vervang de inhoud van de laag",
    "Restore this version": "Keer terug naar deze versie",
    "Save": "Opslaan",
    "Save anyway": "Sla toch op",
    "Save current edits": "Huidige bewerkingen opslaan",
    "Save this center and zoom": "Bewaar deze positie op de kaart en het zoomniveau",
    "Save this location as new feature": "Sla deze locatie op als nieuw object",
    "Search a place name": "Zoek plaatsnaam",
    "Search location": "Zoek locatie",
    "See all": "Toon alles",
    "See data layers": "Bekijk datalagen",
    "See full screen": "Op volledig scherm weergeven",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Zet op onwaar ('false') om deze laag te verbergen in de slideshow, data verkenner, popup navigatie, ...",
    "Shape properties": "Eigenschappen van de vorm",
    "Short URL": "Korte URL",
    "Short credits": "Korte bronvermelding",
    "Show/hide layer": "Laag tonen/verbergen",
    "Simple link: [[http://example.com]]": "Eenvoudige link: [[http://example.com]]",
    "Slideshow": "Slideshow",
    "Sort key": "Sleutel om op te sorteren",
    "Split line": "Splits de lijn",
    "Start a hole here": "Begin hier een gat",
    "Start editing": "Starten met editeren",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop met editeren",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Toegestaan datamodel",
    "Supported variables that will be dynamically replaced": "Toegestane variabele die dynamisch vervangen zullen worden",
    "TMS format": "TMS-formaat",
    "Text color for the cluster label": "Kleur van de text voor het label van de cluster",
    "Text formatting": "Opmaak van de tekst",
    "To use if remote server doesn't allow cross domain (slower)": "Activeer indien de externe server geen cross domain toelaat (trager)",
    "To zoom": "Tot zoomniveau",
    "Transfer shape to edited feature": "Verplaats vorm naar bewerkt object",
    "Transform to lines": "Omzetten naar lijnen",
    "Transform to polygon": "Omzetten naar polygoon",
    "Type of layer": "Type laag",
    "Unable to detect format of file {filename}": "Kan het bestandstype van {filename} niet detecteren",
    "Untitled layer": "Laag zonder naam",
    "Untitled map": "Kaart zonder naam",
    "Update permissions": "Gebruiksrechten aanpassen",
    "Update permissions and editors": "Bijwerken van permissies en bewerkers",
    "Url": "URL",
    "Use current bounds": "Gebied begrenzen op wat nu te zien is",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Gebruik een \"placeholders\" met de eigenschappen van objecten, vb. &#123;naam&#125;. Deze zullen dynamisch vervangen worden door de bijhorende waarde.",
    "User content credits": "Gebruikersinhoud bronvermelding",
    "User interface options": "Gebruikersinterfaceopties",
    "Versions": "Versies",
    "View Fullscreen": "Toon op volledig scherm",
    "Where do we go from here?": "Wat gaan we doen?",
    "Whether to display or not polygons paths.": "Schakelaar toon polygoon omlijning",
    "Whether to fill polygons with color.": "Schakelaar vul polygonen met een kleur",
    "Who can edit": "Wie kan bewerken",
    "Who can view": "Wie kan bekijken",
    "Will be displayed in the bottom right corner of the map": "Zal getoond worden in de rechter onderhoek van de kaart",
    "Will be visible in the caption of the map": "Zal getoond worden in de hoofding van de kaart",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Oei! Iemand anders lijkt de kaart ook bewerkt te hebben. Je kan opslaan, maar dat zal eerdere wijzigingen overschrijven.",
    "Zoom in": "Inzoomen",
    "Zoom level for automatic zooms": "Schaalniveau voor automatische zooms",
    "Zoom out": "Uitzoomen",
    "Zoom to layer extent": "Zodanig zoomen dat alle data in venster past",
    "Zoom to the next": "Inzoomen op de volgende",
    "Zoom to the previous": "Inzoomen op de vorige",
    "Zoom to this feature": "Op dit object inzoomen",
    "Zoom to this place": "Inzoomen op deze plaats",
    "attribution": "bronvermelding",
    "by": "door",
    "display name": "toon de naam",
    "height": "hoogte",
    "licence": "licentie",
    "max East": "maximale oostwaarde",
    "max North": "maximale noordwaarde",
    "max South": "maximale zuidwaarde",
    "max West": "maximale westwaarde",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "volgende",
    "previous": "vorige",
    "width": "breedte",
    "{count} errors during import: {message}": "{count} fouten tijdens import: {message}",
    "Measure distances": "Afstanden meten",
    "NM": "NM",
    "kilometers": "kilometer",
    "km": "km",
    "mi": "mi",
    "miles": "mijl",
    "nautical miles": "zeemijl",
    "1 day": "1 dag",
    "1 hour": "1 uur",
    "5 min": "5 minuten",
    "Cache proxied request": "Cache proxied request",
    "No cache": "Geen cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (groot)",
    "Popup content style": "Stijl van de inhoud van de Popup",
    "Popup shape": "Vorm van de Popup",
    "Skipping unknown geometry.type: {type}": "Overgeslaan wegens onbekend geometry.type: {type}",
    "Optional.": "Optioneel.",
    "Paste your data here": "Plak je data hier",
    "Please save the map first": "Graag eerst de kaart opslaan",
    "Feature identifier key": "Unieke identificator van het object",
    "Open current feature on load": "Dit object openen bij laden",
    "Permalink": "Permalink",
    "The name of the property to use as feature unique identifier.": "De naam van de eigenschap die als unieke identificator van objecten geldt",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Example: key1,key2,key3": "Example: key1,key2,key3",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Permanent credits": "Permanent credits",
    "Permanent credits background": "Permanent credits background",
    "Select data": "Select data",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "Animated transitions": "Animated transitions",
    "Background overlay url": "Background overlay url",
    "Custom overlay": "Custom overlay",
    "Display the star map button": "Display the star map button",
    "Error in the overlay URL": "Error in the overlay URL",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Opacity": "Opacity",
    "Star this map": "Star this map",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "Direct link": "Direct link",
    "Export options": "Export options",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Copy link": "Copy link",
    "Email": "Email",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Send me the link": "Send me the link",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "icon opacity": "icon opacity",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)",
    "Default view": "Default view",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature properties": "Feature properties",
    "Issue reaching that URL (network problem or CORS protection): {url}": "Issue reaching that URL (network problem or CORS protection): {url}",
    "Latest feature": "Latest feature",
    "No results for these facets": "No results for these facets",
    "Saved center and zoom": "Saved center and zoom",
    "User location": "User location",
    "Visibility: {status}": "Visibility: {status}",
    "Fit all data": "Fit all data",
    "Verify remote URL": "Verify remote URL",
    "Add": "Add",
    "Change": "Change",
    "Powered by uMap": "Powered by uMap",
    "Search": "Search",
    "Datalayers": "Datalayers",
    "Secret edit link:": "Secret edit link:",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Current map view": "Current map view",
    "Filter": "Filter",
    "Choropleth": "Choropleth",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Equidistant": "Equidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Manual": "Manual",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Show this layer in the caption",
    "Back to preview": "Back to preview",
    "Drawing": "Drawing",
    "Edit the title of the map": "Edit the title of the map",
    "Go to the homepage": "Go to the homepage",
    "Switch to edit mode": "Switch to edit mode",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "View": "View",
    "Add image URL": "Add image URL",
    "Backup data": "Backup data",
    "Download full data": "Download full data",
    "Emoji & Character": "Emoji & Character",
    "Generic": "Generic",
    "Symbol": "Symbol",
    "Type char or paste emoji": "Type char or paste emoji",
    "URL": "URL"
}
L.registerLocale("nl", locale)
L.setLocale("nl")
